@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
- * Copyright (c) 2003 thierry lorthiois (lorthioist@wanadoo.fr)
+ * Copyright (c) 2003 thierry lorthiois <lorthioist@wanadoo.fr>
+ * Copyright (c) 2007 Jan Hambrecht <jaham@gmx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,12 +19,12 @@
 #ifndef _WMFIMPORTPARSER_H_
 #define _WMFIMPORTPARSER_H_
 
-#include <qpainter.h>
-#include <qdom.h>
-#include <core/vdocument.h>
-#include <core/vcomposite.h>
+#include <QPainter>
 #include <kowmfread.h>
 
+class KoShape;
+class KoPathShape;
+class VDocument;
 
 /**
  * WMFImportParser inherit KoWmfRead
@@ -61,7 +62,8 @@ private:
     // Drawing attributes/modes
     void  setBackgroundColor( const QColor &c );
     void  setBackgroundMode( Qt::BGMode mode );
-    void  setRasterOp( Qt::RasterOp op );
+
+    void  setCompositionMode( QPainter::CompositionMode );
 
     /**
      * Change logical Coordinate
@@ -71,7 +73,7 @@ private:
      */
     void  setWindowOrg( int left, int top );
     void  setWindowExt( int width, int height );
-    
+
     // Clipping
     // the 'CoordinateMode' is ommitted : always CoordPainter in wmf
     // setClipRegion() is often used with save() and restore() => implement all or none
@@ -87,13 +89,13 @@ private:
     void  drawArc( int x, int y, int w, int h, int a, int alen );
     void  drawPie( int x, int y, int w, int h, int a, int alen );
     void  drawChord( int x, int y, int w, int h, int a, int alen );
-    void  drawPolyline( const QPointArray &pa );
-    void  drawPolygon( const QPointArray &pa, bool winding=FALSE );
+    void  drawPolyline( const QPolygon &pa );
+    void  drawPolygon( const QPolygon &pa, bool winding=false );
     /**
      * drawPolyPolygon draw the XOR of a list of polygons
      * listPa : list of polygons
      */
-    void  drawPolyPolygon( QPtrList<QPointArray>& listPa, bool winding=FALSE );
+    void  drawPolyPolygon( QList<QPolygon>& listPa, bool winding=false );
     void  drawImage( int x, int y, const QImage &, int sx = 0, int sy = 0, int sw = -1, int sh = -1 );
 
     // Text drawing 
@@ -102,26 +104,20 @@ private:
     void  drawText( int x, int y, int w, int h, int flags, const QString &s, double rotation );
 
     // matrix transformation : only used in some bitmap manipulation
-    void  setWorldMatrix( const QWMatrix &, bool combine=FALSE );
+    void  setMatrix( const QMatrix &, bool combine=false );
 
     //-----------------------------------------------------------------------------
     // Utilities 
     // Add pen, brush and points to a path
-    void appendPen( VObject& obj );
-    void appendBrush( VObject& obj );
-    void appendPoints(VPath& path, const QPointArray& pa);
+    void appendPen( KoShape& obj );
+    void appendBrush( KoShape& obj );
+    void appendPoints(KoPathShape& path, const QPolygon& pa);
     // coordinate transformation
-    // translate wmf to (0,0) -> scale to document size -> translate to karbon (0,0)
-    // Wmf origin is (left,top) corner
-    // Karbon origin is (left,bottom) corner
-    double coordX( int left ) 
-            { return ((double)(left - mCurrentOrg.x()) * mScaleX); }
-    double coordY( int top ) 
-            { return (mDoc->height() - ((double)(top - mCurrentOrg.y()) * mScaleY)); }
-    double scaleW( int width ) 
-            { return (width * mScaleX); }
-    double scaleH( int height ) 
-            { return (height * mScaleY); }
+    // translate wmf to (0,0) -> scale to document size
+    double coordX( int left );
+    double coordY( int top );
+    double scaleW( int width );
+    double scaleH( int height );
 
 private:
     VDocument *mDoc;
