@@ -26,11 +26,12 @@ class KisOpenEXRImport : public KoFilter {
     Q_OBJECT
 
 public:
-    KisOpenEXRImport(KoFilter *parent, const char *name, const QStringList&);
+    KisOpenEXRImport(QObject* parent, const QStringList&);
     virtual ~KisOpenEXRImport();
 
 public:
-    virtual KoFilter::ConversionStatus convert(const QCString& from, const QCString& to);
+    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    void setPixel(quint8 *dst, half red, half green, half blue, half alpha) const;
 };
 
 #endif // KIS_OPENEXR_IMPORT_H_
