@@ -14,30 +14,35 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
-#include <strstream>
+#include <sstream>
 
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kgenericfactory.h>
-#include <koFilterChain.h>
+#include <KoFilterChain.h>
 
-#include <kspread_doc.h>
-#include <kspread_sheet.h>
-#include <kspread_cell.h>
+#include <kspread/Doc.h>
+#include <kspread/Sheet.h>
+#include <kspread/Cell.h>
+#include <kspread/Map.h>
 
 #include <qproimport.h>
 
 #include <qproformula.h>
 #include <qpro/stream.h>
 #include <qpro/record_factory.h>
-#include <qfile.h>
+#include <QFile>
+//Added by qt3to4:
+#include <QByteArray>
 
-typedef KGenericFactory<QpImport, KoFilter> QPROImportFactory;
-K_EXPORT_COMPONENT_FACTORY( libqproimport, QPROImportFactory( "kspreadqprofilter" ) )
+using namespace KSpread;
+
+typedef KGenericFactory<QpImport> QPROImportFactory;
+K_EXPORT_COMPONENT_FACTORY( libqproimport, QPROImportFactory( "kofficefilters" ) )
 
 // ---------------------------------------------------------------
 
@@ -56,7 +61,7 @@ QpTableList::~QpTableList()
 
 
 void
-QpTableList::table(unsigned pIdx, KSpreadSheet* pTable)
+QpTableList::table(unsigned pIdx, Sheet* pTable)
 {
    if(pIdx < cNameCnt)
    {
@@ -64,7 +69,7 @@ QpTableList::table(unsigned pIdx, KSpreadSheet* pTable)
    }
 }
 
-KSpreadSheet*
+Sheet*
 QpTableList::table(unsigned pIdx)
 {
    return (pIdx < cNameCnt ? cTable[pIdx] : 0);
@@ -73,10 +78,9 @@ QpTableList::table(unsigned pIdx)
 
 // ---------------------------------------------------------------
 
-QpImport::QpImport( KoFilter*, const char*, const QStringList& )
- : KoFilter()
+QpImport::QpImport( QObject* parent, const QStringList& )
+ : KoFilter(parent)
 {
-//cout << "Hooray - in QpImport::QpImport" << endl; // ???
 }
 
 void
@@ -93,7 +97,7 @@ QpImport::InitTableName(int pIdx, QString& pResult)
    }
 }
 
-KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCString& to )
+KoFilter::ConversionStatus QpImport::convert( const QByteArray& from, const QByteArray& to )
 {
     bool bSuccess=true;
 
@@ -101,27 +105,27 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
     if ( !document )
         return KoFilter::StupidError;
 
-    kdDebug(30501) << "here we go... " << document->className() << endl;
+    kDebug(30523) <<"here we go..." << document->metaObject()->className();
 
-    if(strcmp(document->className(), "KSpreadDoc")!=0)  // it's safer that way :)
+    if( !::qobject_cast<const KSpread::Doc *>( document ) )  // it's safer that way :)
     {
-        kdWarning(30501) << "document isn't a KSpreadDoc but a " << document->className() << endl;
+        kWarning(30501) << "document isn't a KSpread::Doc but a " << document->metaObject()->className();
         return KoFilter::NotImplemented;
     }
     if(from!="application/x-quattropro" || to!="application/x-kspread")
     {
-        kdWarning(30501) << "Invalid mimetypes " << from << " " << to << endl;
+        kWarning(30501) << "Invalid mimetypes " << from << " " << to;
         return KoFilter::NotImplemented;
     }
 
-    kdDebug(30501) << "...still here..." << endl;
+    kDebug(30523) <<"...still here...";
 
     // No need for a dynamic cast here, since we use Qt's moc magic
-    KSpreadDoc *ksdoc=(KSpreadDoc*)document;
+    Doc *ksdoc=(Doc*)document;
 
     if(ksdoc->mimeType()!="application/x-kspread")
     {
-        kdWarning(30501) << "Invalid document mimetype " << ksdoc->mimeType() << endl;
+        kWarning(30501) << "Invalid document mimetype " << ksdoc->mimeType();
         return KoFilter::NotImplemented;
     }
 
@@ -129,15 +133,13 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
 
     if( !lIn )
     {
-        KMessageBox::sorry( 0L, i18n("QPRO filter can't open input file - please report.") );
+        KMessageBox::sorry( 0L, i18n("QPRO filter cannot open input file - please report.") );
         return KoFilter::FileNotFound;
     }
 
-    KSpreadSheet *table=0;
-//    KSpreadSheet *table=ksdoc->createTable();
-//    ksdoc->addTable(table);
+    Sheet *table=0;
 
-    QString field = "";
+    QString field;
     int value=0;
     emit sigProgress(value);
 
@@ -169,13 +171,12 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
 
          if( table == 0 )
          {
-            table=ksdoc->createTable();
+            table=ksdoc->map()->addNewSheet();
             // set up a default name for the table
-            table->setTableName( lTableNames.name(lPageIdx)
-                               , TRUE
+            table->setSheetName( lTableNames.name(lPageIdx)
+                               , true
                                );
             lTableNames.table(lPageIdx, table);
-            ksdoc->addTable(table);
          }
          break;
 
@@ -183,13 +184,14 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
          lRecInt = (QpRecIntegerCell*)lRec;
          field.setNum( lRecInt->integer() );
 //cout << "Setting R " << lRecInt->row()+1 << ", C " << ((unsigned)lRecInt->column()) << endl;
-         table->setText( lRecInt->row()+1, ((unsigned)lRecInt->column())+1, field, false );
+         if( table )
+            table->setText( lRecInt->row()+1, ((unsigned)lRecInt->column())+1, field, false );
          break;
 
       case QpFormulaCell:
          lRecFormula = (QpRecFormulaCell*)lRec;
          {
-            KSpreadFormula lAnswer(*lRecFormula, lTableNames);
+            QuattroPro::Formula lAnswer(*lRecFormula, lTableNames);
 
             char*     lFormula = lAnswer.formula();
 
@@ -206,31 +208,33 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
                // we're about to reference a table that hasn't been created yet.
                // setText gets upset about this, so create a blank table
 
-               KSpreadSheet* lNewTable=ksdoc->createTable();
+               Sheet* lNewTable=ksdoc->map()->addNewSheet();
 
                // set up a default name for the table
-               lNewTable->setTableName( lTableNames.name(lIdx)
-                                      , TRUE
+               lNewTable->setSheetName( lTableNames.name(lIdx)
+                                      , true
                                       );
                lTableNames.table(lIdx, lNewTable);
-               ksdoc->addTable(lNewTable);
             }
          }
 
-         table->setText( lRecFormula->row()+1, lRecFormula->column()+1, field, false );
+         if( table )
+            table->setText( lRecFormula->row()+1, lRecFormula->column()+1, field, false );
          break;
 
       case QpFloatingPointCell:
          lRecFloat = (QpRecFloatingPointCell*)lRec;
          field.setNum( lRecFloat->value() );
-         table->setText( lRecFloat->row()+1, lRecFloat->column()+1, field, false );
+         if( table )
+            table->setText( lRecFloat->row()+1, lRecFloat->column()+1, field, false );
          break;
 
       case QpLabelCell:
          lRecLabel = (QpRecLabelCell*)lRec;
          field = "'";
          field += lRecLabel->label();
-         table->setText( lRecLabel->row()+1, lRecLabel->column()+1, field, false );
+         if( table )
+            table->setText( lRecLabel->row()+1, lRecLabel->column()+1, field, false );
          break;
 
       case QpPageName:
@@ -238,8 +242,8 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
 
          if( lTableNames.allocated(lPageIdx) && lTableNames.table(lPageIdx) )
          {
-            lTableNames.table(lPageIdx)->setTableName( lRecPageName->pageName()
-//                                                     , TRUE
+            lTableNames.table(lPageIdx)->setSheetName( lRecPageName->pageName()
+//                                                     , true
                                                      );
             lTableNames.name(lPageIdx, lRecPageName->pageName());
          }
@@ -249,6 +253,7 @@ KoFilter::ConversionStatus QpImport::convert( const QCString& from, const QCStri
         KMessageBox::sorry( 0L, i18n("Unable to open password protected files.\n"
                                      "The password algorithm has not been published")
                           );
+        delete lRec;
         return KoFilter::NotImplemented;
       }
 
