@@ -23,14 +23,15 @@
 #include <dom/dom_text.h>
 #include <dom/dom2_views.h>
 #include <dom/dom_doc.h>
-#include <qcolor.h>
 #include <dom/dom_element.h>
 #include <dom/html_table.h>
 #include <khtmlview.h>
-#include <qwidget.h>
 #include <kapplication.h>
 #include <dom/html_misc.h>
-#include <qregexp.h>
+
+#include <QColor>
+#include <QWidget>
+#include <QRegExp>
 
 KHTMLReader::KHTMLReader(KWDWriter *w){
 	_html=new KHTMLPart();
@@ -43,8 +44,8 @@ void qt_enter_modal( QWidget *widget );
 void qt_leave_modal( QWidget *widget );
 
 
-bool KHTMLReader::filter(KURL url) {
-	kdDebug(30503) << "KHTMLReader::filter" << endl;
+bool KHTMLReader::filter(const KUrl& url) {
+	kDebug(30503) <<"KHTMLReader::filter";
 	QObject::connect(_html,SIGNAL(completed()),this,SLOT(completed()));
 
 	_state.clear();
@@ -56,16 +57,21 @@ bool KHTMLReader::filter(KURL url) {
 	_html->setPluginsEnabled(false);
 	_html->setJavaEnabled(false);
 	_html->setMetaRefreshEnabled(false);
-	if (_html->openURL(url) == false) {
-		kdWarning(30503) << "openURL returned false" << endl;
+	if (_html->openUrl(url) == false) {
+		kWarning(30503) << "openUrl returned false";
 		return false;
 	}
 
+#ifdef __GNUC__
+#warning "kde4: port it"
+#endif
+#if 0
 	//FIXME use synchronous IO instead of this hack if possible.
-	QWidget dummy(0,0,WType_Dialog | WShowModal);
+	QWidget dummy(0);//,0,WType_Dialog | WShowModal);
 	qt_enter_modal(&dummy);
 	qApp->enter_loop();
 	qt_leave_modal(&dummy);
+#endif
 	return _it_worked;
 }
 
@@ -100,7 +106,7 @@ void KHTMLReader::popState() {
 	HTMLReader_state *s=_state.pop();
 
 	/**
-	   the recursion trough html is somewhat clumsy still, i'm working on a better method.
+	   the recursion trough html is somewhat clumsy still, I am working on a better method.
 	   popState gets called when a tag is closed, but since a closed tag doesn't mean the end
 	   of a (kword) "tag" we have to copy some things over from the closed tag:
 	   	- the paragraph (after a </B>, we still are in the same paragraph, but
@@ -124,22 +130,20 @@ void KHTMLReader::startNewLayout(bool startNewFormat) {
 }
 
 void KHTMLReader::startNewLayout(bool startNewFormat, QDomElement layout) {
-	if (!(_writer->getText(state()->paragraph).isEmpty())) {
-		startNewParagraph(startNewFormat,true);
-	}
+	startNewParagraph(startNewFormat,true);
 	state()->layout=_writer->setLayout(state()->paragraph,layout);
 }
 
 
 void KHTMLReader::completed() {
-	kdDebug(30503) << "KHTMLReader::completed" << endl;
+	kDebug(30503) <<"KHTMLReader::completed";
         qApp->exit_loop();
 	DOM::Document doc=_html->document(); // FIXME parse <HEAD> too
 	DOM::NodeList list=doc.getElementsByTagName("body");
 	DOM::Node docbody=list.item(0);
 
 	if (docbody.isNull()) {
-		kdWarning(30503) << "no <BODY>, giving up" << endl;
+		kWarning(30503) << "no <BODY>, giving up";
 		_it_worked=false;
 		return;
 	}
@@ -152,7 +156,7 @@ void KHTMLReader::completed() {
 	if (!dochead.isNull())
 		parse_head(dochead);
 	else
-		kdWarning(30503) << "WARNING: no html <HEAD> section" << endl;
+		kWarning(30503) << "WARNING: no html <HEAD> section";
 
 	_writer->cleanUpParagraph(state()->paragraph);
         _it_worked=_writer->writeDoc();
@@ -271,41 +275,7 @@ bool KHTMLReader::parseTag(DOM::Element e) {
 
 
 
-void KHTMLReader::parseStyle(DOM::Element e) {
-  // styles are broken broken broken broken broken broken.
-  //FIXME: wait until getComputedStyle is more than
-  // 'return 0' in khtml
-  kdDebug(30503) << "entering parseStyle" << endl;
-     DOM::CSSStyleDeclaration s1=e.style();
-     DOM::Document doc=_html->document();
-     DOM::CSSStyleDeclaration s2=doc.defaultView().getComputedStyle(e,"");
 
-     kdDebug(30503) << "font-weight=" << s1.getPropertyValue("font-weight").string() << endl;
-     if ( s1.getPropertyValue("font-weight").string() == "bolder" )
-     {
-	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
-     }
-     if ( s1.getPropertyValue("font-weight").string() == "bold" )
-     {
-	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
-     }
-     /*if (DOM::PROPV("font-weight") == "bolder")
-	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
-     if (PROPV("font-weight") == "bold")
-	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
-     */
-/*
-     // debugging code.
-     kdDebug(30503) << "e.style()" << endl;
-     for (unsigned int i=0;i<s1.length();i++) {
-        kdDebug(30503) << QString("%1: %2").arg(s1.item(i).string()).arg(s1.getPropertyValue(s1.item(i)).string()) << endl;
-     }
-     kdDebug(30503) << "override style" << endl;
-     for (unsigned int i=0;i<s2.length();i++) {
-        kdDebug(30503) << QString("%1: %2").arg(s2.item(i).string()).arg(s2.getPropertyValue(s2.item(i)).string()) << endl;
-     }
-*/
-}
 
 void KHTMLReader::startNewParagraph(bool startnewformat, bool startnewlayout) {
 
@@ -358,8 +328,8 @@ KHTMLReader::~KHTMLReader(){
 
 
 bool KHTMLReader::parse_CommonAttributes(DOM::Element e) {
-        kdDebug(30503) << "entering KHTMLReader::parse_CommonAttributes" << endl;
-        kdDebug(30503) << "tagName is " << e.tagName().string() << endl;
+        kDebug(30503) <<"entering KHTMLReader::parse_CommonAttributes";
+        kDebug(30503) <<"tagName is" << e.tagName().string();
         QString s=e.getAttribute("align").string();
         if (!s.isEmpty()) 
         {
@@ -384,7 +354,7 @@ bool KHTMLReader::parse_a(DOM::Element e) {
 			/* Link without text -> just drop it*/
 			return false; /* stop parsing recursively */
 		}
-		linkName = t.data().string().simplifyWhiteSpace();
+		linkName = t.data().string().simplified();
 		t.setData(DOM::DOMString("#")); // replace with '#'
 		_writer->createLink(state()->paragraph, linkName, url);
         }
@@ -394,14 +364,8 @@ bool KHTMLReader::parse_a(DOM::Element e) {
 bool KHTMLReader::parse_p(DOM::Element e) {
         // For every starting paragraph, a line break has to be inserted.
         // exception: the first paragraph, e.g. if the <body> starts with a <p>.
-        static bool firstparagraph=true;
-        if (firstparagraph)
-        {
-          firstparagraph=false;
-        }
-        else {
-	  startNewParagraph();
-	}
+        if (!(_writer->getText(state()->paragraph).isEmpty()))
+          startNewParagraph(false,false);
 	parse_CommonAttributes(e);
 	return true;
 }
@@ -415,7 +379,7 @@ bool KHTMLReader::parse_hr(DOM::Element /*e*/) {
 
 bool KHTMLReader::parse_br(DOM::Element /*e*/) {
 	startNewParagraph(false,false); //keep the current format and layout
-	return false; // a BR tag has no childs.
+	return false; // a BR tag has no children.
 }
 
 static const QColor parsecolor(const QString& colorstring) {
@@ -427,7 +391,7 @@ static const QColor parsecolor(const QString& colorstring) {
             colorstring.mid(5,2).toInt(0,16)
             );
       } else {
-            QString colorlower=colorstring.lower();
+            QString colorlower=colorstring.toLower();
             // Grays
             if (colorlower=="black")
                   color.setRgb(0,0,0);
@@ -472,25 +436,93 @@ static const QColor parsecolor(const QString& colorstring) {
       return colorstring;
 }
 
+void KHTMLReader::parseStyle(DOM::Element e) {
+  // styles are broken broken broken broken broken broken.
+  // FIXME: use getComputedStyle - note: it only returns 0, but works nevertheless
+  kDebug(30503) <<"entering parseStyle";
+  DOM::CSSStyleDeclaration s1=e.style();
+  DOM::Document doc=_html->document();
+  DOM::CSSStyleDeclaration s2=doc.defaultView().getComputedStyle(e,"");
+
+  kDebug(30503) <<"font-weight=" << s1.getPropertyValue("font-weight").string();
+  if ( s1.getPropertyValue("font-weight").string() == "bolder" )
+  {
+    _writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+  }
+  if ( s1.getPropertyValue("font-weight").string() == "bold" )
+  {
+    _writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+  }
+
+  // process e.g. <style="color: #ffffff">
+  if ( s1.getPropertyValue("color").string() != QString() )
+  {
+    QColor c=parsecolor(s1.getPropertyValue("color").string());
+    _writer->formatAttribute(state()->paragraph,"COLOR","red",QString::number(c.red()));
+    _writer->formatAttribute(state()->paragraph,"COLOR","green",QString::number(c.green()));
+    _writer->formatAttribute(state()->paragraph,"COLOR","blue",QString::number(c.blue()));
+  } // done
+  // process e.g. <style="font-size: 42">
+  if ( s1.getPropertyValue("font-size").string() != QString() )
+  {
+    QString size=s1.getPropertyValue("font-size").string();
+    if (size.endsWith("pt"))
+    {
+      size=size.left(size.length()-2);
+    }
+    _writer->formatAttribute(state()->paragraph,"SIZE","value",size);
+  }
+  // done
+  // process e.g. <style="text-align: center">this is in the center</style>
+  if ( s1.getPropertyValue("text-align").string() != QString() )
+  {
+    state()->layout=_writer->setLayout(state()->paragraph,state()->layout);
+    _writer->layoutAttribute(state()->paragraph, "FLOW","align",s1.getPropertyValue("text-align").string());
+  }
+  // done
+
+     /*if (DOM::PROPV("font-weight") == "bolder")
+	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+     */
+/*
+     // debugging code.
+     kDebug(30503) <<"e.style()";
+     for (unsigned int i=0;i<s1.length();i++) {
+        kDebug(30503) << QString("%1: %2").arg(s1.item(i).string()).arg(s1.getPropertyValue(s1.item(i)).string());
+     }
+     kDebug(30503) <<"override style";
+     for (unsigned int i=0;i<s2.length();i++) {
+        kDebug(30503) << QString("%1: %2").arg(s2.item(i).string()).arg(s2.getPropertyValue(s2.item(i)).string());
+     }
+*/
+}
 
 bool KHTMLReader::parse_table(DOM::Element e) {
 	if(_writer->isInTable()) {
 		// We are already inside of a table. Tables in tables are not supported
 		// yet. So, just add that table-content as text.
 		for (DOM::Node rows=e.firstChild().firstChild();!rows.isNull();rows=rows.nextSibling())
-			if (!rows.isNull() && rows.nodeName().string().lower() == "tr")
+			if (!rows.isNull() && rows.nodeName().string().toLower() == "tr")
 				for (DOM::Node cols=rows.firstChild();!cols.isNull();cols=cols.nextSibling())
-					if (!cols.isNull() && cols.nodeName().string().lower() == "td")
+					if (!cols.isNull())
 						parseNode(cols);
 		return false;
 	}
 
+ 	DOM::Element table_body=e.firstChild();
+	if(table_body.isNull()) {
+ 		// If the table_body is empty, we don't continue cause else
+ 		// KHTML will throw a DOM::DOMException if we try to access
+ 		// the null element.
+ 		return true;
+	}
+
 	int tableno=_writer->createTable();
  	int nrow=0;
  	int ncol=0;
- 	int has_borders=false;
+ 	bool has_borders=false;
 	QColor bgcolor=parsecolor("#FFFFFF");
- 	DOM::Element table_body=e.firstChild();
+
  	if (!table_body.getAttribute("bgcolor").string().isEmpty())
  	       bgcolor=parsecolor(table_body.getAttribute("bgcolor").string());
  	if ((e.getAttribute("border").string().toInt() > 0))
@@ -500,17 +532,18 @@ bool KHTMLReader::parse_table(DOM::Element e) {
  	//(maybe using computed sizes from khtml if thats once exported)
  	for (DOM::Node rowsnode=table_body.firstChild();!rowsnode.isNull();rowsnode=rowsnode.nextSibling()) {
  	DOM::Element rows = rowsnode;
- 	if (!rows.isNull() && rows.tagName().string().lower() == "tr") {
+ 	if (!rows.isNull() && rows.tagName().string().toLower() == "tr") {
  	    QColor obgcolor=bgcolor;
  	    if (!rows.getAttribute("bgcolor").string().isEmpty())
  	       	bgcolor=parsecolor(rows.getAttribute("bgcolor").string());
 
  		ncol=0;
  		for (DOM::Node colsnode=rows.firstChild();!colsnode.isNull();colsnode=colsnode.nextSibling()) {
- 		        DOM::Element cols = colsnode;
- 		        if (!cols.isNull() && cols.nodeName().string().lower() == "td") {
- 		             QColor bbgcolor=bgcolor;
-		 	    if (!cols.getAttribute("bgcolor").string().isEmpty())
+			DOM::Element cols = colsnode;
+			const QString nodename = cols.isNull() ? QString() : cols.nodeName().string().toLower();
+			if (nodename == "td" || nodename == "th") {
+				QColor bbgcolor=bgcolor;
+				if (!cols.getAttribute("bgcolor").string().isEmpty())
  	       			bgcolor=parsecolor(cols.getAttribute("bgcolor").string());
 
 			    	pushNewState();
@@ -584,9 +617,9 @@ bool KHTMLReader::parse_font(DOM::Element e) {
         	color=parsecolor(e.getAttribute("color").string());
         QString size=e.getAttribute("size").string();
         int isize=-1;
-        if (size.startsWith("+"))
+        if (size.startsWith('+'))
         	isize=12+size.right(size.length()-1).toInt();
-        else if (size.startsWith("-"))
+        else if (size.startsWith('-'))
         	isize=12-size.right(size.length()-1).toInt();
         else
 	        isize=12+size.toInt();
@@ -605,7 +638,7 @@ bool KHTMLReader::parse_ul(DOM::Element e) {
         _list_depth++;
         bool popstateneeded = false;
         for (DOM::Node items=e.firstChild();!items.isNull();items=items.nextSibling()) {
-                  if (items.nodeName().string().lower() == "li") {
+                  if (items.nodeName().string().toLower() == "li") {
                   		if (popstateneeded) {
                   			popState();
                   			//popstateneeded = false;
@@ -615,7 +648,7 @@ bool KHTMLReader::parse_ul(DOM::Element e) {
                   		popstateneeded = true;
                   		_writer->layoutAttribute(state()->paragraph,"COUNTER","numberingtype","1");
                   		_writer->layoutAttribute(state()->paragraph,"COUNTER","righttext",".");
-                  		if (e.tagName().string().lower() == "ol")
+                  		if (e.tagName().string().toLower() == "ol")
 	                  		{
 	                  		_writer->layoutAttribute(state()->paragraph,"COUNTER","type","1");
 	                  		_writer->layoutAttribute(state()->paragraph,"COUNTER","numberingtype","1");
