@@ -21,22 +21,22 @@
 #ifndef KWORD_1_3_PICTURE
 #define KWORD_1_3_PICTURE
 
-class KTempFile;
+class KTemporaryFile;
 class KoStore;
 
-#include <qstring.h>
+#include <QString>
 
 class KWord13Picture
 {
 public:
-    KWord13Picture( void );
+    explicit KWord13Picture( void );
     ~KWord13Picture( void );
 public:
     bool loadPicture( KoStore* store );
     QString getOasisPictureName( void ) const;
 public:
     QString m_storeName; ///< Name of the file in store
-    KTempFile* m_tempFile; ///< Temporary file
+    KTemporaryFile* m_tempFile; ///< Temporary file
     bool m_valid; ///< Is the picture valid?
 };
 
