@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "document.h"
@@ -23,9 +23,8 @@
 #include "graphicshandler.h"
 #include "versionmagic.h"
 
-#include <koRect.h>
-#include <koUnit.h>
-#include <koPageLayout.h>
+#include <KoUnit.h>
+#include <KoPageLayout.h>
 #include <kdebug.h>
 
 #include <wv2/styles.h>
@@ -36,8 +35,10 @@
 #include <wv2/paragraphproperties.h>
 #include <wv2/associatedstrings.h>
 #include <klocale.h>
-#include <koStore.h>
-#include <koFilterChain.h>
+#include <KoStore.h>
+#include <KoFilterChain.h>
+//Added by qt3to4:
+#include <Q3ValueList>
 
 
 Document::Document( const std::string& fileName, QDomDocument& mainDocument, QDomDocument& documentInfo, QDomElement& framesetsElement, KoFilterChain* chain )
@@ -67,8 +68,8 @@ Document::Document( const std::string& fileName, QDomDocument& mainDocument, QDo
         m_parser->setInlineReplacementHandler( m_replacementHandler );
         processStyles();
         processAssociatedStrings();
-        connect( m_tableHandler, SIGNAL( sigTableCellStart( int, int, int, int, const KoRect&, const QString&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::SHD& ) ),
-                 this, SLOT( slotTableCellStart( int, int, int, int, const KoRect&, const QString&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::SHD& ) ) );
+        connect( m_tableHandler, SIGNAL( sigTableCellStart( int, int, int, int, const QRectF&, const QString&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::SHD& ) ),
+                 this, SLOT( slotTableCellStart( int, int, int, int, const QRectF&, const QString&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::BRC&, const wvWare::Word97::SHD& ) ) );
         connect( m_tableHandler, SIGNAL( sigTableCellEnd() ),
                  this, SLOT( slotTableCellEnd() ) );
     }
@@ -120,7 +121,7 @@ void Document::finishDocument()
     Q_ASSERT ( !paperElement.isNull() ); // slotFirstSectionFound should have been called!
     if ( !paperElement.isNull() )
     {
-        kdDebug(30513) << k_funcinfo << "m_headerFooters=" << m_headerFooters << endl;
+        kDebug(30513) <<"m_headerFooters=" << m_headerFooters;
         paperElement.setAttribute("hType", Conversion::headerMaskToHType( m_headerFooters ) );
         paperElement.setAttribute("fType", Conversion::headerMaskToFType( m_headerFooters ) );
     }
@@ -177,12 +178,12 @@ void Document::processStyles()
     m_textHandler->setFrameSetElement( stylesElem ); /// ### naming!
     const wvWare::StyleSheet& styles = m_parser->styleSheet();
     unsigned int count = styles.size();
-    //kdDebug(30513) << k_funcinfo << "styles count=" << count << endl;
+    //kDebug(30513) <<"styles count=" << count;
     for ( unsigned int i = 0; i < count ; ++i )
     {
         const wvWare::Style* style = styles.styleByIndex( i );
         Q_ASSERT( style );
-        //kdDebug(30513) << k_funcinfo << "style " << i << " " << style << endl;
+        //kDebug(30513) <<"style" << i <<"" << style;
         if ( style && style->type() == wvWare::Style::sgcPara )
         {
             QDomElement styleElem = m_mainDocument.createElement("STYLE");
@@ -193,7 +194,7 @@ void Document::processStyles()
             element.setAttribute( "value", name.string() );
             styleElem.appendChild( element );
 
-            kdDebug(30513) << k_funcinfo << "Style " << i << ": " << name.string() << endl;
+            kDebug(30513) <<"Style" << i <<":" << name.string();
 
             const wvWare::Style* followingStyle = styles.styleByID( style->followingStyle() );
             if ( followingStyle && followingStyle != style )
@@ -224,7 +225,7 @@ bool Document::parse()
 
 void Document::bodyStart()
 {
-    kdDebug(30513) << k_funcinfo << endl;
+    kDebug(30513) ;
 
     QDomElement mainFramesetElement = m_mainDocument.createElement("FRAMESET");
     mainFramesetElement.setAttribute("frameType",1);
@@ -243,7 +244,7 @@ void Document::bodyStart()
 
 void Document::bodyEnd()
 {
-    kdDebug(30513) << k_funcinfo << endl;
+    kDebug(30513) ;
     disconnect( m_textHandler, SIGNAL( firstSectionFound( wvWare::SharedPtr<const wvWare::Word97::SEP> ) ),
              this, SLOT( slotFirstSectionFound( wvWare::SharedPtr<const wvWare::Word97::SEP> ) ) );
 }
@@ -251,7 +252,7 @@ void Document::bodyEnd()
 
 void Document::slotFirstSectionFound( wvWare::SharedPtr<const wvWare::Word97::SEP> sep )
 {
-    kdDebug(30513) << k_funcinfo << endl;
+    kDebug(30513) ;
     QDomElement elementDoc = m_mainDocument.documentElement();
 
     QDomElement elementPaper = m_mainDocument.createElement("PAPER");
@@ -264,10 +265,10 @@ void Document::slotFirstSectionFound( wvWare::SharedPtr<const wvWare::Word97::SE
     // guessFormat takes millimeters
     width = POINT_TO_MM( width );
     height = POINT_TO_MM( height );
-    KoFormat paperFormat = KoPageFormat::guessFormat( landscape ? height : width, landscape ? width : height );
+    KoPageFormat::Format  paperFormat = KoPageFormat::guessFormat( landscape ? height : width, landscape ? width : height );
     elementPaper.setAttribute("format",paperFormat);
 
-    elementPaper.setAttribute("orientation", landscape ? PG_LANDSCAPE : PG_PORTRAIT );
+    elementPaper.setAttribute("orientation", landscape ? KoPageFormat::Landscape : KoPageFormat::Portrait );
     elementPaper.setAttribute("columns", sep->ccolM1 + 1 );
     elementPaper.setAttribute("columnspacing", (double)sep->dxaColumns / 20.0);
     elementPaper.setAttribute("spHeadBody", (double)sep->dyaHdrTop / 20.0);
@@ -288,7 +289,7 @@ void Document::slotFirstSectionFound( wvWare::SharedPtr<const wvWare::Word97::SE
 
 void Document::headerStart( wvWare::HeaderData::Type type )
 {
-    kdDebug(30513) << "startHeader type=" << type << " (" << Conversion::headerTypeToFramesetName( type ) << ")" << endl;
+    kDebug(30513) <<"startHeader type=" << type <<" (" << Conversion::headerTypeToFramesetName( type ) <<")";
     // Werner says the headers are always emitted in the order of the Type enum.
 
     QDomElement framesetElement = m_mainDocument.createElement("FRAMESET");
@@ -328,10 +329,10 @@ void Document::footnoteStart()
     framesetElement.setAttribute( "frameInfo", 7 /* footnote/endnote */ );
     if ( type == wvWare::FootnoteData::Endnote )
         // Keep name in sync with KWordTextHandler::footnoteFound
-        framesetElement.setAttribute("name", i18n("Endnote %1").arg( ++m_endNoteNumber ) );
+        framesetElement.setAttribute("name", i18n("Endnote %1", ++m_endNoteNumber ) );
     else
         // Keep name in sync with KWordTextHandler::footnoteFound
-        framesetElement.setAttribute("name", i18n("Footnote %1").arg( ++m_footNoteNumber ) );
+        framesetElement.setAttribute("name", i18n("Footnote %1", ++m_footNoteNumber ) );
     m_framesetsElement.appendChild(framesetElement);
 
     createInitialFrame( framesetElement, 29, 798, 567, 567+41, true, NoFollowup );
@@ -341,18 +342,18 @@ void Document::footnoteStart()
 
 void Document::footnoteEnd()
 {
-    kdDebug(30513) << k_funcinfo << endl;
+    kDebug(30513) ;
     m_textHandler->setFrameSetElement( QDomElement() );
 }
 
-void Document::slotTableCellStart( int row, int column, int rowSpan, int columnSpan, const KoRect& cellRect, const QString& tableName, const wvWare::Word97::BRC& brcTop, const wvWare::Word97::BRC& brcBottom, const wvWare::Word97::BRC& brcLeft, const wvWare::Word97::BRC& brcRight, const wvWare::Word97::SHD& shd )
+void Document::slotTableCellStart( int row, int column, int rowSpan, int columnSpan, const QRectF& cellRect, const QString& tableName, const wvWare::Word97::BRC& brcTop, const wvWare::Word97::BRC& brcBottom, const wvWare::Word97::BRC& brcLeft, const wvWare::Word97::BRC& brcRight, const wvWare::Word97::SHD& shd )
 {
     // Create footnote/endnote frameset
     QDomElement framesetElement = m_mainDocument.createElement("FRAMESET");
     framesetElement.setAttribute( "frameType", 1 /* text */ );
     framesetElement.setAttribute( "frameInfo", 0 /* normal text */ );
     framesetElement.setAttribute( "grpMgr", tableName );
-    QString name = i18n("Table_Name Cell row,column", "%1 Cell %2,%3").arg(tableName).arg(row).arg(column);
+    QString name = i18nc("Table_Name Cell row,column", "%1 Cell %2,%3",tableName,row,column);
     framesetElement.setAttribute( "name", name );
     framesetElement.setAttribute( "row", row );
     framesetElement.setAttribute( "col", column );
@@ -404,10 +405,10 @@ void Document::generateFrameBorder( QDomElement& frameElementOut, const wvWare::
     {
         // If ipat = 0 (solid fill), icoBack is the background color.
         // But otherwise, icoFore is the one we need to set as bkColor
-        // (and icoBack is usually white; it's the other colour of the pattern,
+        // (and icoBack is usually white; it's the other color of the pattern,
         // something that we can't set in Qt apparently).
         int bkColor = shd.ipat ? shd.icoFore : shd.icoBack;
-        kdDebug(30513) << "generateFrameBorder: " << " icoFore=" << shd.icoFore << " icoBack=" << shd.icoBack << " ipat=" << shd.ipat << " -> bkColor=" << bkColor << endl;
+        kDebug(30513) <<"generateFrameBorder:" <<" icoFore=" << shd.icoFore <<" icoBack=" << shd.icoBack <<" ipat=" << shd.ipat <<" -> bkColor=" << bkColor;
 
         // Reverse-engineer MSWord's own hackery: it models various gray levels
         // using dithering. But this looks crappy with Qt. So we go back to a QColor.
@@ -438,7 +439,7 @@ void Document::generateFrameBorder( QDomElement& frameElementOut, const wvWare::
 
 void Document::slotSubDocFound( const wvWare::FunctorBase* functor, int data )
 {
-    SubDocument subdoc( functor, data, QString::null, QString::null );
+    SubDocument subdoc( functor, data, QString(), QString() );
     m_subdocQueue.push( subdoc );
 }
 
@@ -472,8 +473,8 @@ void Document::processSubDocQueue()
         {
             KWord::Table& table = m_tableQueue.front();
             m_tableHandler->tableStart( &table );
-            QValueList<KWord::Row> &rows = table.rows;
-            for( QValueList<KWord::Row>::Iterator it = rows.begin(); it != rows.end(); ++it ) {
+            Q3ValueList<KWord::Row> &rows = table.rows;
+            for( Q3ValueList<KWord::Row>::Iterator it = rows.begin(); it != rows.end(); ++it ) {
                 KWord::TableRowFunctorPtr f = (*it).functorPtr;
                 Q_ASSERT( f );
                 (*f)(); // call it
@@ -485,7 +486,7 @@ void Document::processSubDocQueue()
     }
 }
 
-KoStoreDevice* Document::createPictureFrameSet( const KoSize& size )
+KoStoreDevice* Document::createPictureFrameSet( const QSizeF& size )
 {
     // Grab data that was stored with the functor, that triggered this parsing
     SubDocument subdoc( m_subdocQueue.front() );
@@ -511,7 +512,7 @@ KoStoreDevice* Document::createPictureFrameSet( const KoSize& size )
     keyElem.setAttribute( "filename", subdoc.extraName );
     m_pictureList.append( subdoc.extraName );
 
-    kdDebug(30513) << "Preparing to write picture for '" << subdoc.name << "' into " << subdoc.extraName << endl;
+    kDebug(30513) <<"Preparing to write picture for '" << subdoc.name <<"' into" << subdoc.extraName;
     return m_chain->storageFile( subdoc.extraName, KoStore::Write );
 }
 
