@@ -13,27 +13,29 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "mswordimport.h"
 
 #include <qdom.h>
 #include <qfontinfo.h>
-#include <qfile.h>
+#include <QFile>
+//Added by qt3to4:
+#include <QByteArray>
 
 #include <kdebug.h>
 #include <kgenericfactory.h>
 
-#include <koFilterChain.h>
+#include <KoFilterChain.h>
 
 #include <document.h>
 
-typedef KGenericFactory<MSWordImport, KoFilter> MSWordImportFactory;
+typedef KGenericFactory<MSWordImport> MSWordImportFactory;
 K_EXPORT_COMPONENT_FACTORY( libmswordimport, MSWordImportFactory( "kofficefilters" ) )
 
-MSWordImport::MSWordImport( KoFilter *, const char *, const QStringList& ) : KoFilter()
+MSWordImport::MSWordImport( QObject *parent, const QStringList& ) : KoFilter(parent)
 {
 }
 
@@ -41,13 +43,13 @@ MSWordImport::~MSWordImport()
 {
 }
 
-KoFilter::ConversionStatus MSWordImport::convert( const QCString& from, const QCString& to )
+KoFilter::ConversionStatus MSWordImport::convert( const QByteArray& from, const QByteArray& to )
 {
     // check for proper conversion
     if ( to != "application/x-kword" || from != "application/msword" )
         return KoFilter::NotImplemented;
 
-    kdDebug(30513) << "######################## MSWordImport::convert ########################" << endl;
+    kDebug(30513) <<"######################## MSWordImport::convert ########################";
 
     QDomDocument mainDocument;
     QDomElement framesetsElem;
@@ -69,12 +71,12 @@ KoFilter::ConversionStatus MSWordImport::convert( const QCString& from, const QC
 
     KoStoreDevice* out = m_chain->storageFile( "root", KoStore::Write );
     if ( !out ) {
-        kdError(30502) << "Unable to open output file!" << endl;
+        kError(30502) << "Unable to open output file!" << endl;
         return KoFilter::StorageCreationError;
     }
-    QCString cstr = mainDocument.toCString();
+    QByteArray cstr = mainDocument.toByteArray();
     // WARNING: we cannot use KoStore::write(const QByteArray&) because it gives an extra NULL character at the end.
-    out->writeBlock( cstr, cstr.length() );
+    out->write( cstr, cstr.length() );
     out->close();
 
     out = m_chain->storageFile( "documentinfo.xml", KoStore::Write );
@@ -82,11 +84,11 @@ KoFilter::ConversionStatus MSWordImport::convert( const QCString& from, const QC
 	return KoFilter::StorageCreationError;
     }
 
-    cstr = documentInfo.toCString();
-    out->writeBlock( cstr, cstr.length() );
+    cstr = documentInfo.toByteArray();
+    out->write( cstr, cstr.length() );
     out->close();
 
-    kdDebug(30513) << "######################## MSWordImport::convert done ####################" << endl;
+    kDebug(30513) <<"######################## MSWordImport::convert done ####################";
     return KoFilter::OK;
 }
 
