@@ -18,23 +18,25 @@
  * Boston, MA 02110-1301, USA.
 */
 
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QComboBox>
+#include <QLabel>
+#include <QLayout>
 #include <qtabwidget.h>
 #include <qradiobutton.h>
-#include <qvbuttongroup.h>
+#include <Q3ButtonGroup>
+//Added by qt3to4:
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include "KoUnitWidgets.h"
+#include "KoUnitDoubleSpinBox.h"
 
 #include "karbon_part.h"
 #include "vcolor.h"
 #include "vselection.h"
-#include "vstrokecmd.h"
 #include "vstroke.h"
 #include "vstrokedlg.h"
 #include "vcolortab.h"
@@ -44,13 +46,13 @@ VStrokeDlg::VStrokeDlg( KarbonPart* part, QWidget* parent, const char* name )
 {
 	enableButtonSeparator( true );
 	QTabWidget *mainWidget = new QTabWidget( this, "strokemain" );
-	QHBoxLayout *mainLayout = new QHBoxLayout (mainWidget, 3);
+	Q3HBoxLayout *mainLayout = new Q3HBoxLayout (mainWidget, 3);
 
-	QVBoxLayout *leftLayout = new QVBoxLayout( mainLayout, 4 );
+	Q3VBoxLayout *leftLayout = new Q3VBoxLayout( mainLayout, 4 );
 
-	QLabel* widthLabel = new QLabel( i18n ( "stroke width", "Width:" ), mainWidget );
+	QLabel* widthLabel = new QLabel( i18n ( "Width:" ), mainWidget );
 	leftLayout->addWidget ( widthLabel );
-	m_setLineWidth = new KoUnitDoubleSpinBox( mainWidget, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 1 );
+	m_setLineWidth = new KoUnitDoubleSpinBox( mainWidget, 0.0, 1000.0, 0.5, 1.0, KoUnit::Point, 1 );
 	leftLayout->addWidget ( m_setLineWidth );
 
 	//Dashing ->
@@ -62,7 +64,7 @@ VStrokeDlg::VStrokeDlg( KarbonPart* part, QWidget* parent, const char* name )
 	// <- Dashing - reserved for later
 
 	QRadioButton* button;
-	m_typeOption = new QVButtonGroup ( mainWidget );
+	m_typeOption = new Q3VButtonGroup ( mainWidget );
 	button = new QRadioButton ( i18n( "None" ), m_typeOption );
 	m_typeOption->insert( button );
 	button = new QRadioButton ( i18n( "Stroke" ), m_typeOption );
@@ -73,8 +75,7 @@ VStrokeDlg::VStrokeDlg( KarbonPart* part, QWidget* parent, const char* name )
 	mainLayout->addWidget( m_typeOption );
 	connect( m_typeOption, SIGNAL( clicked( int ) ), this, SLOT( slotTypeChanged( int ) ) );
 
-	m_capOption = new QVButtonGroup ( mainWidget );
-	//button = new QRadioButton ( i18n( "Butt" ), m_capOption );	                                                          
+	m_capOption = new Q3VButtonGroup ( mainWidget );
 	button = new QRadioButton ( m_capOption );
 	button->setPixmap( DesktopIcon( "cap_butt" ) );
 	m_capOption->insert( button );
@@ -88,7 +89,7 @@ VStrokeDlg::VStrokeDlg( KarbonPart* part, QWidget* parent, const char* name )
 	mainLayout->addWidget( m_capOption );
 	connect( m_capOption, SIGNAL( clicked( int ) ), this, SLOT( slotCapChanged( int ) ) );
 
-	m_joinOption = new QVButtonGroup ( mainWidget );
+	m_joinOption = new Q3VButtonGroup ( mainWidget );
 	button = new QRadioButton ( m_joinOption );
 	button->setPixmap( DesktopIcon( "join_miter" ) );
 	m_joinOption->insert( button );
