@@ -20,7 +20,7 @@
 #include "KarbonLayerModel.h"
 
 #include <vdocument.h>
-#include <KarbonShapePainter.h>
+#include <KoShapePainter.h>
 
 #include <KoShapeManager.h>
 #include <KoShapeBorderModel.h>
@@ -39,6 +39,7 @@
 #include <klocale.h>
 #include <kicon.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 #include <QtCore/QAbstractItemModel>
 #include <QtCore/QMimeData>
@@ -268,12 +269,12 @@ void KarbonLayerModel::setProperties( KoShape* shape, const PropertyList &proper
     shape->setLocked( properties.at( 1 ).state.toBool() );
 
     if( ( oldVisibleState != shape->isVisible() ) || ( oldLockedState != shape->isLocked() ) )
-        shape->repaint();
+        shape->update();
 }
 
 QImage KarbonLayerModel::createThumbnail( KoShape* shape, const QSize &thumbSize ) const
 {
-    KarbonShapePainter painter;
+    KoShapePainter painter;
 
     QList<KoShape*> shapes;
 
@@ -359,6 +360,9 @@ QMimeData * KarbonLayerModel::mimeData( const QModelIndexList & indexes ) const
 
 bool KarbonLayerModel::dropMimeData( const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent )
 {
+    Q_UNUSED( row );
+    Q_UNUSED( column );
+
     // check if the action is supported
     if( ! data || action != Qt::MoveAction )
         return false;
