@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2001-2002 Lennart Kudling <kudling@kde.org>
-   Copyright (C) 2001-2006 Rob Buis <buis@kde.org>
+   Copyright (C) 2001-2007 Rob Buis <buis@kde.org>
    Copyright (C) 2002-2006 Laurent Montel <montel@kde.org>
    Copyright (C) 2002 Werner Trobin <trobin@kde.org>
    Copyright (C) 2002-2006 David Faure <faure@kde.org>
@@ -21,7 +21,7 @@
    Copyright (C) 2006 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
    Copyright (C) 2006 Jaison Lee <lee.jaison@gmail.com>
    Copyright (C) 2006 Casper Boemann <cbr@boemann.dk>
-   Copyright (C) 2006 Thorsten Zachmann <t.zachmann@zagge.de>
+   Copyright (C) 2006-2007 Thorsten Zachmann <t.zachmann@zagge.de>
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
 
    This library is free software; you can redistribute it and/or
@@ -44,15 +44,13 @@
 #include "karbon_factory.h"
 #include "karbon_view.h"
 #include "vglobal.h"
-#include "vpainter.h"
-#include "vpainterfactory.h"
-#include "vselection.h"
 #include "KarbonCanvas.h"
 #include "vdocumentdocker.h"
 
 #include <KoApplication.h>
 #include <KoOasisStyles.h>
 #include <KoOasisLoadingContext.h>
+#include <KoOdfReadStore.h>
 #include <KoShapeSavingContext.h>
 #include <KoXmlWriter.h>
 #include <KoXmlNS.h>
@@ -63,8 +61,10 @@
 #include <KoToolManager.h>
 #include <KoShapeManager.h>
 #include <KoShapeLayer.h>
+#include <KoImageCollection.h>
 
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <klocale.h>
 
@@ -83,30 +83,25 @@
 KarbonPart::KarbonPart( QWidget* parentWidget, const char* widgetName, QObject* parent, const char* name, bool singleViewMode )
 : KoDocument( parentWidget, parent, singleViewMode )
 {
-	Q_UNUSED(widgetName)
+    Q_UNUSED(widgetName)
 
-	setObjectName(name);
-	setComponentData( KarbonFactory::componentData(), false );
-	setTemplateType( "karbon_template" );
-	m_bShowStatusBar = true;
+    setObjectName(name);
+    setComponentData( KarbonFactory::componentData(), false );
+    setTemplateType( "karbon_template" );
+    m_bShowStatusBar = true;
 
-	initConfig();
+    initConfig();
 
-	m_merge = false;
+    m_merge = false;
 
-	m_maxRecentFiles = 10;
+    m_maxRecentFiles = 10;
 
-	// set as default paper
-	m_pageLayout.format = KoPageFormat::defaultFormat();
-	m_pageLayout.orientation = KoPageFormat::Portrait;
+    // set as default paper
+    m_pageLayout.format = KoPageFormat::defaultFormat();
+    m_pageLayout.orientation = KoPageFormat::Portrait;
     m_pageLayout.width = MM_TO_POINT( KoPageFormat::width( m_pageLayout.format, m_pageLayout.orientation ) );
     m_pageLayout.height = MM_TO_POINT( KoPageFormat::height( m_pageLayout.format, m_pageLayout.orientation ) );
     m_doc.setPageSize( QSizeF( m_pageLayout.width, m_pageLayout.height ) );
-	// enable selection drawing
-	m_doc.selection()->showHandle();
-	m_doc.selection()->setSelectObjects();
-	m_doc.selection()->setState( VObject::selected );
-	m_doc.selection()->selectNodes();
 }
 
 KarbonPart::~KarbonPart()
@@ -116,26 +111,26 @@ KarbonPart::~KarbonPart()
 void
 KarbonPart::setPageLayout( KoPageLayout& layout, KoUnit _unit )
 {
-	m_pageLayout = layout;
-	m_doc.setUnit( _unit );
+    m_pageLayout = layout;
+    m_doc.setUnit( _unit );
     m_doc.setPageSize( QSizeF( m_pageLayout.width, m_pageLayout.height ) );
 }
 
 KoView*
 KarbonPart::createViewInstance( QWidget* parent )
 {
-	KarbonView *result = new KarbonView( this, parent );
-	return result;
+    KarbonView *result = new KarbonView( this, parent );
+    return result;
 }
 
 void
 KarbonPart::removeView( KoView *view )
 {
-	kDebug(38000) <<"KarbonPart::removeView";
-	KoDocument::removeView( view );
+    kDebug(38000) <<"KarbonPart::removeView";
+    KoDocument::removeView( view );
 }
 
-double getAttribute(KoXmlElement &element, const char *attributeName, double defaultValue)
+static double getAttribute(KoXmlElement &element, const char *attributeName, double defaultValue)
 {
     QString value = element.attribute( attributeName );
     if( ! value.isEmpty() )
@@ -144,7 +139,7 @@ double getAttribute(KoXmlElement &element, const char *attributeName, double def
         return defaultValue;
 }
 
-int getAttribute(KoXmlElement &element, const char *attributeName, int defaultValue)
+static int getAttribute(KoXmlElement &element, const char *attributeName, int defaultValue)
 {
     QString value = element.attribute( attributeName );
     if( ! value.isEmpty() )
@@ -156,43 +151,43 @@ int getAttribute(KoXmlElement &element, const char *attributeName, int defaultVa
 bool
 KarbonPart::loadXML( QIODevice*, const KoXmlDocument& document )
 {
-	bool success = false;
+    bool success = false;
 
-	KoXmlElement doc = document.documentElement();
+    KoXmlElement doc = document.documentElement();
 
-	if( m_merge )
-	{
-		m_doc.loadDocumentContent( doc );
-		return true;
-	}
+    if( m_merge )
+    {
+        m_doc.loadDocumentContent( doc );
+        return true;
+    }
 
-	success = m_doc.loadXML( doc );
+    success = m_doc.loadXML( doc );
 
-	//m_pageLayout = KoPageLayout::standardLayout();
+    //m_pageLayout = KoPageLayout::standardLayout();
 
-	// <PAPER>
-	KoXmlElement paper = doc.namedItem( "PAPER" ).toElement();
-	if ( !paper.isNull() )
-	{
+    // <PAPER>
+    KoXmlElement paper = doc.namedItem( "PAPER" ).toElement();
+    if ( !paper.isNull() )
+    {
         m_pageLayout.format = static_cast<KoPageFormat::Format>( getAttribute( paper, "format", 0 ) );
         m_pageLayout.orientation = static_cast<KoPageFormat::Orientation>( getAttribute( paper, "orientation", 0 ) );
 
-		if( m_pageLayout.format == KoPageFormat::CustomSize )
-		{
-            m_pageLayout.width	= m_doc.pageSize().width();
-            m_pageLayout.height	= m_doc.pageSize().height();
-		}
-		else
-		{
+        if( m_pageLayout.format == KoPageFormat::CustomSize )
+        {
+            m_pageLayout.width    = m_doc.pageSize().width();
+            m_pageLayout.height    = m_doc.pageSize().height();
+        }
+        else
+        {
             m_pageLayout.width = getAttribute( paper, "width", 0.0 );
             m_pageLayout.height = getAttribute( paper, "height", 0.0 );
-		}
-	}
-	else
-	{
+        }
+    }
+    else
+    {
         m_pageLayout.width = getAttribute( doc, "width", 595.277);
         m_pageLayout.height = getAttribute( doc, "height", 841.891 );
-	}
+    }
 
     kDebug() <<" width=" << m_pageLayout.width;
     kDebug() <<" height=" << m_pageLayout.height;
@@ -207,42 +202,41 @@ KarbonPart::loadXML( QIODevice*, const KoXmlDocument& document )
             m_pageLayout.right = borders.attribute( "right" ).toDouble();
         if( borders.hasAttribute( "bottom" ) )
             m_pageLayout.bottom = borders.attribute( "bottom" ).toDouble();
-	}
+    }
 
-	setUnit( m_doc.unit() );
+    setUnit( m_doc.unit() );
 
-	return success;
+    return success;
 }
 
 QDomDocument
 KarbonPart::saveXML()
 {
-	QDomDocument doc = m_doc.saveXML();
-	QDomElement me = doc.documentElement();
-	QDomElement paper = doc.createElement( "PAPER" );
-	me.appendChild( paper );
-	paper.setAttribute( "format", static_cast<int>( m_pageLayout.format ) );
-	paper.setAttribute( "pages", pageCount() );
+    QDomDocument doc = m_doc.saveXML();
+    QDomElement me = doc.documentElement();
+    QDomElement paper = doc.createElement( "PAPER" );
+    me.appendChild( paper );
+    paper.setAttribute( "format", static_cast<int>( m_pageLayout.format ) );
+    paper.setAttribute( "pages", pageCount() );
     paper.setAttribute( "width", m_pageLayout.width );
     paper.setAttribute( "height", m_pageLayout.height );
-	paper.setAttribute( "orientation", static_cast<int>( m_pageLayout.orientation ) );
+    paper.setAttribute( "orientation", static_cast<int>( m_pageLayout.orientation ) );
 
-	QDomElement paperBorders = doc.createElement( "PAPERBORDERS" );
+    QDomElement paperBorders = doc.createElement( "PAPERBORDERS" );
     paperBorders.setAttribute( "left", m_pageLayout.left );
     paperBorders.setAttribute( "top", m_pageLayout.top );
     paperBorders.setAttribute( "right", m_pageLayout.right );
     paperBorders.setAttribute( "bottom", m_pageLayout.bottom );
-	paper.appendChild(paperBorders);
+    paper.appendChild(paperBorders);
 
-	return doc;
+    return doc;
 }
 
-bool KarbonPart::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyles,
-                       const KoXmlDocument & settings, KoStore* store )
+bool KarbonPart::loadOdf( KoOdfReadStore & odfStore )
 {
     kDebug(38000) <<"Start loading OASIS document..." /*<< doc.toString()*/;
 
-    KoXmlElement contents = doc.documentElement();
+    KoXmlElement contents = odfStore.contentDoc().documentElement();
     kDebug(38000) <<"Start loading OASIS document..." << contents.text();
     kDebug(38000) <<"Start loading OASIS contents..." << contents.lastChild().localName();
     kDebug(38000) <<"Start loading OASIS contents..." << contents.lastChild().namespaceURI();
@@ -273,14 +267,14 @@ bool KarbonPart::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyle
     }
 
     QString masterPageName = "Standard"; // use default layout as fallback
-    KoXmlElement *master = oasisStyles.masterPages()[ masterPageName ];
+    KoXmlElement *master = odfStore.styles().masterPages()[ masterPageName ];
     if ( !master ) //last test...
-        master = oasisStyles.masterPages()[ "Default" ];
+        master = odfStore.styles().masterPages()[ "Default" ];
     Q_ASSERT( master );
 
     if( master )
     {
-        const KoXmlElement *style = oasisStyles.findStyle(
+        const KoXmlElement *style = odfStore.styles().findStyle(
             master->attributeNS( KoXmlNS::style, "page-layout-name", QString() ) );
         m_pageLayout.loadOasis( *style );
         m_doc.setPageSize( QSizeF( m_pageLayout.width, m_pageLayout.height ) );
@@ -288,7 +282,7 @@ bool KarbonPart::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyle
     else
         return false;
 
-    KoOasisLoadingContext context( this, oasisStyles, store );
+    KoOasisLoadingContext context( this, odfStore.styles(), odfStore.store() );
     KoShapeLoadingContext shapeContext( context );
 
     m_doc.loadOasis( page, shapeContext );
@@ -301,11 +295,16 @@ bool KarbonPart::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyle
         m_doc.setPageSize( pageSize );
     }
 
-    loadOasisSettings( settings );
+    loadOasisSettings( odfStore.settingsDoc() );
 
     return true;
 }
 
+bool KarbonPart::completeLoading( KoStore* store )
+{
+    return m_doc.imageCollection()->loadFromStore( store );
+}
+
 void
 KarbonPart::loadOasisSettings( const KoXmlDocument&settingsDoc )
 {
@@ -344,7 +343,7 @@ bool KarbonPart::saveOasis( KoStore *store, KoXmlWriter *manifestWriter )
 void
 KarbonPart::slotDocumentRestored()
 {
-	setModified( false );
+    setModified( false );
 }
 
 void
@@ -352,64 +351,31 @@ KarbonPart::repaintAllViews( bool /*repaint*/ )
 {
 // TODO: needs porting
 /*
-	foreach ( KoView* view, views() )
-		static_cast<KarbonView*>( view )->canvasWidget()->repaintAll( repaint );*/
+    foreach ( KoView* view, views() )
+        static_cast<KarbonView*>( view )->canvasWidget()->repaintAll( repaint );*/
 }
 
-void
-KarbonPart::paintContent( QPainter& painter, const QRect& rect)
+void KarbonPart::paintContent( QPainter& painter, const QRect& rect)
 {
-	kDebug(38000) <<"**** part->paintContent()";
+    kDebug(38000) <<"**** part->paintContent()";
 
-	QRectF r = rect;
-	double zoomFactorX = double( r.width() ) / double( document().pageSize().width() );
-	double zoomFactorY = double( r.height() ) / double( document().pageSize().height() );
-	double zoomFactor = qMin( zoomFactorX, zoomFactorY );
-
-	painter.eraseRect( rect );
-	VPainterFactory *painterFactory = new VPainterFactory;
-	//QPaintDeviceMetrics metrics( painter.device() );
-	painterFactory->setPainter( painter.device(), rect.width(), rect.height() );
-	VPainter *p = painterFactory->painter();
-	//VPainter *p = new VQPainter( painter.device() );
-	p->begin();
-	p->setZoomFactor( zoomFactor );
-	kDebug(38000) <<"painter.worldMatrix().dx() :" << painter.matrix().dx();
-	kDebug(38000) <<"painter.worldMatrix().dy() :" << painter.matrix().dy();
-	kDebug(38000) <<"rect.x() :"<< rect.x();
-	kDebug(38000) <<"rect.y() :"<< rect.y();
-	kDebug(38000) <<"rect.width() :"<< rect.width();
-	kDebug(38000) <<"rect.height() :"<< rect.height();
-	r = document().boundingBox();
-	QMatrix mat = painter.matrix();
-	mat.scale( 1, -1 );
-	mat.translate( 0, -r.height() * zoomFactor );
-	p->setMatrix( mat );
-
-	m_doc.selection()->clear();
-	/*
-	Q3PtrListIterator<VLayer> itr( m_doc.layers() );
-
-	for( ; itr.current(); ++itr )
-	{
-		itr.current()->draw( p, &r );
-	}
-	*/
-	p->end();
-	delete painterFactory;
+    QRectF r = rect;
+    double zoomFactorX = double( r.width() ) / double( document().pageSize().width() );
+    double zoomFactorY = double( r.height() ) / double( document().pageSize().height() );
+    double zoomFactor = qMin( zoomFactorX, zoomFactorY );
 }
 
 void
 KarbonPart::setShowStatusBar( bool b )
 {
-	m_bShowStatusBar = b;
+    m_bShowStatusBar = b;
 }
 
 void
 KarbonPart::reorganizeGUI()
 {
-	foreach ( KoView* view, views() )
-		static_cast<KarbonView*>( view )->reorganizeGUI();
+    foreach ( KoView* view, views() )
+        static_cast<KarbonView*>( view )->reorganizeGUI();
 }
 
 void
@@ -460,12 +426,12 @@ KarbonPart::initConfig()
 bool
 KarbonPart::mergeNativeFormat( const QString &file )
 {
-	m_merge = true;
-	bool result = loadNativeFormat( file );
-	if ( !result )
-		showLoadingErrorDialog();
-	m_merge = false;
-	return result;
+    m_merge = true;
+    bool result = loadNativeFormat( file );
+    if ( !result )
+        showLoadingErrorDialog();
+    m_merge = false;
+    return result;
 }
 
 void KarbonPart::addShape( KoShape* shape )
