@@ -50,6 +50,7 @@ using std::cerr;
 
 // KOffice
 #include <KoZoomHandler.h>
+#include <KoDom.h>
 #include <KoXmlNS.h>
 #include <KoXmlWriter.h>
 #include <KoXmlReader.h>
@@ -60,13 +61,12 @@ using std::cerr;
 #include <KoStoreDevice.h>
 #include <KoShapeSavingContext.h>
 #include <KoToolManager.h>
-#include <KoOdfLoadingContext.h>
-#include <KoOdfStylesReader.h>
+#include <KoOasisLoadingContext.h>
+#include <KoOasisStyles.h>
 #include <KoOdfReadStore.h>
 #include <KoOdfWriteStore.h>
 #include <KoShapeLoadingContext.h>
 #include <KoShapeRegistry.h>
-#include <KoDataCenter.h>
 
 // KDChart
 #include "KDChartChart"
@@ -98,7 +98,7 @@ KChartPart::KChartPart( QWidget *parentWidget,
     m_chartData( 0 )
 {
     // A KChart part contains a single chart Flake shape. 
-    m_chartShape = ( ChartShape* )( KoShapeRegistry::instance()->value("ChartShape") )->createDefaultShapeAndInit( dataCenterMap() );
+    m_chartShape = ( ChartShape* )( KoShapeRegistry::instance()->value("ChartShape") )->createDefaultShape();
     setComponentData( KChartFactory::global(), false );
     setTemplateType( "kchart_template" );
 
@@ -159,8 +159,6 @@ KoView* KChartPart::createViewInstance( QWidget* parent )
 
 void KChartPart::paintContent( QPainter& painter, const QRect& rect)
 {
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
 #if 0
     int  numDatasets;
 
@@ -229,7 +227,7 @@ void KChartPart::paintContent( QPainter& painter, const QRect& rect)
 
 #else
     // Paint the shape that is the real chart.
-    kDebug(35001) << "################## Painting!";
+    kDebug() << "################## Painting!";
     //KoZoomHandler  zoomHandler;
     //m_chartShape->paint( painter, zoomHandler );
     return;
@@ -325,13 +323,6 @@ void KChartPart::removeShape( KoShape* )
 {
 }
 
-QMap<QString, KoDataCenter *> KChartPart::dataCenterMap() const
-{
-    //Q_ASSERT(false);
-    // if the kchart app ever supports more than a single shape this should be implemented
-    // along with several other methods - see any other app or ask boemann
-    return QMap<QString, KoDataCenter *>() ;
-}
 
 // ----------------------------------------------------------------
 
@@ -602,7 +593,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     KoXmlElement  content = odfStore.contentDoc().documentElement();
 
     // Find office:body
-    KoXmlElement  realBody ( KoXml::namedItemNS( content, 
+    KoXmlElement  realBody ( KoDom::namedItemNS( content, 
                                                  KoXmlNS::office, "body" ) );
     if ( realBody.isNull() ) {
         setErrorMessage( i18n( "Invalid OpenDocument file. No office:body tag found." ));
@@ -610,10 +601,10 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     }
 
     // Find office:chart
-    KoXmlElement bodyElement = KoXml::namedItemNS( realBody,
+    KoXmlElement bodyElement = KoDom::namedItemNS( realBody,
                                                    KoXmlNS::office, "chart" );
     if ( bodyElement.isNull() ) {
-        kError(32001) << "No office:chart found!";
+        kError(32001) << "No office:chart found!" << endl;
 
         KoXmlElement  childElem;
         QString       localName;
@@ -629,7 +620,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     }
 
     // Find chart:chart
-    KoXmlElement chartElement = KoXml::namedItemNS( bodyElement, 
+    KoXmlElement chartElement = KoDom::namedItemNS( bodyElement, 
                                                     KoXmlNS::chart, "chart" );
     if ( chartElement.isNull() ) {
         setErrorMessage( i18n( "No chart found in the file" ) );
@@ -639,11 +630,11 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     // Load styles first
 #if 0
     loadAllStyles( context );
-    styleManager()->loadOasisStyleTemplate( stylesReader, this );
+    styleManager()->loadOasisStyleTemplate( oasisStyles, this );
 #endif
 
-    KoOdfLoadingContext  context( odfStore.styles(), odfStore.store() );
-    KoShapeLoadingContext  shapeContext( context, dataCenterMap() );
+    KoOasisLoadingContext  context( this, odfStore.styles(), odfStore.store() );
+    KoShapeLoadingContext  shapeContext( context );
 
     // ----------------------------------------------------------------
     // FIXME: Load chart here.
@@ -668,19 +659,19 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     setChartDefaults();
 
     KoXmlElement  content = doc.documentElement();
-    KoXmlElement  bodyElem ( KoXml::namedItemNS( content,
+    KoXmlElement  bodyElem ( KoDom::namedItemNS( content,
 						KoXmlNS::office, "body" ) );
     if ( bodyElem.isNull() ) {
-        kError(32001) << "No office:body found!";
+        kError(32001) << "No office:body found!" << endl;
         setErrorMessage( i18n( "Invalid OASIS OpenDocument file. No office:body tag found." ) );
         return false;
     }
 
     // Get the office:chart element.
-    KoXmlElement officeChartElem = KoXml::namedItemNS( bodyElem,
+    KoXmlElement officeChartElem = KoDom::namedItemNS( bodyElem,
 						      KoXmlNS::office, "chart" );
     if ( officeChartElem.isNull() ) {
-        kError(32001) << "No office:chart found!";
+        kError(32001) << "No office:chart found!" << endl;
         KoXmlElement  childElem;
         QString      localName;
         forEachElement( childElem, bodyElem ) {
@@ -695,7 +686,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
         return false;
     }
 
-    KoXmlElement chartElem = KoXml::namedItemNS( officeChartElem,
+    KoXmlElement chartElem = KoDom::namedItemNS( officeChartElem,
 						KoXmlNS::chart, "chart" );
     if ( chartElem.isNull() ) {
         setErrorMessage( i18n( "Invalid OASIS OpenDocument file. No chart:chart tag found." ) );
@@ -703,7 +694,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     }
 
     // Get the loading context and stylestack from the styles.
-    KoOdfLoadingContext  loadingContext( stylesReader, store );
+    KoOasisLoadingContext  loadingContext( this, oasisStyles, store );
     //KoStyleStack          &styleStack = loadingContext.styleStack();
 
 #if 0  // Example code!!
@@ -713,7 +704,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     loadingContext.fillStyleStack( chartElem, KoXmlNS::chart, "style-name" );
 
     const QString fillColor = styleStack.property( KoXmlNS::draw, "fill-color" );
-    kDebug(35001) <<"fillColor=" << fillColor;
+    kDebug() <<"fillColor=" << fillColor;
 
     styleStack.restore();
 #endif
@@ -731,7 +722,7 @@ bool KChartPart::loadOdf( KoOdfReadStore & odfStore )
     // TODO Load data direction (see loadAuxiliary)
 
     // Load the data table.
-    KoXmlElement tableElem = KoXml::namedItemNS( chartElem,
+    KoXmlElement tableElem = KoDom::namedItemNS( chartElem,
 						KoXmlNS::table, "table" );
     if ( !tableElem.isNull() ) {
         ok = loadOasisData( tableElem );
@@ -749,7 +740,7 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
     Q_UNUSED( tableElem );
 #if 0
     int          numberHeaderColumns = 0;
-    KoXmlElement  tableHeaderColumns = KoXml::namedItemNS( tableElem,
+    KoXmlElement  tableHeaderColumns = KoDom::namedItemNS( tableElem,
 							  KoXmlNS::table,
 							  "table-header-columns" );
 
@@ -765,7 +756,7 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
     Q_ASSERT( numberHeaderColumns == 1 );
 
     int numberDataColumns = 0;
-    KoXmlElement tableColumns = KoXml::namedItemNS( tableElem, KoXmlNS::table, "table-columns" );
+    KoXmlElement tableColumns = KoDom::namedItemNS( tableElem, KoXmlNS::table, "table-columns" );
     forEachElement( elem, tableColumns ) {
         if ( elem.localName() == "table-column" ) {
             int repeated = elem.attributeNS( KoXmlNS::table, "number-columns-repeated", QString() ).toInt();
@@ -775,19 +766,19 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
 
     // Parse table-header-rows for the column names.
     m_colLabels.clear();
-    KoXmlElement tableHeaderRows = KoXml::namedItemNS( tableElem, KoXmlNS::table, "table-header-rows" );
+    KoXmlElement tableHeaderRows = KoDom::namedItemNS( tableElem, KoXmlNS::table, "table-header-rows" );
     if ( tableHeaderRows.isNull() )
-        kWarning(35001) << "No table-header-rows element found!";
-    KoXmlElement tableHeaderRow = KoXml::namedItemNS( tableHeaderRows, KoXmlNS::table, "table-row" );
+        kWarning(35001) << "No table-header-rows element found!" << endl;
+    KoXmlElement tableHeaderRow = KoDom::namedItemNS( tableHeaderRows, KoXmlNS::table, "table-row" );
     if ( tableHeaderRow.isNull() )
-        kWarning(35001) << "No table-row inside table-header-rows!";
+        kWarning(35001) << "No table-row inside table-header-rows!" << endl;
 
     int cellNum = 0;
     forEachElement( elem, tableHeaderRow ) {
         if ( elem.localName() == "table-cell" ) {
             ++cellNum;
             if ( cellNum > numberHeaderColumns ) {
-                KoXmlElement pElem = KoXml::namedItemNS( elem, KoXmlNS::text, "p" );
+                KoXmlElement pElem = KoDom::namedItemNS( elem, KoXmlNS::text, "p" );
                 m_colLabels.append( pElem.text() );
             }
         }
@@ -800,7 +791,7 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
 
     // Get the number of rows, and read row labels
     int          numberDataRows = 0;
-    KoXmlElement  tableRows = KoXml::namedItemNS( tableElem, KoXmlNS::table, "table-rows" );
+    KoXmlElement  tableRows = KoDom::namedItemNS( tableElem, KoXmlNS::table, "table-rows" );
 
     m_rowLabels.clear();
     forEachElement( elem, tableRows ) {
@@ -809,8 +800,8 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
             Q_ASSERT( repeated <= 1 ); // we don't handle yet the case where data rows are repeated (can this really happen?)
             numberDataRows += qMax( 1, repeated );
             if ( numberHeaderColumns > 0 ) {
-                KoXmlElement firstCell = KoXml::namedItemNS( elem, KoXmlNS::table, "table-cell" );
-                KoXmlElement pElem = KoXml::namedItemNS( firstCell, KoXmlNS::text, "p" );
+                KoXmlElement firstCell = KoDom::namedItemNS( elem, KoXmlNS::table, "table-cell" );
+                KoXmlElement pElem = KoDom::namedItemNS( firstCell, KoXmlNS::text, "p" );
                 m_rowLabels.append( pElem.text() );
             }
         }
@@ -818,11 +809,11 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
 
     kDebug(35001) <<"numberHeaderColumns=" << numberHeaderColumns
 		   << " numberDataColumns=" << numberDataColumns
-                   << " numberDataRows=" << numberDataRows;
+                   << " numberDataRows=" << numberDataRows << endl;
 
     if ( (int)m_rowLabels.count() != numberDataRows)
         kWarning(35001) << "Got " << m_rowLabels.count()
-			 << " row labels, expected " << numberDataRows;
+			 << " row labels, expected " << numberDataRows << endl;
 
     m_currentData.expand( numberDataRows, numberDataColumns );
     m_currentData.setUsedCols( numberDataColumns );
@@ -842,10 +833,10 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
                     if ( cellNum > numberHeaderColumns ) {
                         QString valueType = cellElem.attributeNS( KoXmlNS::office, "value-type", QString() );
                         if ( valueType != "float" )
-                            kWarning(35001) << "Don't know how to handle value-type " << valueType;
+                            kWarning(35001) << "Don't know how to handle value-type " << valueType << endl;
                         else {
                             QString  value = cellElem.attributeNS( KoXmlNS::office, "value", QString() );
-                            qreal    val = value.toDouble();
+                            double   val = value.toDouble();
 
                             m_currentData.setCell( row, col, val );
                         }
@@ -861,10 +852,8 @@ bool KChartPart::loadOasisData( const KoXmlElement& tableElem )
 }
 
 
-bool KChartPart::saveOdf( SavingContext & documentContext )
+bool KChartPart::saveOasis( KoStore* store, KoXmlWriter* manifestWriter )
 {
-    KoStore * store = documentContext.odfStore.store();
-    KoXmlWriter * manifestWriter = documentContext.odfStore.manifestWriter();
     // Check if we can create the content.xml file inside the store.
     if ( !store->open( "content.xml" ) )
         return false;
@@ -897,9 +886,8 @@ bool KChartPart::saveOdf( SavingContext & documentContext )
     contentTmpWriter.startElement( "office:chart" );
 
     // Write the chart itself.
-    KoGenStyles           mainStyles;
-    KoShapeSavingContext  shapeSavingContext( contentTmpWriter, mainStyles, 
-                                              documentContext.embeddedSaver );
+    KoGenStyles      mainStyles;
+    KoShapeSavingContext shapeSavingContext( contentTmpWriter, mainStyles );
     m_chartShape->saveOdf( shapeSavingContext );
 
     contentTmpWriter.endElement(); // office:chart
@@ -921,7 +909,7 @@ bool KChartPart::saveOdf( SavingContext & documentContext )
     // Phase 3: Add the contents to the file
     contentWriter->addCompleteElement( &contentTmpFile );
 
-    contentWriter->endElement(); // office:automatic-styles
+    contentWriter->endElement(); // root element
     contentWriter->endDocument();
     delete contentWriter;
 
@@ -946,7 +934,7 @@ bool KChartPart::saveOdf( SavingContext & documentContext )
         return false;
 
 
-    if( !store->open("settings.xml") )
+    if(!store->open("settings.xml"))
         return false;
 
     // Write settings
@@ -958,7 +946,7 @@ bool KChartPart::saveOdf( SavingContext & documentContext )
     settingsWriter->startElement("config:config-item-set");
     settingsWriter->addAttribute("config:name", "view-settings");
 
-    saveUnitOdf(settingsWriter);
+    KoUnit::saveOasis(settingsWriter, unit());
 
     //saveOasisSettings( *settingsWriter );
 
@@ -993,8 +981,8 @@ void KChartPart::writeAutomaticStyles( KoXmlWriter& contentWriter,
 {
     QList<KoGenStyles::NamedStyle>  styles = mainStyles.styles( KoGenStyle::StyleAuto );
     QList<KoGenStyles::NamedStyle>::const_iterator  it;
-    for ( it = styles.constBegin(); it != styles.constEnd(); ++it ) {
-        kDebug(35001) << "Style: " << (*it).name;
+    for ( it = styles.begin(); it != styles.end(); ++it ) {
+        kDebug() << "Style: " << (*it).name;
         (*it).style->writeStyle( &contentWriter, mainStyles, "style:style",
                                  (*it).name, "style:chart-properties" );
     }
@@ -1069,13 +1057,13 @@ QDomDocument KChartPart::saveXML()
                 default: {
                     valType = "(unknown)";
                     kDebug(35001) <<"ERROR: cell" << i <<"," << j
-				   << " has unknown type.";
+				   << " has unknown type." << endl;
                 }
             }
 
             e.setAttribute( "valType", valType );
             //kDebug(35001) <<"      cell" << i <<"," << j
-	    //	   << " saved with type '" << valType << "'." ;
+	    //	   << " saved with type '" << valType << "'." << endl;
             switch ( value.type() ) {
                 case QVariant::String:  e.setAttribute( "value", value.toString() );
                               break;
@@ -1087,7 +1075,7 @@ QDomDocument KChartPart::saveXML()
                     e.setAttribute( "value", "" );
                     if( QVariant::Invalid != value.type() )
                         kDebug(35001) <<"ERROR: cell" << i <<"," << j
-				       << " has unknown type." ;
+				       << " has unknown type." << endl;
                 }
             }
         }
@@ -1099,7 +1087,7 @@ QDomDocument KChartPart::saveXML()
 }
 
 
-bool KChartPart::loadXML( const KoXmlDocument& doc, KoStore* )
+bool KChartPart::loadXML( QIODevice*, const KoXmlDocument& doc )
 {
     Q_UNUSED( doc );
 
@@ -1303,7 +1291,7 @@ bool KChartPart::loadData( const KoXmlDocument& doc )
                     }
                     else if ( "double" == valueType ) {
                         bool bOk;
-                        qreal val = e.attribute("value").toDouble(&bOk);
+                        double val = e.attribute("value").toDouble(&bOk);
                         if ( !bOk )
                             val = 0.0;
                         t = val;
