@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
 
    Copyright 1999-2007  Kalle Dalheimer <kalle@kde.org>
-   Copyright 2005-2009  Inge Wallin <inge@lysator.liu.se>
+   Copyright 2005-2007  Inge Wallin <inge@lysator.liu.se>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 */
 
 
-// Own
+// Local
 #include "KChartView.h"
 
 // Qt
@@ -57,11 +57,11 @@
 #include <KoShapeCreateCommand.h>
 #include <KoTemplateCreateDia.h>
 #include <KoToolBoxFactory.h>
+#include <KoToolDockerFactory.h>
 #include <KoToolManager.h>
 #include <KoViewAdaptor.h>
 #include <KoZoomAction.h>
 #include <KoZoomHandler.h>
-#include <KoDockerManager.h>
 #include <KoCanvasController.h>
 
 // KChart
@@ -70,15 +70,12 @@
 #include "KChartViewAdaptor.h"
 #include "KCPageLayout.h"
 #include "KCPrinterDialog.h"
-#include "KChartPrintJob.h"
 #include "ChartShape.h"
 #include "KChartCanvas.h"
 
 #include "prefs.h"
 
 #include "commands/ChartTypeCommand.h"
-#include <KoMainWindow.h>
-
 
 using namespace std;
 
@@ -105,7 +102,7 @@ KChartView::KChartView( KChartPart* part, QWidget* parent )
     actionCollection()->addAction("extra_template", actionExtraCreateTemplate );
     connect(actionExtraCreateTemplate, SIGNAL(triggered(bool)), SLOT( extraCreateTemplate() ));
 
-    m_edit  = new KAction(KIcon("document-properties"), i18n("Edit &Data..."), this);
+    m_edit  = new KAction(KIcon("edit"), i18n("Edit &Data..."), this);
     actionCollection()->addAction("editdata", m_edit );
     connect(m_edit, SIGNAL(triggered(bool) ), SLOT( editData() ));
 
@@ -121,8 +118,9 @@ KChartView::KChartView( KChartPart* part, QWidget* parent )
     m_canvasController = new KoCanvasController( this );
     m_canvasController->setCanvas( m_canvas );
     m_canvasController->setCanvasMode( KoCanvasController::Centered );
+    m_canvasController->show();
 
-    m_zoomController = new KoZoomController( m_canvasController, m_zoomHandler, actionCollection() );
+    m_zoomController = new KoZoomController( m_canvasController, m_zoomHandler, actionCollection(), true );
 
     connect( m_canvasController, SIGNAL( moveDocumentOffset( const QPoint& ) ),
              m_canvas, SLOT( setDocumentOffset( const QPoint& ) ) );
@@ -152,8 +150,8 @@ KChartView::KChartView( KChartPart* part, QWidget* parent )
     m_zoomController->setDocumentSize( m_canvas->documentViewRect().size() );
 
     addStatusBarItem( zoomAction->createWidget( ( QWidget* )statusBar() ), 0 );
-    connect( m_zoomController, SIGNAL(zoomChanged(KoZoomMode::Mode, qreal)),
-             this, SLOT(zoomChanged(KoZoomMode::Mode, qreal)));
+    connect( m_zoomController, SIGNAL(zoomChanged(KoZoomMode::Mode, double)),
+             this, SLOT(zoomChanged(KoZoomMode::Mode, double)));
     m_zoomController->setZoomMode( KoZoomMode::ZOOM_PAGE );
 
     // initialize the configuration
@@ -164,34 +162,29 @@ KChartView::KChartView( KChartPart* part, QWidget* parent )
     KoToolManager::instance()->addController( m_canvasController );
     KoToolManager::instance()->registerTools( actionCollection(), m_canvasController );
 
-    if (shell())
-    {
-        connect( m_canvasController, SIGNAL( toolOptionWidgetsChanged(const QMap<QString, QWidget *> &) ),
-             shell()->dockerManager(), SLOT( newOptionWidgets(const  QMap<QString, QWidget *> &) ) );
+    KoToolDockerFactory toolDockerFactory;
+    KoToolDocker *td =  dynamic_cast<KoToolDocker*>( createDockWidget( &toolDockerFactory ) );
+    connect( m_canvasController, SIGNAL( toolOptionWidgetChanged(QWidget* ) ), td, SLOT( newOptionWidget( QWidget* ) ) );
 
-        KoToolBoxFactory toolBoxFactory( m_canvasController, i18n("Tools") );
-        shell()->createDockWidget( &toolBoxFactory );
-    }
+    KoToolBoxFactory toolBoxFactory( m_canvasController, "KChart" );
+    createDockWidget( &toolBoxFactory );
 	
     // Disable some things if we can't change the data, e.g. because
     // we are inside another application that provides the data for us.
-    if ( !part->canChangeValue() ) {
+    if ( !part->canChangeValue() )
+    {
         m_edit->setEnabled( false );
         m_importData->setEnabled( false );
     }
 
     m_canvas->shapeManager()->add( part->chart() );
     connect( m_canvas->shapeManager()->selection(), SIGNAL( selectionChanged() ), this, SLOT( selectionChanged() ) );
-    
-    m_canvasController->show();
 }
 
 
 KChartView::~KChartView()
 {
-    delete m_dbus;
-
-    // FIXME: More deletions here?  There are lots of new's in the constructor.
+//     delete m_dcop;
 }
 
 
@@ -278,12 +271,7 @@ void KChartView::slotConfigPageLayout()
     delete dialog;
 }
 
-KoPrintJob * KChartView::createPrintJob()
-{
-    return new KChartPrintJob(this);
-}
 
-#if 0                           // Disable printing for now.
 void KChartView::setupPrinter( QPrinter &printer, QPrintDialog &printDialog )
 {
 /*  In Qt dialogs get added to QPrintDialog, when prinitn gets ativated again will need to fix
@@ -296,6 +284,7 @@ void KChartView::setupPrinter( QPrinter &printer, QPrintDialog &printDialog )
 void KChartView::print(QPrinter &printer, QPrintDialog &printDialog)
 {
     Q_UNUSED( printer );
+#if 0                           // Disable printing for now.
     printer.setFullPage( false );
 
     QPainter painter;
@@ -323,8 +312,8 @@ void KChartView::print(QPrinter &printer, QPrintDialog &printDialog)
 		   0, 		// regions
 		   &rect);
     painter.end();
-}
 #endif
+}
 
 
 // Import data from a Comma Separated Values file.
@@ -379,9 +368,9 @@ void KChartView::importData()
 	for (uint col = 0; col < cols; col++) {
 	    bool     ok;
 	    QString  tmp;
-	    qreal   val;
+	    double   val;
 
-	    // Get the text and convert to qreal unless in the headers.
+	    // Get the text and convert to double unless in the headers.
 	    tmp = dialog->text( row, col );
 	    if ( ( row == 0 && hasRowHeaders )
 		 || ( col == 0 && hasColHeaders ) ) {
@@ -406,9 +395,7 @@ void KChartView::importData()
     ((KChartPart*)koDocument())->doSetData( data,
 					    hasRowHeaders, hasColHeaders );
 #else
-//js 2008-03-19
-//?? warning C4930: 'QStandardItemModel data(void)': prototyped function not called (was a variable definition intended?)
-//??    QStandardItemModel  data();
+    QStandardItemModel  data();
 #endif
 }
 
@@ -434,7 +421,6 @@ void KChartView::extraCreateTemplate()
 void KChartView::selectionChanged()
 {
     KoSelection *selection = m_canvas->shapeManager()->selection();
-    Q_UNUSED(selection);
     emit selectionChange();
 }
 
@@ -447,11 +433,8 @@ void KChartView::documentViewRectChanged( const QRectF &viewRect )
     m_canvasController->ensureVisible( m_canvas->shapeManager()->selection()->boundingRect() );
 }
 
-void KChartView::zoomChanged( KoZoomMode::Mode mode, qreal zoom )
+void KChartView::zoomChanged( KoZoomMode::Mode mode, double zoom )
 {
-    Q_UNUSED(mode);
-    Q_UNUSED(zoom);
-
     QRectF documentViewRect = m_canvas->documentViewRect();
     m_zoomController->setDocumentSize( documentViewRect.size() );
     m_canvasController->setPreferredCenter( m_zoomHandler->documentToView( documentViewRect ).center().toPoint() );
