@@ -31,25 +31,33 @@ typedef enum {
     BarChartType,
     LineChartType,
     AreaChartType,
-    PieChartType,
-    HiLoChartType,
+    CircleChartType,		// Pie in KDChart
     RingChartType,
-    PolarChartType,
-    BoxWhiskerChartType
+    ScatterChartType,
+    RadarChartType,		// Polar in KDChart
+    StockChartType,
+    BubbleChartType,
+    SurfaceChartType,
+    GanttChartType,
+
+    LastChartType               // Not an actual type, just a place holder
 } OdfChartType;
+const int NUM_CHARTTYPES = int ( LastChartType );
 
 
-// Chart subtypes
+// Chart subtypes, applicable to Bar, Line, Area, and Radar
 typedef enum {
-    BarNormalSubtype,
-    BarStackedSubtype,
-    BarPercentSubtype,
-
-    LineNormalSubtype,
-    LineStackedSubtype,
-    LinePercentSubtype
+    NoChartSubtype,             // for charts with no subtypes
+    NormalChartSubtype,         // For bar, line and area charts
+    StackedChartSubtype,
+    PercentChartSubtype
 } OdfChartSubtype;
 
+struct ChartTypeOptions
+{
+    OdfChartSubtype subtype;
+};
+
 // Data direction
 typedef  enum {
     DataRowsDirection    = 0,
