@@ -1,5 +1,5 @@
 /****************************************************************************
- ** Copyright (C) 2006 Klarälvdalens Datakonsult AB.  All rights reserved.
+ ** Copyright (C) 2007 Klarälvdalens Datakonsult AB.  All rights reserved.
  **
  ** This file is part of the KD Chart library.
  **
@@ -217,8 +217,15 @@ const QPair< qreal, qreal > GlobalMeasureScaling::currentFactors()
     return instance()->mFactors.top();
 }
 
+void GlobalMeasureScaling::setPaintDevice( QPaintDevice* paintDevice )
+{
+    instance()->m_paintDevice = paintDevice;
+}
 
-
+QPaintDevice* GlobalMeasureScaling::paintDevice()
+{
+    return instance()->m_paintDevice;
+}
 
 }
 
