@@ -18,57 +18,37 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef KCHART_PROXYMODEL_H
-#define KCHART_PROXYMODEL_H
+#ifndef KCHART_CHART_PROXY_MODEL
+#define KCHART_CHART_PROXY_MODEL
 
-
-// KChart
-#include "ChartShape.h"
-#include "CellRegion.h"
-
-
-namespace KoChart
-{
-    class ChartModel;
-}
-
-
-// Qt
 #include <QAbstractProxyModel>
+#include <QAbstractTableModel>
 
+class QAbstractItemModel;
 
 namespace KChart {
 
-class CHARTSHAPELIB_EXPORT ChartProxyModel : public QAbstractProxyModel
+class ChartShape;
+
+class ChartProxyModel : public QAbstractProxyModel
 {
     Q_OBJECT
 
 public:
-    ChartProxyModel();
+    ChartProxyModel( ChartShape *shape, QObject *parent = 0 );
     ~ChartProxyModel();
 
 public slots:
     virtual void setSourceModel( QAbstractItemModel *sourceModel );
-    virtual void setSourceModel( QAbstractItemModel *sourceModel,
-                                 const QVector<QRect> &selection );
-
-    void setSelection( const QVector<QRect> &selection );
-    
-    void setAutomaticDataSetCreation( bool enable );
-    bool automaticDataSetCreation() const;
-
-    QList<DataSet*> createDataSetsFromRegion( QList<DataSet*> dataSetsToRecycle );
-
-    /**
-    * Load series from ODF
-    */
-    bool loadOdf( const KoXmlElement &element, KoShapeLoadingContext &context );
-    void saveOdf( KoShapeSavingContext &context ) const;
 
     virtual QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const;
     virtual QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
 
+    virtual bool setData( const QModelIndex &index, const QVariant& data, int role = Qt::EditRole );
+
     virtual void dataChanged( const QModelIndex& topLeft, const QModelIndex& bottomRight );
+    // Overloaded method for convenience. It marks the entire dataset as changed.
+    void dataChanged();
 
     virtual QMap<int, QVariant> itemData( const QModelIndex &index ) const;
 
@@ -84,44 +64,9 @@ public slots:
     virtual int rowCount( const QModelIndex &parent = QModelIndex() ) const;
     virtual int columnCount( const QModelIndex &parent = QModelIndex() ) const;
 
-    // The following methods are specific to the chart
     void setFirstRowIsLabel( bool b );
     void setFirstColumnIsLabel( bool b );
     void setDataDirection( Qt::Orientation orientation );
-    void setDataDimensions( int dimensions );
-    
-    void slotRowsInserted( const QModelIndex &parent, int start, int end );
-    void slotRowsRemoved( const QModelIndex &parent, int start, int end );
-    void slotColumnsInserted( const QModelIndex &parent, int start, int end );
-    void slotColumnsRemoved( const QModelIndex &parent, int start, int end );
-
-    bool firstRowIsLabel() const;
-    bool firstColumnIsLabel() const;
-    Qt::Orientation dataDirection();
-    
-    QString categoryDataRegion() const;
-    void setCategoryDataRegion(const QString& region);
-
-    QList<DataSet*> dataSets() const;
-
-    void invalidateDataSets();
-    /**
-     * Discards old and creates new data sets from the current region selection
-     * if and only if automaticDataSetCreation() returns true.
-     */
-    void rebuildDataMap();
-
-signals:
-    void dataChanged();
-
-protected slots:
-    void slotModelReset();
-
-protected:
-    // TODO: Remove once we depend on Qt 4.6
-    // For compatability with Qt < 4.6
-    void beginResetModel();
-    void endResetModel();
 
 private:
     class Private;
@@ -130,4 +75,4 @@ private:
 
 } // namespace KChart
 
-#endif // KCHART_PROXYMODEL_H
+#endif
