@@ -20,20 +20,27 @@
 // Local
 #include "ChartShapeFactory.h"
 
+// QT
 #include <QStringList>
+#include <QStandardItemModel>
 
+// KDE
 #include <kiconloader.h>
 #include <kgenericfactory.h>
 #include <klocale.h>
 
+// KOffice
 #include <KoProperties.h>
 #include <KoToolRegistry.h>
 #include <KoShapeRegistry.h>
 
+// Chart shape
 #include "ChartShape.h"
 #include "ChartTypeToolFactory.h"
-//#include "ChartDataConfigFactory.h"
+#include "ChartLegendToolFactory.h"
 #include "ChartTypeConfigWidget.h"
+#include "ChartLegendConfigWidget.h"
+
 
 using namespace KChart;
 
@@ -41,9 +48,12 @@ K_EXPORT_COMPONENT_FACTORY( chartshape, KGenericFactory<ChartShapePlugin>( "Char
 
 ChartShapePlugin::ChartShapePlugin( QObject * parent,  const QStringList& )
 {
+    // Register all the chart shape.factory.
     KoShapeRegistry::instance()->add( new ChartShapeFactory( parent ) );
 
+    // Register all tools for the chart shape.
     KoToolRegistry::instance()->add( new ChartTypeToolFactory( parent ) );
+    KoToolRegistry::instance()->add( new ChartLegendToolFactory( parent ) );
 }
 
 
@@ -51,34 +61,71 @@ ChartShapeFactory::ChartShapeFactory( QObject* parent )
     : KoShapeFactory( parent, ChartShapeId, i18n( "Chart" ) )
 {
     setToolTip( i18n( "A shape that shows a chart" ) );
+
     KIconLoader::global()->addAppDir("kchart");
     setIcon( "kchart" );
-    // default 'app specific' config pages
-    // i.e. unless an app defines other config pages, these are used.
+
+    // Default 'app specific' config pages i.e. unless an app defines
+    // other config pages, these are used.
     QList<KoShapeConfigFactory*> panelFactories;
-//     panelFactories.append( new ChartDataConfigFactory() );
+    // panelFactories.append( new ChartDataConfigFactory() );
     setOptionPanels( panelFactories );
 }
 
+
 KoShape* ChartShapeFactory::createDefaultShape() const
 {
     ChartShape* shape = new ChartShape();
+
+    // Fill cells with data if there is none.
+    QStandardItemModel  *m_chartData = new QStandardItemModel();
+    m_chartData->setRowCount( 4 );
+    m_chartData->setColumnCount( 5 );
+
+    // Insert example data
+    for ( uint row = 0; row < 4; ++row ) {
+        // The first column has row labels, except the upper left
+        // corner which is unused.
+        if ( row > 0 )
+            m_chartData->setItem( row, 0,
+                                  new QStandardItem( i18n( "Row %1", row ) ) );
+
+        for ( uint col = 1; col < 5; ++col ) {
+            if ( row == 0 )
+                // First row has column labels
+                m_chartData->setData( m_chartData->index( 0, col ),
+                                      i18n( "Column %1", col ),
+                                      Qt::EditRole | Qt::DisplayRole );
+            else
+                m_chartData->setData( m_chartData->index( row, col ),
+                                      QString::number( row + col ),
+                                      Qt::EditRole | Qt::DisplayRole );
+        }
+    }
+
+    // We want KChart to take over and handle this model itself
+    shape->setInternalModel( m_chartData );
+    shape->setFirstRowIsLabel( true );
+    shape->setFirstColumnIsLabel( true );
+    shape->setSize( QSizeF( CM_TO_POINT( 12 ), CM_TO_POINT( 8 ) ) );
+
     return shape;
 }
 
 KoShape* ChartShapeFactory::createShape( const KoProperties* params ) const
 {
     Q_UNUSED( params );
-    ChartShape* shape = new ChartShape();
-    return shape;
+
+    return new ChartShape();
 }
 
+
 QList<KoShapeConfigWidgetBase*> ChartShapeFactory::createShapeOptionPanels()
 {
-    QList<KoShapeConfigWidgetBase*> answer;
+    QList<KoShapeConfigWidgetBase*>  answer;
     answer.append(new ChartTypeConfigWidget());
-    // TODO Stefan: SubType
-    // TODO Stefan: Labels/Legend
+    answer.append(new ChartLegendConfigWidget());
+
     // TODO Stefan: Axes
     return answer;
 }
