@@ -4,8 +4,11 @@
 
 #include "KoShapeConfigWidgetBase.h"
 
+#include "kchart_export.h"
 #include "kchart_global.h"
 
+#include "ui_ChartTypeConfigWidget.h"
+
 class KoShape;
 
 namespace KChart
@@ -15,7 +18,7 @@ class ChartShape;
 /**
  * Chart type configuration widget.
  */
-class ChartTypeConfigWidget : public KoShapeConfigWidgetBase
+class CHARTSHAPELIB_EXPORT ChartTypeConfigWidget : public KoShapeConfigWidgetBase
 {
     Q_OBJECT
 
@@ -31,10 +34,15 @@ public:
     virtual bool showOnShapeCreate() { return true; }
 
 private Q_SLOTS:
+    void chartSubtypeSelected( int type );
     void chartTypeSelected( int type );
+    void setThreeDMode( bool threeD );
+    void updateChartTypeOptions( ChartTypeOptions options );
 
 Q_SIGNALS:
-    void chartTypeChange(KChart::OdfChartType);
+    void chartTypeChange( KChart::OdfChartType );
+    void chartSubtypeChange( KChart::OdfChartSubtype );
+    void threeDModeToggled( bool threeD );
 
 private:
     class Private;
