@@ -20,6 +20,7 @@
 #ifndef CHARTTYPETOOLFACTORY_H
 #define CHARTTYPETOOLFACTORY_H
 
+#include "kchart_export.h"
 #include <KoToolFactory.h>
 
 #include <QStringList>
@@ -27,15 +28,15 @@
 namespace KChart
 {
 
-class ChartTypeToolFactory : public KoToolFactory
+class CHARTSHAPELIB_EXPORT ChartTypeToolFactory : public KoToolFactory
 {
     Q_OBJECT
 
 public:
-    explicit ChartTypeToolFactory(QObject *parent);
+    explicit ChartTypeToolFactory( QObject *parent );
     ~ChartTypeToolFactory();
 
-    KoTool * createTool(KoCanvasBase *canvas);
+    KoTool * createTool( KoCanvasBase *canvas );
 };
 
 } // namespace KChart
