@@ -49,55 +49,6 @@
 #include <KActionCollection>
 #include <KDialog>
 
-class KexiToggleViewModeAction::Private
-{
-	public:
-		Private()
-		{
-		}
-	Kexi::ViewMode mode;
-};
-
-KexiToggleViewModeAction::KexiToggleViewModeAction(
-	Kexi::ViewMode mode, QObject* parent, QObject* receiver, const char* slot)
- : KAction(
-	KIcon( Kexi::iconNameForViewMode(mode) ), 
-	Kexi::nameForViewMode( mode, true/*withAmpersand*/),
-	parent )
- , d( new Private )
-{
-	d->mode = mode;
-	connect(this, SIGNAL(toggled(bool)), this, SLOT(slotToggled(bool)));
-	if (receiver && slot)
-		connect(this, SIGNAL(switchedTo(Kexi::ViewMode)), receiver, slot);
-	setCheckable(true);
-	if (d->mode == Kexi::DataViewMode) {
-		setObjectName("view_data_mode");
-		setToolTip(i18n("Switch to data view"));
-		setWhatsThis(i18n("Switches to data view."));
-	}
-	else if (d->mode == Kexi::DesignViewMode) {
-		setObjectName("view_design_mode");
-		setToolTip(i18n("Switch to design view"));
-		setWhatsThis(i18n("Switches to design view."));
-	}
-	else if (d->mode == Kexi::TextViewMode) {
-		setObjectName("view_text_mode");
-		setToolTip(i18n("Switch to text view"));
-		setWhatsThis(i18n("Switches to text view."));
-	}
-	else {
-		kexiwarn << "KexiToggleViewModeAction: invalid mode " << mode << endl;
-	}
-}
-
-void KexiToggleViewModeAction::slotToggled(bool checked)
-{
-	if (!checked)
-		return;
-	emit switchedTo(d->mode);
-}
-
 //----------------------------------------------------------
 
 //! @internal
@@ -105,8 +56,8 @@ class KexiWindow::Private
 {
 	public:
 		Private()
-		: viewModeGroup(0)
-		, schemaData(0)
+//		: viewModeGroup(0)
+		: schemaData(0)
 		, isRegistered(false)
 		, dirtyChangedEnabled(true)
 		, switchToViewModeEnabled(true)
@@ -118,6 +69,12 @@ class KexiWindow::Private
 			id = -1;
 			item = 0;
 		}
+
+		~Private() {
+//			delete d->stack;
+//			d->stack = 0;
+//			qDeleteAll(sharedViewActions);
+		}
 		
 		inline int indexForView( int mode ) const {
 			return indicesForViews.contains(mode) ? indicesForViews.value(mode) : -1;
@@ -129,9 +86,12 @@ class KexiWindow::Private
 		QVBoxLayout* mainLyr;
 		QStackedWidget* stack;
 //		KToolBar* topBar;
-		KexiFlowLayout *topBarLyr;
-		QActionGroup* viewModeGroup;
-		QHash<Kexi::ViewMode, QAction*> toggleViewModeActions;
+//		KexiFlowLayout *topBarLyr;
+//		QActionGroup* viewModeGroup;
+//		QHash<Kexi::ViewMode, QAction*> toggleViewModeActions;
+
+		/*! View-level actions, owned by the window. */
+//		QHash<QByteArray, KAction*> sharedViewActions;
 
 		Kexi::ViewModes supportedViewModes;
 		Kexi::ViewModes openedViewModes;
@@ -144,7 +104,7 @@ class KexiWindow::Private
 		int id;
 		QPointer<KexiPart::Part> part;
 		KexiPart::Item *item;
-		QString origCaption; //!< helper
+//		QString origCaption; //!< helper
 		KexiDB::SchemaData* schemaData;
 		QPointer<KexiView> newlySelectedView; //!< Used in isDirty(), temporary set in switchToViewMode()
 		                                   //!< during view setup, when a new view is not yet raised.
@@ -162,7 +122,7 @@ class KexiWindow::Private
 		bool isRegistered : 1;
 		bool dirtyChangedEnabled : 1; //!< used in setDirty(), affects dirtyChanged()
 		bool switchToViewModeEnabled : 1; //!< used internally switchToViewMode() to avoid infinite loop
-		
+
 	protected:
 		QHash<int, int> indicesForViews;
 };
@@ -234,19 +194,13 @@ void KexiWindow::createSubwidgets()
 {
 	d->mainLyr = new QVBoxLayout(this);
 	d->mainLyr->setContentsMargins(0,KDialog::marginHint()/2,0,0);
-	QHBoxLayout *topBarHLyr = new QHBoxLayout(d->mainLyr); //needed unless KexiFlowLayout properly handles contents margins
-	topBarHLyr->addSpacing(KDialog::marginHint()/2);
-	d->topBarLyr = new KexiFlowLayout(topBarHLyr, KDialog::marginHint()/2, 2);
-//	d->topBarLyr->setContentsMargins(KDialog::marginHint()/2,KDialog::marginHint()/2,0,0);
-//	d->topBar = new KToolBar(this);
-//	d->topBar->setFont( Kexi::smallFont() ); 
-//	d->topBar->setIconDimensions( IconSize( K3Icon::Small ) );
-//	d->topBar->setToolButtonStyle( Qt::ToolButtonTextBesideIcon ); 
-//	d->mainLyr->addWidget( d->topBar );
+//	QHBoxLayout *topBarHLyr = new QHBoxLayout(d->mainLyr); //needed unless KexiFlowLayout properly handles contents margins
+//	topBarHLyr->addSpacing(KDialog::marginHint()/2);
+//	d->topBarLyr = new KexiFlowLayout(topBarHLyr, KDialog::marginHint()/2, 2);
 
 	const bool userMode = KexiMainWindowIface::global()->userMode();
 
-	if (userMode
+/*	if (userMode
 		|| d->supportedViewModes == Kexi::DataViewMode
 		|| d->supportedViewModes == Kexi::DesignViewMode
 		|| d->supportedViewModes == Kexi::TextViewMode)
@@ -256,13 +210,13 @@ void KexiWindow::createSubwidgets()
 	else {
 		createViewModeToggleButtons();
 		d->topBarLyr->addWidget( new KexiToolBarSeparator(this));
-	}
+	}*/
 
 	// Data actions
 	QAction * a;
 	KActionCollection *ac = KexiMainWindowIface::global()->actionCollection();
 	KexiSmallToolButton *btn;
-
+/*
 	a = sharedAction("project_save");
 	d->saveDesignButton = new KexiSmallToolButton(a, this);
 	d->saveDesignButton->setText(i18n("Save Design"));
@@ -272,23 +226,18 @@ void KexiWindow::createSubwidgets()
 	d->topBarLyr->addWidget( d->saveDesignButtonSeparator = new KexiToolBarSeparator(this));
 
 	a = sharedAction("data_save_row");
-	//	a = new KAction(KIcon("dialog-ok"), i18n("&Save Row"), this);
-//	a->setShortcut( KShortcut(Qt::SHIFT | Qt::Key_Return) );
-//	a->setToolTip(i18n("Save changes made to the current row"));
-//	a->setWhatsThis(i18n("Saves changes made to the current row."));
 	btn = new KexiSmallToolButton(a, this);
 	btn->setToolButtonStyle( Qt::ToolButtonIconOnly );
 	d->topBarLyr->add(btn);
 
 	a = sharedAction("data_cancel_row_changes");
-/*	a = new KAction(KIcon("dialog-cancel"), i18n("&Cancel Row Changes"), this);
-	a->setToolTip(i18n("Cancel changes made to the current row"));
-	a->setWhatsThis(i18n("Cancels changes made to the current row."));*/
 	btn = new KexiSmallToolButton(a, this);
 	btn->setToolButtonStyle( Qt::ToolButtonIconOnly );
 	d->topBarLyr->add(btn);
 
 	d->topBarLyr->addWidget( new KexiToolBarSeparator(this));
+*/
+/* moved...
 
 	a = sharedAction("data_sort_az");
 	btn = new KexiSmallToolButton(a, this);
@@ -305,7 +254,7 @@ void KexiWindow::createSubwidgets()
 	btn = new KexiSmallToolButton(a, this);
 	btn->setToolButtonStyle( Qt::ToolButtonIconOnly );
 	d->topBarLyr->add(btn);
-
+*/
 /*TODO
 // "data_execute"
 	a = new KAction(KIcon("media-playback-start"), i18n("&Execute"), this);
@@ -316,6 +265,7 @@ void KexiWindow::createSubwidgets()
 	d->mainLyr->addWidget( d->stack );
 }
 
+/*
 void KexiWindow::createViewModeToggleButtons()
 {
 	KAction * a;
@@ -339,7 +289,7 @@ void KexiWindow::createViewModeToggleButtons()
 	}
 	if (supportsViewMode(Kexi::TextViewMode)) {
 		a = new KexiToggleViewModeAction(Kexi::TextViewMode, d->viewModeGroup, 
-			this, SIGNAL(switchToViewModeInternal(Kexi::ViewMode)));
+			this, SLOT(switchToViewModeInternal(Kexi::ViewMode)));
 		QString customTextViewModeCaption( d->part->internalPropertyValue("textViewModeCaption").toString() );
 		if (!customTextViewModeCaption.isEmpty())
 			a->setText( customTextViewModeCaption );
@@ -348,7 +298,7 @@ void KexiWindow::createViewModeToggleButtons()
 		btn = new KexiSmallToolButton(a, this);
 		d->topBarLyr->add(btn);
 	}
-}
+}*/
 
 KexiView *KexiWindow::selectedView() const
 {
@@ -380,6 +330,24 @@ void KexiWindow::addView(KexiView *view, Kexi::ViewMode mode)
 	d->openedViewModes |= mode;
 }
 
+/*
+void KexiWindow::initViewActions(KexiView* view, Kexi::ViewMode mode)
+{
+	QList<QAction*> viewActionsList( view->viewActions() );
+	foreach(QAction* action, viewActionsList) {
+		if (action->isSeparator()) {
+			d->topBarLyr->addWidget( new KexiToolBarSeparator(this));
+		}
+		else {
+			KexiSmallToolButton *btn = new KexiSmallToolButton(action, this);
+			btn->setText(action->text());
+			btn->setToolTip(action->toolTip());
+			btn->setWhatsThis(action->whatsThis());
+			d->topBarLyr->add(btn);
+		}
+	}
+}*/
+
 void KexiWindow::removeView(Kexi::ViewMode mode)
 {
 	KexiView *view = viewForMode(mode);
@@ -669,6 +637,7 @@ tristate KexiWindow::switchToViewMode(
 			return false;
 		}
 		d->creatingViewsMode = Kexi::NoViewMode;
+		newView->initViewActions();
 		addView(newView, newViewMode);
 	}
 	const Kexi::ViewMode prevViewMode = d->currentViewMode;
@@ -712,22 +681,46 @@ tristate KexiWindow::switchToViewMode(
 		d->currentViewMode = prevViewMode;
 		return cancelled;
 	}
-	if (view)
+	if (view) {
 		takeActionProxyChild( view ); //take current proxy child
+		// views have distinct local toolbars, and user has switched the mode button so switch it back
+		//view->toggleViewModeButtonBack();
+	}
 	addActionProxyChild( newView ); //new proxy child
 	d->stack->setCurrentWidget( newView ); //d->indexForView(newViewMode) );
 	newView->propertySetSwitched();
 	KexiMainWindowIface::global()->invalidateSharedActions( newView );
 	QTimer::singleShot(10, newView, SLOT(setFocus())); //newView->setFocus(); //js ok?
 //	setFocus();
+/*TODO move
 	QAction* toggleAction = d->toggleViewModeActions.value(newViewMode);
 	if (toggleAction) {
 		d->switchToViewModeEnabled = false;
 		toggleAction->setChecked(true);
 		d->switchToViewModeEnabled = true;
-	}
+	}*/
 //! @todo sometimes save button is needed for data view mode as well (for queries, forms...)
-	showSaveDesignButton( newViewMode == Kexi::DesignViewMode || newViewMode == Kexi::TextViewMode );
+//moved	showSaveDesignButton( newViewMode == Kexi::DesignViewMode || newViewMode == Kexi::TextViewMode );
+
+/*TODO
+
+	const QList<QWidget*> childWidgets( d->topBarLyr->findChildren<QWidget*>() );
+	foreach(QWidget* childWidget, childWidgets) {
+		if (dynamic_cast<KexiToolBarSeparator*>(childWidget)) {
+
+		}
+		else if (dynamic_cast<KexiSmallToolButton*>(childWidget)) {
+			QAction *a = dynamic_cast<KexiSmallToolButton*>(childWidget)->action();
+			if (a && a != newView->viewAction(a->objectName().toLatin1())) {
+				childWidget->hide();
+				kDebug() << "Hide " << a->objectName();
+			}
+			else {
+				childWidget->show();
+				kDebug() << "Show " << a->objectName();
+			}
+		}
+	}*/
 	return true;
 }
 
@@ -815,39 +808,16 @@ void KexiWindow::dirtyChanged(KexiView* view)
 		return;
 	d->viewThatRecentlySetDirtyFlag = isDirty() ? view : 0;
 	updateCaption();
-	d->saveDesignButton->setEnabled( isDirty() );
+//moved	d->saveDesignButton->setEnabled( isDirty() );
 	emit dirtyChanged(this);
 }
 
 void KexiWindow::updateCaption()
 {
-	if (!d->item || !d->part || !d->origCaption.isEmpty())
+	if (!d->item || !d->part)
 		return;
-	QString capt = d->item->name();
-	QString fullCapt = capt;
-	if (d->part)
-		fullCapt += (" : " + d->part->instanceCaption());
-#ifdef __GNUC__
-#warning TODO KexiWindow::updateCaption()
-#else
-#pragma WARNING( TODO KexiWindow::updateCaption() )
-#endif
-	if (isDirty()) {
-		setWindowTitle(fullCapt+"*");
-	}
-	else {
-		setWindowTitle(fullCapt);
-	}
-#if 0 //TODO
-	if (isDirty()) {
-		QWidget::setCaption(fullCapt+"*");
-		QWidget::setTabCaption(capt+"*");
-	}
-	else {
-		QWidget::setCaption(fullCapt);
-		QWidget::setTabCaption(capt);
-	}
-#endif
+	QString fullCapt( KexiPart::fullCaptionForItem(*d->item, d->part) );
+	setWindowTitle(fullCapt + (isDirty() ? "*" : ""));
 }
 
 bool KexiWindow::neverSaved() const
@@ -1036,10 +1006,22 @@ Kexi::ViewMode KexiWindow::creatingViewsMode() const
 	return d->creatingViewsMode;
 }
 
+QVariant KexiWindow::internalPropertyValue(const QByteArray& name, 
+	const QVariant& defaultValue) const
+{
+	return d->part->internalPropertyValue(name, defaultValue);
+}
+
+/*
 void KexiWindow::showSaveDesignButton(bool show)
 {
 	d->saveDesignButton->setVisible(show);
 	d->saveDesignButtonSeparator->setVisible(show);
-}
+}*/
+
+/*KAction* KexiWindow::sharedViewAction(const char* name)
+{
+	return d->sharedViewActions.value(name);
+}*/
 
 #include "KexiWindow.moc"
