@@ -28,35 +28,35 @@ class KEXICORE_EXPORT KexiGUIMessageHandler : public KexiDB::MessageHandler
 	public:
 		KexiGUIMessageHandler(QWidget *parent = 0);
 		virtual ~KexiGUIMessageHandler();
-		virtual void showErrorMessage(const QString &title, const QString &details = QString::null);
-		virtual void showErrorMessage(KexiDB::Object *obj, const QString& msg = QString::null);
+		virtual void showErrorMessage(const QString &title, const QString &details = QString());
+		virtual void showErrorMessage(KexiDB::Object *obj, const QString& msg = QString());
 
 		void showErrorMessage(const QString&,const QString&,KexiDB::Object *obj);
 		void showErrorMessage(Kexi::ObjectStatus *status);
 		void showErrorMessage(const QString &message, Kexi::ObjectStatus *status);
 
 		/*! Displays a "Sorry" message with \a title text and optional \a details. */
-		void showSorryMessage(const QString &title, const QString &details = QString::null);
+		void showSorryMessage(const QString &title, const QString &details = QString());
 
 		/*! Displays a message of a type \a type, with \a title text and optional \a details.
 		 \a dontShowAgainName can be specified to add "Do not show again" option if \a type is Warning. */
 		virtual void showMessage(MessageType type, const QString &title, const QString &details,
-			const QString& dontShowAgainName = QString::null);
+			const QString& dontShowAgainName = QString());
 
 		/*! Displays a Warning message with \a title text and optional \a details 
 		 with "Continue" button instead "OK".
 		 \a dontShowAgainName can be specified to add "Do not show again" option. */
-		virtual void showWarningContinueMessage(const QString &title, const QString &details = QString::null,
-			const QString& dontShowAgainName = QString::null);
+		virtual void showWarningContinueMessage(const QString &title, const QString &details = QString(),
+			const QString& dontShowAgainName = QString());
 
 		/*! Interactively asks a question using KMessageBox.
 		 See KexiDB::MessageHandler::askQuestion() for details. */
 		virtual int askQuestion( const QString& message, 
 			KMessageBox::DialogType dlgType, KMessageBox::ButtonCode defaultResult,
-			const KGuiItem &buttonYes=KStdGuiItem::yes(), 
-			const KGuiItem &buttonNo=KStdGuiItem::no(),
-			const QString &dontShowAskAgainName = QString::null,
-			int options = KMessageBox::Notify );
+			const KGuiItem &buttonYes=KStandardGuiItem::yes(), 
+			const KGuiItem &buttonNo=KStandardGuiItem::no(),
+			const QString &dontShowAskAgainName = QString(),
+			KMessageBox::Options options = KMessageBox::Notify );
 };
 
 #endif
