@@ -22,13 +22,21 @@
 #include <qpixmap.h>
 #include <qrect.h>
 #include <qevent.h>
-#include <qvaluevector.h>
+#include <q3valuevector.h>
 #include <qlayout.h>
 #include <qcursor.h>
+//Added by qt3to4:
+#include <Q3CString>
+#include <Q3GridLayout>
+#include <QKeyEvent>
+#include <Q3ValueList>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
+#include <QMouseEvent>
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 
 #include <cstdlib> // for abs()
 
@@ -40,7 +48,15 @@
 #include "formmanager.h"
 #include "commands.h"
 #include "events.h"
-#include "kexiflowlayout.h"
+#include <kexiutils/utils.h>
+
+#define KEXI_NO_FLOWLAYOUT
+#ifdef __GNUC__
+#warning "Port Kexi flow layout!"
+#endif
+#ifndef KEXI_NO_FLOWLAYOUT
+#include <kexiutils/FlowLayout.h>
+#endif
 
 using namespace KFormDesigner;
 
@@ -64,9 +80,9 @@ EventEater::eventFilter(QObject *, QEvent *ev)
 	if(ev->type() == QEvent::MouseButtonRelease && m_widget->inherits("QTabWidget"))
 	{
 		QMouseEvent *mev = static_cast<QMouseEvent*>(ev);
-		if(mev->button() == LeftButton)
+		if(mev->button() == Qt::LeftButton)
 		{
-			QMouseEvent *myev = new QMouseEvent(QEvent::MouseButtonPress, mev->pos(), mev->button(), mev->state());
+			QMouseEvent *myev = new QMouseEvent(QEvent::MouseButtonPress, mev->pos(), mev->button(), mev->buttons(), mev->modifiers());
 			m_container->eventFilter(m_widget, myev);
 			delete myev;
 			//return true;
@@ -88,44 +104,57 @@ EventEater::~EventEater()
 
 // Container itself
 
-Container::Container(Container *toplevel, QWidget *container, QObject *parent, const char *name)
-: QObject(parent, name)
+#ifdef __GNUC__
+#warning Container::Private: move more m_* here
+#else
+#pragma WARNING( Container::Private: move more m_* here )
+#endif
+class Container::Private
+{
+	public:
+		Private() {}
+		QPointer<Form> form;
+};
+
+Container::Container(Container *toplevel, QWidget *container, QObject *parent)
+: QObject(parent)
 , m_insertBegin(-1,-1)
 , m_mousePressEventReceived(false)
-, m_mouseReleaseEvent(QEvent::None, QPoint(), 0, 0)
+, m_mouseReleaseEvent(QEvent::None, QPoint(), Qt::NoButton, Qt::NoButton, Qt::NoModifier)
+, d(new Private())
 {
 	m_container = container;
 	m_toplevel = toplevel;
 
 	m_moving = 0;
 	m_tree = 0;
-	m_form = toplevel ? toplevel->form() : 0;
+	if (toplevel)
+		d->form = toplevel->form();
 	m_layout = 0;
 	m_layType = NoLayout;
 	m_state = DoingNothing;
 
-	QCString classname = container->className();
+	Q3CString classname = container->metaObject()->className();
 	if((classname == "HBox") || (classname == "Grid") || (classname == "VBox") ||
 		(classname == "HFlow")  || (classname == "VFlow"))
 		m_margin = 4; // those containers don't have frames, so little margin
 	else
-		m_margin = m_form ? m_form->defaultMargin() : 0;
-	m_spacing = m_form ? m_form->defaultSpacing() : 0;
+		m_margin = d->form ? d->form->defaultMargin() : 0;
+	m_spacing = d->form ? d->form->defaultSpacing() : 0;
 
-	if(toplevel)
-	{
-		ObjectTreeItem *it = new ObjectTreeItem(m_form->library()->displayName(classname),
-			widget()->name(), widget(), this, this);
+	if (toplevel) {
+		ObjectTreeItem *it = new ObjectTreeItem(d->form->library()->displayName(classname),
+			widget()->objectName(), widget(), this, this);
 		setObjectTree(it);
 
 		if(parent->isWidgetType())
 		{
-			QString n = parent->name();
-			ObjectTreeItem *parent = m_form->objectTree()->lookup(n);
-			m_form->objectTree()->addItem(parent, it);
+			QString n = parent->objectName();
+			ObjectTreeItem *parent = d->form->objectTree()->lookup(n);
+			d->form->objectTree()->addItem(parent, it);
 		}
 		else
-			m_form->objectTree()->addItem(toplevel->objectTree(), it);
+			d->form->objectTree()->addItem(toplevel->objectTree(), it);
 
 		connect(toplevel, SIGNAL(destroyed()), this, SLOT(widgetDeleted()));
 	}
@@ -135,21 +164,27 @@ Container::Container(Container *toplevel, QWidget *container, QObject *parent, c
 
 Container::~Container()
 {
-	kdDebug() << " Container being deleted this == " << name() << endl;
+	kDebug() << " Container being deleted this == " << objectName() << endl;
+	delete d;
+}
+
+Form* Container::form() const
+{
+	return d->form;
 }
 
 void
 Container::setForm(Form *form)
 {
-	m_form = form;
-	m_margin = m_form ? m_form->defaultMargin() : 0;
-	m_spacing = m_form ? m_form->defaultSpacing() : 0;
+	d->form = form;
+	m_margin = d->form ? d->form->defaultMargin() : 0;
+	m_spacing = d->form ? d->form->defaultSpacing() : 0;
 }
 
 bool
 Container::eventFilter(QObject *s, QEvent *e)
 {
-//	kdDebug() << e->type() << endl;
+//	kDebug() << e->type() << endl;
 	switch(e->type())
 	{
 		case QEvent::MouseButtonPress:
@@ -157,9 +192,9 @@ Container::eventFilter(QObject *s, QEvent *e)
 			m_insertBegin = QPoint(-1, -1);
 			m_mousePressEventReceived = true;
 
-			kdDebug() << "QEvent::MouseButtonPress sender object = " << s->name()
-				<< "of type " << s->className() << endl;
-			kdDebug() << "QEvent::MouseButtonPress this          = " << name() << endl;
+			kDebug() << "QEvent::MouseButtonPress sender object = " << s->objectName()
+				<< "of type " << s->metaObject()->className() << endl;
+			kDebug() << "QEvent::MouseButtonPress this          = " << this->objectName() << endl;
 
 			m_moving = static_cast<QWidget*>(s);
 			QMouseEvent *mev = static_cast<QMouseEvent*>(e);
@@ -171,46 +206,46 @@ Container::eventFilter(QObject *s, QEvent *e)
 				return true;
 			}
 
-			if(((mev->state() == ControlButton) || (mev->state() == ShiftButton)) 
-				&& (!FormManager::self()->isInserting())) // multiple selection mode
+			if((mev->modifiers() == Qt::ControlModifier || mev->modifiers() == Qt::ShiftModifier) 
+				&& !FormManager::self()->isInserting()) // multiple selection mode
 			{
-				if(m_form->selectedWidgets()->findRef(m_moving) != -1) // widget is already selected
+				if(d->form->selectedWidgets()->findRef(m_moving) != -1) // widget is already selected
 				{
-					if(m_form->selectedWidgets()->count() > 1) // we remove it from selection
+					if(d->form->selectedWidgets()->count() > 1) // we remove it from selection
 						unSelectWidget(m_moving);
 					else // the widget is the only selected, so it means we want to copy it
 					{
 						//m_copyRect = m_moving->geometry();
 						m_state = CopyingWidget;
-						if(m_form->formWidget())
-							m_form->formWidget()->initBuffer();
+						if(d->form->formWidget())
+							d->form->formWidget()->initBuffer();
 					}
 				}
 				else // the widget is not yet selected, we add it
-					setSelectedWidget(m_moving, true, (mev->button() == RightButton));
+					setSelectedWidget(m_moving, true, (mev->button() == Qt::RightButton));
 			}
-			else if((m_form->selectedWidgets()->count() > 1))//&& (!m_form->manager()->isInserting())) // more than one widget selected
+			else if((d->form->selectedWidgets()->count() > 1))//&& (!d->form->manager()->isInserting())) // more than one widget selected
 			{
-				if(m_form->selectedWidgets()->findRef(m_moving) == -1) // widget is not selected, it becomes the only selected widget
-					setSelectedWidget(m_moving, false, (mev->button() == RightButton));
+				if(d->form->selectedWidgets()->findRef(m_moving) == -1) // widget is not selected, it becomes the only selected widget
+					setSelectedWidget(m_moving, false, (mev->button() == Qt::RightButton));
 				// If the widget is already selected, we do nothing (to ease widget moving, etc.)
 			}
-			else// if(!m_form->manager()->isInserting())
-				setSelectedWidget(m_moving, false, (mev->button() == RightButton));
+			else// if(!d->form->manager()->isInserting())
+				setSelectedWidget(m_moving, false, (mev->button() == Qt::RightButton));
 
 			// we are inserting a widget or drawing a selection rect in the form
 			if((/*s == m_container &&*/ FormManager::self()->isInserting()) || ((s == m_container) && !m_toplevel))
 			{
 				int tmpx,tmpy;
-				if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (LeftButton|ControlButton|AltButton)))
+				if(!FormManager::self()->snapWidgetsToGrid() || (mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ControlModifier|Qt::AltModifier))
 				{
 					tmpx = mev->x();
 					tmpy = mev->y();
 				}
 				else
 				{
-					int gridX = m_form->gridSize();
-					int gridY = m_form->gridSize();
+					int gridX = d->form->gridSize();
+					int gridY = d->form->gridSize();
 					tmpx = int( (float)mev->x() / ((float)gridX) + 0.5 ); // snap to grid
 					tmpx *= gridX;
 					tmpy = int( (float)mev->y() / ((float)gridY) + 0.5 );
@@ -218,8 +253,8 @@ Container::eventFilter(QObject *s, QEvent *e)
 				}
 
 				m_insertBegin = (static_cast<QWidget*>(s))->mapTo(m_container, QPoint(tmpx, tmpy));
-				if(m_form->formWidget())
-					m_form->formWidget()->initBuffer();
+				if(d->form->formWidget())
+					d->form->formWidget()->initBuffer();
 
 				if(!FormManager::self()->isInserting())
 					m_state = DrawingSelectionRect;
@@ -253,8 +288,8 @@ Container::eventFilter(QObject *s, QEvent *e)
 		case QEvent::MouseMove:
 		{
 			QMouseEvent *mev = static_cast<QMouseEvent*>(e);
-			if(m_insertBegin!=QPoint(-1,-1) && FormManager::self()->isInserting() && ((mev->state() == LeftButton) || (mev->state() == (LeftButton|ControlButton)) ||
-			(mev->state() == (LeftButton|ControlButton|AltButton)) || (mev->state() == (LeftButton|ShiftButton)) ) )
+			if(m_insertBegin!=QPoint(-1,-1) && FormManager::self()->isInserting() && ((mev->buttons() == Qt::LeftButton) || (mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ControlModifier) ||
+			(mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ControlModifier|Qt::AltModifier) || (mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ShiftModifier) ) )
 			// draw the insert rect
 			{
 				drawInsertRect(mev, s);
@@ -263,16 +298,16 @@ Container::eventFilter(QObject *s, QEvent *e)
 			// Creating a connection, we highlight sender and receiver, and we draw a link between them
 			else if(FormManager::self()->isCreatingConnection() && !FormManager::self()->createdConnection()->sender().isNull())
 			{
-				ObjectTreeItem *tree = m_form->objectTree()->lookup(FormManager::self()->createdConnection()->sender());
+				ObjectTreeItem *tree = d->form->objectTree()->lookup(FormManager::self()->createdConnection()->sender());
 				if(!tree || !tree->widget())
 					return true;
 
-				if(m_form->formWidget() && (tree->widget() != s))
-					m_form->formWidget()->highlightWidgets(tree->widget(), static_cast<QWidget*>(s));
+				if(d->form->formWidget() && (tree->widget() != s))
+					d->form->formWidget()->highlightWidgets(tree->widget(), static_cast<QWidget*>(s));
 			}
-			else if(m_insertBegin!=QPoint(-1,-1) && s == m_container && !m_toplevel && (mev->state() != ControlButton) && !FormManager::self()->isCreatingConnection()) // draw the selection rect
+			else if(m_insertBegin!=QPoint(-1,-1) && s == m_container && !m_toplevel && (mev->modifiers() != Qt::ControlModifier) && !FormManager::self()->isCreatingConnection()) // draw the selection rect
 			{
-				if((mev->state() != LeftButton) || /*m_inlineEditing*/ m_state == InlineEditing)
+				if((mev->buttons() != Qt::LeftButton) || /*m_inlineEditing*/ m_state == InlineEditing)
 					return true;
 				int topx = (m_insertBegin.x() < mev->x()) ? m_insertBegin.x() :  mev->x();
 				int topy = (m_insertBegin.y() < mev->y()) ? m_insertBegin.y() : mev->y();
@@ -281,22 +316,25 @@ Container::eventFilter(QObject *s, QEvent *e)
 				QRect r = QRect(QPoint(topx, topy), QPoint(botx, boty));
 				m_insertRect = r;
 
-				if(m_form->formWidget())
-					m_form->formWidget()->drawRect(r, 1);
+				if(d->form->formWidget())
+					d->form->formWidget()->drawRect(r, 1);
 
 				m_state = DoingNothing;
 				return true;
 			}
-			else if(mev->state() == (LeftButton|ControlButton)) // draw the insert rect for the copied widget
+			else if(mev->buttons() == Qt::LeftButton && mev->modifiers() == Qt::ControlModifier)
 			{
-				if(s == m_container)// || (m_form->selectedWidgets()->count() > 1))
+				// draw the insert rect for the copied widget
+				if(s == m_container)// || (d->form->selectedWidgets()->count() > 1))
 					return true;
 				drawCopiedWidgetRect(mev);
 				return true;
 			}
-			else if( ( (mev->state() == Qt::LeftButton) || (mev->state() == (LeftButton|ControlButton|AltButton)) )
-			  && !FormManager::self()->isInserting() && (m_state != CopyingWidget)) // we are dragging the widget(s) to move it
+			else if( 
+				( mev->buttons() == Qt::LeftButton || (mev->buttons() == Qt::LeftButton && mev->modifiers() == Qt::ControlModifier|Qt::AltModifier) )
+			  && !FormManager::self()->isInserting() && m_state != CopyingWidget)
 			{
+			  // we are dragging the widget(s) to move it
 				if(!m_toplevel && m_moving == m_container) // no effect for form
 					return false;
 				if((!m_moving) || (!m_moving->parentWidget()))// || (m_moving->parentWidget()->inherits("QWidgetStack")))
@@ -313,12 +351,12 @@ Container::eventFilter(QObject *s, QEvent *e)
 		{
 			if(s != m_container)
 				return false;
-			int gridX = m_form->gridSize();
-			int gridY = m_form->gridSize();
+			int gridX = d->form->gridSize();
+			int gridY = d->form->gridSize();
 
 			QPainter p(m_container);
-			p.setPen(QPen(white, 2));
-			p.setRasterOp(XorROP);
+			p.setPen(QPen(Qt::white, 2));
+			p.setCompositionMode(QPainter::CompositionMode_Xor);
 			int cols = m_container->width() / gridX;
 			int rows = m_container->height() / gridY;
 
@@ -335,7 +373,7 @@ Container::eventFilter(QObject *s, QEvent *e)
 
 		case QEvent::Resize: // we are resizing a widget, so we set m_move to true -> the layout will be reloaded when releasing mouse
 		{
-			if(m_form->interactiveMode())
+			if(d->form->interactiveMode())
 				m_state = MovingWidget;
 			break;
 		}
@@ -345,21 +383,21 @@ Container::eventFilter(QObject *s, QEvent *e)
 		{
 			QKeyEvent *kev = static_cast<QKeyEvent*>(e);
 
-			if(kev->key() == Key_F2) // pressing F2 == double-clicking
+			if(kev->key() == Qt::Key_F2) // pressing F2 == double-clicking
 			{
 				m_state = InlineEditing;
 				QWidget *w;
 
 				// try to find the widget which was clicked last and should be edited
-				if(m_form->selectedWidgets()->count() == 1)
-					w = m_form->selectedWidgets()->first();
-				else if(m_form->selectedWidgets()->findRef(m_moving) != -1)
+				if(d->form->selectedWidgets()->count() == 1)
+					w = d->form->selectedWidgets()->first();
+				else if(d->form->selectedWidgets()->findRef(m_moving) != -1)
 					w = m_moving;
 				else
-					w = m_form->selectedWidgets()->last();
-				m_form->library()->startEditing(w->className(), w, this);
+					w = d->form->selectedWidgets()->last();
+				d->form->library()->startEditing(w->metaObject()->className(), w, this);
 			}
-			else if(kev->key() == Key_Escape)
+			else if(kev->key() == Qt::Key_Escape)
 			{
 				if(FormManager::self()->isCreatingConnection())
 					FormManager::self()->stopCreatingConnection();
@@ -367,13 +405,13 @@ Container::eventFilter(QObject *s, QEvent *e)
 					FormManager::self()->stopInsert();
 				return true;
 			}
-			else if((kev->key() == Key_Control) && (m_state == MovingWidget))
+			else if((kev->key() == Qt::Key_Control) && (m_state == MovingWidget))
 			{
 				if(!m_moving)
 					return true;
 				// we simulate a mouse move event to update screen
-				QMouseEvent *mev = new QMouseEvent(QEvent::MouseMove, m_moving->mapFromGlobal(QCursor::pos()), NoButton,
-				LeftButton|ControlButton );
+				QMouseEvent *mev = new QMouseEvent(QEvent::MouseMove, m_moving->mapFromGlobal(QCursor::pos()), Qt::NoButton,
+				Qt::LeftButton|Qt::ControlModifier );
 				eventFilter(m_moving, mev);
 				delete mev;
 			}
@@ -382,30 +420,30 @@ Container::eventFilter(QObject *s, QEvent *e)
 					FormManager::self()->createContextMenu(static_cast<QWidget*>(s), this, false);
 					return true;
 			}
-			else if (kev->key() == Key_Delete)
+			else if (kev->key() == Qt::Key_Delete)
 			{
 				FormManager::self()->deleteWidget();
 				return true;
 			}
 			// directional buttons move the widget
-			else if(kev->key() == Key_Left){ // move the widget of gridX to the left
+			else if(kev->key() == Qt::Key_Left){ // move the widget of gridX to the left
 				moveSelectedWidgetsBy(-form()->gridSize(), 0);
 				return true;
 			}
-			else if(kev->key() == Key_Right){ // move the widget of gridX to the right
+			else if(kev->key() == Qt::Key_Right){ // move the widget of gridX to the right
 				moveSelectedWidgetsBy(form()->gridSize(), 0);
 				return true;
 			}
-			else if(kev->key() == Key_Up){ // move the widget of gridY to the top
+			else if(kev->key() == Qt::Key_Up){ // move the widget of gridY to the top
 				moveSelectedWidgetsBy(0, - form()->gridSize());
 				return true;
 			}
-			else if(kev->key() == Key_Down){ // move the widget of gridX to the bottom
+			else if(kev->key() == Qt::Key_Down){ // move the widget of gridX to the bottom
 				moveSelectedWidgetsBy(0, form()->gridSize());
 				return true;
 			}
-			else if((kev->key() == Key_Tab) || (kev->key() == Key_BackTab)){
-				ObjectTreeItem *item = form()->objectTree()->lookup(form()->selectedWidgets()->first()->name());
+			else if((kev->key() == Qt::Key_Tab) || (kev->key() == Qt::Key_Backtab)){
+				ObjectTreeItem *item = form()->objectTree()->lookup(form()->selectedWidgets()->first()->objectName());
 				if(!item || !item->parent())
 					return true;
 				ObjectTreeList *list = item->parent()->children();
@@ -413,7 +451,7 @@ Container::eventFilter(QObject *s, QEvent *e)
 					return true;
 				int index = list->findRef(item);
 
-				if(kev->key() == Key_BackTab){
+				if(kev->key() == Qt::Key_Backtab){
 					if(index == 0) // go back to the last item
 						index = list->count() - 1;
 					else
@@ -436,25 +474,25 @@ Container::eventFilter(QObject *s, QEvent *e)
 		case QEvent::KeyRelease:
 		{
 			QKeyEvent *kev = static_cast<QKeyEvent*>(e);
-			if((kev->key() == Key_Control) && (m_state == CopyingWidget)) {
+			if((kev->key() == Qt::Key_Control) && (m_state == CopyingWidget)) {
 				// cancel copying
 				//m_copyRect = QRect();
-				if(m_form->formWidget())
-					m_form->formWidget()->clearForm();
+				if(d->form->formWidget())
+					d->form->formWidget()->clearForm();
 			}
 			return true;
 		}
 
 		case QEvent::MouseButtonDblClick: // editing
 		{
-			kdDebug() << "Container: Mouse dbl click for widget " << s->name() << endl;
+			kDebug() << "Container: Mouse dbl click for widget " << s->objectName() << endl;
 			QWidget *w = static_cast<QWidget*>(s);
 			if(!w)
 				return false;
 
 			//m_inlineEditing = true;
 			m_state = InlineEditing;
-			m_form->library()->startEditing(w->className(), w, this);
+			d->form->library()->startEditing(w->metaObject()->className(), w, this);
 			return true;
 		}
 
@@ -479,29 +517,29 @@ Container::handleMouseReleaseEvent(QObject *s, QMouseEvent *mev)
 {
 	if(FormManager::self()->isInserting()) // we insert the widget at cursor pos
 	{
-		if(m_form->formWidget())
-			m_form->formWidget()->clearForm();
-		KCommand *com = new InsertWidgetCommand(this/*, mev->pos()*/);
-		m_form->addCommand(com, true);
+		if(d->form->formWidget())
+			d->form->formWidget()->clearForm();
+		K3Command *com = new InsertWidgetCommand(this/*, mev->pos()*/);
+		d->form->addCommand(com, true);
 		m_insertBegin = QPoint(-1,-1);
 		m_insertRect = QRect();
 		return true;
 	}
-	else if(s == m_container && !m_toplevel && (mev->button() != RightButton) && m_insertRect.isValid()) // we are drawing a rect to select widgets
+	else if(s == m_container && !m_toplevel && (mev->button() != Qt::RightButton) && m_insertRect.isValid()) // we are drawing a rect to select widgets
 	{
 		drawSelectionRect(mev);
 		return true;
 	}
-	if(mev->button() == RightButton) // Right-click -> context menu
+	if(mev->button() == Qt::RightButton) // Right-click -> context menu
 	{
 		FormManager::self()->createContextMenu(static_cast<QWidget*>(s), this);
 	}
-	else if(mev->state() == (Qt::LeftButton|Qt::ControlButton))// && (m_copyRect.isValid()))
+	else if(mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ControlModifier)// && (m_copyRect.isValid()))
 	{
 		// copying a widget by Ctrl+dragging
 
-		if(m_form->formWidget())
-			m_form->formWidget()->clearForm();
+		if(d->form->formWidget())
+			d->form->formWidget()->clearForm();
 		if(s == m_container) // should have no effect on form
 			return true;
 
@@ -509,19 +547,19 @@ Container::handleMouseReleaseEvent(QObject *s, QMouseEvent *mev)
 		if( ( (mev->pos().x() - m_grab.x()) < form()->gridSize() &&  (m_grab.x() - mev->pos().x()) < form()->gridSize() ) &&
 			( (mev->pos().y() - m_grab.y()) < form()->gridSize() &&  (m_grab.y() - mev->pos().y()) < form()->gridSize() ) )
 		{
-			kdDebug() << "The widget has not been moved. No copying" << endl;
+			kDebug() << "The widget has not been moved. No copying" << endl;
 			return true;
 		}
 
-		m_form->setInteractiveMode(false);
+		d->form->setInteractiveMode(false);
 		// We simulate copy and paste
 		FormManager::self()->copyWidget();
-		if(m_form->selectedWidgets()->count() > 1)
+		if(d->form->selectedWidgets()->count() > 1)
 			FormManager::self()->setInsertPoint( mev->pos() );
 		else
 			FormManager::self()->setInsertPoint( static_cast<QWidget*>(s)->mapTo(m_container, mev->pos() - m_grab) );
 		FormManager::self()->pasteWidget();
-		m_form->setInteractiveMode(true);
+		d->form->setInteractiveMode(true);
 
 		//m_initialPos = QPoint();
 	}
@@ -539,15 +577,15 @@ void
 Container::setSelectedWidget(QWidget *w, bool add, bool dontRaise, bool moreWillBeSelected)
 {
 	if (w)
-		kdDebug() << "slotSelectionChanged " << w->name()<< endl;
+		kDebug() << "slotSelectionChanged " << w->objectName()<< endl;
 
 	if(!w)
 	{
-		m_form->setSelectedWidget(m_container);
+		d->form->setSelectedWidget(m_container);
 		return;
 	}
 
-	m_form->setSelectedWidget(w, add, dontRaise, moreWillBeSelected);
+	d->form->setSelectedWidget(w, add, dontRaise, moreWillBeSelected);
 }
 
 void
@@ -556,7 +594,7 @@ Container::unSelectWidget(QWidget *w)
 	if(!w)
 		return;
 
-	m_form->unSelectWidget(w);
+	d->form->unSelectWidget(w);
 }
 
 Container*
@@ -573,10 +611,10 @@ Container::deleteWidget(QWidget *w)
 {
 	if(!w)
 		return;
-//	kdDebug() << "Deleting a widget: " << w->name() << endl;
-	m_form->objectTree()->removeItem(w->name());
+//	kDebug() << "Deleting a widget: " << w->objectName() << endl;
+	d->form->objectTree()->removeItem(w->objectName());
 	FormManager::self()->deleteWidgetLater( w );
-	m_form->setSelectedWidget(m_container);
+	d->form->setSelectedWidget(m_container);
 }
 
 void
@@ -602,14 +640,14 @@ Container::setLayout(LayoutType type)
 	{
 		case HBox:
 		{
-			m_layout = (QLayout*) new QHBoxLayout(m_container, m_margin, m_spacing);
-			createBoxLayout(new HorWidgetList(m_form->toplevelContainer()->widget()));
+			m_layout = (QLayout*) new Q3HBoxLayout(m_container, m_margin, m_spacing);
+			createBoxLayout(new HorWidgetList(d->form->toplevelContainer()->widget()));
 			break;
 		}
 		case VBox:
 		{
-			m_layout = (QLayout*) new QVBoxLayout(m_container, m_margin, m_spacing);
-			createBoxLayout(new VerWidgetList(m_form->toplevelContainer()->widget()));
+			m_layout = (QLayout*) new Q3VBoxLayout(m_container, m_margin, m_spacing);
+			createBoxLayout(new VerWidgetList(d->form->toplevelContainer()->widget()));
 			break;
 		}
 		case Grid:
@@ -619,18 +657,22 @@ Container::setLayout(LayoutType type)
 		}
 		case  HFlow:
 		{
+#ifndef KEXI_NO_FLOWLAYOUT
 			KexiFlowLayout *flow = new KexiFlowLayout(m_container,m_margin, m_spacing);
-			flow->setOrientation(Horizontal);
+			flow->setOrientation(Qt::Horizontal);
 			m_layout = (QLayout*)flow;
 			createFlowLayout();
+#endif
 			break;
 		}
 		case VFlow:
 		{
+#ifndef KEXI_NO_FLOWLAYOUT
 			KexiFlowLayout *flow = new KexiFlowLayout(m_container,m_margin, m_spacing);
-			flow->setOrientation(Vertical);
+			flow->setOrientation(Qt::Vertical);
 			m_layout = (QLayout*)flow;
 			createFlowLayout();
+#endif
 			break;
 		}
 		default:
@@ -654,7 +696,7 @@ Container::reloadLayout()
 void
 Container::createBoxLayout(WidgetList *list)
 {
-	QBoxLayout *layout = static_cast<QBoxLayout*>(m_layout);
+	Q3BoxLayout *layout = static_cast<Q3BoxLayout*>(m_layout);
 
 	for(ObjectTreeItem *tree = m_tree->children()->first(); tree; tree = m_tree->children()->next())
 		list->append( tree->widget());
@@ -668,19 +710,20 @@ Container::createBoxLayout(WidgetList *list)
 void
 Container::createFlowLayout()
 {
+#ifndef KEXI_NO_FLOWLAYOUT
 	KexiFlowLayout *flow = dynamic_cast<KexiFlowLayout*>(m_layout);
 	if(!flow || m_tree->children()->isEmpty())
 		return;
 
 	const int offset = 15;
 	WidgetList *list=0, *list2=0;
-	if(flow->orientation() == Horizontal) {
-		list = new VerWidgetList(m_form->toplevelContainer()->widget());
-		list2 = new HorWidgetList(m_form->toplevelContainer()->widget());
+	if(flow->orientation() == Qt::Horizontal) {
+		list = new VerWidgetList(d->form->toplevelContainer()->widget());
+		list2 = new HorWidgetList(d->form->toplevelContainer()->widget());
 	}
 	else {
-		list = new HorWidgetList(m_form->toplevelContainer()->widget());
-		list2 = new VerWidgetList(m_form->toplevelContainer()->widget());
+		list = new HorWidgetList(d->form->toplevelContainer()->widget());
+		list2 = new VerWidgetList(d->form->toplevelContainer()->widget());
 	}
 
 	// fill the list
@@ -688,7 +731,7 @@ Container::createFlowLayout()
 		list->append( tree->widget());
 	list->sort();
 
-	if(flow->orientation() == Horizontal) {
+	if(flow->orientation() == Qt::Horizontal) {
 		int y = list->first()->y();
 		for(QWidget *w = list->first(); w; w = list->next()) {
 			if( (w->y() > y +offset)) {
@@ -727,17 +770,18 @@ Container::createFlowLayout()
 
 	delete list;
 	delete list2;
+#endif
 }
 
 void
 Container::createGridLayout(bool testOnly)
 {
 	//Those lists sort widgets by y and x
-	VerWidgetList *vlist = new VerWidgetList(m_form->toplevelContainer()->widget());
-	HorWidgetList *hlist = new HorWidgetList(m_form->toplevelContainer()->widget());
+	VerWidgetList *vlist = new VerWidgetList(d->form->toplevelContainer()->widget());
+	HorWidgetList *hlist = new HorWidgetList(d->form->toplevelContainer()->widget());
 	// The vector are used to store the x (or y) beginning of each column (or row)
-	QValueVector<int> cols;
-	QValueVector<int> rows;
+	Q3ValueVector<int> cols;
+	Q3ValueVector<int> rows;
 	int end=-1000;
 	bool same = false;
 
@@ -801,7 +845,7 @@ Container::createGridLayout(bool testOnly)
 				end = w->geometry().bottom();
 		}
 	}
-	kdDebug() << "the new grid will have n rows: n == " << rows.size() << endl;
+	kDebug() << "the new grid will have n rows: n == " << rows.size() << endl;
 
 	end = -10000;
 	same = false;
@@ -828,12 +872,13 @@ Container::createGridLayout(bool testOnly)
 				end = w->geometry().right();
 		}
 	}
-	kdDebug() << "the new grid will have n columns: n == " << cols.size() << endl;
+	kDebug() << "the new grid will have n columns: n == " << cols.size() << endl;
 
 	// We create the layout ..
-	QGridLayout *layout=0;
+	Q3GridLayout *layout=0;
 	if(!testOnly) {
-		layout = new QGridLayout(m_container, rows.size(), cols.size(), m_margin, m_spacing, "grid");
+		layout = new Q3GridLayout(m_container, rows.size(), cols.size(), m_margin, m_spacing);
+		layout->setObjectName("grid");
 		m_layout = (QLayout*)layout;
 	}
 
@@ -848,7 +893,7 @@ Container::createGridLayout(bool testOnly)
 		// We look for widget row(s) ..
 		while(r.y() >= rows[i])
 		{
-			if(rows.size() <= i+1) // we are the last row
+			if((uint)rows.size() <= (i+1)) // we are the last row
 			{
 				wrow = i;
 				break;
@@ -858,7 +903,7 @@ Container::createGridLayout(bool testOnly)
 				wrow = i; // the widget will be in this row
 				uint j = i + 1;
 				// Then we check if the widget needs to span multiple rows
-				while(rows.size() >= j+1 && r.bottom() > rows[j])
+				while((uint)rows.size() >= (j+1) && r.bottom() > rows[j])
 				{
 					endrow = j;
 					j++;
@@ -868,14 +913,14 @@ Container::createGridLayout(bool testOnly)
 			}
 			i++;
 		}
-		//kdDebug() << "the widget " << w->name() << " wil be in the row " << wrow <<
+		//kDebug() << "the widget " << w->objectName() << " wil be in the row " << wrow <<
 		   //" and will go to the row " << endrow << endl;
 
 		// .. and column(s)
 		i = 0;
 		while(r.x() >= cols[i])
 		{
-			if(cols.size() <= i+1) // last column
+			if((uint)cols.size() <= (i+1)) // last column
 			{
 				wcol = i;
 				break;
@@ -885,7 +930,7 @@ Container::createGridLayout(bool testOnly)
 				wcol = i;
 				uint j = i + 1;
 				// Then we check if the widget needs to span multiple columns
-				while(cols.size() >= j+1 && r.right() > cols[j])
+				while((uint)cols.size() >= (j+1) && r.right() > cols[j])
 				{
 					endcol = j;
 					j++;
@@ -895,10 +940,10 @@ Container::createGridLayout(bool testOnly)
 			}
 			i++;
 		}
-		//kdDebug() << "the widget " << w->name() << " wil be in the col " << wcol <<
+		//kDebug() << "the widget " << w->objectName() << " wil be in the col " << wcol <<
 		 // " and will go to the col " << endcol << endl;
 
-		ObjectTreeItem *item = m_form->objectTree()->lookup(w->name());
+		ObjectTreeItem *item = d->form->objectTree()->lookup(w->objectName());
 		if(!endrow && !endcol) {
 			if(!testOnly)
 				layout->addWidget(w, wrow, wcol);
@@ -943,7 +988,7 @@ Container::stringToLayoutType(const QString &name)
 void
 Container::drawConnection(QMouseEvent *mev)
 {
-	if(mev->button() != LeftButton)
+	if(mev->button() != Qt::LeftButton)
 	{
 		FormManager::self()->resetCreatedConnection();
 		return;
@@ -951,11 +996,11 @@ Container::drawConnection(QMouseEvent *mev)
 	// First click, we select the sender and display menu to choose signal
 	if(FormManager::self()->createdConnection()->sender().isNull())
 	{
-		FormManager::self()->createdConnection()->setSender(m_moving->name());
-		if(m_form->formWidget())
+		FormManager::self()->createdConnection()->setSender(m_moving->objectName());
+		if(d->form->formWidget())
 		{
-			m_form->formWidget()->initBuffer();
-			m_form->formWidget()->highlightWidgets(m_moving, 0/*, QPoint()*/);
+			d->form->formWidget()->initBuffer();
+			d->form->formWidget()->highlightWidgets(m_moving, 0/*, QPoint()*/);
 		}
 		FormManager::self()->createSignalMenu(m_moving);
 		return;
@@ -969,7 +1014,7 @@ Container::drawConnection(QMouseEvent *mev)
 	// second click to choose the receiver
 	if(FormManager::self()->createdConnection()->receiver().isNull())
 	{
-		FormManager::self()->createdConnection()->setReceiver(m_moving->name());
+		FormManager::self()->createdConnection()->setReceiver(m_moving->objectName());
 		FormManager::self()->createSlotMenu(m_moving);
 		m_container->repaint();
 		return;
@@ -986,8 +1031,8 @@ void
 Container::drawSelectionRect(QMouseEvent *mev)
 {
 	//finish drawing unclipped selection rectangle: clear the surface
-	if(m_form->formWidget())
-		m_form->formWidget()->clearForm();
+	if(d->form->formWidget())
+		d->form->formWidget()->clearForm();
 	int topx = (m_insertBegin.x() < mev->x()) ? m_insertBegin.x() :  mev->x();
 	int topy = (m_insertBegin.y() < mev->y()) ? m_insertBegin.y() : mev->y();
 	int botx = (m_insertBegin.x() > mev->x()) ? m_insertBegin.x() :  mev->x();
@@ -1021,9 +1066,9 @@ Container::drawInsertRect(QMouseEvent *mev, QObject *s)
 {
 	int tmpx, tmpy;
 	QPoint pos = static_cast<QWidget*>(s)->mapTo(m_container, mev->pos());
-	int gridX = m_form->gridSize();
-	int gridY = m_form->gridSize();
-	if(!FormManager::self()->snapWidgetsToGrid() || (mev->state() == (LeftButton|ControlButton|AltButton)) )
+	int gridX = d->form->gridSize();
+	int gridY = d->form->gridSize();
+	if(!FormManager::self()->snapWidgetsToGrid() || (mev->buttons() == Qt::LeftButton && mev->modifiers() == Qt::ControlModifier|Qt::AltModifier))
 	{
 		tmpx = pos.x();
 		tmpy = pos.y();
@@ -1053,11 +1098,11 @@ Container::drawInsertRect(QMouseEvent *mev, QObject *s)
 
 	if(FormManager::self()->isInserting() && m_insertRect.isValid())
 	{
-		if(m_form->formWidget())
+		if(d->form->formWidget())
 		{
-			QRect drawRect = QRect(m_container->mapTo(m_form->widget(), m_insertRect.topLeft())
+			QRect drawRect = QRect(m_container->mapTo(d->form->widget(), m_insertRect.topLeft())
 				, m_insertRect.size());
-			m_form->formWidget()->drawRect(drawRect, 2);
+			d->form->formWidget()->drawRect(drawRect, 2);
 		}
 	}
 }
@@ -1069,28 +1114,30 @@ Container::drawCopiedWidgetRect(QMouseEvent *mev)
 	if(m_state == MovingWidget)  {
 		//FormManager::self()->undo(); // undo last moving
 		//m_moving->move(m_initialPos);
-		if(m_form->formWidget())  {
+		if(d->form->formWidget())  {
 			m_container->repaint();
-			m_form->formWidget()->initBuffer();
+			d->form->formWidget()->initBuffer();
 		}
 		m_state = CopyingWidget;
 	}
 
 	//m_copyRect.moveTopLeft(m_container->mapFromGlobal( mev->globalPos()) - m_grab);
 
-	if(m_form->formWidget())  {
-		QValueList<QRect> rectList;
-		for(QWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next()) {
+	if(d->form->formWidget())  {
+		QList<QRect> rectList;
+		for(QWidget *w = d->form->selectedWidgets()->first(); 
+			w; w = d->form->selectedWidgets()->next())
+		{
 			QRect drawRect = w->geometry();
 			QPoint p = mev->pos() - m_grab;
-			drawRect.moveBy(p.x(), p.y());
-			p = m_container->mapTo(m_form->widget(), QPoint(0, 0));
-			//drawRect = QRect( ((QWidget*)s)->mapTo(m_form->widget(), drawRect.topLeft()), drawRect.size());
-			drawRect.moveBy(p.x(), p.y());
+			drawRect.moveTo(drawRect.x()+p.x(), drawRect.y()+p.y());
+			p = m_container->mapTo(d->form->widget(), QPoint(0, 0));
+			//drawRect = QRect( ((QWidget*)s)->mapTo(d->form->widget(), drawRect.topLeft()), drawRect.size());
+			drawRect.moveTo(drawRect.x()+p.x(), drawRect.y()+p.y());
 			rectList.append(drawRect);
 		}
 
-		m_form->formWidget()->drawRects(rectList, 2);
+		d->form->formWidget()->drawRects(rectList, 2);
 	}
 }
 
@@ -1098,19 +1145,19 @@ Container::drawCopiedWidgetRect(QMouseEvent *mev)
 void
 Container::moveSelectedWidgetsBy(int realdx, int realdy, QMouseEvent *mev)
 {
-	if (m_form->selectedWidget() == m_form->widget())
+	if (d->form->selectedWidget() == d->form->widget())
 		return; //do not move top-level widget
 
-	const int gridX = m_form->gridSize();
-	const int gridY = m_form->gridSize();
+	const int gridX = d->form->gridSize();
+	const int gridY = d->form->gridSize();
 	int dx=realdx, dy=realdy;
 
-	for(QWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next())
+	for(QWidget *w = d->form->selectedWidgets()->first(); w; w = d->form->selectedWidgets()->next())
 	{
 		if(!w || !w->parent() || w->parent()->inherits("QTabWidget") || w->parent()->inherits("QWidgetStack"))
 			continue;
 
-		if(w->parentWidget() && w->parentWidget()->isA("QWidgetStack"))
+		if(w->parentWidget() && KexiUtils::objectIsA(w->parentWidget(), "QWidgetStack"))
 		{
 			w = w->parentWidget(); // widget is WidgetStack page
 			if(w->parentWidget() && w->parentWidget()->inherits("QTabWidget")) // widget is tabwidget page
@@ -1120,23 +1167,23 @@ Container::moveSelectedWidgetsBy(int realdx, int realdy, QMouseEvent *mev)
 		int tmpx = w->x() + realdx;
 		int tmpy = w->y() + realdy;
 		if(tmpx < 0)
-			dx = QMAX(0 - w->x(), dx); // because dx is <0
+			dx = qMax(0 - w->x(), dx); // because dx is <0
 		else if(tmpx > w->parentWidget()->width() - gridX)
-			dx = QMIN(w->parentWidget()->width() - gridX - w->x(), dx);
+			dx = qMin(w->parentWidget()->width() - gridX - w->x(), dx);
 
 		if(tmpy < 0)
-			dy = QMAX(0 - w->y(), dy); // because dy is <0
+			dy = qMax(0 - w->y(), dy); // because dy is <0
 		else if(tmpy > w->parentWidget()->height() - gridY)
-			dy = QMIN(w->parentWidget()->height() - gridY - w->y(), dy);
+			dy = qMin(w->parentWidget()->height() - gridY - w->y(), dy);
 	}
 
-	for(QWidget *w = m_form->selectedWidgets()->first(); w; w = m_form->selectedWidgets()->next())
+	for(QWidget *w = d->form->selectedWidgets()->first(); w; w = d->form->selectedWidgets()->next())
 	{
 		// Don't move tab widget pages (or widget stack pages)
 		if(!w || !w->parent() || w->parent()->inherits("QTabWidget") || w->parent()->inherits("QWidgetStack"))
 			continue;
 
-		if(w->parentWidget() && w->parentWidget()->isA("QWidgetStack"))
+		if(w->parentWidget() && KexiUtils::objectIsA(w->parentWidget(), "QWidgetStack"))
 		{
 			w = w->parentWidget(); // widget is WidgetStack page
 			if(w->parentWidget() && w->parentWidget()->inherits("QTabWidget")) // widget is tabwidget page
@@ -1144,7 +1191,7 @@ Container::moveSelectedWidgetsBy(int realdx, int realdy, QMouseEvent *mev)
 		}
 
 		int tmpx, tmpy;
-		if(!FormManager::self()->snapWidgetsToGrid() || (mev && mev->state() == (LeftButton|ControlButton|AltButton)) )
+		if(!FormManager::self()->snapWidgetsToGrid() || (mev && mev->buttons() == Qt::LeftButton && mev->modifiers()==Qt::ControlModifier|Qt::AltModifier))
 		{
 			tmpx = w->x() + dx;
 			tmpy = w->y() + dy;
