@@ -19,29 +19,33 @@
 */
 
 #include <kdebug.h>
+#include <KIcon>
+#include <KActionCollection>
 
 #include "libactionwidget.h"
 #include "widgetfactory.h"
+#include "formmanager.h"
 
 using namespace KFormDesigner;
 
 LibActionWidget::LibActionWidget(WidgetInfo *w, KActionCollection *c)
- : KToggleAction(w->name(), w->pixmap(), 0/*Key_F5*/, 0, 0 /*SLOT(slotWidget())*/, 
-	c, QString("library_widget_" + w->className()).latin1())
+ : KToggleAction(KIcon(w->pixmap()), w->name(), c)
 {
-//	kdDebug() << "LibActionWidget::LibActionWidget(): " << QString("library_widget_" + w->className()).latin1() << endl;
+	setObjectName( QString("library_widget_" + w->className()) );
+	FormManager::self()->widgetActionGroup()->addAction( this );
+//	kDebug() << "LibActionWidget::LibActionWidget(): " << QString("library_widget_" + w->className()).toLatin1() << endl;
 	m_className = w->className();
-	setExclusiveGroup("LibActionWidgets");
+//kde4 not needed	setExclusiveGroup("LibActionWidgets");
 	setToolTip(w->name());
 	setWhatsThis(w->description());
 //	connect(this, SIGNAL(activated()), this, SLOT(slotWidget()));
 }
 
 void
-LibActionWidget::slotActivated()
+LibActionWidget::slotToggled(bool checked)
 {
-	KToggleAction::slotActivated();
-	if (isChecked())
+	KToggleAction::slotToggled(checked);
+	if (checked)
 		emit prepareInsert(m_className);
 }
 
