@@ -20,10 +20,6 @@
 #ifndef KEXIDB_DRIVER_SQLITE_H
 #define KEXIDB_DRIVER_SQLITE_H
 
-#include <qstringlist.h>
-//Added by qt3to4:
-#include <Q3CString>
-
 #include <kexidb/driver.h>
 
 namespace KexiDB
@@ -53,14 +49,14 @@ class SQLiteDriver : public Driver
 
 		//! Escape a string for use as a value
 		virtual QString escapeString(const QString& str) const;
-		virtual Q3CString escapeString(const Q3CString& str) const;
+		virtual QByteArray escapeString(const QByteArray& str) const;
 
 		//! Escape BLOB value \a array
 		virtual QString escapeBLOB(const QByteArray& array) const;
 
 	protected:
 		virtual QString drv_escapeIdentifier( const QString& str) const;
-		virtual Q3CString drv_escapeIdentifier( const Q3CString& str) const;
+		virtual QByteArray drv_escapeIdentifier( const QByteArray& str) const;
 		virtual Connection *drv_createConnection( ConnectionData &conn_data );
 		virtual AdminTools* drv_createAdminTools() const;
 
@@ -80,4 +76,3 @@ class SQLiteDriver : public Driver
 }
 
 #endif
-
