@@ -20,7 +20,7 @@
 #ifndef KEXIDB_GLOBAL_H
 #define KEXIDB_GLOBAL_H
 
-#include <kexidb/kexidb_export.h>
+#include "kexidb_export.h"
 #include <qstring.h>
 
 //global public definitions
@@ -158,16 +158,13 @@ enum ObjectTypes {
 }
 
 
-/*
- * TODO:  Remove these once we start using Qt4 containers:
- * Shortcuts for iterating over Q3PtrList and Q3PtrDict 
- */
-
+#if 0 //Qt4: remove
 /*! a shortcut for iterating over lists or maps, eg. QMap, QValueList */
 #define foreach_list(_class, _variable, _list) \
 	        for (_class _variable(_list); _variable.current(); ++_variable)
 
 #define foreach_dict(_class, _variable, _list) foreach_list(_class, _variable, _list)
+#endif
 
 #ifndef futureI18n
 # define futureI18n QString
