@@ -39,10 +39,6 @@
 #endif
 
 /* -- compile-time settings -- */
-#if defined(Q_WS_WIN) || defined(KEXI_OPTIONS)
-/* defined in a .pro file or 'KEXI_OPTIONS' env. variable */
-#else
-#endif
 
 /* Might want to add GUI defines here if widgets are to be
  * distributed as part of kexidb - mart */
