@@ -19,25 +19,25 @@
 
 #include "utils.h"
 #include "utils_p.h"
-#include <kexi_global.h>
+#include "kexiutils_global.h"
 
-#include <qregexp.h>
-#include <qpainter.h>
-#include <qimage.h>
-#include <qwmatrix.h>
-#include <qicon.h>
+#include <QRegExp>
+#include <QPainter>
+#include <QImage>
+#include <QIcon>
 #include <QMetaProperty>
 #include <QBitmap>
 #include <QFocusEvent>
-#include <qfile.h>
+#include <QFile>
+#include <QStyle>
 
-#include <kdebug.h>
-#include <kcursor.h>
-#include <kapplication.h>
-#include <kiconeffect.h>
-#include <kpixmapeffect.h>
-#include <kiconloader.h>
+#include <KDebug>
+#include <KCursor>
+#include <KApplication>
+#include <KIconEffect>
+#include <KIconLoader>
 #include <KGlobalSettings>
+#include <KAction>
 
 using namespace KexiUtils;
 
@@ -57,6 +57,7 @@ void DelayedCursorHandler::stop() {
 	QApplication::restoreOverrideCursor();
 }
 void DelayedCursorHandler::show() {
+	QApplication::restoreOverrideCursor();
 	QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
 }
 
@@ -89,7 +90,8 @@ WaitCursorRemover::WaitCursorRemover()
 
 WaitCursorRemover::~WaitCursorRemover()
 {
-	_delayedCursorHandler->start(true);
+	if (m_reactivateCursor)
+		_delayedCursorHandler->start(true);
 }
 
 //--------------------------------------------------------------------------------
@@ -305,16 +307,19 @@ QColor KexiUtils::bleachedColor(const QColor& c, int factor)
 
 QIcon KexiUtils::colorizeIconToTextColor(const QPixmap& icon, const QPalette& palette)
 {
+#ifdef __GNUC__
+#warning KexiUtils::colorizeIconToTextColor OK?
+#else
+#pragma WARNING(port KexiUtils::colorizeIconToTextColor OK?)
+#endif
 	QPixmap pm(
 		KIconEffect().apply( icon, KIconEffect::Colorize, 1.0f,
 			palette.color(QPalette::Active, QPalette::ButtonText), false ) );
-
-	return QIcon(
-		KPixmapEffect::fade( pm, 0.33, 
-			palette.color(QPalette::Active, QPalette::ButtonText) ) );
+	KIconEffect::semiTransparent( pm );
+	return QIcon(pm);
 }
 
-QPixmap KexiUtils::emptyIcon(K3Icon::Group iconGroup)
+QPixmap KexiUtils::emptyIcon(KIconLoader::Group iconGroup)
 {
 	QPixmap noIcon( IconSize( iconGroup ), IconSize( iconGroup ) );
 	QBitmap bmpNoIcon(noIcon.size());
@@ -594,9 +599,78 @@ QFont KexiUtils::smallFont(QWidget *init)
 		const int wdth = KGlobalSettings::desktopGeometry(init).width();
 		int size = 10 + qMax(0, wdth - 1100) / 100;
 		size = qMin( init->fontInfo().pixelSize(), size );
+		size = qMax( KGlobalSettings::smallestReadableFont().pixelSize(), size );
 		_smallFont->setPixelSize( size );
 	}
 	return *_smallFont;
 }
 
+//---------
+
+//! @internal
+class StaticSetOfStrings::Private {
+	public:
+		Private() : array(0), set(0) {}
+		~Private() { delete set; }
+	const char** array;
+	QSet<QByteArray> *set;
+};
+
+StaticSetOfStrings::StaticSetOfStrings()
+ : d( new Private )
+{
+}
+
+StaticSetOfStrings::StaticSetOfStrings(const char* array[])
+ : d( new Private )
+{
+	setStrings(array);
+}
+
+StaticSetOfStrings::~StaticSetOfStrings()
+{
+	delete d;
+}
+
+void StaticSetOfStrings::setStrings(const char* array[])
+{
+	delete d->set;
+	d->set = 0;
+	d->array = array;
+}
+
+bool StaticSetOfStrings::isEmpty() const
+{
+	return d->array == 0;
+}
+
+bool StaticSetOfStrings::contains( const QByteArray& string ) const
+{
+	if (!d->set) {
+		d->set = new QSet<QByteArray>();
+		for (const char ** p = d->array;*p;p++)
+			d->set->insert(QByteArray::fromRawData(*p, qstrlen(*p)+1));
+	}
+	return d->set->contains(string);
+}
+
+//---------------------
+
+KTextEditorFrame::KTextEditorFrame( QWidget * parent, Qt::WindowFlags f )
+ : QFrame(parent, f)
+{
+	QEvent dummy(QEvent::StyleChange);
+	changeEvent(&dummy);
+}
+
+void KTextEditorFrame::changeEvent(QEvent *event)
+{
+	if (event->type()==QEvent::StyleChange) {
+		if (style()->objectName()!="oxygen") // oxygen already nicely paints the frame
+			setFrameStyle(QFrame::Sunken|QFrame::StyledPanel);
+		else
+			setFrameStyle(QFrame::NoFrame);
+	}
+}
+
 #include "utils_p.moc"
