@@ -21,6 +21,8 @@
 #ifndef KEXIMAINWINDOW_P_H
 #define KEXIMAINWINDOW_P_H
 
+#define KEXI_NO_PROCESS_EVENTS
+
 #ifdef KEXI_NO_PROCESS_EVENTS
 # define KEXI_NO_PENDING_DIALOGS
 #endif
@@ -48,6 +50,7 @@ class KexiTabbedToolBar : public KTabWidget
 	protected slots:
 		void slotCurrentChanged(int index);
 		void slotDelayedTabRaise();
+		void slotSettingsChanged(int category);
 	private:
 		void addAction(KToolBar *tbar, const char* actionName);
 		void addSeparatorAndAction(KToolBar *tbar, const char* actionName);
@@ -56,6 +59,27 @@ class KexiTabbedToolBar : public KTabWidget
 		Private * const d;
 };
 
+//! @internal window container created to speedup opening new tabs
+class KexiWindowContainer : public QWidget
+{
+	public:
+		KexiWindowContainer(QWidget* parent)
+			: QWidget(parent)
+			, window(0)
+			, lyr( new QVBoxLayout(this) )
+		{
+			lyr->setContentsMargins(0,0,0,0);
+		}
+		void setWindow(KexiWindow* w) {
+			window = w;
+			if (w)
+				lyr->addWidget(w);
+		}
+		KexiWindow *window;
+	private:
+		QVBoxLayout *lyr;
+};
+
 //! @internal
 class KexiTabbedToolBar::Private
 {
@@ -64,7 +88,7 @@ class KexiTabbedToolBar::Private
 		 : createId(-1), createWidgetToolBar(0), tabToRaise(-1)
 		{
 			tabRaiseTimer.setSingleShot(true);
-			tabRaiseTimer.setInterval(500);
+			tabRaiseTimer.setInterval(300);
 		}
 		KActionCollection *ac;
 		int createId;
@@ -89,11 +113,14 @@ KexiTabbedToolBar::KexiTabbedToolBar(QWidget *parent)
 	QAction* a;
 
 	KexiUtils::smallFont(this/*init*/);
+	slotSettingsChanged( KGlobalSettings::FontChanged );
+	connect(KGlobalSettings::self(), SIGNAL(settingsChanged(int)), this, SLOT(slotSettingsChanged(int)));
+
 //	KToolBar* helpToolBar = new KToolBar(this);
 //	helpToolBar->setFont(Kexi::smallFont());
 /*
 	helpToolBar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-	helpToolBar->setIconSize( QSize(IconSize(K3Icon::Small), IconSize(K3Icon::Small)) );
+	helpToolBar->setIconSize( QSize(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)) );
 	a = d->ac->action("help_whats_this");
 	helpToolBar->addAction(a);
 	a = d->ac->action("help_contents");
@@ -204,6 +231,12 @@ KexiTabbedToolBar::KexiTabbedToolBar(QWidget *parent)
 */
 
 	connect(this, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentChanged(int)));
+/*tmp
+	QPalette pal(palette());
+	QBrush bg( pal.brush( backgroundRole() ) );
+	bg.setColor( Qt::red ); //pal.color( QPalette::Button ) );
+	pal.setColor( QPalette::Window, Qt::red );
+	setPalette( pal );*/
 }
 
 KexiTabbedToolBar::~KexiTabbedToolBar()
@@ -211,6 +244,13 @@ KexiTabbedToolBar::~KexiTabbedToolBar()
 	delete d;
 }
 
+void KexiTabbedToolBar::slotSettingsChanged(int category)
+{
+	if (category == KGlobalSettings::FontChanged) {
+		setFont( KGlobalSettings::menuFont() ); // toolbar acts like a menu
+	}
+}
+
 KToolBar* KexiTabbedToolBar::createWidgetToolBar() const
 {
 	return d->createWidgetToolBar;
@@ -390,12 +430,12 @@ bool KexiMainWidget::queryExit()
 
 void KexiMainWidget::slotCurrentTabIndexChanged(int index)
 {
-	KexiWindow* w = dynamic_cast<KexiWindow*>( m_tabWidget->widget(index) );
-	if ((KexiWindow*)m_previouslyActiveWindow == w)
+	KexiWindowContainer* cont = dynamic_cast<KexiWindowContainer*>( m_tabWidget->widget(index) );
+	if ((KexiWindow*)m_previouslyActiveWindow == cont->window)
 		return;
 	if (m_mainWindow)
-		m_mainWindow->activeWindowChanged( w, (KexiWindow*)m_previouslyActiveWindow );
-	m_previouslyActiveWindow = w;
+		m_mainWindow->activeWindowChanged( cont->window, (KexiWindow*)m_previouslyActiveWindow );
+	m_previouslyActiveWindow = cont->window;
 }
 
 //------------------------------------------
@@ -661,7 +701,9 @@ void updatePropEditorDockWidthInfo() {
 	void updatePropEditorVisibility(Kexi::ViewMode viewMode)
 	{
 		if (propEditorDockWidget) {
-			propEditorDockWidget->setVisible( wnd->currentWindow() && wnd->currentWindow()->propertySet() );
+			bool visible = wnd->currentWindow() && wnd->currentWindow()->propertySet();
+			kDebug() << "updatePropEditorVisibility(): visible == " << visible;
+			propEditorDockWidget->setVisible( visible );
 		}
 
 #ifdef __GNUC__
@@ -704,8 +746,6 @@ void updatePropEditorDockWidthInfo() {
 //				ds->setKeepSize(true);
 
 				config->setGroup("MainWindow");
-# if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
-
 				if (wasAutoOpen) //(dw2->isVisible())
 //				ds->setSeparatorPosInPercent( 100 * nav->width() / wnd->width() );
 					ds->setSeparatorPosInPercent(
@@ -717,10 +757,6 @@ void updatePropEditorDockWidthInfo() {
 					qMax(20, config->readEntry("LeftDockPosition", 20/* % */)));
 
 	//			dw->resize( d->config->readEntry("LeftDockPosition", 115/* % */), dw->height() );
-# else
-				//there were problems on KDE < 3.4
-				ds->setSeparatorPosInPercent( 20 );
-# endif
 				//if (!wasAutoOpen) //(dw2->isVisible())
 //					ds->setSeparatorPos( ds->separatorPos(), true );
 			}
