@@ -29,6 +29,7 @@
 #include "kexiprojectset.h"
 #include "kexiguimsghandler.h"
 
+#include <kexidb/utils.h>
 #include <kexidb/driver.h>
 #include <kexidb/drivermanager.h>
 #include "KexiStartupDialog.h"
@@ -73,11 +74,16 @@ class KexiStartupHandler::Private
 		{
 		}
 
-		~Private()
-		{
+		~Private() {
+			destroyGui();
+		}
+		void destroyGui() {
 			delete passwordDialog;
+			passwordDialog = 0;
 			delete connDialog;
+			connDialog = 0;
 			delete startupDialog;
+			startupDialog = 0;
 		}
 
 		KexiDBPasswordDialog* passwordDialog;
@@ -194,6 +200,7 @@ KexiStartupHandler::KexiStartupHandler()
  , KexiStartupData()
  , d( new Private() )
 {
+	connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(slotAboutToAppQuit()));
 }
 
 KexiStartupHandler::~KexiStartupHandler()
@@ -201,6 +208,11 @@ KexiStartupHandler::~KexiStartupHandler()
 	delete d;
 }
 
+void KexiStartupHandler::slotAboutToAppQuit()
+{
+	d->destroyGui();
+}
+
 bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QByteArray &action_name)
 {
 	QStringList list = args->getOptionList(action_name);
@@ -244,14 +256,15 @@ bool KexiStartupHandler::getAutoopenObjects(KCmdLineArgs *args, const QByteArray
 		if (name_required && obj_name.isEmpty())
 			continue;
 
-		KexiProjectData::ObjectInfo info;
-		info["name"]=obj_name;
-		info["type"]=type_name;
-		info["action"]=action_name;
-		//ok, now add info for this object
 		atLeastOneFound = true;
-		if (projectData())
+		if (projectData()) {
+			KexiProjectData::ObjectInfo* info = new KexiProjectData::ObjectInfo();
+			info->insert("name", obj_name);
+			info->insert("type", type_name);
+			info->insert("action", action_name);
+			//ok, now add info for this object
 			projectData()->autoopenObjects.append( info );
+		}
 		else
 			return true; //no need to find more because we do not have projectData() anyway
 	} //for
@@ -294,7 +307,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 	}
 
 //	if (cdata.driverName.isEmpty())
-//		cdata.driverName = KexiDB::Driver::defaultFileBasedDriverName();
+//		cdata.driverName = KexiDB::defaultFileBasedDriverName();
 	if (!args->getOption("host").isEmpty())
 		cdata.hostName = args->getOption("host");
 	if (!args->getOption("local-socket").isEmpty())
@@ -435,7 +448,7 @@ tristate KexiStartupHandler::init(int /*argc*/, char ** /*argv*/)
 
 		if (createDB) {
 			if (cdata.driverName.isEmpty())
-				cdata.driverName = KexiDB::Driver::defaultFileBasedDriverName();
+				cdata.driverName = KexiDB::defaultFileBasedDriverName();
 			m_projectData = new KexiProjectData(cdata, prjName); //dummy
 		}
 		else {
