@@ -24,6 +24,7 @@
 #include "KexiConnSelector.h"
 #include "KexiStartupFileWidget.h"
 #include <kexiutils/utils.h>
+#include <kexidb/utils.h>
 #include <kexi_global.h>
 
 #include <qlayout.h>
@@ -75,12 +76,11 @@ public:
 //		, pageOpenRecentID(-1)
 	{
 		result = -1;
-		QString iconname(
-			KMimeType::mimeType( KexiDB::Driver::defaultFileBasedDriverMimeType() )->iconName() );
-		kexi_sqlite_icon = KIconLoader::global()->loadMimeTypeIcon( iconname, K3Icon::Desktop );
+		QString iconname( KexiDB::defaultFileBasedDriverIcon() );
+		kexi_sqlite_icon = KIconLoader::global()->loadMimeTypeIcon( iconname, KIconLoader::Desktop );
 		iconname = KMimeType::mimeType("application/x-kexiproject-shortcut")->iconName();
 		kexi_shortcut_icon = KIconLoader::global()->loadMimeTypeIcon(
-			iconname, K3Icon::Desktop );
+			iconname, KIconLoader::Desktop );
 		prj_selector = 0;
 		chkDoNotShow = 0;
 		openExistingConnWidget = 0;
@@ -221,7 +221,7 @@ KexiStartupDialog::~KexiStartupDialog()
 bool KexiStartupDialog::shouldBeShown()
 {
 	KConfigGroup group = KGlobal::config()->group("Startup");
-	return group.readEntry<bool>("ShowStartupDialog", true);
+	return group.readEntry("ShowStartupDialog", true);
 }
 
 void KexiStartupDialog::showEvent( QShowEvent *e )
@@ -368,8 +368,7 @@ void KexiStartupDialog::setupPageTemplates()
 	//- page "templates"
 //	d->templatesSectionID_templates = itemID++;
 	QString none;
-	QString kexi_sqlite_icon_name 
-		= KMimeType::mimeType( KexiDB::Driver::defaultFileBasedDriverMimeType() )->iconName();
+	QString kexi_sqlite_icon_name( KexiDB::defaultFileBasedDriverIcon() );
 	templPageWidget = new QFrame(d->templatesWidget); 
 	d->templPageWidgetItem_CreateFromTemplate = d->templatesWidget->addPage(templPageWidget, 
 		i18nc("Keep this text narrow: split to multiple rows if needed", "Create From\nTemplate"));
@@ -772,10 +771,10 @@ void KexiStartupDialog::templateSelected(const QString& fileName)
 		accept();
 }
 
-Q3ValueList<KexiProjectData::ObjectInfo> KexiStartupDialog::autoopenObjects() const
+const KexiProjectData::AutoOpenObjects& KexiStartupDialog::autoopenObjects() const
 {
 	if (d->result != CreateFromTemplateResult || !d->viewTemplates)
-		Q3ValueList<KexiProjectData::ObjectInfo>();
+		KexiProjectData::AutoOpenObjects();
 
 	return d->viewTemplates->autoopenObjectsForSelectedTemplate();
 }
