@@ -1,7 +1,7 @@
 /***************************************************************************
  * kexidbfieldlist.h
  * This file is part of the KDE project
- * copyright (C)2004-2005 by Sebastian Sauer (mail@dipe.org)
+ * copyright (C)2004-2006 by Sebastian Sauer (mail@dipe.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -17,19 +17,16 @@
  * Boston, MA 02110-1301, USA.
  ***************************************************************************/
 
-#ifndef KROSS_KEXIDB_KEXIDBFIELDLIST_H
-#define KROSS_KEXIDB_KEXIDBFIELDLIST_H
+#ifndef SCRIPTING_KEXIDBFIELDLIST_H
+#define SCRIPTING_KEXIDBFIELDLIST_H
 
 #include <qstring.h>
-
-#include <api/object.h>
-#include <api/list.h>
-#include <api/class.h>
+#include <qobject.h>
 
 #include <kexidb/drivermanager.h>
 #include <kexidb/fieldlist.h>
 
-namespace Kross { namespace KexiDB {
+namespace Scripting {
 
     // Forward declarations.
     class KexiDBField;
@@ -37,7 +34,7 @@ namespace Kross { namespace KexiDB {
 
     /**
     * A list of fields. The KexiDBFieldList can be used to handle KexiDBField objects
-    * in a backend-independend way.
+    * in a backend-independent way.
     *
     * Example (in Python) ;
     * @code
@@ -56,49 +53,50 @@ namespace Kross { namespace KexiDB {
     * cursor = connection.executeQuerySchema(query)
     * @endcode
     */
-    class KexiDBFieldList : public Kross::Api::Class<KexiDBFieldList>
+    class KexiDBFieldList : public QObject
     {
+            Q_OBJECT
         public:
-            KexiDBFieldList(::KexiDB::FieldList* fieldlist);
+            KexiDBFieldList(QObject* parent, ::KexiDB::FieldList* fieldlist, bool owner);
             virtual ~KexiDBFieldList();
-            virtual const QString getClassName() const;
             ::KexiDB::FieldList* fieldlist() { return m_fieldlist; }
 
-        private:
+        public slots:
 
             /** Returns the number of fields. */
             uint fieldCount();
-            /** Return the field specified by the index-number passed as an argument. */
-            KexiDBField* field(uint index);
-            /** Return the field specified by the as an argument passed fieldname. */
-            KexiDBField* fieldByName(const QString& name);
+            /** Return the \a KexiDBField specified by the index-number passed as an argument. */
+            QObject* field(uint index);
+            /** Return the \a KexiDBField specified by the as an argument passed fieldname. */
+            QObject* fieldByName(const QString& name);
 
-            /** Returns a list of all fields. */
-            Kross::Api::List* fields();
-            /** Returns true if the KexiDBField object passed as an argument is in the field list. */
-            bool hasField(KexiDBField* field);
+            /** Returns true if the passed \a KexiDBField \p field object is in the field list. */
+            bool hasField(QObject* field);
             /** Return a list of field names. */
             const QStringList names() const;
 
-            /** Adds the KexiDBField object passed as an argument to the field list. */
-            void addField(KexiDBField* field);
-            /** Inserts the KexiDBField object passed as the second argument
+            /** Adds the \a KexiDBField object passed as an argument to the field list. */
+            bool addField(QObject* field);
+            /** Inserts the \a KexiDBField object passed as the second argument
             into the field list at the position defined by the first argument. */
-            void insertField(uint index, KexiDBField* field);
-            /** Removes the KexiDBField object passed as an argument from the field list. */
-            void removeField(KexiDBField* field);
+            bool insertField(uint index, QObject* field);
+            /** Removes the \a KexiDBField object passed as an argument from the field list. */
+            bool removeField(QObject* field);
             /** Removes all KexiDBField objects from the fieldlist. */
             void clear();
-            /** Set the fieldlist to the as argument passed list of fields. */
-            void setFields(KexiDBFieldList* fieldlist);
-            /** Creates and returns list that contain fields selected by name. */
-            KexiDBFieldList* subList(QValueList<QVariant> list);
+
+            /** Set the list of field to the as argument passed \a KexiDBFieldList \p fieldlist . */
+            bool setFields(QObject* fieldlist);
+
+            /** Creates and returns a \a KexiDBFieldList object that contain fields selected by name. */
+            QObject* subList(QVariantList list);
 
         private:
             ::KexiDB::FieldList* m_fieldlist;
+            bool m_owner;
     };
 
-}}
+}
 
 #endif
 
