@@ -39,9 +39,7 @@
 #include <kexidb/connection.h>
 #include <kexidb/cursor.h>
 #include <KexiWindow.h>
-//Added by qt3to4:
 #include <Q3CString>
-#include <Q3PtrList>
 
 //! @internal
 class KexiTablePart::Private
@@ -85,12 +83,13 @@ void KexiTablePart::initPartActions()
 
 void KexiTablePart::initInstanceActions()
 {
-//moved to main window	createSharedAction(Kexi::DataViewMode, i18n("Filter"), "search-filter", 0, "tablepart_filter");
+//moved to main window	createSharedAction(Kexi::DataViewMode, i18n("Filter"), "view-filter", 0, "tablepart_filter");
+/*2.0 moved to createViewActions()
 	KAction *a = createSharedToggleAction(
 		Kexi::DesignViewMode, i18n("Primary Key"), "key", KShortcut(),
 		"tablepart_toggle_pkey");
 //		Kexi::DesignViewMode, i18n("Toggle Primary Key"), "key", KShortcut(), "tablepart_toggle_pkey");
-	a->setWhatsThis(i18n("Sets or removes primary key for currently selected field."));
+	a->setWhatsThis(i18n("Sets or removes primary key for currently selected field.")); */
 }
 
 KexiWindowData* KexiTablePart::createWindowData(KexiWindow* window)
@@ -180,15 +179,14 @@ tristate KexiTablePart::askForClosingObjectsUsingTableSchema(
 	QWidget *parent, KexiDB::Connection& conn, 
 	KexiDB::TableSchema& table, const QString& msg)
 {
-	Q3PtrList<KexiDB::Connection::TableSchemaChangeListenerInterface>* listeners
+	QSet<KexiDB::Connection::TableSchemaChangeListenerInterface*>* listeners
 		= conn.tableSchemaChangeListeners(table);
 	if (!listeners || listeners->isEmpty())
 		return true;
 	
 	QString openedObjectsStr = "<ul>";
-	for (Q3PtrListIterator<KexiDB::Connection::TableSchemaChangeListenerInterface> it(*listeners);
-		it.current(); ++it)	{
-			openedObjectsStr += QString("<li>%1</li>").arg(it.current()->listenerInfoString);
+	foreach (KexiDB::Connection::TableSchemaChangeListenerInterface* iface, *listeners) {
+		openedObjectsStr += QString("<li>%1</li>").arg(iface->listenerInfoString);
 	}
 	openedObjectsStr += "</ul>";
 	int r = KMessageBox::questionYesNo(parent, 
