@@ -39,7 +39,6 @@
 #include <k3listview.h>
 #include <kmessagebox.h>
 #include <klineedit.h>
-#include <kimageeffect.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <KActionCollection>
@@ -820,6 +819,7 @@ KexiBrowserListView::KexiBrowserListView(QWidget *parent)
  , enableExecuteArea(true)
 {
 	setObjectName("KexiBrowserListView");
+	setAlternateBackground(Qt::red);
 }
 
 KexiBrowserListView::~KexiBrowserListView()
