@@ -21,6 +21,9 @@
 
 #include <kexidataawareobjectiface.h>
 #include <utils/kexisharedactionclient.h>
+#include <core/KexiMainWindowIface.h>
+#include <core/KexiStandardAction.h>
+#include <KActionCollection>
 
 #include <qlayout.h>
 #include <Q3VBoxLayout>
@@ -60,8 +63,8 @@ void KexiDataAwareView::init( QWidget* viewWidget, KexiSharedActionClient* actio
 		m_dataAwareObject->connectReloadActionsSignal(this, SLOT(reloadActions()));
 	}
 
-	Q3VBoxLayout *box = new Q3VBoxLayout(this);
-	box->addWidget(m_internalView);
+//2.0	Q3VBoxLayout *box = new Q3VBoxLayout(this);
+//2.0	box->addWidget(m_internalView);
 
 	setMinimumSize(m_internalView->minimumSizeHint().width(), 
 		m_internalView->minimumSizeHint().height());
@@ -76,6 +79,21 @@ void KexiDataAwareView::init( QWidget* viewWidget, KexiSharedActionClient* actio
 
 void KexiDataAwareView::initActions()
 {
+	// - setup local actions
+	QList<QAction*> viewActions;
+	KAction* a;
+	if (m_dataAwareObject->isSortingEnabled()) {
+//		a = new KAction(this);
+//		a->setSeparator(true);
+//		viewActions << a;
+		viewActions
+			<< KexiStandardAction::sortAscending(this, SLOT(sortAscending()), this)
+			<< KexiStandardAction::sortDescending(this, SLOT(sortDescending()), this);
+	}
+	KActionCollection *ac = KexiMainWindowIface::global()->actionCollection();
+	viewActions << (a = dynamic_cast<KAction*>( ac->action("edit_find") ));
+	setViewActions(viewActions);
+
 	plugSharedAction("edit_delete_row", this, SLOT(deleteCurrentRow()));
 	m_actionClient->plugSharedAction(sharedAction("edit_delete_row")); //for proper shortcut
 
@@ -91,10 +109,10 @@ void KexiDataAwareView::initActions()
 	plugSharedAction("data_cancel_row_changes", this, SLOT(cancelRowEdit()));
 	m_actionClient->plugSharedAction(sharedAction("data_cancel_row_changes")); //for proper shortcut
 
-	if (m_dataAwareObject->isSortingEnabled()) {
-		plugSharedAction("data_sort_az", this, SLOT(sortAscending()));
-		plugSharedAction("data_sort_za", this, SLOT(sortDescending()));
-	}
+//	if (m_dataAwareObject->isSortingEnabled()) {
+//moved up		plugSharedAction("data_sort_az", this, SLOT(sortAscending()));
+//moved up		plugSharedAction("data_sort_za", this, SLOT(sortDescending()));
+//	}
 
 	m_actionClient->plugSharedAction(sharedAction("edit_insert_empty_row")); //for proper shortcut
 
@@ -192,7 +210,7 @@ void KexiDataAwareView::reloadActions()
 //warning FIXME Move this to the table part
 /*
 	kDebug()<<"INIT ACTIONS***********************************************************************"<<endl;
-	new KAction(i18n("Filter"), "search-filter", 0, this, SLOT(filter()), actionCollection(), "tablepart_filter");
+	new KAction(i18n("Filter"), "view-filter", 0, this, SLOT(filter()), actionCollection(), "tablepart_filter");
 	setXMLFile("kexidatatableui.rc");
 */
 	m_dataAwareObject->contextMenu()->clear();
@@ -320,12 +338,12 @@ bool KexiDataAwareView::setupFindAndReplace(QStringList& columnNames, QStringLis
 {
 	if (!dataAwareObject() || !dataAwareObject()->data())
 		return false;
-	KexiTableViewColumn::List columns( dataAwareObject()->data()->columns );
-	for (KexiTableViewColumn::ListIterator it(columns); it.current(); ++it) {
-		if (!it.current()->visible())
+	const KexiTableViewColumn::List columns( dataAwareObject()->data()->columns() );
+	foreach (KexiTableViewColumn *col, columns) {
+		if (!col->isVisible())
 			continue;
-		columnNames.append( it.current()->field()->name() );
-		columnCaptions.append( it.current()->captionAliasOrName() );
+		columnNames.append( col->field()->name() );
+		columnCaptions.append( col->captionAliasOrName() );
 	}
 
 	//update "look in" selection if there was any
