@@ -15,32 +15,16 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "kexiquerydesignersqleditor.h"
 
-#ifdef KTEXTEDIT_BASED_SQL_EDITOR
-#else
-# include <ktexteditor/highlightinginterface.h>
-#endif
-
-KexiQueryDesignerSQLEditor::KexiQueryDesignerSQLEditor(
-	KexiMainWindow *mainWin, QWidget *parent, const char *name)
- : KexiEditor(mainWin, parent, name)
+KexiQueryDesignerSQLEditor::KexiQueryDesignerSQLEditor(QWidget *parent)
+	: KexiEditor(parent)
 {
-#ifdef KTEXTEDIT_BASED_SQL_EDITOR
-#else
-	KTextEditor::HighlightingInterface *hl = KTextEditor::highlightingInterface(document());
-	for(uint i=0; i < hl->hlModeCount(); i++)  {
-//		kdDebug() << "hlmode("<<i<<"): " << hl->hlModeName(i) << endl;
-		if (hl->hlModeName(i).contains("sql", false))  {
-			hl->setHlMode(i);
-			break;
-		}
-	}
-#endif
+	setHighlightMode("sql");
 }
 
 KexiQueryDesignerSQLEditor::~KexiQueryDesignerSQLEditor()
