@@ -20,8 +20,8 @@
 #ifndef KexiDropDownButton_H
 #define KexiDropDownButton_H
 
-#include <qtoolbutton.h>
-#include <qguardedptr.h>
+#include <kexi_export.h>
+#include <QToolButton>
 
 //! @short A button for drop-down "Image" menu
 /*! Used in KexiDBImageBox and KexiBlobTableEdit.
@@ -35,11 +35,11 @@ class KEXIGUIUTILS_EXPORT KexiDropDownButton : public QToolButton
 		KexiDropDownButton(QWidget *parent);
 		virtual ~KexiDropDownButton();
 
-		virtual void drawButton( QPainter *p );
-		
-		virtual QSize sizeHint () const;
+		virtual QSize sizeHint() const;
 
-		virtual void keyPressEvent ( QKeyEvent * e );
+	protected:
+		virtual void paintEvent( QPaintEvent *e );
+		virtual void keyPressEvent( QKeyEvent * e );
 };
 
 #endif
