@@ -37,6 +37,10 @@ public:
 
     /// @return The element's ElementType
     ElementType elementType() const;
+
+protected:
+    /// Process @p raw and render it to @p path
+    void renderToPath( const QString& rawString, QPainterPath& path ) const;
 };
 
 #endif // NUMBERELEMENT_H
