@@ -45,9 +45,9 @@
 #include "EncloseElement.h"
 #include "MultiscriptElement.h"
 #include "UnderOverElement.h"
-#include "MatrixElement.h"
-#include "MatrixRowElement.h"
-#include "MatrixEntryElement.h"
+#include "TableElement.h"
+#include "TableRowElement.h"
+#include "TableEntryElement.h"
 #include "ActionElement.h"
 
 static void load(BasicElement* element, const QString& input)
@@ -137,10 +137,10 @@ void TestLoad::numberElement_data()
     addRow( "<mn> 1.000.000,11 </mn>", 0 );
 
     // Glyph element contents
-    addRow( "<mn>12<mglyph fontfamnly=\"serif\" alt=\"8\" index=\"56\"/></mn>", 1);
-    addRow( "<mn> <mglyph fontfamnly=\"serif\" alt=\"8\" index=\"56\"/> </mn>", 1);
-    addRow( "<mn> <mglyph fontfamnly=\"serif\" alt=\"8\" index=\"56\"/> "
-            "     <mglyph fontfamnly=\"serif\" alt=\"7\" index=\"55\"/> </mn>", 2);
+    addRow( "<mn>12<mglyph fontfamily=\"serif\" alt=\"8\" index=\"56\"/></mn>", 1);
+    addRow( "<mn> <mglyph fontfamily=\"serif\" alt=\"8\" index=\"56\"/> </mn>", 1);
+    addRow( "<mn> <mglyph fontfamily=\"serif\" alt=\"8\" index=\"56\"/> "
+            "     <mglyph fontfamily=\"serif\" alt=\"7\" index=\"55\"/> </mn>", 2);
 
     // Be sure attributes don't break anything
     addRow( "<mn mathvariant=\"bold\">1</mn>", 0 );
@@ -158,10 +158,10 @@ void TestLoad::operatorElement_data()
     addRow( "<mo> ++ </mo>", 0 );
 
     // Glyph element contents
-    addRow( "<mo>+<mglyph fontfamoly=\"serif\" alt=\"+\" index=\"43\"/></mo>", 1);
-    addRow( "<mo> <mglyph fontfamoly=\"serif\" alt=\"+\" index=\"43\"/> </mo>", 1);
-    addRow( "<mo> <mglyph fontfamoly=\"serif\" alt=\"+\" index=\"43\"/> "
-            "     <mglyph fontfamoly=\"serif\" alt=\"=\" index=\"61\"/> </mo>", 2);
+    addRow( "<mo>+<mglyph fontfamily=\"serif\" alt=\"+\" index=\"43\"/></mo>", 1);
+    addRow( "<mo> <mglyph fontfamily=\"serif\" alt=\"+\" index=\"43\"/> </mo>", 1);
+    addRow( "<mo> <mglyph fontfamily=\"serif\" alt=\"+\" index=\"43\"/> "
+            "     <mglyph fontfamily=\"serif\" alt=\"=\" index=\"61\"/> </mo>", 2);
 
     // Be sure attributes don't break anything
     addRow( "<mo mathvariant=\"bold\">+</mo>", 0 );
@@ -183,10 +183,10 @@ void TestLoad::textElement_data()
     addRow( "<mtext> more text </mtext>", 0 );
 
     // Glyph element contents
-    addRow( "<mtext>tex<mglyph fontfamtextly=\"serif\" alt=\"t\" index=\"116\"/></mtext>", 1);
-    addRow( "<mtext> <mglyph fontfamtextly=\"serif\" alt=\"t\" index=\"116\"/> </mtext>", 1);
-    addRow( "<mtext>te <mglyph fontfamtextly=\"serif\" alt=\"x\" index=\"120\"/> "
-            "     <mglyph fontfamtextly=\"serif\" alt=\"t\" index=\"116\"/> </mtext>", 2);
+    addRow( "<mtext>tex<mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/></mtext>", 1);
+    addRow( "<mtext> <mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/> </mtext>", 1);
+    addRow( "<mtext>te <mglyph fontfamily=\"serif\" alt=\"x\" index=\"120\"/> "
+            "     <mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/> </mtext>", 2);
 
     // Be sure attributes don't break anything
     addRow( "<mtext mathvariant=\"bold\">text</mtext>", 0 );
@@ -220,10 +220,10 @@ void TestLoad::stringElement_data()
     addRow( "<ms> more text </ms>", 0 );
 
     // Glyph element contents
-    addRow( "<ms>tex<mglyph fontfamsly=\"serif\" alt=\"t\" index=\"116\"/></ms>", 1);
-    addRow( "<ms> <mglyph fontfamsly=\"serif\" alt=\"t\" index=\"116\"/> </ms>", 1);
-    addRow( "<ms>te <mglyph fontfamsly=\"serif\" alt=\"x\" index=\"120\"/> "
-            "     <mglyph fontfamsly=\"serif\" alt=\"t\" index=\"116\"/> </ms>", 2);
+    addRow( "<ms>tex<mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/></ms>", 1);
+    addRow( "<ms> <mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/> </ms>", 1);
+    addRow( "<ms>te <mglyph fontfamily=\"serif\" alt=\"x\" index=\"120\"/> "
+            "     <mglyph fontfamily=\"serif\" alt=\"t\" index=\"116\"/> </ms>", 2);
 
     // Be sure attributes don't break anything
     addRow( "<ms mathvariant=\"bold\">text</ms>", 0 );
@@ -292,7 +292,7 @@ void TestLoad::fracElement_data()
     QTest::addColumn<int>("outputRecursive");
 
     // Basic content
-    addRow( "<mfrac><mi>x</mi><mi>y</mi></mfrac>", 2, 4 );
+    addRow( "<mfrac><mi>x</mi><mi>y</mi></mfrac>", 2, 2 );
 
     // More complex content
     addRow( "<mfrac linethickness=\"2\">"
@@ -304,7 +304,7 @@ void TestLoad::fracElement_data()
             "  <mi> c </mi>"
             "  <mi> d </mi>"
             " </mfrac>"
-            "</mfrac>", 2, 12 );
+            "</mfrac>", 2, 6 );
 
     addRow( "<mfrac>"
             " <mn> 1 </mn>"
@@ -319,7 +319,7 @@ void TestLoad::fracElement_data()
             "   <mn> 3 </mn>"
             "  </mfrac>"
             " </mrow>"
-            "</mfrac>", 2, 14 );
+            "</mfrac>", 2, 9 );
 }
 
 void TestLoad::rootElement_data()
