@@ -14,14 +14,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef kfconfig_h
 #define kfconfig_h
 
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 
 #include <kformulaconfigpage.h>
 
@@ -31,11 +31,11 @@ class KFormulaPartView;
 /**
  * The big config dialog.
  */
-class KFConfig : public KDialogBase
+class KFConfig : public KPageDialog
 {
     Q_OBJECT
 public:
-    KFConfig( KFormulaPartView* parent );
+    explicit KFConfig( KFormulaPartView* parent );
 
 public slots:
     void slotApply();
@@ -43,6 +43,7 @@ public slots:
 
 private:
     KFormula::ConfigurePage* _page;
+    KPageWidgetItem *p1;
 //     KFormula::MathFontsConfigurePage* _mathFontPage;
 };
 
