@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef CONNECTOR_PLUGIN_H
 #define CONNECTOR_PLUGIN_H
@@ -24,7 +24,7 @@
 
 #include <klibloader.h>
 
-class KInstance;
+class KComponentData;
 
 class ConnectorToolFactory : public KLibFactory
 { Q_OBJECT
@@ -32,13 +32,13 @@ public:
   ConnectorToolFactory( QObject* parent = 0, const char* name = 0 );
   ~ConnectorToolFactory();
 
-  virtual QObject* create( QObject* parent = 0, const char* name = 0,
+  virtual QObject* createObject( QObject* parent = 0, const char* name = 0,
                            const char* classname = "QObject", const QStringList &args = QStringList() );
 
-  static KInstance* global();
+  static KComponentData global();
 
 private:
-  static KInstance* s_global;
+  static KComponentData s_global;
 };
 
 #endif
