@@ -1,6 +1,7 @@
 /*
  * Kivio - Visual Modelling and Flowcharting
  * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
+ * Copyright (C) 2003-2005 Peter Simonsson <psn@linux.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,28 +15,30 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef TOOL_SELECT_H
 #define TOOL_SELECT_H
 
 #include <qptrlist.h>
-#include <koPoint.h>
-#include "tool.h"
-
-#include "kivio_rect.h"
+#include <KoPoint.h>
+#include <KoRect.h>
+#include "kivio_mousetool.h"
 
 class KivioView;
 class KivioPage;
 class QMouseEvent;
-class KPopupMenu;
+class QKeyEvent;
+class KMenu;
+class KRadioAction;
+class KAction;
 
 class KivioStencil;
 
 class KivioSelectDragData
 {
-public:
-    KivioRect rect;
+  public:
+    KoRect rect;
 };
 
 enum {
@@ -48,29 +51,31 @@ enum {
     stUngroup
 };
 
-class SelectTool : public Tool
+class SelectTool : public Kivio::MouseTool
 {
   Q_OBJECT
   public:
-    SelectTool( KivioView* view );
+    SelectTool( KivioView* parent );
     ~SelectTool();
 
-    virtual void processEvent( QEvent* );
-    virtual void activate();
-    virtual void deactivate();
-    virtual void configure();
+    virtual bool processEvent(QEvent* e);
 
     void select(const QRect&);
 
+  public slots:
+    void setActivated(bool a);
+
   signals:
     void operationDone();
 
   protected slots:
-    void editText();
+    void editText(QPtrList<KivioStencil>* stencils);
+    void showProperties();
+    void editStencilText();
 
   protected:
     void mousePress(const QPoint&);
-    void mouseMove(const QPoint&);
+    void mouseMove(QMouseEvent*);
     void mouseRelease(const QPoint&);
     void leftDoubleClick(const QPoint&);
 
@@ -79,9 +84,9 @@ class SelectTool : public Tool
     bool startCustomDragging(const QPoint&, bool);
     bool startRubberBanding(const QPoint&);
 
-    void continueDragging(const QPoint&);
+    void continueDragging(const QPoint&, bool ignoreGridGuides = false);
     void continueCustomDragging(const QPoint&);
-    void continueResizing(const QPoint&);
+    void continueResizing(const QPoint&, bool ignoreGridGuides = false);
     void continueRubberBanding(const QPoint&);
 
     void endResizing(const QPoint&);
@@ -93,6 +98,9 @@ class SelectTool : public Tool
 
     void changeMouseCursor(const QPoint&);
     int isOverResizeHandle( KivioStencil *pStencil, const double x, const double y );
+    
+    void keyPress(QKeyEvent* e);
+    
     QPoint m_startPoint, m_releasePoint;
     KoPoint m_lastPoint;
     KoPoint m_origPoint;
@@ -105,21 +113,23 @@ class SelectTool : public Tool
       stmCustomDragging,
       stmResizing
     };
+
   private:
-    // Flag to indicate that we are drawing a rubber band
-    int m_mode;
+    int m_mode;     // Flag to indicate that we are drawing a rubber band
     KivioStencil *m_pResizingStencil;
     KivioStencil *m_pCustomDraggingStencil;
     int m_resizeHandle;
-    char m_keys[32];
-    bool m_shiftKey;
+    bool m_controlKey;
     int m_customDragID;
     QPtrList <KivioSelectDragData> m_lstOldGeometry;
-    KivioRect m_selectedRect;
+    KoRect m_selectedRect;
+    KoPoint m_customDragOrigPoint;
 
-    KPopupMenu *m_pMenu;
+    KRadioAction* m_selectAction;
+    KAction* m_arrowHeadAction;
+    KAction* m_textEditAction;
+
+    bool m_firstTime;
 };
 
 #endif
-
-
