@@ -24,7 +24,7 @@
 
 #include <klibloader.h>
 
-class KInstance;
+class KComponentData;
 
 class ZoomToolFactory : public KLibFactory
 { Q_OBJECT
@@ -34,10 +34,10 @@ public:
 
   virtual QObject* createObject( QObject* parent = 0, const char* name = 0,
                            const char* classname = "QObject", const QStringList &args = QStringList() );
-  static KInstance* global();
+  static KComponentData global();
 
 private:
-  static KInstance* s_global;
+  static KComponentData s_global;
 };
 
 #endif
