@@ -2,6 +2,7 @@
   Copyright (C) 1998, 1999, 2000 Torben Weis <weis@kde.org>
   Copyright (C) 2004 - 2007 Dag Andersen <danders@get2net.dk>
   Copyright (C) 2006 Raphael Langerhorst <raphael.langerhorst@kdemail.net>
+  Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -31,17 +32,13 @@
 #include <KoDocumentChild.h>
 
 class KoView;
-class K3CommandHistory;
-class K3Command;
 
 /// The main namespace.
 namespace KPlato
 {
 
 class DocumentChild;
-class View;
 class Project;
-class MainProjectDialog;
 class Context;
 class GanttView;
 
@@ -57,24 +54,18 @@ public:
 
     virtual void paintContent( QPainter& painter, const QRect& rect);
 
-    /**
-     * Edit the settings of the project
-     */
-    void editProject();
-
-    Project &getProject() { return * m_project; }
+    void setProject( Project *project );
+    Project &getProject() { return *m_project; }
     const Project &getProject() const { return * m_project; }
 
     // The load and save functions. Look in the file kplato.dtd for info
     virtual bool loadXML( QIODevice *, const KoXmlDocument &document );
     virtual QDomDocument saveXML();
-
+    /// Save a workpackage file containing @node with schedule identity @id
+    QDomDocument saveWorkPackageXML( const Node *node, long id = -1 );
+    
     bool saveOasis( KoStore*, KoXmlWriter* ) { return false; }
-    bool loadOasis( const KoXmlDocument &doc, KoOasisStyles &, const KoXmlDocument&, KoStore * );
-
-    void addCommand( K3Command * cmd, bool execute = true );
-
-    void setCommandType( int type );
+    bool loadOdf( KoOdfReadStore & odfStore );
 
     Config &config() { return m_config; }
     Context *context() const { return m_context; }
@@ -87,6 +78,13 @@ public:
     void activate( QWidget *w = 0 );
     DocumentChild *createChild( KoDocument *doc, const QRect &geometry = QRect() );
     
+    bool saveWorkPackageToStream( QIODevice * dev, const Node *node, long id );
+    bool saveWorkPackageFormat( const QString &file, const Node *node, long id  );
+    bool saveWorkPackageUrl( const KUrl & _url, const Node *node, long id  );
+
+signals:
+    void changed();
+    
 protected:
     virtual KoView* createViewInstance( QWidget* parent );
     virtual bool loadChildren( KoStore* );
@@ -98,8 +96,6 @@ protected:
 
 
 protected slots:
-    void slotDocumentRestored();
-    void slotCommandExecuted( K3Command * );
     void slotViewDestroyed();
 
 private:
@@ -108,12 +104,7 @@ private:
     
 private:
     Project *m_project;
-    MainProjectDialog *m_projectDialog;
     QWidget* m_parentWidget;
-    View *m_view;
-
-    K3CommandHistory *m_commandHistory;
-    bool m_update, m_calculate;
 
     Config m_config;
     Context *m_context;
