@@ -44,6 +44,9 @@ public:
     /// reimplemented
     virtual KoPAMasterPage * newMasterPage();
 
+    /// reimplemented
+    virtual KoOdf::DocumentType documentType() const;
+
     /**
      * @brief Add animation to shape
      *
@@ -74,7 +77,7 @@ protected:
     /**
      * @brief get the animations of the page
      */
-    KPrShapeAnimations * animationsByPage( KoPAPageBase * page );
+    KPrShapeAnimations & animationsByPage( KoPAPageBase * page );
 };
 
 #endif /* KPRDOCUMENT_H */
