@@ -34,15 +34,23 @@ public:
     explicit KPrView( KPrDocument * document, QWidget * parent = 0 );
     ~KPrView();
 
-protected:    
+    virtual KoViewConverter * viewConverter();
+
+protected:
     void initGUI();
     void initActions();
 
 protected slots:
     void startPresentation();
+    void createAnimation();
+    void createPageEffect();
+    void deletePageEffect();
 
 private:
     KAction *m_actionStartPresentation;
+    KAction *m_actionCreateAnimation;
+    KAction *m_actionCreatePageEffect;
+    KAction *m_actionDeletePageEffect;
     KPrViewModePresentation *m_presentationMode;
     KoPAViewMode *m_normalMode;
 };
