@@ -357,7 +357,7 @@ bool KisBrush::saveToDevice(QIODevice* dev) const
     return true;
 }
 
-QImage KisBrush::img()
+QImage KisBrush::img() const
 {
     QImage image = m_img;
 
@@ -382,7 +382,7 @@ KisQImagemaskSP KisBrush::mask(const KisPaintInformation& info, double subPixelX
         createScaledBrushes();
     }
 
-    double scale = scaleForPressure(info.pressure);
+    double scale = scaleForPressure(info.pressure());
 
     const ScaledBrush *aboveBrush = 0;
     const ScaledBrush *belowBrush = 0;
@@ -415,13 +415,13 @@ KisQImagemaskSP KisBrush::mask(const KisPaintInformation& info, double subPixelX
     return outputMask;
 }
 
-KisPaintDeviceSP KisBrush::image(KoColorSpace * /*colorSpace*/, const KisPaintInformation& info, double subPixelX, double subPixelY) const
+KisPaintDeviceSP KisBrush::image(const KoColorSpace * /*colorSpace*/, const KisPaintInformation& info, double subPixelX, double subPixelY) const
 {
     if (m_scaledBrushes.isEmpty()) {
         createScaledBrushes();
     }
 
-    double scale = scaleForPressure(info.pressure);
+    double scale = scaleForPressure(info.pressure());
 
     const ScaledBrush *aboveBrush = 0;
     const ScaledBrush *belowBrush = 0;
@@ -508,7 +508,7 @@ void KisBrush::setHotSpot(QPointF pt)
 
 QPointF KisBrush::hotSpot(const KisPaintInformation& info) const
 {
-    double scale = scaleForPressure(info.pressure);
+    double scale = scaleForPressure(info.pressure());
     double w = width() * scale;
     double h = height() * scale;
 
@@ -614,13 +614,13 @@ double KisBrush::scaleForPressure(double pressure)
 qint32 KisBrush::maskWidth(const KisPaintInformation& info) const
 {
     // Add one for sub-pixel shift
-    return static_cast<qint32>(ceil(width() * scaleForPressure(info.pressure)) + 1);
+    return static_cast<qint32>(ceil(width() * scaleForPressure(info.pressure())) + 1);
 }
 
 qint32 KisBrush::maskHeight(const KisPaintInformation& info) const
 {
     // Add one for sub-pixel shift
-    return static_cast<qint32>(ceil(height() * scaleForPressure(info.pressure)) + 1);
+    return static_cast<qint32>(ceil(height() * scaleForPressure(info.pressure())) + 1);
 }
 
 KisQImagemaskSP KisBrush::scaleMask(const ScaledBrush *srcBrush, double scale, double subPixelX, double subPixelY) const
@@ -1262,7 +1262,7 @@ void KisBrush::generateBoundary() {
         dev = image(KoColorSpaceRegistry::instance()->colorSpace("RGBA",0), KisPaintInformation());
     } else {
         KisQImagemaskSP amask = mask(KisPaintInformation());
-        KoColorSpace* cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA",0);
+        const KoColorSpace* cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA",0);
         dev = new KisPaintDevice(cs, "tmp for generateBoundary");
 
         KisHLineIteratorPixel it = dev->createHLineIterator(0, 0, w);
