@@ -38,7 +38,7 @@
 
 #include "kis_brush.h"
 #include "kis_debug_areas.h"
-#include "kis_gradient.h"
+#include "KoSegmentGradient.h"
 #include "kis_image.h"
 #include "kis_iterators_pixel.h"
 #include "kis_layer.h"
@@ -469,27 +469,34 @@ namespace {
 
 KisGradientPainter::KisGradientPainter()
     : KisPainter()
+    , m_gradient( 0 )
 {
-    m_gradient = 0;
 }
 
-KisGradientPainter::KisGradientPainter(KisPaintDeviceSP device) : KisPainter(device), m_gradient(0)
+KisGradientPainter::KisGradientPainter(KisPaintDeviceSP device)
+    : KisPainter(device)
+    , m_gradient(0)
+{
+}
+
+KisGradientPainter::KisGradientPainter(KisPaintDeviceSP device, KisSelectionSP selection)
+    : KisPainter( device, selection )
+    , m_gradient( 0 )
 {
 }
 
 bool KisGradientPainter::paintGradient(const QPointF& gradientVectorStart,
-                       const QPointF& gradientVectorEnd,
-                       enumGradientShape shape,
-                       enumGradientRepeat repeat,
-                       double antiAliasThreshold,
-                       bool reverseGradient,
-                       qint32 startx,
-                       qint32 starty,
-                       qint32 width,
-                       qint32 height)
+                                       const QPointF& gradientVectorEnd,
+                                       enumGradientShape shape,
+                                       enumGradientRepeat repeat,
+                                       double antiAliasThreshold,
+                                       bool reverseGradient,
+                                       qint32 startx,
+                                       qint32 starty,
+                                       qint32 width,
+                                       qint32 height)
 {
     Q_UNUSED( antiAliasThreshold );
-    m_cancelRequested = false;
 
     if (!m_gradient) return false;
 
@@ -535,8 +542,8 @@ bool KisGradientPainter::paintGradient(const QPointF& gradientVectorStart,
 
     //If the device has a selection only iterate over that selection
     QRect r;
-    if( m_device->hasSelection() ) {
-        r = m_device->selection()->selectedExactRect();
+    if( m_selection ) {
+        r = m_selection->selectedExactRect();
         startx = r.x();
         starty = r.y();
         width = r.width();
@@ -549,7 +556,7 @@ bool KisGradientPainter::paintGradient(const QPointF& gradientVectorStart,
     int linesProcessed = 0;
     int lastProgressPercent = 0;
 
-    emit notifyProgressStage(i18n("Rendering gradient..."), 0);
+    if (m_progressUpdater) m_progressUpdater->setProgress( 0 );
 
 
  /*   if (antiAliasThreshold < 1 - DBL_EPSILON) {
@@ -583,22 +590,22 @@ bool KisGradientPainter::paintGradient(const QPointF& gradientVectorStart,
         int progressPercent = (linesProcessed * 100) / height;
 
         if (progressPercent > lastProgressPercent) {
-            emit notifyProgress(progressPercent);
+            if (m_progressUpdater) m_progressUpdater->setProgress(progressPercent);
             lastProgressPercent = progressPercent;
 
-            if (m_cancelRequested) {
+            if (m_progressUpdater && m_progressUpdater->interrupted()) {
                 break;
             }
         }
 
-        if (m_cancelRequested) {
+        if (m_progressUpdater && m_progressUpdater->interrupted()) {
             break;
         }
     }
 
-/*    if (!m_cancelRequested && antiAliasThreshold < 1 - DBL_EPSILON) {
+/*    if (!if (m_progressUpdater) m_progressUpdater->interrupted() && antiAliasThreshold < 1 - DBL_EPSILON) {
 
-        emit notifyProgressStage(i18n("Anti-aliasing gradient..."), lastProgressPercent);
+        if (m_progressUpdater) m_progressUpdater->setProgressStage(i18n("Anti-aliasing gradient..."), lastProgressPercent);
         quint8 * layerPointer = layer.bits();
         for (int y = starty; y <= endy; y++) {
             for (int x = startx; x <= endx; x++) {
@@ -690,28 +697,33 @@ bool KisGradientPainter::paintGradient(const QPointF& gradientVectorStart,
                 int progressPercent = (pixelsProcessed * 100) / totalPixels;
 
                 if (progressPercent > lastProgressPercent) {
-                    emit notifyProgress(progressPercent);
+                    if (m_progressUpdater) m_progressUpdater->setProgress(progressPercent);
                     lastProgressPercent = progressPercent;
 
-                    if (m_cancelRequested) {
+                    if (if (m_progressUpdater) m_progressUpdater->interrupted()) {
                         break;
                     }
                 }
                 layerPointer += 4;
             }
 
-            if (m_cancelRequested) {
+            if (if (m_progressUpdater) m_progressUpdater->interrupted()) {
                 break;
             }
         }
     }*/
 
-    if (!m_cancelRequested) {
-        bltSelection(startx, starty, m_compositeOp, dev, m_opacity, startx, starty, width, height);
+    if (m_progressUpdater) {
+        if(!m_progressUpdater->interrupted())
+            bltSelection(startx, starty, m_compositeOp, dev, m_opacity, startx, starty, width, height);
     }
+    else
+        bltSelection(startx, starty, m_compositeOp, dev, m_opacity, startx, starty, width, height);
+
     delete shapeStrategy;
 
-    emit notifyProgressDone();
+    if (m_progressUpdater) m_progressUpdater->setProgress(100);
 
-    return !m_cancelRequested;
+return true;
+//    return !m_progressUpdater->interrupted();
 }
