@@ -87,7 +87,7 @@ public:
 
     KoUnit unit;
 
-    KoColorSpace * colorSpace;
+    const KoColorSpace * colorSpace;
 
     KisGroupLayerSP rootLayer; // The layers are contained in here
     QList<KisLayer*> dirtyLayers; // for thumbnails
@@ -100,14 +100,14 @@ public:
 
     vKisAnnotationSP annotations;
 
-    KisSelectionSP globalSelection;
+    KisSelectionSP globalSelection; // XXX_SELECTION: Use the selection from the root layer for this
 
 };
 
 
 
 
-KisImage::KisImage(KisUndoAdapter *adapter, qint32 width, qint32 height,  KoColorSpace * colorSpace, const QString& name)
+KisImage::KisImage(KisUndoAdapter *adapter, qint32 width, qint32 height, const KoColorSpace * colorSpace, const QString& name)
     : QObject(0)
     , KisShared()
     , m_d( new KisImagePrivate() )
@@ -189,7 +189,6 @@ void KisImage::nodeHasBeenAdded( KisNode *parent, int index )
         props.setProperty( "temporary", false );
 
         if ( !layer->check( props ) ) {
-
             emit sigLayerMoved( layer );
         }
     }
@@ -288,7 +287,7 @@ void KisImage::rollBackLayerName()
     m_d->nserver->rollback();
 }
 
-void KisImage::init(KisUndoAdapter *adapter, qint32 width, qint32 height,  KoColorSpace * colorSpace)
+void KisImage::init(KisUndoAdapter *adapter, qint32 width, qint32 height, const KoColorSpace * colorSpace)
 {
     if (colorSpace == 0) {
         colorSpace = KoColorSpaceRegistry::instance()->rgb8();
@@ -314,7 +313,7 @@ void KisImage::init(KisUndoAdapter *adapter, qint32 width, qint32 height,  KoCol
     m_d->width = width;
     m_d->height = height;
 
-    m_d->recorder = new KisActionRecorder;
+    m_d->recorder = new KisActionRecorder(this);
 }
 
 bool KisImage::locked() const
@@ -424,7 +423,7 @@ void KisImage::emitSizeChanged()
 }
 
 
-void KisImage::scale(double sx, double sy, KisProgressDisplayInterface *progress, KisFilterStrategy *filterStrategy)
+void KisImage::scale(double sx, double sy, KoUpdater *progress, KisFilterStrategy *filterStrategy)
 {
     QStringList list;
     list << "KisLayer";
@@ -473,7 +472,7 @@ void KisImage::scale(double sx, double sy, KisProgressDisplayInterface *progress
 
 
 
-void KisImage::rotate(double radians, KisProgressDisplayInterface *progress)
+void KisImage::rotate(double radians, KoUpdater *progress)
 {
     lock();
 
@@ -511,7 +510,7 @@ void KisImage::rotate(double radians, KisProgressDisplayInterface *progress)
     }
 }
 
-void KisImage::shear(double angleX, double angleY, KisProgressDisplayInterface *progress)
+void KisImage::shear(double angleX, double angleY, KoUpdater *progress)
 {
     const double pi=3.1415926535897932385;
 
@@ -563,7 +562,7 @@ void KisImage::shear(double angleX, double angleY, KisProgressDisplayInterface *
     }
 }
 
-void KisImage::convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
+void KisImage::convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
 {
     if ( m_d->colorSpace == dstColorSpace )
     {
@@ -572,7 +571,7 @@ void KisImage::convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransfor
 
     lock();
 
-    KoColorSpace * oldCs = m_d->colorSpace;
+    const KoColorSpace * oldCs = m_d->colorSpace;
 
     if (undo()) {
         m_d->adapter->beginMacro(i18n("Convert Image Type"));
@@ -594,7 +593,7 @@ void KisImage::convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransfor
     }
 }
 
-KoColorProfile * KisImage::profile() const
+const KoColorProfile * KisImage::profile() const
 {
     return colorSpace()->profile();
 }
@@ -603,13 +602,13 @@ void KisImage::setProfile(const KoColorProfile * profile)
 {
     if (profile == 0) return;
 
-    KoColorSpace * dstCs= KoColorSpaceRegistry::instance()->colorSpace( colorSpace()->id(),
+    const KoColorSpace * dstCs= KoColorSpaceRegistry::instance()->colorSpace( colorSpace()->id(),
                                                                                          profile);
     if (dstCs) {
 
         lock();
 
-        KoColorSpace * oldCs = colorSpace();
+        const KoColorSpace * oldCs = colorSpace();
         setColorSpace(dstCs);
         emit(sigProfileChanged(const_cast<KoColorProfile *>(profile)));
 
@@ -685,9 +684,12 @@ KisGroupLayerSP KisImage::rootLayer() const
 
 KisPaintDeviceSP KisImage::projection()
 {
+    m_d->projection->sync();
+    
     Q_ASSERT( m_d->rootLayer );
-    Q_ASSERT( m_d->rootLayer->projection() );
-    return m_d->rootLayer->projection();
+    KisPaintDeviceSP projection = m_d->rootLayer->projection();
+    Q_ASSERT( projection );
+    return projection;
 }
 
 bool KisImage::addLayer(KisLayerSP layer, KisGroupLayerSP group)
@@ -879,7 +881,7 @@ void KisImage::renderToPainter(qint32 srcX,
                                qint32 width,
                                qint32 height,
                                QPainter &painter,
-                               KoColorProfile *  monitorProfile,
+                               const KoColorProfile *  monitorProfile,
                                float exposure)
 {
     QImage img = convertToQImage(srcX, srcY, width, height, monitorProfile, exposure);
@@ -890,11 +892,11 @@ QImage KisImage::convertToQImage(qint32 x,
                                  qint32 y,
                                  qint32 w,
                                  qint32 h,
-                                 KoColorProfile * profile,
+                                 const KoColorProfile * profile,
                                  float exposure)
 {
     KisPaintDeviceSP dev = m_d->rootLayer->projection();
-    QImage img = dev->convertToQImage(profile, x, y, w, h, exposure);
+    QImage img = dev->convertToQImage(const_cast<KoColorProfile*>( profile ), x, y, w, h, exposure);
 
     if (!img.isNull()) {
 
@@ -921,8 +923,14 @@ QImage KisImage::convertToQImage(qint32 x,
 }
 
 
-QImage KisImage::convertToQImage(const QRect& r, const double xScale, const double yScale, KoColorProfile *profile, float exposure, KisSelectionSP mask)
+QImage KisImage::convertToQImage(const QRect& r, const double xScale, const double yScale, const KoColorProfile *profile, float exposure, KisSelectionSP mask)
 {
+    Q_UNUSED( mask )
+
+#ifdef __GNUC__
+    #warning "KisImage::convertToQImage: Implement direct rendering of current mask onto scaled image pixels"
+#endif
+
     if (r.isEmpty()) {
         return QImage();
     }
@@ -973,7 +981,7 @@ QImage KisImage::convertToQImage(const QRect& r, const double xScale, const doub
     t.restart();
     delete [] imageRow;
 
-    QImage image = colorSpace()->convertToQImage(scaledImageData, r.width(), r.height(), profile, KoColorConversionTransformation::IntentPerceptual, exposure);
+    QImage image = colorSpace()->convertToQImage(scaledImageData, r.width(), r.height(), const_cast<KoColorProfile*>( profile ), KoColorConversionTransformation::IntentPerceptual, exposure);
     delete [] scaledImageData;
 
 #ifdef WORDS_BIGENDIAN
@@ -1058,12 +1066,12 @@ void KisImage::slotSelectionChanged(const QRect& r)
     }
 }
 
-KoColorSpace * KisImage::colorSpace() const
+const KoColorSpace * KisImage::colorSpace() const
 {
     return m_d->colorSpace;
 }
 
-void KisImage::setColorSpace(KoColorSpace * colorSpace)
+void KisImage::setColorSpace(const KoColorSpace * colorSpace)
 {
     m_d->colorSpace = colorSpace;
     m_d->rootLayer->resetProjection();
@@ -1120,7 +1128,7 @@ void KisImage::removeAnnotation(const QString& type)
 
 vKisAnnotationSP_it KisImage::beginAnnotations()
 {
-    KoColorProfile * profile = colorSpace()->profile();
+    const KoColorProfile * profile = colorSpace()->profile();
     KisAnnotationSP annotation;
 
     if (profile)
@@ -1129,7 +1137,7 @@ vKisAnnotationSP_it KisImage::beginAnnotations()
         // XXX productName(), or just "ICC Profile"?
         if( profile->valid())
         {
-            KoIccColorProfile* iccprofile = dynamic_cast<KoIccColorProfile*>(profile);
+            const KoIccColorProfile* iccprofile = dynamic_cast<const KoIccColorProfile*>(profile);
             if (!iccprofile->rawData().isEmpty())
             {
                 annotation = new  KisAnnotation("icc", iccprofile->name(), iccprofile->rawData());
