@@ -46,7 +46,7 @@ class KisActionRecorder;
 class KisUndoAdapter;
 class KisFilterStrategy;
 class KoColorProfile;
-class KisProgressDisplayInterface;
+class KoUpdater;
 class KisPerspectiveGrid;
 
 /**
@@ -58,7 +58,7 @@ class KRITAIMAGE_EXPORT KisImage : public QObject, public KisNodeFacade, public
     Q_OBJECT
 
 public:
-    KisImage(KisUndoAdapter * adapter, qint32 width, qint32 height, KoColorSpace * colorSpace, const QString& name);
+    KisImage(KisUndoAdapter * adapter, qint32 width, qint32 height, const KoColorSpace * colorSpace, const QString& name);
     KisImage(const KisImage& rhs);
     virtual ~KisImage();
 
@@ -85,7 +85,7 @@ public:
                          qint32 width,
                          qint32 height,
                          QPainter &painter,
-                         KoColorProfile *profile,
+                         const KoColorProfile *profile,
                          float exposure = 0.0f);
 
     /**
@@ -95,7 +95,7 @@ public:
                            qint32 y1,
                            qint32 width,
                            qint32 height,
-                           KoColorProfile * profile,
+                           const KoColorProfile * profile,
                            float exposure = 0.0f);
 
      /**
@@ -118,7 +118,7 @@ public:
       */
      QImage convertToQImage(const QRect& r,
                             const double xScale, const double yScale,
-                            KoColorProfile *profile,
+                            const KoColorProfile *profile,
                             float exposure = 0.0f,
                             KisSelectionSP mask = 0);
 
@@ -199,25 +199,25 @@ public:
     /**
      * Execute a scale transform on all layers in this image.
      */
-    void scale(double sx, double sy, KisProgressDisplayInterface *m_progress, KisFilterStrategy *filterStrategy);
+    void scale(double sx, double sy, KoUpdater *m_progress, KisFilterStrategy *filterStrategy);
 
     /**
      * Execute a rotate transform on all layers in this image.
      */
-    void rotate(double radians, KisProgressDisplayInterface *m_progress);
+    void rotate(double radians, KoUpdater *m_progress);
 
     /**
      * Execute a shear transform on all layers in this image.
      */
-    void shear(double angleX, double angleY, KisProgressDisplayInterface *m_progress);
+    void shear(double angleX, double angleY, KoUpdater *m_progress);
 
     /**
      * Convert the image and all its layers to the dstColorSpace
      */
-    void convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual);
+    void convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual);
 
     // Get the profile associated with this image
-    KoColorProfile *  profile() const;
+    const KoColorProfile *  profile() const;
 
     /**
      * Set the profile of the image to the new profile and do the same for
@@ -260,7 +260,7 @@ public:
      * The default colorspace of this image: new layers will have this colorspace
      * and the projection will have this colorspace.
      */
-    KoColorSpace * colorSpace() const;
+    const KoColorSpace * colorSpace() const;
 
     /**
      * X resolution in pixels per pt
@@ -439,7 +439,7 @@ public:
     */
     void notifyLayerUpdated(KisLayerSP layer);
 
-    void setColorSpace(KoColorSpace * colorSpace);
+    void setColorSpace(const KoColorSpace * colorSpace);
     void setRootLayer(KisGroupLayerSP rootLayer);
 
     /**
@@ -496,7 +496,7 @@ signals:
 
     void sigSizeChanged(qint32 w, qint32 h);
     void sigProfileChanged(KoColorProfile *  profile);
-    void sigColorSpaceChanged(KoColorSpace*  cs);
+    void sigColorSpaceChanged(const KoColorSpace*  cs);
 
     /**
      * Inform the model that we're going to add a layer.
@@ -524,15 +524,10 @@ public slots:
     void slotSelectionChanged(const QRect& r);
 
    void slotProjectionUpdated( const QRect & rc );
-    /**
-       Called whenever a KisCommand has been executed. This notifies
-       the layers, who then notify the layerbox that they are ready
-       for new thumbnails
-    */
 
 private:
     KisImage& operator=(const KisImage& rhs);
-    void init(KisUndoAdapter * adapter, qint32 width, qint32 height,  KoColorSpace * colorSpace);
+    void init(KisUndoAdapter * adapter, qint32 width, qint32 height, const KoColorSpace * colorSpace);
     void emitSizeChanged();
     void preparePaintLayerAfterAdding( KisLayerSP layer );
 
