@@ -29,7 +29,7 @@
 #include <QThread>
 #include <threadweaver/ThreadWeaver.h>
 #include <klocale.h>
-#include <kdebug.h>
+#include <kconfiggroup.h>
 
 #include "KoColorProfile.h"
 #include "KoColor.h"
@@ -50,7 +50,7 @@
 #include "kis_random_accessor.h"
 #include "kis_random_sub_accessor.h"
 #include "kis_selection.h"
-#include "kis_layer.h"
+#include "kis_node.h"
 #include "kis_painterly_overlay.h"
 #include "kis_paint_device.h"
 #include "kis_datamanager.h"
@@ -66,17 +66,12 @@ class KisPaintDevice::Private {
 
 public:
 
-    KisLayerWSP parentLayer;
+    KisNodeWSP parent;
     qint32 x;
     qint32 y;
-    KoColorSpace * colorSpace;
+    const KoColorSpace * colorSpace;
     qint32 pixelSize;
     qint32 nChannels;
-    // The selection is a read/write mask. Pixels that are not selected should be skipped
-    mutable bool hasSelection;
-    mutable bool selectionDeselected;
-    mutable KisSelectionSP selection;
-
     QPaintEngine * paintEngine;
 
 #ifdef CACHE_EXACT_BOUNDS
@@ -87,88 +82,13 @@ public:
 
 };
 
-
-namespace {
-
-    class KisPaintDeviceCommand : public QUndoCommand {
-        typedef QUndoCommand super;
-
-    public:
-        KisPaintDeviceCommand(const QString& name, KisPaintDeviceSP paintDevice);
-        virtual ~KisPaintDeviceCommand() {}
-
-    protected:
-        void setUndo(bool undo);
-
-        KisPaintDeviceSP m_paintDevice;
-    };
-
-    KisPaintDeviceCommand::KisPaintDeviceCommand(const QString& name, KisPaintDeviceSP paintDevice) :
-        super(name), m_paintDevice(paintDevice)
-    {
-    }
-
-    void KisPaintDeviceCommand::setUndo(bool undo)
-    {
-        if (m_paintDevice->undoAdapter()) {
-            m_paintDevice->undoAdapter()->setUndo(undo);
-        }
-    }
-
-    class KisConvertLayerTypeCmd : public KisPaintDeviceCommand {
-        typedef KisPaintDeviceCommand super;
-
-    public:
-        KisConvertLayerTypeCmd(KisPaintDeviceSP paintDevice,
-                       KisDataManagerSP beforeData, KoColorSpace * beforeColorSpace,
-                       KisDataManagerSP afterData, KoColorSpace * afterColorSpace
-                ) : super(i18n("Convert Layer Type"), paintDevice)
-            {
-                m_beforeData = beforeData;
-                m_beforeColorSpace = beforeColorSpace;
-                m_afterData = afterData;
-                m_afterColorSpace = afterColorSpace;
-            }
-
-        virtual ~KisConvertLayerTypeCmd()
-            {
-            }
-
-    public:
-        virtual void redo()
-            {
-                setUndo(false);
-                m_paintDevice->setDataManager(m_afterData, m_afterColorSpace);
-                setUndo(true);
-            }
-
-        virtual void undo()
-            {
-                setUndo(false);
-                m_paintDevice->setDataManager(m_beforeData, m_beforeColorSpace);
-                setUndo(true);
-            }
-
-    private:
-        KisDataManagerSP m_beforeData;
-        KoColorSpace * m_beforeColorSpace;
-
-        KisDataManagerSP m_afterData;
-        KoColorSpace * m_afterColorSpace;
-    };
-
-}
-
-KisPaintDevice::KisPaintDevice(KoColorSpace * colorSpace, const QString& name)
+KisPaintDevice::KisPaintDevice(const KoColorSpace * colorSpace, const QString& name)
     : QObject(0)
     , m_d( new Private() )
 {
     setObjectName(name);
 
-    if (colorSpace == 0) {
-        kWarning(41001) << "Cannot create paint device without colorspace!\n";
-        return;
-    }
+    Q_ASSERT(colorSpace);
 
     m_d->x = 0;
     m_d->y = 0;
@@ -184,18 +104,15 @@ KisPaintDevice::KisPaintDevice(KoColorSpace * colorSpace, const QString& name)
 
     Q_CHECK_PTR(m_datamanager);
 
-    m_d->parentLayer = 0;
+    m_d->parent = 0;
 
     m_d->colorSpace = colorSpace;
 
-    m_d->hasSelection = false;
-    m_d->selectionDeselected = false;
-    m_d->selection = 0;
     m_d->paintEngine = new KisPaintEngine();
 
 }
 
-KisPaintDevice::KisPaintDevice(KisLayerWSP parent, KoColorSpace * colorSpace, const QString& name)
+KisPaintDevice::KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, const QString& name)
     : QObject(0)
     , m_d( new Private() )
 {
@@ -205,18 +122,9 @@ KisPaintDevice::KisPaintDevice(KisLayerWSP parent, KoColorSpace * colorSpace, co
     m_d->x = 0;
     m_d->y = 0;
 
-    m_d->hasSelection = false;
-    m_d->selectionDeselected = false;
-    m_d->selection = 0;
+    m_d->parent = parent;
 
-    m_d->parentLayer = parent;
-
-    if (colorSpace == 0 && parent != 0 && parent->image() != 0) {
-        m_d->colorSpace = parent->image()->colorSpace();
-    }
-    else {
-        m_d->colorSpace = colorSpace;
-    }
+    m_d->colorSpace = colorSpace;
 
     m_d->pixelSize = m_d->colorSpace->pixelSize();
     m_d->nChannels = m_d->colorSpace->channelCount();
@@ -239,7 +147,7 @@ KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs)
     , m_d( new Private() )
 {
     if (this != &rhs) {
-        m_d->parentLayer = 0;
+        m_d->parent = 0;
         if (rhs.m_datamanager) {
             m_datamanager = new KisDataManager(*rhs.m_datamanager);
             Q_CHECK_PTR(m_datamanager);
@@ -250,8 +158,6 @@ KisPaintDevice::KisPaintDevice(const KisPaintDevice& rhs)
         m_d->x = rhs.m_d->x;
         m_d->y = rhs.m_d->y;
         m_d->colorSpace = rhs.m_d->colorSpace;
-        m_d->hasSelection = false;
-        m_d->selection = 0;
 
         m_d->pixelSize = rhs.m_d->pixelSize;
 
@@ -329,8 +235,8 @@ void KisPaintDevice::setDirty(const QRect & rc)
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds |= rc;
 #endif
-    if ( m_d->parentLayer.isValid() )
-        m_d->parentLayer->setDirty( rc );
+    if ( m_d->parent.isValid() )
+        m_d->parent->setDirty( rc );
 }
 
 void KisPaintDevice::setDirty( const QRegion & region )
@@ -338,27 +244,16 @@ void KisPaintDevice::setDirty( const QRegion & region )
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds |= region.boundingRect();
 #endif
-    if ( m_d->parentLayer.isValid() )
-        m_d->parentLayer->setDirty( region );
+    if ( m_d->parent.isValid() )
+        m_d->parent->setDirty( region );
 }
 
 void KisPaintDevice::setDirty()
 {
-    if ( m_d->parentLayer.isValid() )
-        m_d->parentLayer->setDirty();
+    if ( m_d->parent.isValid() )
+        m_d->parent->setDirty();
 }
 
-KisImageSP KisPaintDevice::image() const
-{
-    if ( m_d->parentLayer.isValid() ) {
-        if ( m_d->parentLayer ) {
-            return m_d->parentLayer->image();
-        }
-    }
-    return 0;
-}
-
-
 void KisPaintDevice::move(qint32 x, qint32 y)
 {
     QRect dirtyRegion = extent();
@@ -368,12 +263,6 @@ void KisPaintDevice::move(qint32 x, qint32 y)
 
     dirtyRegion |= extent();
 
-    if(m_d->selection)
-    {
-        m_d->selection->setX(x);
-        m_d->selection->setY(y);
-    }
-
     setDirty(dirtyRegion);
 
 }
@@ -527,21 +416,21 @@ void KisPaintDevice::clear( const QRect & rc )
     m_datamanager->clear( rc.x(), rc.y(), rc.width(), rc.height(), m_datamanager->defaultPixel() );
 }
 
-void KisPaintDevice::mirrorX()
+void KisPaintDevice::mirrorX( KisSelection * selection )
 {
     KisPaintDeviceSP dst = this;
     if ( !m_datamanager->hasCurrentMemento() )
         dst = new KisPaintDevice( colorSpace() );
 
     QRect r;
-    if (hasSelection()) {
-        r = selection()->selectedExactRect();
+    if ( selection ) {
+        r = selection->selectedExactRect();
     }
     else {
         r = exactBounds();
     }
     {
-        KisHLineConstIteratorPixel srcIt = createHLineConstIterator(r.x(), r.top(), r.width());
+        KisHLineConstIteratorPixel srcIt = createHLineConstIterator(r.x(), r.top(), r.width(), selection);
         KisHLineIteratorPixel dstIt = dst->createHLineIterator(r.x(), r.top(), r.width());
 
         for (qint32 y = r.top(); y <= r.bottom(); ++y) {
@@ -569,7 +458,7 @@ void KisPaintDevice::mirrorX()
     setDirty(r);
 }
 
-void KisPaintDevice::mirrorY()
+void KisPaintDevice::mirrorY( KisSelection * selection )
 {
     KisPaintDeviceSP dst = this;
     if ( !m_datamanager->hasCurrentMemento() )
@@ -577,8 +466,8 @@ void KisPaintDevice::mirrorY()
 
     /* Read a line from bottom to top and and from top to bottom and write their values to each other */
     QRect r;
-    if (hasSelection()) {
-        r = selection()->selectedExactRect();
+    if ( selection ) {
+        r = selection->selectedExactRect();
     }
     else {
         r = exactBounds();
@@ -587,7 +476,7 @@ void KisPaintDevice::mirrorY()
     qint32 y1, y2;
     for (y1 = r.top(), y2 = r.bottom(); y1 <= r.bottom(); ++y1, --y2) {
 
-        KisHLineIteratorPixel itTop = dst->createHLineIterator(r.x(), y1, r.width());
+        KisHLineIteratorPixel itTop = dst->createHLineIterator(r.x(), y1, r.width(), selection);
         KisHLineConstIteratorPixel itBottom = createHLineConstIterator(r.x(), y2, r.width());
 
         while (!itTop.isDone() && !itBottom.isDone()) {
@@ -624,7 +513,7 @@ bool KisPaintDevice::read(KoStore *store)
         return retval;
 }
 
-void KisPaintDevice::convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
+void KisPaintDevice::convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent)
 {
     if (   colorSpace()->id() == dstColorSpace->id()
         && colorSpace()->profile() == dstColorSpace->profile() )
@@ -723,31 +612,32 @@ void KisPaintDevice::convertTo(KoColorSpace * dstColorSpace, KoColorConversionTr
     }
 
     KisDataManagerSP oldData = m_datamanager;
-    KoColorSpace *oldColorSpace = m_d->colorSpace;
+    const KoColorSpace *oldColorSpace = m_d->colorSpace;
 
     setDataManager(dst.m_datamanager, dstColorSpace);
 
-    if (undoAdapter() && undoAdapter()->undo()) {
-        undoAdapter()->addCommand(new KisConvertLayerTypeCmd(KisPaintDeviceSP(this), oldData, oldColorSpace, m_datamanager, m_d->colorSpace));
-    }
+// XXX: make undoable
+//     if (undoAdapter() && undoAdapter()->undo()) {
+//         undoAdapter()->addCommand(new KisConvertLayerTypeCmd(KisPaintDeviceSP(this), oldData, oldColorSpace, m_datamanager, m_d->colorSpace));
+//     }
 
     delete weaver;
     // XXX: emit colorSpaceChanged(dstColorSpace);
 }
 
-void KisPaintDevice::setProfile(KoColorProfile * profile)
+void KisPaintDevice::setProfile(const KoColorProfile * profile)
 {
     if (profile == 0) return;
 
-    KoColorSpace * dstSpace =
+    const KoColorSpace * dstSpace =
             KoColorSpaceRegistry::instance()->colorSpace( colorSpace()->id(),
-                                                                      profile);
+                                                                      const_cast<KoColorProfile*>(profile)); // FIXME don't const_cast and anyway should clone when cloning is available
     if (dstSpace)
         m_d->colorSpace = dstSpace;
     emit profileChanged(profile);
 }
 
-void KisPaintDevice::setDataManager(KisDataManagerSP data, KoColorSpace * colorSpace)
+void KisPaintDevice::setDataManager(KisDataManagerSP data, const KoColorSpace * colorSpace)
 {
     m_datamanager = data;
     m_d->colorSpace = colorSpace;
@@ -755,23 +645,12 @@ void KisPaintDevice::setDataManager(KisDataManagerSP data, KoColorSpace * colorS
     m_d->nChannels = m_d->colorSpace->channelCount();
 
     setDirty(extent());
-//         m_d->parentLayer->notifyPropertyChanged();
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds = extent();
 #endif
 
 }
 
-KisUndoAdapter *KisPaintDevice::undoAdapter() const
-{
-    if ( m_d->parentLayer.isValid() ) {
-        if (m_d->parentLayer && m_d->parentLayer->image()) {
-            return m_d->parentLayer->image()->undoAdapter();
-        }
-    }
-    return 0;
-}
-
 void KisPaintDevice::convertFromQImage(const QImage& image, const QString &srcProfileName,
                                        qint32 offsetX, qint32 offsetY)
 {
@@ -811,7 +690,7 @@ void KisPaintDevice::convertFromQImage(const QImage& image, const QString &srcPr
 //    }
 }
 
-QImage KisPaintDevice::convertToQImage(KoColorProfile *  dstProfile, float exposure)
+QImage KisPaintDevice::convertToQImage(const KoColorProfile *  dstProfile, float exposure)
 {
     qint32 x1;
     qint32 y1;
@@ -821,22 +700,16 @@ QImage KisPaintDevice::convertToQImage(KoColorProfile *  dstProfile, float expos
     x1 = - x();
     y1 = - y();
 
-    if (image()) {
-        w = image()->width();
-        h = image()->height();
-    }
-    else {
-        QRect rc = exactBounds();
-        x1 = rc.x();
-        y1 = rc.y();
-        w = rc.width();
-        h = rc.height();
-    }
+    QRect rc = exactBounds();
+    x1 = rc.x();
+    y1 = rc.y();
+    w = rc.width();
+    h = rc.height();
 
     return convertToQImage(dstProfile, x1, y1, w, h, exposure);
 }
 
-QImage KisPaintDevice::convertToQImage(KoColorProfile *  dstProfile, qint32 x1, qint32 y1, qint32 w, qint32 h, float exposure)
+QImage KisPaintDevice::convertToQImage(const KoColorProfile *  dstProfile, qint32 x1, qint32 y1, qint32 w, qint32 h, float exposure)
 {
     if (w < 0)
         return QImage();
@@ -870,17 +743,9 @@ KisPaintDeviceSP KisPaintDevice::createThumbnailDevice(qint32 w, qint32 h) const
     thumbnail->clear();
 
     int srcw, srch;
-    if( image() )
-    {
-        srcw = image()->width();
-        srch = image()->height();
-    }
-    else
-    {
-        const QRect e = exactBounds();
-        srcw = e.width();
-        srch = e.height();
-    }
+    const QRect e = extent();
+    srcw = e.width();
+    srch = e.height();
 
     if (w > srcw)
     {
@@ -938,31 +803,31 @@ QImage KisPaintDevice::createThumbnail(qint32 w, qint32 h)
     return dev->convertToQImage( KoColorSpaceRegistry::instance()->rgb8()->profile() );
 }
 
-KisRectIteratorPixel KisPaintDevice::createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h)
+KisRectIteratorPixel KisPaintDevice::createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection)
 {
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds &= QRect( left, top, w, h );
 #endif
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = m_d->selection->m_datamanager.data();
+    if ( selection )
+        selectionDm = selection->dataManager().data();
 
     return KisRectIteratorPixel(m_datamanager.data(), selectionDm, left, top, w, h, m_d->x, m_d->y);
 }
 
-KisRectConstIteratorPixel KisPaintDevice::createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h) const
+KisRectConstIteratorPixel KisPaintDevice::createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection) const
 {
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = const_cast< KisDataManager*>(m_d->selection->m_datamanager.data());
+    if(selection)
+        selectionDm = const_cast< KisDataManager*>(selection->dataManager().data());
 
     return KisRectConstIteratorPixel(dm, selectionDm, left, top, w, h, m_d->x, m_d->y);
 }
 
-KisHLineIteratorPixel  KisPaintDevice::createHLineIterator(qint32 x, qint32 y, qint32 w)
+KisHLineIteratorPixel  KisPaintDevice::createHLineIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection)
 {
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds &= QRect( x, y, w, 1 );
@@ -970,24 +835,24 @@ KisHLineIteratorPixel  KisPaintDevice::createHLineIterator(qint32 x, qint32 y, q
 
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = m_d->selection->m_datamanager.data();
+    if(selection)
+        selectionDm = selection->dataManager().data();
 
     return KisHLineIteratorPixel(m_datamanager.data(), selectionDm, x, y, w, m_d->x, m_d->y);
 }
 
-KisHLineConstIteratorPixel  KisPaintDevice::createHLineConstIterator(qint32 x, qint32 y, qint32 w) const
+KisHLineConstIteratorPixel  KisPaintDevice::createHLineConstIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection) const
 {
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = const_cast< KisDataManager*>(m_d->selection->m_datamanager.data());
+    if(selection)
+        selectionDm = const_cast< KisDataManager*>(selection->dataManager().data());
 
     return KisHLineConstIteratorPixel(dm, selectionDm, x, y, w, m_d->x, m_d->y);
 }
 
-KisVLineIteratorPixel  KisPaintDevice::createVLineIterator(qint32 x, qint32 y, qint32 h)
+KisVLineIteratorPixel  KisPaintDevice::createVLineIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection)
 {
 #ifdef CACHE_EXACT_BOUNDS
     m_d->exactBounds &= QRect( x, y, 1, h );
@@ -995,142 +860,58 @@ KisVLineIteratorPixel  KisPaintDevice::createVLineIterator(qint32 x, qint32 y, q
 
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = m_d->selection->m_datamanager.data();
+    if(selection)
+        selectionDm = selection->dataManager().data();
 
     return KisVLineIteratorPixel(m_datamanager.data(), selectionDm, x, y, h, m_d->x, m_d->y);
 }
 
-KisVLineConstIteratorPixel  KisPaintDevice::createVLineConstIterator(qint32 x, qint32 y, qint32 h) const
+KisVLineConstIteratorPixel  KisPaintDevice::createVLineConstIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection) const
 {
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = const_cast< KisDataManager*>(m_d->selection->m_datamanager.data());
+    if(selection)
+        selectionDm = const_cast< KisDataManager*>(selection->dataManager().data());
 
     return KisVLineConstIteratorPixel(dm, selectionDm, x, y, h, m_d->x, m_d->y);
 }
 
-KisRandomAccessorPixel KisPaintDevice::createRandomAccessor(qint32 x, qint32 y)
+KisRandomAccessorPixel KisPaintDevice::createRandomAccessor(qint32 x, qint32 y, const KisSelection * selection)
 {
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = m_d->selection->m_datamanager.data();
+    if(selection)
+        selectionDm = selection->dataManager().data();
 
     return KisRandomAccessorPixel(m_datamanager.data(), selectionDm, x, y, m_d->x, m_d->y);
 }
 
-KisRandomConstAccessorPixel KisPaintDevice::createRandomConstAccessor(qint32 x, qint32 y) const {
+KisRandomConstAccessorPixel KisPaintDevice::createRandomConstAccessor(qint32 x, qint32 y, const KisSelection * selection) const
+{
     KisDataManager* dm = const_cast< KisDataManager*>(m_datamanager.data()); // TODO: don't do this
     KisDataManager* selectionDm = 0;
 
-    if(hasSelection())
-        selectionDm = const_cast< KisDataManager*>(m_d->selection->m_datamanager.data());
+    if(selection)
+        selectionDm = const_cast< KisDataManager*>(selection->dataManager().data());
 
     return KisRandomConstAccessorPixel(dm, selectionDm, x, y, m_d->x, m_d->y);
 }
 
-KisRandomSubAccessorPixel KisPaintDevice::createRandomSubAccessor() const
+KisRandomSubAccessorPixel KisPaintDevice::createRandomSubAccessor( const KisSelection * selection ) const
 {
     KisPaintDevice* pd = const_cast<KisPaintDevice*>(this);
     return KisRandomSubAccessorPixel(pd);
 }
 
-void KisPaintDevice::emitSelectionChanged()
+void KisPaintDevice::clearSelection( KisSelectionSP selection )
 {
-    if ( m_d->parentLayer.isValid() ) {
-        if (m_d->parentLayer && m_d->parentLayer->image()) {
-            m_d->parentLayer->image()->slotSelectionChanged();
-        }
-
-        if (m_d->selection)
-            m_d->selection->updateProjection();
-    }
-}
-
-void KisPaintDevice::emitSelectionChanged(const QRect& r)
-{
-    if ( m_d->parentLayer.isValid() ) {
-        if (m_d->parentLayer  && m_d->parentLayer->image()) {
-            m_d->parentLayer->image()->slotSelectionChanged(r);
-        }
-    }
-    if (m_d->selection)
-        m_d->selection->updateProjection(r);
-}
-
-KisSelectionSP KisPaintDevice::selection()
-{
-    // XXX: Fix when we fix the API
-
-    if ( m_d->selectionDeselected && m_d->selection ) {
-        m_d->selectionDeselected = false;
-    }
-    else if (!m_d->selection) {
-        m_d->selection = KisSelectionSP(new KisSelection(KisPaintDeviceSP(this)));
-        Q_CHECK_PTR(m_d->selection);
-        m_d->selection->setX(m_d->x);
-        m_d->selection->setY(m_d->y);
-    }
-    m_d->hasSelection = true;
-
-    return m_d->selection;
-}
-
-const KisSelectionSP KisPaintDevice::selection() const
-{
-    if ( m_d->selectionDeselected && m_d->selection ) {
-        m_d->selectionDeselected = false;
-    }
-    else if (!m_d->selection) {
-        m_d->selection = KisSelectionSP(new KisSelection(const_cast<KisPaintDevice*>(this)));
-        Q_CHECK_PTR(m_d->selection);
-        m_d->selection->setX(m_d->x);
-        m_d->selection->setY(m_d->y);
-    }
-    m_d->hasSelection = true;
-
-    return m_d->selection;
-}
-
-
-bool KisPaintDevice::hasSelection() const
-{
-    return m_d->hasSelection;
-}
-
-bool KisPaintDevice::selectionDeselected()
-{
-    return m_d->selectionDeselected;
-}
-
-
-void KisPaintDevice::deselect()
-{
-    if (m_d->selection && m_d->hasSelection) {
-        m_d->hasSelection = false;
-        m_d->selectionDeselected = true;
-    }
-}
-
-void KisPaintDevice::reselect()
-{
-    m_d->hasSelection = true;
-    m_d->selectionDeselected = false;
-}
-
-void KisPaintDevice::clearSelection()
-{
-    if (!hasSelection()) return;
-
-    QRect r = m_d->selection->selectedExactRect();
+    QRect r = selection->selectedExactRect();
 
     if (r.isValid()) {
 
         KisHLineIterator devIt = createHLineIterator(r.x(), r.y(), r.width());
-        KisHLineConstIterator selectionIt = m_d->selection->createHLineIterator(r.x(), r.y(), r.width());
+        KisHLineConstIterator selectionIt = selection->createHLineIterator(r.x(), r.y(), r.width());
 
         for (qint32 y = 0; y < r.height(); y++) {
 
@@ -1173,17 +954,6 @@ void KisPaintDevice::applySelectionMask(KisSelectionSP mask)
     }
 }
 
-KisSelectionSP KisPaintDevice::setSelection( KisSelectionSP selection)
-{
-    if (selection) {
-        KisSelectionSP oldSelection = m_d->selection;
-        m_d->selection = selection;
-        m_d->hasSelection = true;
-        return oldSelection;
-    }
-    else return KisSelectionSP(0);
-}
-
 bool KisPaintDevice::pixel(qint32 x, qint32 y, QColor *c, quint8 *opacity)
 {
     KisHLineConstIteratorPixel iter = createHLineIterator(x, y, 1);
@@ -1262,15 +1032,11 @@ qint32 KisPaintDevice::rowStride(qint32 x, qint32 y) const
 void KisPaintDevice::setX(qint32 x)
 {
     m_d->x = x;
-    if(m_d->selection && m_d->selection.data() != this)
-        m_d->selection->setX(x);
 }
 
 void KisPaintDevice::setY(qint32 y)
 {
     m_d->y = y;
-    if(m_d->selection && m_d->selection.data() != this)
-        m_d->selection->setY(y);
 }
 
 
@@ -1327,7 +1093,7 @@ quint32 KisPaintDevice::channelCount() const
 ;
 }
 
-KoColorSpace * KisPaintDevice::colorSpace() const
+const KoColorSpace * KisPaintDevice::colorSpace() const
 {
     Q_ASSERT(m_d->colorSpace != 0);
     return m_d->colorSpace;
