@@ -28,16 +28,19 @@
 #include <QPaintDevice>
 #include <QPaintEngine>
 
-#include "kis_types.h"
 #include "kdebug.h"
-#include "kis_global.h"
-#include "kis_image.h"
+
 #include "KoColorSpace.h"
 #include "KoColor.h"
-#include <krita_export.h>
+
+#include "kis_types.h"
+#include "kis_global.h"
+#include "kis_image.h"
 #include <kis_shared.h>
 #include "kis_iterators_pixel.h"
 
+#include <krita_export.h>
+
 class QRect;
 class QImage;
 class QPoint;
@@ -76,17 +79,17 @@ public:
      * @param colorSpace the colorspace of this paint device
      * @param name for debugging purposes
      */
-    KisPaintDevice(KoColorSpace * colorSpace, const QString& name = QString());
+    KisPaintDevice(const KoColorSpace * colorSpace, const QString& name = QString());
 
     /**
      * Create a new paint device with the specified colorspace. The
-     * parentLayer will be notified of changes to this paint device.
+     * parent node will be notified of changes to this paint device.
      *
-     * @param parentLayer the layer that contains this paint device.
+     * @param parent the node that contains this paint device.
      * @param colorSpace the colorspace of this paint device
      * @param name for debugging purposes
      */
-    KisPaintDevice(KisLayerWSP parentLayer, KoColorSpace * colorSpace, const QString& name = QString());
+    KisPaintDevice(KisNodeWSP parent, const KoColorSpace * colorSpace, const QString& name = QString());
 
     KisPaintDevice(const KisPaintDevice& rhs);
     virtual ~KisPaintDevice();
@@ -194,17 +197,20 @@ public:
     void crop(const QRect & r);
 
     /**
-     * Complete erase the current paint device. Its size will become 0.
+     * Complete erase the current paint device. Its size will become 0. This
+     * does not take the selection into account.
      */
     virtual void clear();
 
     /**
-     * Clear the given rectangle to transparent black
+     * Clear the given rectangle to transparent black. This does not take the selection
+     * into account.
      */
     void clear( const QRect & rc );
 
     /**
-     * Fill the given rectangle with the given pixel.
+     * Fill the given rectangle with the given pixel. This does not take the
+     * selection into account.
      */
     void fill(qint32 x, qint32 y, qint32 w, qint32 h, const quint8 *fillPixel);
 
@@ -284,13 +290,13 @@ public:
     /**
      *   Converts the paint device to a different colorspace
      */
-    void convertTo(KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual);
+    void convertTo(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual);
 
     /**
      * Changes the profile of the colorspace of this paint device to the given
      * profile. If the given profile is 0, nothing happens.
      */
-    void setProfile(KoColorProfile * profile);
+    void setProfile(const KoColorProfile * profile);
 
     /**
      * Fill this paint device with the data from img; starting at (offsetX, offsetY)
@@ -310,7 +316,7 @@ public:
      * like sRGB).
      * @param exposure The exposure setting used to render a preview of a high dynamic range image.
      */
-    virtual QImage convertToQImage(KoColorProfile *  dstProfile, qint32 x, qint32 y, qint32 w, qint32 h, float exposure = 0.0f);
+    virtual QImage convertToQImage(const KoColorProfile *  dstProfile, qint32 x, qint32 y, qint32 w, qint32 h, float exposure = 0.0f);
 
     /**
      * Create an RGBA QImage from a rectangle in the paint device. The
@@ -321,7 +327,7 @@ public:
      * like sRGB).
      * @param exposure The exposure setting used to render a preview of a high dynamic range image.
      */
-    virtual QImage convertToQImage(KoColorProfile *  dstProfile, float exposure = 0.0f);
+    virtual QImage convertToQImage(const KoColorProfile *  dstProfile, float exposure = 0.0f);
 
     /**
      * Creates a paint device thumbnail of the paint device, retaining
@@ -388,7 +394,7 @@ public:
     /**
      * @return the colorspace of the pixels in this paint device
      */
-    KoColorSpace * colorSpace() const;
+    const KoColorSpace * colorSpace() const;
 
     /**
      * @return the internal datamanager that keeps the pixels.
@@ -398,7 +404,7 @@ public:
     /**
      * Replace the pixel data, color strategy, and profile.
      */
-    void setDataManager(KisDataManagerSP data, KoColorSpace * colorSpace);
+    void setDataManager(KisDataManagerSP data, const KoColorSpace * colorSpace);
 
     /**
      * Return the number of bytes a pixel takes.
@@ -456,11 +462,11 @@ public:
     /**
      * Mirror the device along the X axis
      */
-    void mirrorX();
+    void mirrorX( KisSelection * selection = 0);
     /**
      * Mirror the device along the Y axis
      */
-    void mirrorY();
+    void mirrorY( KisSelection * selection = 0);
 
     /**
      * Create an iterator over a rectangle section of a paint device, the path followed by
@@ -468,9 +474,10 @@ public:
      * use this type of iterator if you are combining two differents layers.
      * @param w width
      * @param h height
+     * @param selection an up-to-date selection that has the same origin as the paint device
      * @return an iterator which points to the first pixel of an rectangle
      */
-    KisRectIteratorPixel createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h);
+    KisRectIteratorPixel createRectIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection = 0);
 
     /**
      * Create an iterator over a rectangle section of a paint device, the path followed by
@@ -478,82 +485,63 @@ public:
      * use this type of iterator if you are combining two differents layers.
      * @param w width
      * @param h height
-     * @return an iterator which points to the first pixel of an rectangle, this iterator
+     * @param selection an up-to-date selection that has the same origin as the paint device* @return an iterator which points to the first pixel of an rectangle, this iterator
      * does not allow to change the pixel values
      */
-    KisRectConstIteratorPixel createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h) const;
+    KisRectConstIteratorPixel createRectConstIterator(qint32 left, qint32 top, qint32 w, qint32 h, const KisSelection * selection = 0) const;
 
     /**
+     * @param selection an up-to-date selection that has the same origin as the paint device
      * @return an iterator which points to the first pixel of a horizontal line, this iterator
      * does not allow to change the pixel values
      */
-    KisHLineConstIteratorPixel createHLineConstIterator(qint32 x, qint32 y, qint32 w) const;
+    KisHLineConstIteratorPixel createHLineConstIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection = 0) const;
 
     /**
+    * @param selection an up-to-date selection that has the same origin as the paint device
      * @return an iterator which points to the first pixel of a horizontal line
      */
-    KisHLineIteratorPixel createHLineIterator(qint32 x, qint32 y, qint32 w);
+    KisHLineIteratorPixel createHLineIterator(qint32 x, qint32 y, qint32 w, const KisSelection * selection = 0);
 
     /**
+     * @param selection an up-to-date selection that has the same origin as the paint device
      * This function return an iterator which points to the first pixel of a vertical line
      */
-    KisVLineIteratorPixel createVLineIterator(qint32 x, qint32 y, qint32 h);
+    KisVLineIteratorPixel createVLineIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection = 0);
 
     /**
+     * @param selection an up-to-date selection that has the same origin as the paint device
      * This function return an iterator which points to the first pixel of a vertical line
      */
-    KisVLineConstIteratorPixel createVLineConstIterator(qint32 x, qint32 y, qint32 h) const;
+    KisVLineConstIteratorPixel createVLineConstIterator(qint32 x, qint32 y, qint32 h, const KisSelection * selection = 0) const;
 
     /**
      * This function creates a random accessor which allow to randomly access any pixels on
      * the paint device.
      * <b>Note:</b> random access is way slower than iterators, always use iterators whenever
-     * you can
+     * you can.
+     * @param selection an up-to-date selection that has the same origin as the paint device
      */
-    KisRandomAccessorPixel createRandomAccessor(qint32 x, qint32 y);
+    KisRandomAccessorPixel createRandomAccessor(qint32 x, qint32 y, const KisSelection * selection = 0);
 
     /**
      * This function creates a random accessor which allow to randomly access any pixels on
      * the paint device.
      * <b>Note:</b> random access is way slower than iterators, always use iterators whenever
-     * you can
+     * you can.
+     * @param selection an up-to-date selection that has the same origin as the paint device
      */
-    KisRandomConstAccessorPixel createRandomConstAccessor(qint32 x, qint32 y) const;
+    KisRandomConstAccessorPixel createRandomConstAccessor(qint32 x, qint32 y, const KisSelection * selection = 0) const;
 
     /**
      * This function create a random accessor which can easily access to sub pixel values.
+     * @param selection an up-to-date selection that has the same origin as the paint device
      */
-    KisRandomSubAccessorPixel createRandomSubAccessor() const;
+    KisRandomSubAccessorPixel createRandomSubAccessor( const KisSelection * selection = 0) const;
 
-public:
-
-    /**
-     * @return the current selection or create one if this paintdevice
-     * hasn't got a selection yet.
-     */
-    KisSelectionSP selection();
-
-    /**
-     * @return the current selection or create one if this
-     * paintdevice hasn't got a selection yet.
-     */
-    const KisSelectionSP selection() const;
-
-
-    /** Whether there is a valid selection for this paintdevice. */
-    bool hasSelection() const;
-
-   /** Whether the previous selection was deselected. */
-    bool selectionDeselected();
-
-    /** Deselect the selection for this paintdevice. */
-    void deselect();
-
-    /** Reinstates the old selection */
-    void reselect();
 
     /** Clear the selected pixels from the paint device */
-    void clearSelection();
+    void clearSelection( KisSelectionSP selection);
 
     /**
      * Apply a mask to the image data, i.e. multiply each pixel's opacity by its
@@ -561,44 +549,11 @@ public:
      */
     void applySelectionMask(KisSelectionSP mask);
 
-
-    /**
-     * Sets the selection of this paint device to the new selection,
-     * returns the old selection, if there was an old selection,
-     * otherwise 0
-     */
-    KisSelectionSP setSelection(KisSelectionSP selection);
-
-    /**
-     * Notify the owning image that the current selection has changed.
-     */
-    void emitSelectionChanged();
-
-
-    /**
-     * Notify the owning image that the current selection has changed.
-     *
-     * @param r the area for which the selection has changed
-     */
-    void emitSelectionChanged(const QRect& r);
-
-    /**
-     * XXX
-     */
-    KisUndoAdapter *undoAdapter() const;
-
-
-    /**
-     * Returns the image associated with this paint device, or 0 if
-     * this paint device is not associated with an image.
-     */
-    KisImageSP image() const;
-
 signals:
 
     void ioProgress(qint8 percentage);
-    void profileChanged(KoColorProfile *  profile);
-    void colorSpaceChanged(KoColorSpace *colorspace);
+    void profileChanged(const KoColorProfile *  profile);
+    void colorSpaceChanged(const KoColorSpace *colorspace);
 
     /**
      * Emitted when the default empty painterly overlay for this paint
