@@ -37,6 +37,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <ksharedconfig.h>
+#include <kconfiggroup.h>
 
 #include "kis_brush.h"
 #include "kis_complex_color.h"
@@ -63,11 +64,21 @@
 #define BEZIER_FLATNESS_THRESHOLD 0.5
 
 KisPainter::KisPainter()
+    : m_selection( 0 )
 {
     init();
 }
 
-KisPainter::KisPainter(KisPaintDeviceSP device)
+KisPainter::KisPainter( KisPaintDeviceSP device )
+    : m_selection( 0 )
+{
+    init();
+    Q_ASSERT(device);
+    begin(device);
+}
+
+KisPainter::KisPainter(KisPaintDeviceSP device, KisSelectionSP selection)
+    : m_selection(selection)
 {
     init();
     Q_ASSERT(device);
@@ -89,6 +100,7 @@ void KisPainter::init()
     m_pressure = PRESSURE_MIN;
     m_antiAliasPolygonFill = true;
     m_bounds = QRect();
+    m_progressUpdater = 0;
 
     KConfigGroup cfg = KGlobal::config()->group("");
     m_useBoundingDirtyRect = cfg.readEntry("aggregate_dirty_regions", true);
@@ -101,10 +113,15 @@ KisPainter::~KisPainter()
     end();
 }
 
-void KisPainter::begin(KisPaintDeviceSP device)
+void KisPainter::begin( KisPaintDeviceSP device )
+{
+    begin( device, m_selection );
+}
+
+void KisPainter::begin( KisPaintDeviceSP device, KisSelectionSP selection )
 {
     if (!device) return;
-
+    m_selection = selection;
     Q_ASSERT( device->colorSpace() );
 
     if (m_transaction) {
@@ -117,6 +134,9 @@ void KisPainter::begin(KisPaintDeviceSP device)
     m_pixelSize = device->pixelSize();
 }
 
+
+
+
 QUndoCommand *KisPainter::end()
 {
     return endTransaction();
@@ -206,7 +226,7 @@ void KisPainter::bitBlt(qint32 dx, qint32 dy,
     if ( src->depth() != 32 ) return;
 
     QRect srcRect = QRect( sx, sy, sw, sh );
-    KoColorSpace * srcCs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * srcCs = KoColorSpaceRegistry::instance()->rgb8();
 
     // Make sure we don't try to blit outside the source image
     if ( src->rect().isValid() && op != srcCs->compositeOp( COMPOSITE_COPY ) ) {
@@ -290,7 +310,7 @@ void KisPainter::bitBlt(qint32 dx, qint32 dy,
 
     addDirtyRect( QRect( dx, dy, sw, sh ) );
 
-    KoColorSpace * srcCs = srcdev->colorSpace();
+    const KoColorSpace * srcCs = srcdev->colorSpace();
 
     qint32 dstY = dy;
     qint32 srcY = sy;
@@ -378,7 +398,7 @@ void KisPainter::bltMask(qint32 dx, qint32 dy,
         srcRect &= srcdev->exactBounds();
     }
 
-    srcRect &= selMask->exactBounds();
+    srcRect &= selMask->exactBounds().translated( -dx + sx, -dy + sy );
 
     if (srcRect.isEmpty()) {
         return;
@@ -392,7 +412,7 @@ void KisPainter::bltMask(qint32 dx, qint32 dy,
     sw = srcRect.width();
     sh = srcRect.height();
 
-    KoColorSpace * srcCs = srcdev->colorSpace();
+    const KoColorSpace * srcCs = srcdev->colorSpace();
 
     qint32 dstY = dy;
     qint32 srcY = sy;
@@ -495,11 +515,12 @@ void KisPainter::bltSelection(qint32 dx, qint32 dy,
                               qint32 sw, qint32 sh)
 {
     if (m_device.isNull()) return;
-    if (!m_device->hasSelection()) {
+    if ( !m_selection ) {
         bitBlt(dx, dy, op, srcdev, opacity, sx, sy, sw, sh);
     }
-    else
-        bltSelection(dx,dy,op,srcdev, m_device->selection(),opacity,sx,sy,sw,sh);
+    else {
+        bltSelection(dx, dy, op, srcdev, m_selection, opacity, sx, sy, sw, sh );
+    }
 }
 
 double KisPainter::paintLine(const KisPaintInformation &pi1,
