@@ -27,8 +27,8 @@
 #include "kis_types.h"
 #include "kis_paint_device.h"
 
-#include "kis_progress_subject.h"
-#include "KoColorSpace.h"
+#include <KoColorSpace.h>
+#include <KoProgressUpdater.h>
 #include "kis_selection.h"
 
 #include <krita_export.h>
@@ -57,31 +57,38 @@ class KisPaintInformation;
  * For more complex operations, you might want to have a look at the subclasses
  * of KisPainter: KisConvolutionPainter, KisFillPainter and KisGradientPainter
  */
-class KRITAIMAGE_EXPORT KisPainter : public KisProgressSubject {
+class KRITAIMAGE_EXPORT KisPainter {
 
 
 public:
     /// Construct painter without a device
     KisPainter();
-    /// Construct a painter, and begin painting on the device
-    KisPainter(KisPaintDeviceSP device);
-    virtual ~KisPainter();
 
-private:
-    // Implement KisProgressSubject
-    virtual void cancel() { m_cancelRequested = true; }
+    /// Construct a painter, and begin painting on the device
+    KisPainter( KisPaintDeviceSP device );
+    KisPainter(KisPaintDeviceSP device, KisSelectionSP selection);
+    virtual ~KisPainter();
 
 public:
     /**
      * Start painting on the specified device. Not undoable.
      */
-    void begin(KisPaintDeviceSP device);
+    void begin( KisPaintDeviceSP device );
+    void begin( KisPaintDeviceSP device, KisSelectionSP selection );
 
     /**
      * Finish painting on the current device
      */
     QUndoCommand *end();
 
+    /**
+     * If set, the painter action is cancelable, if the action supports that.
+     */
+    void setProgress(KoUpdater * progressUpdater)
+        {
+            m_progressUpdater = progressUpdater;
+        }
+
     /// Begin an undoable paint operation
     void beginTransaction(const QString& customName = QString::null);
 
@@ -571,9 +578,6 @@ public:
     /// Get the currently set dab
     KisPaintDeviceSP dab() const { return m_dab; }
 
-    /// Is cancel Requested by the KisProgressSubject for this painter
-    bool cancelRequested() const { return m_cancelRequested; }
-
     /// Set the composite op for this painter
     void setCompositeOp(const KoCompositeOp * op) { m_compositeOp = op; }
     const KoCompositeOp * compositeOp() { return m_compositeOp; }
@@ -596,15 +600,19 @@ public:
 protected:
     /// Initialize, set everything to '0' or defaults
     void init();
-    KisPainter(const KisPainter&);
-    KisPainter& operator=(const KisPainter&);
 
     /// Fill the polygon defined by points with the fillStyle
     void fillPolygon(const vQPointF& points, FillStyle fillStyle);
 
+private:
+    KisPainter(const KisPainter&);
+    KisPainter& operator=(const KisPainter&);
+
 protected:
     KisPaintDeviceSP m_device;
+    KisSelectionSP m_selection;
     KisTransaction  *m_transaction;
+    KoUpdater * m_progressUpdater;
 
     QRegion m_dirtyRegion;
     QRect m_dirtyRect;
@@ -624,9 +632,8 @@ protected:
     quint8 m_opacity;
     KisPaintOp * m_paintOp;
     double m_pressure;
-    bool m_cancelRequested;
     qint32 m_pixelSize;
-    KoColorSpace * m_colorSpace;
+    const KoColorSpace * m_colorSpace;
     KoColorProfile *  m_profile;
     KisPaintDeviceSP m_dab;
     const KoCompositeOp * m_compositeOp;
