@@ -28,14 +28,14 @@ class KisIteratorTest : public QObject
     Q_OBJECT
 
 private:
-    void allCsApplicator(void (KisIteratorTest::* funcPtr)( KoColorSpace*cs ) );
+    void allCsApplicator(void (KisIteratorTest::* funcPtr)( const KoColorSpace*cs ) );
 
-    void vLineIter( KoColorSpace * cs );
-    void writeBytes( KoColorSpace * cs );
-    void fill( KoColorSpace * cs );
-    void rectIter( KoColorSpace * cs );
-    void hLineIter( KoColorSpace * cs );
-    void randomAccessor( KoColorSpace * cs );
+    void vLineIter( const KoColorSpace * cs );
+    void writeBytes( const KoColorSpace * cs );
+    void fill( const KoColorSpace * cs );
+    void rectIter( const KoColorSpace * cs );
+    void hLineIter( const KoColorSpace * cs );
+    void randomAccessor( const KoColorSpace * cs );
 
 
 private slots:
