@@ -23,24 +23,44 @@
 
 #include "kis_node.h"
 
+class TestNode : public KisNode
+{
+    Q_OBJECT
+public:
+    KisNodeSP clone() { return new TestNode(*this); }
+    bool allowAsChild( KisNodeSP ) { return true; }
+    void setDirty() {
+        KisNode::setDirty( QRect( -1000, -1000, 2000, 200 ) );
+    }
+};
+
+
 class TestNodeA : public KisNode
 {
     Q_OBJECT
+public:
+    KisNodeSP clone() { return new TestNodeA(*this); }
+    bool allowAsChild( KisNodeSP ) { return true; }
 };
 
 class TestNodeB : public KisNode
 {
     Q_OBJECT
+public:
+    KisNodeSP clone() { return new TestNodeB(*this); }
+    bool allowAsChild( KisNodeSP ) { return true; }
 };
 
 class TestNodeC : public KisNode
 {
     Q_OBJECT
+public:
+    KisNodeSP clone() { return new TestNodeC(*this); }
+    bool allowAsChild( KisNodeSP ) { return true; }
 };
 
 
 
-
 class KisNodeTest : public QObject
 {
     Q_OBJECT
@@ -51,6 +71,7 @@ private slots:
     void testOrdering();
     void testSetDirty();
     void testChildNodes();
+    void testDirtyRegion();
 };
 
 #endif
