@@ -38,7 +38,7 @@
 
 void KisPaintDeviceTest::testCreation()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
     QVERIFY( dev->objectName() == QString() );
 
@@ -50,7 +50,6 @@ void KisPaintDeviceTest::testCreation()
     QVERIFY( dev->pixelSize() == cs->pixelSize() );
     QVERIFY( dev->channelCount() == cs->channelCount() );
     QVERIFY( dev->dataManager() != 0 );
-    QVERIFY( dev->hasSelection() == false );
     QVERIFY( dev->paintEngine() != 0 );
 
     KisImageSP image = new KisImage(0, 1000, 1000, cs, "merge test");
@@ -65,7 +64,6 @@ void KisPaintDeviceTest::testCreation()
     QVERIFY( dev->pixelSize() == cs->pixelSize() );
     QVERIFY( dev->channelCount() == cs->channelCount() );
     QVERIFY( dev->dataManager() != 0 );
-    QVERIFY( dev->hasSelection() == false );
     QVERIFY( dev->paintEngine() != 0 );
 
     // Let the layer go out of scope and see what happens
@@ -73,7 +71,6 @@ void KisPaintDeviceTest::testCreation()
         KisPaintLayerSP l2 = new KisPaintLayer( image, "blabla", 250 );
         dev = new KisPaintDevice( l2.data(), cs, "test3" );
     }
-    QVERIFY( dev->image() == 0 );
 
 }
 
@@ -81,7 +78,7 @@ void KisPaintDeviceTest::testPaintEngine()
 {
     // Create a paint device and a QImage. Let the paintEngine paint
     // on both, then do a pixel-by-pixel comparison
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
     quint8* pixel = cs->allocPixelBuffer( 1 );
     cs->fromQColor( Qt::white, pixel );
@@ -142,7 +139,7 @@ void KisPaintDeviceTest::testPaintEngine()
     {
         QRectF target(100.0, 200.0, 80.0, 60.0);
         QRectF source(0.0, 0.0, 70.0, 40.0);
-        QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.jpg");
+        QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.png");
 
         gc.drawImage(target, image, source);
         gc2.drawImage(target, image, source );
@@ -182,7 +179,7 @@ void KisPaintDeviceTest::testPaintEngine()
     {
          QRectF target(200.0, 200.0, 80.0, 60.0);
          QRectF source(0.0, 0.0, 70.0, 40.0);
-         QPixmap pixmap(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.jpg");
+         QPixmap pixmap(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.png");
 
          gc.drawPixmap(target, pixmap, source);
          gc2.drawPixmap(target, pixmap, source);
@@ -283,7 +280,7 @@ void KisPaintDeviceTest::testPaintEngine()
 void KisPaintDeviceTest::testStore()
 {
 
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
     KoStore * readStore =
@@ -321,7 +318,7 @@ void KisPaintDeviceTest::testStore()
 
 void KisPaintDeviceTest::testGeometry()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
     quint8* pixel = cs->allocPixelBuffer( 1 );
@@ -368,7 +365,7 @@ void KisPaintDeviceTest::testGeometry()
 
 void KisPaintDeviceTest::testClear()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
     QVERIFY( dev->extent() == QRect(2147483647,2147483647, 0, 0) );
@@ -394,7 +391,7 @@ void KisPaintDeviceTest::testClear()
 
 void KisPaintDeviceTest::testCrop()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
     quint8* pixel = cs->allocPixelBuffer( 1 );
     cs->fromQColor( Qt::white, pixel );
@@ -413,7 +410,7 @@ void KisPaintDeviceTest::testCrop()
 
 void KisPaintDeviceTest::testRoundtripReadWrite()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
     QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "tile.png");
     dev->convertFromQImage( image, "");
@@ -457,13 +454,13 @@ void KisPaintDeviceTest::testColorSpaceConversion()
     QTime t;
     t.start();
 
-    QList<KoColorSpace*> colorSpaces = TestUtil::allColorSpaces();
+    QList<const KoColorSpace*> colorSpaces = TestUtil::allColorSpaces();
     int failedColorSpaces = 0;
 
     QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "tile.png");
 
-    foreach ( KoColorSpace * srcCs, colorSpaces ) {
-        foreach( KoColorSpace * dstCs,  colorSpaces ) {
+    foreach ( const KoColorSpace * srcCs, colorSpaces ) {
+        foreach( const KoColorSpace * dstCs,  colorSpaces ) {
 
             KisPaintDeviceSP dev  = new KisPaintDevice( srcCs );
             dev->convertFromQImage( image, "");
@@ -498,8 +495,8 @@ void KisPaintDeviceTest::testColorSpaceConversion()
 
 void KisPaintDeviceTest::testRoundtripConversion()
 {
-    QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.jpg");
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.png");
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice(cs);
     dev->convertFromQImage( image, "" );
     QImage result = dev->convertToQImage(0, 0, 0, 640, 441);
@@ -515,8 +512,8 @@ void KisPaintDeviceTest::testRoundtripConversion()
 
 void KisPaintDeviceTest::testThumbnail()
 {
-    QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.jpg");
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    QImage image(QString(FILES_DATA_DIR) + QDir::separator() + "hakonepa.png");
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice(cs);
     dev->convertFromQImage( image, "" );
     {
@@ -534,7 +531,7 @@ void KisPaintDeviceTest::testThumbnail()
 
 void KisPaintDeviceTest::testPixel()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisPaintDeviceSP dev = new KisPaintDevice(cs);
 
     QColor c = Qt::red;
@@ -555,7 +552,7 @@ void KisPaintDeviceTest::testPixel()
 
 void KisPaintDeviceTest::testDirty()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
     KisImageSP image = new KisImage(0, 512, 512, cs, "merge test");
     KisPaintLayerSP layer = new KisPaintLayer(image, "test", OPACITY_OPAQUE);
     KisPaintDeviceSP dev = layer->paintDevice();
@@ -590,7 +587,7 @@ void KisPaintDeviceTest::testDirty()
 
 void KisPaintDeviceTest::testMirror()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
 
@@ -654,7 +651,7 @@ void KisPaintDeviceTest::testMirror()
 
 void KisPaintDeviceTest::testMirrorTransaction()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
     quint8* pixel = cs->allocPixelBuffer( 1 );
@@ -723,7 +720,7 @@ void KisPaintDeviceTest::testSelection()
 
 void KisPaintDeviceTest::testPlanarReadWrite()
 {
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
     KisPaintDeviceSP dev = new KisPaintDevice( cs );
 
     quint8* pixel = cs->allocPixelBuffer( 1 );
