@@ -31,6 +31,8 @@ private slots:
     void testSelectionComponents();
     void testSelectionActions();
     void testInvertSelection();
+    void testUpdateSelectionProjection();
+    void testUpdatePixelSelection();
 };
 
 #endif
