@@ -34,6 +34,7 @@
 #include <k3staticdeleter.h>
 #include <kglobal.h>
 #include <ksharedconfig.h>
+#include <kconfiggroup.h>
 
 #include "kis_tileddatamanager.h"
 #include "kis_tile.h"
@@ -162,11 +163,12 @@ void KisTileManager::deregisterTile(KisTile* tile) {
     if (!m_tileMap.contains(tile)) {
             return;
     }
-    // Q_ASSERT(m_tileMap.contains(tile));
+    
     m_bigKritaLock.lock();
-
+    Q_ASSERT(m_tileMap.contains(tile));
     TileInfo* info = m_tileMap[tile];
-
+    Q_ASSERT(info);
+    
     if (info->onFile) { // It was once mmapped
         // To freelist
         FreeInfo* freeInfo = new FreeInfo();
@@ -232,6 +234,9 @@ void KisTileManager::maySwapTile(const KisTile* tile)
     m_bigKritaLock.lock();
 
     TileInfo* info = m_tileMap[tile];
+
+    Q_ASSERT(info);
+    
     m_swappableList.push_back(info);
     info->validNode = true;
     info->node = -- m_swappableList.end();
@@ -475,7 +480,7 @@ quint8* KisTileManager::findTileFor(qint32 pixelSize)
                 m_pools[i] = new quint8[pixelSize * m_tileSize * m_tilesPerPool];
             }
             catch ( std::bad_alloc ) {
-                kDebug() <<">>>>>>> Could not allocated memory" << pixelSize <<"" << m_tileSize <<"" << m_tilesPerPool;
+                kError() <<">>>>>>> Could not allocate memory" << pixelSize <<"" << m_tileSize <<"" << m_tilesPerPool;
                 // XXX: bart! What shall we do here?
                 abort();
             }
