@@ -17,26 +17,30 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  */
-#include <dcopclient.h>
 #include <kcmdlineargs.h>
-#include <koApplication.h>
-#include "core/kis_aboutdata.h"
+#include <KoApplication.h>
+#include <krita_export.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <kdebug.h>
+#include <QString>
 
-static const KCmdLineOptions options[] = {
-	{ "+[file(s)]", I18N_NOOP("File(s) or URL(s) to open"), 0 },
-	KCmdLineLastOption
-};
+#include "ui/kis_aboutdata.h"
 
-extern "C" KRITA_EXPORT int kdemain(int argc, char **argv)
+extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
-	KCmdLineArgs::init(argc, argv, newKritaAboutData());
-	KCmdLineArgs::addCmdLineOptions(options);
 
-	KoApplication app;
+    KCmdLineArgs::init(argc, argv, newKritaAboutData());
 
-	if (!app.start())
-		return 1;
+    KCmdLineOptions options;
+    options.add("+[file(s)]", ki18n("File(s) or URL(s) to open"));
+    KCmdLineArgs::addCmdLineOptions(options);
 
-	return app.exec();
+    KoApplication app;
+
+    if (!app.start())
+        return 1;
+
+    return app.exec();
 }
 
