@@ -31,12 +31,12 @@
 
 #include "ui_wdgbumpmap.h"
 
-class WdgBumpmap : public QWidget, public Ui::WdgBumpmap
+class BumpmapWidget : public QWidget, public Ui::WdgBumpmap
 {
     Q_OBJECT
 
     public:
-        WdgBumpmap(QWidget *parent) : QWidget(parent) { setupUi(this); }
+        BumpmapWidget(QWidget *parent) : QWidget(parent) { setupUi(this); }
 };
 
 namespace krita {
@@ -72,14 +72,21 @@ class KisFilterBumpmap : public KisFilter
 public:
     KisFilterBumpmap();
 public:
-    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
-    virtual ColorSpaceIndependence colorSpaceIndependence() { return TO_LAB16; }
-    virtual bool supportsPainting() { return true; }
-    virtual bool supportsPreview() { return true; }
-    virtual bool supportsIncrementalPainting() { return true; }
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
+
+    
+    virtual ColorSpaceIndependence colorSpaceIndependence() const { return TO_LAB16; }
+    virtual bool supportsPainting() const { return true; }
+    virtual bool supportsPreview() const { return true; }
+    virtual bool supportsIncrementalPainting() const { return true; }
 
     virtual KisFilterConfigWidget * createConfigurationWidget(QWidget* parent, const KisPaintDeviceSP dev);
-    virtual KisFilterConfiguration* designerConfiguration(const KisPaintDeviceSP);
+    virtual KisFilterConfiguration* factoryConfiguration(const KisPaintDeviceSP);
 };
 
 class KisBumpmapConfigWidget : public KisFilterConfigWidget {
@@ -93,7 +100,7 @@ public:
     void setConfiguration(KisFilterConfiguration * config);
     KisFilterConfiguration* configuration() const;
 
-    WdgBumpmap * m_page;
+    BumpmapWidget * m_page;
 
 private:
 
