@@ -58,7 +58,7 @@ public:
     quint16 nTransfers;
     // Caching of adjustment
     bool dirty;
-    KoColorSpace* oldCs;
+    const KoColorSpace* oldCs;
     KoColorTransformation* adjustment;
 };
 
@@ -70,18 +70,16 @@ class KisPerChannelFilter
     : public KisFilter
 {
 public:
-    KisPerChannelFilter() : KisFilter( id(), CategoryAdjust, i18n("&Color Adjustment curves...")) {}
+    KisPerChannelFilter();
 public:
     virtual KisFilterConfigWidget * createConfigurationWidget(QWidget* parent, KisPaintDeviceSP dev);
-//     virtual KisFilterConfiguration* configuration() { return new KisPerChannelFilterConfiguration(0); }
-    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
     static inline KoID id() { return KoID("perchannel", i18n("Color Adjustment")); }
-    virtual bool supportsPainting() { return true; }
-    virtual bool supportsPreview() { return true; }
-    virtual bool supportsIncrementalPainting() { return false; }
-    virtual std::list<KisFilterConfiguration*> listOfExamplesConfiguration(KisPaintDeviceSP dev);
-
-    virtual ColorSpaceIndependence colorSpaceIndependence() { return TO_LAB16; }
 private:
 };
 
