@@ -36,12 +36,14 @@ class KisFilterInvert : public KisFilter
 public:
     KisFilterInvert();
 public:
-    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
-    virtual ColorSpaceIndependence colorSpaceIndependence() { return FULLY_INDEPENDENT; }
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
     static inline KoID id() { return KoID("invert", i18n("Invert")); }
-    virtual bool supportsPainting() { return true; }
-    virtual bool supportsPreview() { return true; }
-    virtual bool supportsIncrementalPainting() { return false; }
+    
 };
 
 #endif
