@@ -46,9 +46,9 @@ KisFilterConfigWidget * KisSimpleNoiseReducer::createConfigurationWidget(QWidget
     return new KisMultiIntegerFilterWidget(id().id(), parent, id().id(), param );
 }
 
-KisFilterConfiguration * KisSimpleNoiseReducer::designerConfiguration(const KisPaintDeviceSP)
+KisFilterConfiguration * KisSimpleNoiseReducer::factoryConfiguration(const KisPaintDeviceSP)
 {
-    KisFilterConfiguration* config = new KisFilterConfiguration(m_id.id(), 0);
+    KisFilterConfiguration* config = new KisFilterConfiguration(id().id(), 0);
     config->setProperty("threshold", 50);
     config->setProperty("windowsize", 1);
     return config;
@@ -60,8 +60,14 @@ inline int ABS(int v)
     return v;
 }
 
-void KisSimpleNoiseReducer::process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config)
+void KisSimpleNoiseReducer::process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater
+        ) const
 {
+#if 0
     int threshold, windowsize;
     if(config ==0)
     {
@@ -88,7 +94,7 @@ void KisSimpleNoiseReducer::process(const KisPaintDeviceSP src, const QPoint& sr
     painter.applyMatrix(kernel, srcTopLeft.x(), srcTopLeft.y(), size.width(), size.height(), BORDER_REPEAT);
 
     if (painter.cancelRequested()) {
-        cancel();
+        progressUpdater->cancel();
     }
 
 
@@ -119,5 +125,6 @@ void KisSimpleNoiseReducer::process(const KisPaintDeviceSP src, const QPoint& sr
     }
 
     setProgressDone(); // Must be called even if you don't really support progression
+#endif
 }
 
