@@ -37,16 +37,22 @@ public:
     ~KisWaveletNoiseReduction();
 
 public:
-    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
     virtual KisFilterConfigWidget * createConfigurationWidget(QWidget* parent, KisPaintDeviceSP dev);
 
     static inline KoID id() { return KoID("waveletnoisereducer", i18n("Wavelet Noise Reducer")); }
-    virtual bool supportsPainting() { return false; }
-    virtual bool supportsPreview() { return true; }
-    virtual bool supportsIncrementalPainting() { return false; }
-    virtual bool supportsThreading() { return false; }
+    virtual bool supportsPainting() const { return false; }
+    virtual bool supportsPreview() const { return true; }
+    virtual bool supportsIncrementalPainting() const { return false; }
+    
+    virtual bool supportsThreading() const { return false; }
 private:
-    virtual KisFilterConfiguration * designerConfiguration(const KisPaintDeviceSP);
+    virtual KisFilterConfiguration * factoryConfiguration(const KisPaintDeviceSP);
 
 };
 
