@@ -38,14 +38,20 @@ class KisFilterLensCorrection : public KisFilter
     public:
         KisFilterLensCorrection();
     public:
-        virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft,  const QSize& size, const KisFilterConfiguration* config);
-        virtual ColorSpaceIndependence colorSpaceIndependence() { return FULLY_INDEPENDENT; }
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
+        virtual ColorSpaceIndependence colorSpaceIndependence() const { return FULLY_INDEPENDENT; }
         static inline KoID id() { return KoID("lenscorrection", i18n("Lens Correction")); }
-        virtual bool supportsPainting() { return true; }
-        virtual bool supportsPreview() { return true; }
-        virtual bool supportsIncrementalPainting() { return false; }
-        virtual bool supportsAdjustmentLayers() { return false; }
-        virtual KisFilterConfiguration* designerConfiguration(const KisPaintDeviceSP);
+    
+    virtual bool supportsPainting() const { return true; }
+        virtual bool supportsPreview() const { return true; }
+        virtual bool supportsIncrementalPainting() const { return false; }
+        virtual bool supportsAdjustmentLayers() const { return false; }
+        virtual KisFilterConfiguration* factoryConfiguration(const KisPaintDeviceSP);
     public:
         virtual KisFilterConfigWidget * createConfigurationWidget(QWidget* parent, KisPaintDeviceSP dev);
 };
