@@ -23,6 +23,7 @@
 
 #include "kis_filter.h"
 #include "kis_filter_config_widget.h"
+#include "kis_paint_device.h"
 
 class KisRainDropsFilterConfiguration : public KisFilterConfiguration
 {
@@ -46,10 +47,16 @@ class KisRainDropsFilter : public KisFilter
 public:
     KisRainDropsFilter();
 public:
-    virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, const KisFilterConfiguration* config);
+    void process(KisFilterConstantProcessingInformation src,
+                 KisFilterProcessingInformation dst,
+                 const QSize& size,
+                 const KisFilterConfiguration* config,
+                 KoUpdater* progressUpdater = 0
+        ) const;
     static inline KoID id() { return KoID("raindrops", i18n("Raindrops")); }
-    virtual bool supportsPainting() { return false; }
-    virtual bool supportsPreview() { return true; }
+    
+    virtual bool supportsPainting() const { return false; }
+    virtual bool supportsPreview() const { return true; }
     virtual std::list<KisFilterConfiguration*> listOfExamplesConfiguration(KisPaintDeviceSP )
     { std::list<KisFilterConfiguration*> list; list.insert(list.begin(), new KisRainDropsFilterConfiguration( 30, 80, 20)); return list; }
 
