@@ -43,7 +43,7 @@ public:
     virtual KisPaintOp * createOp(const KisPaintOpSettings *settings, KisPainter * painter, KisImageSP image);
     virtual QString id() const { return "paintCPaint"; }
     virtual QString name() const { return i18n("Chinese Brush"); }
-    virtual KisPaintOpSettings *settings(QWidget * parent, const KoInputDevice& inputDevice);
+    virtual KisPaintOpSettings *settings(QWidget * parent, const KoInputDevice& inputDevice, KisImageSP image);
 
 private:
 
