@@ -3,8 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  the Free Software Foundation; version 2 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,12 +20,8 @@
 #include <klocale.h>
 
 #include "kis_dynamic_brush.h"
-#include "kis_size_transformation.h"
 #include "kis_dynamic_sensor.h"
 
-// TODO: temporary stuff
-#include "kis_filters_list_dynamic_program.h"
-
 KisDynamicBrushRegistry *KisDynamicBrushRegistry::singleton = 0;
 
 KisDynamicBrushRegistry* KisDynamicBrushRegistry::instance()
