@@ -3,8 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  the Free Software Foundation; version 2 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,6 +32,8 @@ class KisDynamicSensorTime : public KisDynamicSensor {
     public slots:
         virtual void setPeriodic(bool periodic);
         virtual void setLength(int length);
+        virtual void toXML(QDomDocument&, QDomElement&) const;
+        virtual void fromXML(const QDomElement&);
     private:
         double m_time;
         int m_length;
