@@ -3,8 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  the Free Software Foundation; version 2 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,12 +20,14 @@
 
 #include <QWidget>
 
+#include "dynamicbrush_export.h"
+
 class Ui_SensorSelector;
 class KisDynamicSensor;
 class QHBoxLayout;
 class KoID;
 
-class KisSensorSelector : public QWidget {
+class DYNAMIC_BRUSH_EXPORT KisSensorSelector : public QWidget {
     Q_OBJECT
     public:
         KisSensorSelector(QWidget* parent);
