@@ -80,12 +80,14 @@ void KisToolSelectEraser::initPaint(KoPointerEvent */*e*/)
 
     if (m_painter)
         delete m_painter;
+#if 0
     if(! dev->hasSelection())
     {
         dev->selection()->clear();
         dev->emitSelectionChanged();
     }
-    KisSelectionSP selection = dev->selection();
+#endif
+    KisSelectionSP selection = currentLayer()->selection();
 
     m_target = selection;
     m_painter = new KisPainter(selection);
@@ -109,8 +111,10 @@ void KisToolSelectEraser::initPaint(KoPointerEvent */*e*/)
 
 void KisToolSelectEraser::endPaint() {
     super::endPaint();
+#if 0
     if (currentImage() && currentLayer()->paintDevice())
         currentLayer()->paintDevice()->emitSelectionChanged();
+#endif
 }
 
 QWidget* KisToolSelectEraser::createOptionWidget()
