@@ -201,11 +201,11 @@ void KisToolTransform::initHandles()
     m_origDevice = new KisPaintDevice(*dev.data());
     Q_ASSERT(m_origDevice);
 
-    if(dev->hasSelection())
+    KisSelectionSP selection = m_currentLayer->selection();
+    if(selection)
     {
-        KisSelectionSP sel = dev->selection();
-        QRect r = sel->selectedExactRect();
-        m_origSelection = new KisSelection(*sel.data());
+        QRect r = selection->selectedExactRect();
+        m_origSelection = new KisSelection(*selection.data());
         r.getRect(&x, &y, &w, &h);
     }
     else {
@@ -657,7 +657,7 @@ void KisToolTransform::transform()
         return;
 
     QPointF t = m_translate - rot(m_originalCenter.x() * m_scaleX, m_originalCenter.y() * m_scaleY);
-    //KisProgressDisplayInterface *progress = m_subject->progressDisplay();
+    //KoUpdater *progress = m_subject->progressDisplay();
 
     // This mementoes the current state of the active device.
     TransformCmd * transaction = new TransformCmd(this, m_currentLayer->paintDevice(), m_scaleX,
@@ -676,14 +676,15 @@ void KisToolTransform::transform()
     {
         QRect rc = m_origSelection->selectedRect();
         rc = rc.normalized();
-        m_currentLayer->paintDevice()->selection()->clear();
-        KisPainter sgc(KisPaintDeviceSP(m_currentLayer->paintDevice()->selection().data()));
+        // XXX_SELECTION This used to create a new selection!
+        if ( m_currentLayer->selection() ) m_currentLayer->selection()->clear();
+        KisPainter sgc(KisPaintDeviceSP(m_currentLayer->selection().data()));
         sgc.bitBlt(rc.x(), rc.y(), COMPOSITE_COPY, KisPaintDeviceSP(m_origSelection.data()), rc.x(), rc.y(), rc.width(), rc.height());
         sgc.end();
     }
     else
-        if(m_currentLayer->paintDevice()->hasSelection())
-            m_currentLayer->paintDevice()->selection()->clear();
+        if(m_currentLayer->selection())
+            m_currentLayer->selection()->clear();
 
     // Perform the transform. Since we copied the original state back, this doesn't degrade
     // after many tweaks. Since we started the transaction before the copy back, the memento
@@ -691,13 +692,14 @@ void KisToolTransform::transform()
     KisTransformWorker worker(m_currentLayer->paintDevice(), m_scaleX, m_scaleY, 0, 0, m_a, int(t.x()), int(t.y()), 0/*progress*/, m_filter);
     worker.run();
 
-    // If canceled, go back to the memento
-    if(worker.isCanceled())
-    {
-        transaction->undo();
-        delete transaction;
-        return;
-    }
+// XXX_PROGRESS, XXX_LAYERS
+//     // If canceled, go back to the memento
+//     if(worker.isCanceled())
+//     {
+//         transaction->undo();
+//         delete transaction;
+//         return;
+//     }
 
     m_currentLayer->paintDevice()->setDirty(rc); // XXX: This is not enough - should union with new extent
 
