@@ -20,12 +20,20 @@
 #ifndef DLG_GROW_SELECTION_H
 #define DLG_GROW_SELECTION_H
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
-class WdgGrowSelection;
+#include "ui_wdg_grow_selection.h"
 
-class DlgGrowSelection: public KDialogBase {
-    typedef KDialogBase super;
+class WdgGrowSelection : public QWidget, public Ui::WdgGrowSelection
+{
+    Q_OBJECT
+
+    public:
+        WdgGrowSelection(QWidget *parent) : QWidget(parent) { setupUi(this); }
+};
+
+class DlgGrowSelection: public KDialog {
+    typedef KDialog super;
     Q_OBJECT
 
 public:
@@ -33,8 +41,8 @@ public:
     DlgGrowSelection(QWidget * parent = 0, const char* name = 0);
     ~DlgGrowSelection();
 
-    Q_INT32 xradius();
-    Q_INT32 yradius();
+    qint32 xradius();
+    qint32 yradius();
 
 private slots:
 
