@@ -17,15 +17,18 @@
  */
 
 #include "krs_pattern.h"
+#include "krs_module.h"
 
 #include <kis_pattern.h>
 
-namespace Kross {
+using namespace Scripting;
 
-namespace KritaCore {
-
-Pattern::Pattern(KisPattern* pattern, bool sharedPattern) : Kross::Api::Class<Pattern>("KritaPattern"), m_pattern(pattern), m_sharedPattern(sharedPattern)
+Pattern::Pattern(Module* module, KisPattern* pattern, bool sharedPattern)
+    : QObject(module)
+    , m_pattern(pattern)
+    , m_sharedPattern(sharedPattern)
 {
+    setObjectName("KritaPattern");
 }
 
 Pattern::~Pattern()
@@ -33,7 +36,3 @@ Pattern::~Pattern()
     if(!m_sharedPattern)
         delete m_pattern;
 }
-
-}
-
-}
