@@ -17,11 +17,11 @@ public:
     %{APPNAME}Filter();
 public:
     virtual void process(const KisPaintDeviceSP src, const QPoint& srcTopLeft, KisPaintDeviceSP dst, const QPoint& dstTopLeft, const QSize& size, KisFilterConfiguration* config);
-    virtual ColorSpaceIndependence colorSpaceIndependence() { return FULLY_INDEPENDENT; }
+    virtual ColorSpaceIndependence colorSpaceIndependence() const { return FULLY_INDEPENDENT; }
     static inline KoID id() { return KoID("%{APPNAMELC}", i18n("%{APPNAME}")); }
-    virtual bool supportsPainting() { return true; }
-    virtual bool supportsPreview() { return true; }
-    virtual bool supportsIncrementalPainting() { return false; }
+    virtual bool supportsPainting() const { return true; }
+    virtual bool supportsPreview() const { return true; }
+    virtual bool supportsIncrementalPainting() const { return false; }
 };
 
 #endif
