@@ -234,7 +234,7 @@ PerformanceTab::PerformanceTab(QWidget *parent, const char *name  )
     intChunkSize->setValue( cfg.projectionChunkSize() );
     intNumThreads->setValue( cfg.numProjectionThreads() );
     chkUpdateAllOfQPainterCanvas->setChecked( cfg.updateAllOfQPainterCanvas() );
-    chkFastZoom->setChecked( cfg.fastZoom() );
+    chkUseNearestNeighbour->setChecked( cfg.useNearestNeigbour() );
 }
 
 void PerformanceTab::setDefault()
@@ -247,7 +247,7 @@ void PerformanceTab::setDefault()
     intChunkSize->setValue( 512 );
     intNumThreads->setValue( QThread::idealThreadCount()  );
     chkUpdateAllOfQPainterCanvas->setChecked( true );
-    chkFastZoom->setChecked( false );
+    chkUseNearestNeighbour->setChecked( false );
 }
 
 //---------------------------------------------------------------------------------------------------
@@ -805,14 +805,14 @@ PreferencesDialog::PreferencesDialog( QWidget* parent, const char* name )
     KVBox *vbox = new KVBox();
     KPageWidgetItem *page = new KPageWidgetItem( vbox, i18n( "General"));
     page->setHeader( i18n( "General") );
-    page->setIcon(  KIcon(BarIcon( "configure", K3Icon::SizeMedium )) );
+    page->setIcon(  KIcon(BarIcon( "configure", KIconLoader::SizeMedium )) );
     addPage( page );
     m_general = new GeneralTab( vbox );
 
     vbox = new KVBox();
     page = new KPageWidgetItem( vbox, i18n( "Display" ));
     page->setHeader( i18n( "Display" ) );
-    page->setIcon(  KIcon(BarIcon( "datashow", K3Icon::SizeMedium)));
+    page->setIcon(  KIcon(BarIcon( "datashow", KIconLoader::SizeMedium)));
     addPage( page );
 
     m_displaySettings = new DisplaySettingsTab( vbox );
@@ -820,21 +820,21 @@ PreferencesDialog::PreferencesDialog( QWidget* parent, const char* name )
     vbox = new KVBox();
     page = new KPageWidgetItem( vbox, i18n( "Color Management"));
     page->setHeader( i18n( "Color") );
-    page->setIcon( KIcon( BarIcon( "color-fill", K3Icon::SizeMedium )));
+    page->setIcon( KIcon( BarIcon( "color-fill", KIconLoader::SizeMedium )));
     addPage( page );
     m_colorSettings = new ColorSettingsTab( vbox );
 
     vbox = new KVBox();
     page = new KPageWidgetItem( vbox, i18n( "Performance"));
     page->setHeader( i18n( "Performance") );
-    page->setIcon( KIcon( BarIcon( "fork", K3Icon::SizeMedium )));
+    page->setIcon( KIcon( BarIcon( "fork", KIconLoader::SizeMedium )));
     addPage( page );
 
     m_performanceSettings = new PerformanceTab ( vbox );
     vbox = new KVBox();
     page = new KPageWidgetItem( vbox, i18n( "Tablet" ));
     page->setHeader( i18n( "Tablet" ));
-    page->setIcon( KIcon( BarIcon( "tablet", K3Icon::SizeMedium )));
+    page->setIcon( KIcon( BarIcon( "tablet", KIconLoader::SizeMedium )));
     addPage( page );
 
     m_tabletSettings = new TabletSettingsTab( vbox );
@@ -842,7 +842,7 @@ PreferencesDialog::PreferencesDialog( QWidget* parent, const char* name )
     vbox = new KVBox();
     page = new KPageWidgetItem( vbox, i18n( "Grid" ));
     page->setHeader( i18n( "Grid" ));
-    page->setIcon( KIcon( BarIcon( "grid", K3Icon::SizeMedium )));
+    page->setIcon( KIcon( BarIcon( "grid", KIconLoader::SizeMedium )));
     addPage( page );
 
     m_gridSettings = new GridSettingsTab( vbox );
@@ -895,7 +895,7 @@ bool PreferencesDialog::editPreferences()
         cfg.setAggregateDirtyRegionsInPainter( dialog->m_performanceSettings->chkAggregateDirtyRegions->isChecked() );
         cfg.setUseBoundingRectInProjection( dialog->m_performanceSettings->chkUseBoundingRect->isChecked() );
         cfg.setUpdateAllOfQpainterCanvas( dialog->m_performanceSettings->chkUpdateAllOfQPainterCanvas->isChecked() );
-        cfg.setFastZoom( dialog->m_performanceSettings->chkFastZoom->isChecked() );
+        cfg.setUseNearestNeighbour( dialog->m_performanceSettings->chkUseNearestNeighbour->isChecked() );
         // let the tile manager know
         KisTileManager::instance()->configChanged();
 
