@@ -4,6 +4,7 @@
  *  Copyright (c) 2001 Toshitaka Fujioka  <fujioka@kde.org>
  *  Copyright (c) 2002, 2003 Patrick Julien <freak@codepimps.org>
  *  Copyright (c) 2004-2007 Boudewijn Rempt <boud@valdyas.org>
+ *  Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,7 +52,8 @@
 #include <KoFilterManager.h>
 #include <KoID.h>
 #include <KoMainWindow.h>
-#include <KoOasisStore.h>
+#include <KoOdfReadStore.h>
+#include <KoOdfWriteStore.h>
 #include <KoQueryTrader.h>
 #include <KoStore.h>
 #include <KoStoreDevice.h>
@@ -127,7 +129,7 @@ public:
 
     ~KisDocPrivate()
         {
-            // Don't delete m_d->shapeController or m_d->layerModel because it's in a QObject hierarchy.
+            // Don't delete m_d->shapeController or m_d->nodeModel because it's in a QObject hierarchy.
             //delete undoAdapter;
             //delete nserver;
         }
@@ -143,7 +145,7 @@ public:
 
     KisImageSP image;
     KisShapeController * shapeController;
-    KisNodeModel * layerModel;
+    KisNodeModel * nodeModel;
 };
 
 
@@ -213,7 +215,7 @@ bool KisDoc2::init()
 //     }
 
     m_d->shapeController = new KisShapeController( this, m_d->nserver );
-    m_d->layerModel = new KisNodeModel( this );
+    m_d->nodeModel = new KisNodeModel( this );
 
     return true;
 }
@@ -232,15 +234,14 @@ QDomDocument KisDoc2::saveXML()
     return doc;
 }
 
-bool KisDoc2::loadOasis( const KoXmlDocument& doc, KoOasisStyles&, const KoXmlDocument&, KoStore* store)
+bool KisDoc2::loadOdf( KoOdfReadStore & odfStore )
 {
     kDebug(41008) <<"loading with OpenRaster";
-    KoXmlNode root = doc.documentElement();
+    KoXmlNode root = odfStore.contentDoc().documentElement();
     for (KoXmlNode node = root.firstChild(); !node.isNull(); node = node.nextSibling()) {
         if (node.isElement() && node.nodeName() == "office:body") {
             KoXmlElement elem = node.toElement();
-            KoOasisStore* oasisStore =  new KoOasisStore( store );
-            KisOasisLoadVisitor olv(this,oasisStore);
+            KisOasisLoadVisitor olv(this,odfStore.store());
             olv.loadImage(elem);
             if (!olv.image() )
                 return false;
@@ -258,7 +259,7 @@ bool KisDoc2::saveOasis( KoStore* store, KoXmlWriter* manifestWriter)
 {
     kDebug(41008) <<"saving with OpenRaster";
     manifestWriter->addManifestEntry( "content.xml", "text/xml" );
-    KoOasisStore* oasisStore =  new KoOasisStore( store );
+    KoOdfWriteStore* oasisStore =  new KoOdfWriteStore( store );
     KoXmlWriter* contentWriter = oasisStore->contentWriter();
     if ( !contentWriter ) {
         delete oasisStore;
@@ -375,7 +376,7 @@ KisImageSP KisDoc2::loadImage(const KoXmlElement& element)
     double xres;
     double yres;
     QString colorspacename;
-    KoColorSpace * cs;
+    const KoColorSpace * cs;
 
     if ((attr = element.attribute("mime")) == NATIVE_MIMETYPE) {
         if ((name = element.attribute("name")).isNull())
@@ -534,7 +535,7 @@ KisLayerSP KisDoc2::loadPaintLayer(const KoXmlElement& element, KisImageSP img,
 {
     QString attr;
     KisPaintLayerSP layer;
-    KoColorSpace * cs;
+    const KoColorSpace * cs;
 
     QString colorspacename;
     QString profileProductName;
@@ -696,11 +697,11 @@ bool KisDoc2::completeSaving(KoStore *store)
         }
     }
     if (img->profile()) {
-        KoColorProfile *profile = img->profile();
+        const KoColorProfile *profile = img->profile();
         KisAnnotationSP annotation;
         if (profile)
         {
-            KoIccColorProfile* iccprofile = dynamic_cast<KoIccColorProfile*>(profile);
+            const KoIccColorProfile* iccprofile = dynamic_cast<const KoIccColorProfile*>(profile);
             if (iccprofile and !iccprofile->rawData().isEmpty())
                 annotation = new  KisAnnotation("icc", iccprofile->name(), iccprofile->rawData());
         }
@@ -791,7 +792,7 @@ KoDocument* KisDoc2::hitTest(const QPoint &pos, KoView* view, const QMatrix& mat
 }
 
 
-KisImageSP KisDoc2::newImage(const QString& name, qint32 width, qint32 height, KoColorSpace * colorspace)
+KisImageSP KisDoc2::newImage(const QString& name, qint32 width, qint32 height, const KoColorSpace * colorspace)
 {
     if (!init())
         return KisImageSP(0);
@@ -807,7 +808,7 @@ KisImageSP KisDoc2::newImage(const QString& name, qint32 width, qint32 height, K
     KisPaintLayer *layer = new KisPaintLayer(img.data(), img->nextLayerName(), OPACITY_OPAQUE,colorspace);
     Q_CHECK_PTR(layer);
 
-    KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
     KisFillPainter painter;
 
     layer->paintDevice()->fill( 0, 0, width, height, KoColor(Qt::white, cs).data() );
@@ -822,7 +823,7 @@ KisImageSP KisDoc2::newImage(const QString& name, qint32 width, qint32 height, K
     return img;
 }
 
-bool KisDoc2::newImage(const QString& name, qint32 width, qint32 height, KoColorSpace * cs, const KoColor &bgColor, const QString &description, const double imgResolution)
+bool KisDoc2::newImage(const QString& name, qint32 width, qint32 height, const KoColorSpace * cs, const KoColor &bgColor, const QString &description, const double imgResolution)
 {
     if (!init())
         return false;
@@ -935,15 +936,21 @@ KoShapeControllerBase * KisDoc2::shapeController()
     return m_d->shapeController;
 }
 
-KoShape * KisDoc2::shapeForLayer( KisNodeSP layer )
+KoShape * KisDoc2::shapeForNode( KisNodeSP layer )
 {
-    return m_d->shapeController->shapeForLayer( layer );
+    return m_d->shapeController->shapeForNode( layer );
 }
 
 
-KisNodeModel * KisDoc2::layerModel()
+KoShape * KisDoc2::addShape(const KisNodeSP node)
 {
-    return m_d->layerModel;
+    m_d->shapeController->slotNodeAdded( const_cast<KisNode*>(node.data()), 0 );
+    return m_d->shapeController->shapeForNode( node );
+}
+
+KisNodeModel * KisDoc2::nodeModel()
+{
+    return m_d->nodeModel;
 }
 
 void KisDoc2::setIOSteps(qint32 nsteps)
@@ -1011,7 +1018,7 @@ void KisDoc2::setCurrentImage(KisImageSP image)
     m_d->image = image;
     m_d->image->setUndoAdapter( m_d->undoAdapter );
     m_d->shapeController->setImage( image );
-    m_d->layerModel->setImage( image );
+    m_d->nodeModel->setImage( image );
     setUndo(true);
 
     emit sigLoadingFinished();
@@ -1020,7 +1027,7 @@ void KisDoc2::setCurrentImage(KisImageSP image)
 void KisDoc2::initEmpty()
 {
     KisConfig cfg;
-    KoColorSpace * rgb = KoColorSpaceRegistry::instance()->rgb8();
+    const KoColorSpace * rgb = KoColorSpaceRegistry::instance()->rgb8();
     newImage("", cfg.defImgWidth(), cfg.defImgHeight(), rgb);
 }
 
