@@ -50,7 +50,7 @@ public slots:
 
 private:
     struct Private;
-    Private* const d;
+    Private* const m_d;
 };
 
 #endif
