@@ -13,28 +13,48 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef KIS_GRADIENT_CHOOSER_H_
 #define KIS_GRADIENT_CHOOSER_H_
 
+#include <kdialog.h>
+
 #include "kis_itemchooser.h"
 
 class QLabel;
+class QPushButton;
+class KisView2;
+class KisAutogradient;
+class KisCustomGradientDialog : public KDialog {
 
-class KisGradientChooser : public KisItemChooser {
-	typedef KisItemChooser super;
-	Q_OBJECT
+    Q_OBJECT
 
 public:
-	KisGradientChooser(QWidget *parent = 0, const char *name = 0);
-	virtual ~KisGradientChooser();
 
-protected:
-	virtual void update(KoIconItem *item);
+    KisCustomGradientDialog(KisView2 * view, QWidget * parent, const char *name);
 
 private:
-	QLabel *m_lbName;
+
+    KisAutogradient * m_page;
+
+};
+
+class KisGradientChooser : public KisItemChooser {
+
+    Q_OBJECT
+
+public:
+    // XXX: On library redesign, remove m_view parameter here, it's just a temporary hack for the autogradient dialog!
+    KisGradientChooser(KisView2 * view, QWidget *parent = 0, const char *name = 0);
+    virtual ~KisGradientChooser();
+
+protected:
+    virtual void update(QTableWidgetItem *item);
+
+private:
+    QLabel *m_lbName;
+    QPushButton * m_customGradient;
 };
 
 #endif // KIS_GRADIENT_CHOOSER_H_
