@@ -42,7 +42,6 @@
 #include <KoSelection.h>
 #include <KoShapeManager.h>
 
-
 #include <kis_clone_layer.h>
 #include <kis_shape_layer.h>
 #include <kis_adjustment_layer.h>
@@ -71,7 +70,6 @@
 #include "kis_doc2.h"
 #include "kis_filter_manager.h"
 #include "kis_image_commands.h"
-#include "kis_label_progress.h"
 #include "kis_layer_commands.h"
 #include "kis_resource_provider.h"
 #include "kis_selection_manager.h"
@@ -79,6 +77,8 @@
 #include "kis_view2.h"
 #include "kis_zoom_manager.h"
 #include "kis_canvas2.h"
+#include <kis_node_commands.h>
+
 
 KisLayerManager::KisLayerManager( KisView2 * view, KisDoc2 * doc )
     : m_view( view )
@@ -123,37 +123,7 @@ KisPaintDeviceSP KisLayerManager::activeDevice()
 
 void KisLayerManager::activateLayer( KisLayerSP layer )
 {
-
     Q_ASSERT( layer );
-
-    // XXX: Set the selection on the shape manager to the active layer
-    // and set call KoSelection::setActiveLayer( KoShapeLayer* layer )
-    // with the parent of the active layer.
-
-    Q_ASSERT( m_view );
-    Q_ASSERT( m_view->canvasBase() );
-    Q_ASSERT( m_view->canvasBase()->globalShapeManager() );
-
-    KoSelection * selection = m_view->canvasBase()->globalShapeManager()->selection();
-    Q_ASSERT( selection );
-
-    KoShape * shape = m_view->document()->shapeForLayer( layer );
-    Q_ASSERT( shape );
-
-    selection->deselectAll();
-    selection->select(shape);
-
-    Q_ASSERT( layer->parent() );
-    KoShape * parentShape = m_view->document()->shapeForLayer( static_cast<KisLayer*>( layer->parent().data() ) );
-    Q_ASSERT( parentShape );
-
-    KoShapeLayer * shapeLayer = dynamic_cast<KoShapeLayer*>( parentShape );
-    Q_ASSERT( shapeLayer );
-
-    // So the KoShapeController class can set the right parent on
-    // layers we add.
-    selection->setActiveLayer( shapeLayer );
-
     m_activeLayer = layer;
     emit sigLayerActivated( layer );
     layersUpdated();
@@ -266,16 +236,6 @@ void KisLayerManager::updateGUI()
         nvisible = nlayers - img->nHiddenLayers();
     }
 
-#if 0
-
-    KisPaintLayer * pl = dynamic_cast<KisPaintLayer*>(layer.data());
-
-    if (pl && ( m_currentColorChooserDisplay != KoID("BLA") ||
-                pl->paintDevice()->colorSpace()->id() != m_currentColorChooserDisplay)) {
-        m_currentColorChooserDisplay = pl->paintDevice()->colorSpace()->id();
-    }
-#endif
-
     bool enable = img && layer && layer->visible() && !layer->locked();
 
     m_layerDup->setEnabled(enable);
@@ -379,61 +339,11 @@ void KisLayerManager::actLayerVisChanged(int show)
 
 void KisLayerManager::layerProperties()
 {
-    if ( activeLayer() )
-        showLayerProperties( activeLayer() );
-}
+    KisLayerSP layer = m_activeLayer;
 
-namespace {
-        class KisChangeFilterCmd : public QUndoCommand {
-            typedef QUndoCommand super;
-        public:
-            // The QStrings are the _serialized_ configs
-            KisChangeFilterCmd(KisAdjustmentLayerSP layer,
-                               KisFilterConfiguration* config,
-                               const QString& before,
-                               const QString& after) : super(i18n("Change Filter"))
-            {
-                m_layer = layer;
-                m_config = config;
-                m_before = before;
-                m_after = after;
-            }
-        public:
-            virtual void redo()
-            {
-                QApplication::setOverrideCursor(KisCursor::waitCursor());
-                m_config->fromLegacyXML(m_after);
-                //Q_ASSERT(m_after == m_config->toString());
-                m_layer->setFilter(m_config);
-                m_layer->setDirty();
-                QApplication::restoreOverrideCursor();
-            }
-
-            virtual void undo()
-            {
-                QApplication::setOverrideCursor(KisCursor::waitCursor());
-                m_config->fromLegacyXML(m_before);
-                //Q_ASSERT(m_before == m_config->toString());
-                m_layer->setFilter(m_config);
-                m_layer->setDirty();
-                QApplication::restoreOverrideCursor();
-            }
-        private:
-            KisAdjustmentLayerSP m_layer;
-            KisFilterConfiguration* m_config;
-            QString m_before;
-            QString m_after;
-        };
-}
-
-
-
-void KisLayerManager::showLayerProperties(KisLayerSP layer)
-{
-    Q_ASSERT( layer );
     if ( !layer ) return;
 
-    KoColorSpace * cs = 0;
+    const KoColorSpace * cs = 0;
     KisPaintLayer * pl = dynamic_cast<KisPaintLayer*>( layer.data() );
     if ( pl ) {
         cs = pl->paintDevice()->colorSpace();
@@ -445,14 +355,19 @@ void KisLayerManager::showLayerProperties(KisLayerSP layer)
 
     if (KisAdjustmentLayerSP alayer = KisAdjustmentLayerSP(dynamic_cast<KisAdjustmentLayer*>(layer.data())))
     {
-        KisDlgAdjLayerProps dlg(alayer, alayer->name(), i18n("Adjustment Layer Properties"), m_view, "dlgadjlayerprops");
+        KisPaintDeviceSP dev = alayer->projection();
+        KisLayerSP prev = dynamic_cast<KisLayer*>( alayer->prevSibling().data() );
+        if ( prev ) dev = prev->projection();
+
+        KisDlgAdjLayerProps dlg( dev, alayer->filter(), alayer->name(), i18n("Adjustment Layer Properties"), m_view, "dlgadjlayerprops");
         QString before = dlg.filterConfiguration()->toLegacyXML();
         if (dlg.exec() == QDialog::Accepted)
         {
-            KisChangeFilterCmd * cmd = new KisChangeFilterCmd(alayer,
-                    dlg.filterConfiguration(),
-                    before,
-                    dlg.filterConfiguration()->toLegacyXML());
+            KisChangeFilterCmd<KisAdjustmentLayerSP> * cmd
+                = new KisChangeFilterCmd<KisAdjustmentLayerSP>(alayer,
+                                                               dlg.filterConfiguration(),
+                                                               before,
+                                                               dlg.filterConfiguration()->toLegacyXML());
             cmd->redo();
             m_view->undoAdapter()->addCommand(cmd);
             m_doc->setModified( true );
@@ -474,23 +389,28 @@ void KisLayerManager::showLayerProperties(KisLayerSP layer)
                 layer->opacity() != dlg.getOpacity() ||
                 layer->compositeOp() != dlg.getCompositeOp() ||
                 oldChannelFlags != newChannelFlags
-                )
+               )
             {
                 QApplication::setOverrideCursor(KisCursor::waitCursor());
                 m_view->undoAdapter()->addCommand(new KisImageLayerPropsCommand(layer->image(),
-                                                                                layer,
-                                                                                dlg.getOpacity(),
-                                                                                dlg.getCompositeOp(),
-                                                                                dlg.getName(),
-                                                                                newChannelFlags));
+                    layer,
+                    dlg.getOpacity(),
+                    dlg.getCompositeOp(),
+                    dlg.getName(),
+                    newChannelFlags));
                 layer->setDirty();
                 QApplication::restoreOverrideCursor();
                 m_doc->setModified( true );
             }
         }
     }
+
 }
 
+
+
+
+
 void KisLayerManager::layerAdd()
 {
     KisImageSP img = m_view->image();
@@ -501,7 +421,7 @@ void KisLayerManager::layerAdd()
         addLayer(img->rootLayer(), KisLayerSP(0));
 }
 
-void KisLayerManager::addLayer(KisNodeSP parent, KisLayerSP above)
+void KisLayerManager::addLayer(KisNodeSP parent, KisNodeSP above)
 {
     KisImageSP img = m_view->image();
     if (img) {
@@ -518,7 +438,7 @@ void KisLayerManager::addLayer(KisNodeSP parent, KisLayerSP above)
     }
 }
 
-void KisLayerManager::addGroupLayer(KisNodeSP parent, KisLayerSP above)
+void KisLayerManager::addGroupLayer(KisNodeSP parent, KisNodeSP above)
 {
     KisImageSP img = m_view->image();
     if (img) {
@@ -544,7 +464,7 @@ void KisLayerManager::addCloneLayer()
         addCloneLayer(img->rootLayer(), KisLayerSP(0));
 }
 
-void KisLayerManager::addCloneLayer( KisNodeSP parent, KisLayerSP above )
+void KisLayerManager::addCloneLayer( KisNodeSP parent, KisNodeSP above )
 {
     KisImageSP img = m_view->image();
     if ( img ) {
@@ -588,14 +508,14 @@ void KisLayerManager::addShapeLayer()
 }
 
 
-void KisLayerManager::addShapeLayer( KisNodeSP parent, KisLayerSP above )
+void KisLayerManager::addShapeLayer( KisNodeSP parent, KisNodeSP above )
 {
     KisImageSP img = m_view->image();
     if ( img ) {
         // XXX: Make work with nodes!
         KisLayer * parentLayer = dynamic_cast<KisLayer*>( parent.data() );
         KoShapeContainer * parentContainer =
-            dynamic_cast<KoShapeContainer*>( m_doc->shapeForLayer( parentLayer ) );
+            dynamic_cast<KoShapeContainer*>( m_doc->shapeForNode( parentLayer ) );
         if ( !parentContainer ) return;
 
         KisLayerSP layer = new KisShapeLayer(parentContainer, img.data(), img->nextLayerName(), OPACITY_OPAQUE );
@@ -615,7 +535,7 @@ void KisLayerManager::addAdjustmentLayer()
     addAdjustmentLayer( activeLayer()->parent(), activeLayer() );
 }
 
-void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisLayerSP above)
+void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisNodeSP above)
 {
     Q_ASSERT(parent);
     Q_ASSERT(above);
@@ -659,10 +579,7 @@ void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisLayerSP above)
 
     KisDlgAdjustmentLayer dlg(dev, img->nextLayerName(), i18n("New Adjustment Layer"), m_view, "dlgadjustmentlayer");
     if (dlg.exec() == QDialog::Accepted) {
-        KisSelectionSP selection = KisSelectionSP(0);
-        if (dev->hasSelection()) {
-            selection = dev->selection();
-        }
+        KisSelectionSP selection = l->selection();
         KisFilterConfiguration * filter = dlg.filterConfiguration();
         QString name = dlg.layerName();
 
@@ -671,7 +588,7 @@ void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisLayerSP above)
     }
 }
 
-void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisLayerSP above, const QString & name,
+void KisLayerManager::addAdjustmentLayer(KisNodeSP parent, KisNodeSP above, const QString & name,
                                  KisFilterConfiguration * filter, KisSelectionSP selection)
 {
     Q_ASSERT(parent);
@@ -695,7 +612,6 @@ void KisLayerManager::layerRemove()
 
         if (layer) {
 
-
             img->removeLayer(layer);
 
             if (layer->parent())
@@ -847,7 +763,8 @@ void KisLayerManager::scaleLayer(double sx, double sy, KisFilterStrategy *filter
         Q_CHECK_PTR(t);
     }
 
-    KisTransformWorker worker(dev, sx, sy, 0, 0, 0.0, 0, 0, m_view->statusBar()->progress(), filterStrategy);
+    // XXX_PROGRESS: pass KoUpdater
+    KisTransformWorker worker(dev, sx, sy, 0, 0, 0.0, 0, 0, 0, filterStrategy);
     worker.run();
 
     if (t) m_view->undoAdapter()->addCommand(t);
@@ -871,15 +788,16 @@ void KisLayerManager::rotateLayer(double radians)
 
     KisFilterStrategy *filter = KisFilterStrategyRegistry::instance()->value("Triangle");
     QRect r;
-    if(dev->hasSelection())
-        r = dev->selection()->selectedExactRect();
+
+    if(KisSelectionSP selection = activeLayer()->selection())
+        r = selection->selectedExactRect();
     else
         r = dev->exactBounds();
     double cx = r.x()+r.width()/2.0;
     double cy = r.y()+r.height()/2.0;
     qint32 tx = qint32(cx*cos(radians) - cy*sin(radians) - cx + 0.5);
     qint32 ty = qint32(cy*cos(radians) + cx*sin(radians) - cy + 0.5);
-    KisTransformWorker tw(dev, 1.0, 1.0, 0, 0, radians, -tx, -ty, m_view->statusBar()->progress(), filter);
+    KisTransformWorker tw(dev, 1.0, 1.0, 0, 0, radians, -tx, -ty, 0, filter);
     tw.run();
 
     if (t) m_view->undoAdapter()->addCommand(t);
@@ -901,7 +819,7 @@ void KisLayerManager::shearLayer(double angleX, double angleY)
         undo->beginMacro(i18n("Shear layer"));
     }
 
-    KisShearVisitor v(angleX, angleY, m_view->statusBar()->progress());
+    KisShearVisitor v(angleX, angleY, 0);
     v.setUndoAdapter(undo);
     layer->accept(v);
 
@@ -952,7 +870,6 @@ void KisLayerManager::mergeLayer()
 
 void KisLayerManager::layersUpdated()
 {
-
     KisLayerSP layer = activeLayer();
     if (!layer) return;
 
@@ -1004,7 +921,7 @@ void KisLayerManager::saveLayerAsImage()
 
 bool KisLayerManager::activeLayerHasSelection()
 {
-    return ( activeDevice() && activeDevice()->hasSelection() );
+    return ( activeLayer()->selection() != 0 );
 }
 
 
