@@ -1083,7 +1083,7 @@ QString Cell::saveOasisCellStyle( KoGenStyle &currentCellStyle, KoGenStyles &mai
     if ( !conditions.isEmpty() )
     {
         // this has to be an automatic style
-        currentCellStyle = KoGenStyle( Doc::STYLE_CELL_AUTO, "table-cell" );
+        currentCellStyle = KoGenStyle( KoGenStyle::StyleAutoTableCell, "table-cell" );
         conditions.saveOasisConditions( currentCellStyle );
     }
     return style().saveOasis( currentCellStyle, mainStyles, d->sheet->doc()->styleManager() );
@@ -1993,9 +1993,9 @@ bool Cell::loadCellData(const KoXmlElement & text, Paste::Operation op )
     else // old docs: do the ugly solution of parsing the text
     {
       // ...except for date/time
-      if (isDate() && ( t.contains('/') == 2 ))
+      if (isDate() && ( t.count('/') == 2 ))
         dataType = "Date";
-      else if (isTime() && ( t.contains(':') == 2 ) )
+      else if (isTime() && ( t.count(':') == 2 ) )
         dataType = "Time";
       else
       {
