@@ -35,8 +35,12 @@
 #define KSPREAD_CELL
 
 #include <QDate>
+#include <QLinkedList>
+#include <QList>
 #include <QSharedDataPointer>
 
+#include <KoXmlReader.h>
+
 #include "Condition.h"
 #include "Global.h"
 #include "Format.h"
@@ -53,14 +57,13 @@ class KLocale;
 class KoXmlWriter;
 class KoGenStyles;
 class KoGenStyle;
-class KoOdfLoadingContext;
+class KoOasisLoadingContext;
 
 namespace KSpread
 {
 class Doc;
 class Formula;
-class OdfLoadingContext;
-class OdfSavingContext;
+class GenValidationStyles;
 class Sheet;
 class Validity;
 class Value;
@@ -86,18 +89,18 @@ public:
      * Constructor.
      * Creates a Cell for accessing the data in \p sheet at position \p col , \p row .
      */
-    Cell(const Sheet* sheet, int column, int row);
+    Cell( const Sheet* sheet, int column, int row );
 
     /**
      * Constructor.
      * Creates a Cell for accessing the data in \p sheet at position \p pos .
      */
-    Cell(const Sheet* sheet, const QPoint& pos);
+    Cell( const Sheet* sheet, const QPoint& pos );
 
     /**
      * Copy constructor.
      */
-    Cell(const Cell& other);
+    Cell( const Cell& other );
 
     /**
      * Destructor.
@@ -109,6 +112,11 @@ public:
      */
     Sheet* sheet() const;
 
+    /**
+     * \return the document this cell belongs to
+     */
+    Doc* doc() const;
+
     /**
      * Returns the locale setting of this cell.
      */
@@ -166,19 +174,19 @@ public:
      * Given the cell position, this static function returns the name of the cell.
      * Example: name(5,4) will return "E4".
      */
-    static QString name(int col, int row);
+    static QString name( int col, int row );
 
     /**
      * Given the sheet and cell position, this static function returns the full name
      * of the cell, i.e. with the name of the sheet.
      */
-    static QString fullName(const Sheet *s, int col, int row);
+    static QString fullName( const Sheet *s, int col, int row );
 
     /**
      * Given the column number, this static function returns the corresponding
      * column name, i.e. the first column is "A", the second is "B", and so on.
      */
-    static QString columnName(uint column);
+    static QString columnName( uint column );
 
     /**
      * \return the output text, e.g. the result of a formula
@@ -190,14 +198,14 @@ public:
      */
     QString comment() const;
 
-    void setComment(const QString& comment);
+    void setComment( const QString& comment );
 
     /**
      * \return the conditions associated with this cell
      */
     Conditions conditions() const;
 
-    void setConditions(const Conditions& conditions);
+    void setConditions( const Conditions& conditions );
 
     /**
      * \return the database associated with this cell
@@ -213,7 +221,7 @@ public:
     /**
      * Sets \p formula as associated formula of this cell.
      */
-    void setFormula(const Formula& formula);
+    void setFormula( const Formula& formula );
 
     /**
      * Returns the link associated with cell. It is empty if this cell
@@ -227,7 +235,7 @@ public:
      * Possible choices for link are URL (web, ftp), e-mail address, local file,
      * or another cell.
      */
-    void setLink(const QString& link);
+    void setLink( const QString& link );
 
     /**
      * \return the Style associated with this Cell
@@ -240,14 +248,14 @@ public:
      */
     Style effectiveStyle() const;
 
-    void setStyle(const Style& style);
+    void setStyle( const Style& style );
 
     /**
      * \return the validity checks associated with this cell
      */
     Validity validity() const;
 
-    void setValidity(Validity validity);
+    void setValidity( Validity validity );
 
     /**
      * Returns the value that this cell holds. It could be from the user
@@ -264,7 +272,7 @@ public:
      *
      * \see setUserInput, parseUserInput
      */
-    void setValue(const Value& value);
+    void setValue( const Value& value );
 
     /**
      * Return the text the user entered. This could be a value (e.g. "14.03")
@@ -279,7 +287,7 @@ public:
      *
      * \see parseUserInput, setValue
      */
-    void setUserInput(const QString& text);
+    void setUserInput( const QString& text );
 
     /**
      * Sets the user input and parses it.
@@ -290,16 +298,16 @@ public:
      *
      * \see setUserInput, setValue
      */
-    void parseUserInput(const QString& text);
+    void parseUserInput( const QString& text );
 
     /**
      * \ingroup NativeFormat
      */
-    bool load(const KoXmlElement& cell,
-              int _xshift, int _yshift,
-              Paste::Mode pm = Paste::Normal,
-              Paste::Operation op = Paste::OverWrite,
-              bool paste = false);
+    bool load( const KoXmlElement& cell,
+               int _xshift, int _yshift,
+               Paste::Mode pm = Paste::Normal,
+               Paste::Operation op = Paste::OverWrite,
+               bool paste = false );
 
     /**
      * \ingroup NativeFormat
@@ -329,30 +337,31 @@ public:
      * \ingroup OpenDocument
      * Loads a cell from an OASIS XML element.
      * @param element An OASIS XML element
-     * @param tableContext The loading context assoiated with the XML element
+     * @param oasisContext The loading context assoiated with the XML element
      */
-    bool loadOdf(const KoXmlElement& element, OdfLoadingContext& tableContext);
+    bool loadOasis( const KoXmlElement& element, KoOasisLoadingContext& oasisContext );
 
     /**
      * \ingroup OpenDocument
      */
-    bool saveOdf(KoXmlWriter& xmlwriter, KoGenStyles& mainStyles,
-                 int row, int column, int &repeated,
-                 OdfSavingContext& savingContext);
+    bool saveOasis( KoXmlWriter& xmlwriter, KoGenStyles& mainStyles,
+                    int row, int column, int &repeated,
+                    GenValidationStyles &valStyle, const QMap<int, Style>& columnDefaultStyles,
+                    const QMap<int, Style>& rowDefaultStyles );
 
     /**
      * Copies the format from \p cell .
      *
      * @see copyAll(Cell *cell)
      */
-    void copyFormat(const Cell& cell);
+    void copyFormat( const Cell& cell );
 
     /**
      * Copies the content from \p cell .
      *
      * @see copyAll(Cell *cell)
      */
-    void copyContent(const Cell& cell);
+    void copyContent( const Cell& cell );
 
     /**
      * Copies the format and the content from \p cell .
@@ -360,7 +369,7 @@ public:
      * @see copyContent( const Cell& cell )
      * @see copyFormat( const Cell& cell )
      */
-    void copyAll(const Cell& cell);
+    void copyAll( const Cell& cell);
 
     /**
      * @return the width of this cell as double
@@ -418,7 +427,7 @@ public:
      * @param _y tells to occupy _y additional cells in the vertical
      *
      */
-    void mergeCells(int _col, int _row, int _x, int _y);
+    void mergeCells( int _col, int _row, int _x, int _y );
 
     /**
      * @return true if the cell is forced to obscure other cells.
@@ -482,7 +491,7 @@ public:
      *
      * @return the merged text.
      */
-    QString pasteOperation(const QString &new_text, const QString &old_text, Paste::Operation op);
+    QString pasteOperation( const QString &new_text, const QString &old_text, Paste::Operation op );
 
     //
     //END Cut & paste
@@ -512,8 +521,6 @@ public:
     bool isDate() const;
     /** returns true, if cell format is of time type or content is a time */
     bool isTime() const;
-    /** returns true, if cell format is of text type */
-    bool isText() const;
 
     //
     //END Effective style attributes
@@ -526,21 +533,21 @@ public:
     /**
      * Assignment.
      */
-    Cell& operator=(const Cell& other);
+    Cell& operator=( const Cell& other );
 
     /**
-     * Tests whether this cell's location is less than the \p other 's.
+     * Tests wether this cell's location is less than the \p other 's.
      * (QMap support)
      * \note Does not compare the cell attributes/data.
      */
-    bool operator<(const Cell& other) const;
+    bool operator<( const Cell& other ) const;
 
     /**
      * Tests for equality with \p other 's location only.
      * (QHash support)
      * \note Does not compare the cell attributes/data.
      */
-    bool operator==(const Cell& other) const;
+    bool operator==( const Cell& other ) const;
 
     /**
      * Is null.
@@ -558,7 +565,7 @@ public:
     /**
      * Tests for equality of all cell attributes/data to those in \p other .
      */
-    bool compareData(const Cell& other) const;
+    bool compareData( const Cell& other ) const;
 
 protected:
     /**
@@ -566,17 +573,17 @@ protected:
      * Load the text paragraphs from an OASIS XML cell description.
      * @param parent The DOM element representing the cell.
      */
-    void loadOdfCellText(const KoXmlElement& parent);
+    void loadOasisCellText( const KoXmlElement& parent );
 
     /**
      * \ingroup OpenDocument
      */
-    void loadOdfObjects(const KoXmlElement& e, KoOdfLoadingContext& odfContext);
+    void loadOasisObjects( const KoXmlElement& e, KoOasisLoadingContext& oasisContext );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfAnnotation(KoXmlWriter &xmlwriter);
+    void saveOasisAnnotation( KoXmlWriter &xmlwriter );
 
 private:
     class Private;
@@ -585,42 +592,32 @@ private:
     /**
      * \ingroup NativeFormat
      */
-    bool loadCellData(const KoXmlElement &text, Paste::Operation op, const QString &dataType = QString());
+    bool loadCellData(const KoXmlElement &text, Paste::Operation op);
 
     /**
      * \ingroup NativeFormat
      */
-    bool saveCellResult(QDomDocument& doc, QDomElement& result, QString str);
+    bool saveCellResult( QDomDocument& doc, QDomElement& result, QString str );
 
     /**
      * \ingroup OpenDocument
      */
-    void saveOdfValue(KoXmlWriter &xmlWriter);
+    void saveOasisValue (KoXmlWriter &xmlWriter);
 
     /**
      * \ingroup OpenDocument
      * @return the OASIS style's name
      */
-    QString saveOdfCellStyle(KoGenStyle &currentCellStyle, KoGenStyles &mainStyles);
+    QString saveOasisCellStyle( KoGenStyle &currentCellStyle, KoGenStyles &mainStyles );
 };
 
-inline uint qHash(const Cell& cell)
+inline uint qHash( const Cell& cell )
 {
-    return (static_cast<uint>(cell.column()) << 16) + static_cast<uint>(cell.row());
+    return ( static_cast<uint>( cell.column() ) << 16 ) + static_cast<uint>( cell.row() );
 }
 
 } // namespace KSpread
 
-Q_DECLARE_TYPEINFO(KSpread::Cell, Q_MOVABLE_TYPE);
-
-
-/***************************************************************************
-  kDebug support
-****************************************************************************/
-
-inline kdbgstream operator<<(kdbgstream str, const KSpread::Cell& cell)
-{
-    return str << qPrintable(KSpread::Cell::columnName(cell.column()) + QString::number(cell.row()));
-}
+Q_DECLARE_TYPEINFO( KSpread::Cell, Q_MOVABLE_TYPE );
 
 #endif  // KSPREAD_CELL
