@@ -20,9 +20,10 @@
 
 // Local
 #include "DependencyManager.h"
+#include "DependencyManager_p.h"
 
 #include <QHash>
-#include <QLinkedList>
+#include <QList>
 
 #include "Cell.h"
 #include "CellStorage.h"
@@ -37,115 +38,6 @@
 
 using namespace KSpread;
 
-class DependencyManager::Private
-{
-public:
-    /**
-     * Clears internal structures.
-     */
-    void reset();
-
-    /**
-     * Generates the dependencies of \p cell .
-     * First, it removes the old providing region. Then, the new providing
-     * region is computed. Finally, adds \p cell as consumer and the new
-     * providing region to the data structures.
-     * \see removeDependencies
-     * \see computeDependencies
-     */
-    void generateDependencies(const Cell& cell, const Formula& formula);
-
-    /**
-     * Computes the reference depth.
-     * Depth means the maximum depth of all cells this cell depends on plus one,
-     * while a cell, which do not refer to other cells, has a depth
-     * of zero.
-     *
-     * Examples:
-     * \li A1: '=1.0'
-     * \li A2: '=A1+A1'
-     * \li A3: '=A1+A1+A2'
-     *
-     * \li depth(A1) = 0
-     * \li depth(A2) = 1
-     * \li depth(A3) = 2
-     */
-    int computeDepth(Cell cell) const;
-
-    /**
-     * Used in the recalculation events for changed regions.
-     * Determines the reference depth for each position in \p region .
-     *
-     * \see computeDepth
-     * \see generateDepths(Cell cell)
-     */
-    void generateDepths(const Region& region);
-
-    /**
-     * Generates the depth of cell and all of its consumers.
-     * Calls itself recursively for the cell's consuming cells.
-     */
-    void generateDepths(Cell cell);
-
-    /**
-     * Returns the region, that consumes the value of \p cell.
-     * \return region consuming \p cell 's value
-     */
-    Region consumingRegion(const Cell& cell) const;
-
-    void namedAreaModified(const QString& name);
-
-    /**
-     * Removes all dependencies of \p cell .
-     */
-    void removeDependencies(const Cell& cell);
-
-    /**
-     * Removes the depths of \p cell and all its consumers.
-     */
-    void removeDepths(const Cell& cell);
-
-    /**
-     * Computes and stores the dependencies.
-     */
-    void computeDependencies(const Cell& cell, const Formula& formula);
-
-    enum Direction { Forward, Backward };
-    /**
-     * Removes the circular dependency flag from \p region and all their dependencies.
-     */
-    void removeCircularDependencyFlags( const Region& region, Direction direction );
-
-    /**
-     * For debugging/testing purposes.
-     */
-    void dump() const;
-
-    const Map* map;
-    // stores providing regions ordered by their consuming cell locations
-    QHash<Cell, Region> providers;
-    // stores consuming cell locations ordered by their providing regions
-    QHash<Sheet*, RTree<Cell>*> consumers;
-    // stores consuming cell locations ordered by their providing named area
-    QHash<QString, QList<Cell> > namedAreaConsumers;
-    /*
-     * Stores cells with its reference depth.
-     * Depth means the maximum depth of all cells this cell depends on plus one,
-     * while a cell which has a formula without cell references has a depth
-     * of zero.
-     *
-     * Examples:
-     * \li A1: '=1.0'
-     * \li A2: '=A1+A1'
-     * \li A3: '=A1+A1+A2'
-     *
-     * \li depth(A1) = 0
-     * \li depth(A2) = 1
-     * \li depth(A3) = 2
-     */
-    QHash<Cell, int> depths;
-};
-
 // This is currently not called - but it's really convenient to call it from
 // gdb or from debug output to check that everything is set up ok.
 void DependencyManager::Private::dump() const
@@ -313,12 +205,10 @@ void DependencyManager::regionMoved( const Region& movedRegion, const Cell& dest
     {
         Sheet* const sheet = (*it)->sheet();
         locationOffset.setSheet( ( sheet == destination.sheet() ) ? 0 : destination.sheet() );
-        const QRect range = (*it)->rect();
 
         if ( d->consumers.contains( sheet ) )
         {
-            const QRectF rangeF = QRectF( range ).adjusted( 0, 0, -0.1, -0.1 );
-            QList<Cell> dependentLocations = d->consumers[sheet]->intersects( rangeF );
+            QList<Cell> dependentLocations = d->consumers[sheet]->intersects((*it)->rect());
 
             for ( int i = 0; i < dependentLocations.count(); ++i )
             {
@@ -653,12 +543,11 @@ void DependencyManager::Private::computeDependencies( const Cell& cell, const Fo
                 providingRegion.add(region);
 
                 Sheet* sheet = region.firstSheet();
-                QRectF range = QRectF(region.firstRange()).adjusted(0, 0, -0.1, -0.1);
 
                 // create consumer tree, if not existing yet
                 if ( !consumers.contains( sheet ) ) consumers.insert( sheet, new RTree<Cell>() );
                 // add cell as consumer of the range
-                consumers[sheet]->insert( range, cell );
+                consumers[sheet]->insert(region.firstRange(), cell);
             }
         }
     }
