@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   Copyright 2007 Thorsten Zachmann <zachmann@kde.org>
    Copyright 2005-2006 Inge Wallin <inge@lysator.liu.se>
    Copyright 2004 Ariya Hidayat <ariya@kde.org>
    Copyright 2002-2003 Norbert Andres <nandres@web.de>
@@ -61,12 +62,13 @@
 #include <KoMainWindow.h>
 #include <KoOasisSettings.h>
 #include <KoOasisStyles.h>
+#include <KoOdfReadStore.h>
+#include <KoOdfWriteStore.h>
 #include <KoShapeConfigFactory.h>
 #include <KoShapeFactory.h>
 #include <KoShapeManager.h>
 #include <KoShapeRegistry.h>
 #include <KoStoreDevice.h>
-#include <KoVariable.h>
 #include <KoXmlNS.h>
 #include <KoXmlWriter.h>
 #include <KoZoomHandler.h>
@@ -90,7 +92,6 @@
 #include "SheetShapeContainer.h"
 #include "SheetView.h"
 #include "StyleManager.h"
-#include "Undo.h"
 #include "Util.h"
 #include "ValueCalc.h"
 #include "ValueConverter.h"
@@ -651,7 +652,7 @@ bool Doc::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag
       return false;
     }
 
-    KoXmlWriter* contentWriter = createOasisXmlWriter( &dev, "office:document-content" );
+    KoXmlWriter* contentWriter = KoOdfWriteStore::createOasisXmlWriter( &dev, "office:document-content" );
     KoXmlWriter contentTmpWriter( &contentTmpFile, 1 );
 
 
@@ -667,13 +668,13 @@ bool Doc::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag
     styleManager()->saveOasis( mainStyles );
 
     // Saving the default column style
-    KoGenStyle defaultColumnStyle( Doc::STYLE_COLUMN_USER, "table-column" );
+    KoGenStyle defaultColumnStyle( KoGenStyle::StyleTableColumn, "table-column" );
     defaultColumnStyle.addPropertyPt( "style:column-width", d->defaultColumnFormat->width() );
     defaultColumnStyle.setDefaultStyle( true );
     mainStyles.lookup( defaultColumnStyle, "Default", KoGenStyles::DontForceNumbering );
 
     // Saving the default row style
-    KoGenStyle defaultRowStyle( Doc::STYLE_ROW_USER, "table-row" );
+    KoGenStyle defaultRowStyle( KoGenStyle::StyleTableRow, "table-row" );
     defaultRowStyle.addPropertyPt( "style:row-height", d->defaultRowFormat->height() );
     defaultRowStyle.setDefaultStyle( true );
     mainStyles.lookup( defaultRowStyle, "Default", KoGenStyles::DontForceNumbering );
@@ -684,88 +685,12 @@ bool Doc::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag
     d->namedAreaManager->saveOdf(contentTmpWriter);
     d->databaseManager->saveOdf(contentTmpWriter);
     contentTmpWriter.endElement(); ////office:spreadsheet
-  contentTmpWriter.endElement(); ////office:body
+    contentTmpWriter.endElement(); ////office:body
 
     // Done with writing out the contents to the tempfile, we can now write out the automatic styles
-    contentWriter->startElement( "office:automatic-styles" );
+    mainStyles.saveOdfAutomaticStyles( contentWriter, false );
 
-    Q3ValueList<KoGenStyles::NamedStyle> styles = mainStyles.styles( KoGenStyle::StyleAuto );
-    Q3ValueList<KoGenStyles::NamedStyle>::const_iterator it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "style:style", (*it).name, "style:paragraph-properties" );
-    }
-
-    styles = mainStyles.styles( STYLE_PAGE );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "style:style", (*it).name, "style:table-properties" );
-    }
-
-    styles = mainStyles.styles( STYLE_COLUMN_AUTO );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "style:style", (*it).name, "style:table-column-properties" );
-    }
-
-    styles = mainStyles.styles( STYLE_ROW_AUTO );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "style:style", (*it).name, "style:table-row-properties" );
-    }
-
-    styles = mainStyles.styles( STYLE_CELL_AUTO );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "style:style", (*it).name, "style:table-cell-properties" );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericNumber );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-      (*it).style->writeStyle( contentWriter, mainStyles, "number:number-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericDate );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:date-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericTime );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:time-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericFraction );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:number-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericPercentage );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:percentage-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericCurrency );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:currency-style", (*it).name, 0 );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleNumericScientific );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( contentWriter, mainStyles, "number:number-style", (*it).name, 0 );
-    }
-
-
-    contentWriter->endElement(); // office:automatic-styles
-
-
-   // And now we can copy over the contents from the tempfile to the real one
+    // And now we can copy over the contents from the tempfile to the real one
     contentTmpFile.close();
     contentWriter->addCompleteElement( &contentTmpFile );
 
@@ -778,15 +703,7 @@ bool Doc::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag
     //add manifest line for content.xml
     manifestWriter->addManifestEntry( "content.xml",  "text/xml" );
 
-    //todo add manifest line for style.xml
-    if ( !store->open( "styles.xml" ) )
-        return false;
-
-    manifestWriter->addManifestEntry( "styles.xml",  "text/xml" );
-    saveOasisDocumentStyles( store, mainStyles );
-
-    if ( !store->close() ) // done with styles.xml
-        return false;
+    mainStyles.saveOdfStylesDotXml( store, manifestWriter );
 
 #if 0 // KSPREAD_KOPART_EMBEDDING
     makeUsedPixmapList();
@@ -796,7 +713,7 @@ bool Doc::saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag
     if(!store->open("settings.xml"))
         return false;
 
-    KoXmlWriter* settingsWriter = createOasisXmlWriter(&dev, "office:document-settings");
+    KoXmlWriter* settingsWriter = KoOdfWriteStore::createOasisXmlWriter(&dev, "office:document-settings");
     settingsWriter->startElement("office:settings");
     settingsWriter->startElement("config:config-item-set");
     settingsWriter->addAttribute("config:name", "view-settings");
@@ -880,94 +797,7 @@ void Doc::loadOasisIgnoreList( const KoOasisSettings& settings )
 }
 
 
-void Doc::saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyles ) const
-{
-    KoStoreDevice stylesDev( store );
-    KoXmlWriter* stylesWriter = createOasisXmlWriter( &stylesDev, "office:document-styles" );
-
-    stylesWriter->startElement( "office:styles" );
-    Q3ValueList<KoGenStyles::NamedStyle> styles = mainStyles.styles( KoGenStyle::StyleUser );
-    Q3ValueList<KoGenStyles::NamedStyle>::const_iterator it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:style", (*it).name, "style:paragraph-properties" );
-    }
-
-    // Writing out the common column styles.
-    styles = mainStyles.styles( Doc::STYLE_COLUMN_USER );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-      if ( (*it).style->isDefaultStyle() ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:default-style", (*it).name, "style:table-column-properties" );
-      }
-      else {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:style", (*it).name, "style:table-column-properties" );
-      }
-    }
-
-    // Writing out the row column styles.
-    styles = mainStyles.styles( Doc::STYLE_ROW_USER );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-      if ( (*it).style->isDefaultStyle() ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:default-style", (*it).name, "style:table-row-properties" );
-      }
-      else {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:style", (*it).name, "style:table-row-properties" );
-      }
-    }
-
-    // Writing out the common cell styles.
-    styles = mainStyles.styles( Doc::STYLE_CELL_USER );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        if ( (*it).style->isDefaultStyle() ) {
-          (*it).style->writeStyle( stylesWriter, mainStyles, "style:default-style", (*it).name, "style:table-cell-properties" );
-        }
-        else {
-          (*it).style->writeStyle( stylesWriter, mainStyles, "style:style", (*it).name, "style:table-cell-properties" );
-        }
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StyleHatch );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "draw:hatch", (*it).name, "style:graphic-properties" ,  true,  true /*add draw:name*/);
-    }
-    styles = mainStyles.styles( KoGenStyle::StyleGraphicAuto );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:style", (*it).name , "style:graphic-properties"  );
-    }
-
-    stylesWriter->endElement(); // office:styles
-
-    stylesWriter->startElement( "office:automatic-styles" );
-    styles = mainStyles.styles( KoGenStyle::StylePageLayout );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:page-layout", (*it).name, "style:page-layout-properties", false /*don't close*/ );
-        stylesWriter->endElement();
-    }
-
-    stylesWriter->endElement(); // office:automatic-styles
-    //code from kword
-    stylesWriter->startElement( "office:master-styles" );
-
-    styles = mainStyles.styles( Doc::STYLE_PAGEMASTER );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        (*it).style->writeStyle( stylesWriter, mainStyles, "style:master-page", (*it).name, "" );
-    }
-
-    stylesWriter->endElement(); // office:master-style
-
-
-    stylesWriter->endElement(); // root element (office:document-styles)
-    stylesWriter->endDocument();
-    delete stylesWriter;;
-}
-
-bool Doc::loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles, const KoXmlDocument& settings, KoStore* store)
+bool Doc::loadOdf( KoOdfReadStore & odfStore )
 {
     if ( !d->loadingInfo )
         d->loadingInfo = new LoadingInfo;
@@ -980,7 +810,7 @@ bool Doc::loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles, const
     connect(this, SIGNAL(completed()), this, SLOT(finishLoading()));
     d->spellListIgnoreAll.clear();
 
-    KoXmlElement content = doc.documentElement();
+    KoXmlElement content = odfStore.contentDoc().documentElement();
     KoXmlElement realBody ( KoDom::namedItemNS( content, KoXmlNS::office, "body" ) );
     if ( realBody.isNull() )
     {
@@ -1006,13 +836,13 @@ bool Doc::loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles, const
         return false;
     }
 
-    KoOasisLoadingContext context( this, oasisStyles, store );
+    KoOasisLoadingContext context( this, odfStore.styles(), odfStore.store() );
 
     //load in first
-    styleManager()->loadOasisStyleTemplate( oasisStyles, this );
+    styleManager()->loadOasisStyleTemplate( odfStore.styles(), this );
 
     // load default column style
-    const KoXmlElement* defaultColumnStyle = oasisStyles.defaultStyle( "table-column" );
+    const KoXmlElement* defaultColumnStyle = odfStore.styles().defaultStyle( "table-column" );
     if ( defaultColumnStyle )
     {
 //       kDebug() <<"style:default-style style:family=\"table-column\"";
@@ -1031,7 +861,7 @@ bool Doc::loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles, const
     }
 
     // load default row style
-    const KoXmlElement* defaultRowStyle = oasisStyles.defaultStyle( "table-row" );
+    const KoXmlElement* defaultRowStyle = odfStore.styles().defaultStyle( "table-row" );
     if ( defaultRowStyle )
     {
 //       kDebug() <<"style:default-style style:family=\"table-row\"";
@@ -1065,9 +895,9 @@ bool Doc::loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles, const
     d->databaseManager->loadOdf(body); // table:database-ranges
     d->namedAreaManager->loadOdf(body); // table:named-expressions
 
-    if ( !settings.isNull() )
+    if ( !odfStore.settingsDoc().isNull() )
     {
-        loadOasisSettings( settings );
+        loadOasisSettings( odfStore.settingsDoc() );
     }
     initConfig();
     emit sigProgress(-1);
