@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>
+   Copyright 2007 Thorsten Zachmann <zachmann@kde.org>
    Copyright 2004 Ariya Hidayat <ariya@kde.org>
    Copyright 2002-2003 Norbert Andres <nandres@web.de>
    Copyright 2000-2005 Laurent Montel <montel@kde.org>
@@ -118,22 +119,6 @@ public:
    */
   ~Doc();
 
-  /**
-   * Possible values for the "type" argument of the KoGenStyle constructor.
-   */
-  enum
-  {
-    STYLE_PAGE = KoGenStyle::StyleFirstCustom,      /**< table styles */
-    STYLE_COLUMN_USER,    /**< commmon column styles */
-    STYLE_COLUMN_AUTO,    /**< auto column styles */
-    STYLE_ROW_USER,       /**< common row styles */
-    STYLE_ROW_AUTO,       /**< auto row styles */
-    STYLE_CELL_USER,      /**< common cell styles (used in StyleManager) */
-    STYLE_CELL_AUTO,      /**< auto cell styles */
-    STYLE_PAGEMASTER,     /**< master pages */
-    STYLE_NUMERIC_NUMBER  /**< number styles */
-  };
-
   /**
    * \ingroup OpenDocument
    */
@@ -530,19 +515,12 @@ public:
    */
   virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
 
-  /**
-   * \ingroup OpenDocument
-   * Saves the docment styles.
-   */
-  void saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyles ) const;
-
   /**
    * \ingroup OpenDocument
    * Main loading method.
    * @see Map::loadOasis
    */
-  virtual bool loadOasis( const KoXmlDocument& doc, KoOasisStyles& oasisStyles,
-                          const KoXmlDocument& settings, KoStore* );
+  virtual bool loadOdf( KoOdfReadStore & odfStore );
 
   /**
    * \ingroup OpenDocument
