@@ -33,11 +33,11 @@
 #include "Doc.h"
 #include "Localization.h"
 #include "Sheet.h"
-#include "Undo.h"
 #include "Value.h"
 #include "ValueConverter.h"
 
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 
 #include <QList>
