@@ -26,9 +26,10 @@
 #include "Doc.h"
 #include "Sheet.h"
 #include "Util.h"
-#include "Undo.h"
 #include "View.h"
 
+#include "commands/Undo.h"
+
 #include <kcombobox.h>
 #include <kdebug.h>
 #include <kdialog.h>
