@@ -27,7 +27,7 @@
 // Local
 #include "FormulaDialog.h"
 
-#include <q3textbrowser.h>
+#include <qtextbrowser.h>
 #include <KTabWidget>
 #include <QApplication>
 #include <QCloseEvent>
@@ -116,7 +116,7 @@ FormulaDialog::FormulaDialog( View* parent, const char* name,const QString& form
 
     selectFunction = new QPushButton( page );
     selectFunction->setToolTip( i18n("Insert function") );
-    selectFunction->setIcon( BarIcon( "go-down", K3Icon::SizeSmall ) );
+    selectFunction->setIcon( BarIcon( "go-down", KIconLoader::SizeSmall ) );
     grid1->addWidget( selectFunction, 3, 0 );
 
     result = new KLineEdit( page );
@@ -125,9 +125,10 @@ FormulaDialog::FormulaDialog( View* parent, const char* name,const QString& form
     m_tabwidget = new KTabWidget( page );
     QSizePolicy sp2( QSizePolicy::Expanding, QSizePolicy::Expanding );
     m_tabwidget->setSizePolicy( sp2 );
-    grid1->addWidget( m_tabwidget, 0, 1, 3, 1 );
+    grid1->addWidget( m_tabwidget, 0, 1, 4, 1 );
 
-    m_browser = new Q3TextBrowser( m_tabwidget );
+    m_browser = new QTextBrowser( m_tabwidget );
+    m_browser->document()->setDefaultStyleSheet("h1 { font-size:x-large; } h2 { font-size:large; } h3 { font-size:medium; }");
     m_browser->setMinimumWidth( 300 );
 
     m_tabwidget->addTab( m_browser, i18n("Help") );
@@ -258,6 +259,8 @@ FormulaDialog::FormulaDialog( View* parent, const char* name,const QString& form
 	     this, SLOT( slotSearchText(const QString &) ) );
     connect( searchFunct, SIGNAL( returnPressed() ),
 	     this, SLOT( slotPressReturn() ) );
+
+    resize( QSize(660, 520).expandedTo(minimumSizeHint()) );
 }
 
 FormulaDialog::~FormulaDialog()
@@ -700,7 +703,7 @@ void FormulaDialog::slotSelected( const QString& function )
 
     // Set the help text
     m_browser->setText( m_desc->toQML() );
-    m_browser->setContentsPos( 0, 0 );
+    //m_browser->setContentsPos( 0, 0 );
 
     m_focus=0;
 
