@@ -66,6 +66,7 @@ Value func_effective (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_euro (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_euroconvert (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_fv (valVector args, ValueCalc *calc, FuncExtra *);
+Value func_fvschedule (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_fv_annuity (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_intrate (valVector args, ValueCalc *calc, FuncExtra *);
 Value func_ipmt (valVector args, ValueCalc *calc, FuncExtra *);
@@ -186,7 +187,11 @@ void RegisterFinancialFunctions()
   f->setParamCount (3);
   repo->add (f);
   f = new Function ("FV", func_fv);
-  f->setParamCount (3);
+  f->setParamCount (3, 5);
+  repo->add (f);  
+  f = new Function ("FVSCHEDULE", func_fvschedule);
+  f->setParamCount (2);
+  f->setAcceptArray();
   repo->add (f);
   f = new Function ("FV_ANNUITY", func_fv_annuity);
   f->setParamCount (3);
@@ -235,6 +240,9 @@ void RegisterFinancialFunctions()
   f = new Function ("ODDLYIELD", func_oddlyield);
   f->setParamCount (7,8);
   repo->add (f);
+  f = new Function ("PDURATION", func_duration);
+  f->setParamCount (3);
+  repo->add (f);
   f = new Function ("PMT", func_pmt);
   f->setParamCount (3, 5);
   repo->add (f);
@@ -319,6 +327,21 @@ void awNpv (ValueCalc *c, Value &res, Value val, Value rate)
     res.setElement( 1, 0, c->add( i, Value(1.0) ) ); // increment counter
 }
 
+//
+// helper: calc_fvifa
+//
+static Value calc_fvifa (ValueCalc */*calc*/, Value rate,
+    Value nper)
+{
+  Value res;
+
+  if (rate.isZero())
+    return (nper);
+  else
+    return Value(pow1pm1(rate.asFloat(), nper.asFloat())/rate.asFloat());
+}
+
+
 //
 // helper: getPay
 //
@@ -327,17 +350,24 @@ static Value getPay (ValueCalc *calc, Value rate,
 {
   Value pvif, fvifa;
 
-  if (calc->isZero (rate)) return Value::errorVALUE();
+  // TODO This is for PMT. Check constraints of the other function using this
+  //if (calc->isZero (rate)) return Value::errorVALUE();
+  if ( calc->isZero(rate) )
+    return calc->mul( calc->div( calc->add(pv,fv), nper), Value(-1.0));
 
   //pvif  = pow( 1 + rate, nper );
   //fvifa = ( pvif - 1 ) / rate;
-  pvif = calc->pow (calc->add (rate, 1), nper);
-  fvifa = calc->div (calc->sub (pvif, 1), rate);
+  pvif = Value(pow1p (rate.asFloat(), nper.asFloat()));
+//   fvifa = calc->div (calc->sub (pvif, 1), rate);
+  fvifa = calc_fvifa(calc, rate, nper);
 
   // ( -pv * pvif - fv ) / ( ( 1.0 + rate * type ) * fvifa );
   Value val1 = calc->sub (calc->mul (calc->mul (Value(-1), pv), pvif), fv);
   Value val2 = calc->mul (calc->add (Value(1.0), calc->mul (rate, type)),
       fvifa);
+
+  
+  kDebug()<<"(1.0 + "<<rate<<"*"<<type<<")*"<<fvifa<<") ="<<val2;
   return calc->div (val1, val2);
 }
 
@@ -383,14 +413,27 @@ static double helper_eurofactor(const QString& currency)
 } 
 
 //
-// helper for IPMT and CUMIPMT
+// helper for IPMT and CUMIPMT is calculation of IPMT
 //
 static Value helper_ipmt( ValueCalc* calc, Value rate, Value per, Value nper, Value pv, Value fv, Value type )
 {
-    const Value payment = getPay (calc, rate, nper, pv, fv, type);
-    const Value ineg = getPrinc (calc, pv, payment, rate, calc->sub (per, Value(1)));
-    // -ineg * rate
-    return calc->mul (calc->mul (ineg, Value(-1)), rate);
+//     const Value payment = getPay (calc, rate, nper, pv, fv, type);
+//     const Value ineg = getPrinc (calc, pv, payment, rate, calc->sub (per, Value(1)));
+//     // -ineg * rate
+//     return calc->mul (calc->mul (ineg, Value(-1)), rate);
+
+  const Value pmt = getPay (calc, rate, nper, pv, fv, Value(0)); // Type 0
+
+  // pow1p (rate, per-1)
+  const Value val1 (pow1p (rate.asFloat(), calc->sub( per, Value(1)).asFloat()));
+  // pow1pm1 (rate, per-1)
+  const Value val2 (pow1pm1 (rate.asFloat(), calc->sub( per, Value(1)).asFloat()));
+
+  Value ipmt;
+  // -1*(pv * pow1p(rate, per-1)*rate + pmt* pow1pm1(rate, per-1))
+  ipmt = calc->mul(Value(-1),calc->add(calc->mul( calc->mul( pv, val1), rate), calc->mul(pmt, val2)));
+
+  return (type.isZero()) ? ipmt : calc->div(ipmt, calc->add( Value(1), rate));
 }
 
 
@@ -560,10 +603,12 @@ Value func_accrint (valVector args, ValueCalc *calc, FuncExtra *)
   if ( basis < 0 || basis > 4 || (calc->isZero (Value(frequency))) ||
       (12 % frequency != 0))
     return Value::errorVALUE();
-
-  if ( ( settlement.daysTo( firstInterest ) < 0 )
-       || ( firstInterest.daysTo( maturity ) > 0 ) )
+  
+  if ( maturity >= settlement )
+  {
+    kDebug()<<"maturity >= settlement";
     return Value::errorVALUE();
+  }
 
   double d = daysBetweenDates (maturity, settlement, basis);
   double y = daysPerYear (maturity, basis);
@@ -860,8 +905,8 @@ Value func_cumprinc(valVector args, ValueCalc *calc, FuncExtra *)
     if ( v2.isError() )
         return Value::errorVALUE();
     const int end = v2.asInteger();
-    if ( end < start || end > periods )
-        return Value::errorVALUE();
+    if ( end <=0 || end < start || end > periods )
+        return Value::errorVALUE(); 
     const Value type( calc->conv()->asInteger(args[5]) );
     if ( type.isError() )
         return Value::errorVALUE();
@@ -1177,12 +1222,55 @@ Value func_euroconvert (valVector args, ValueCalc *calc, FuncExtra *)
 //
 Value func_fv (valVector args, ValueCalc *calc, FuncExtra *)
 {
-  Value present = args[0];
-  Value interest = args[1];
-  Value periods = args[2];
+  Value rate = args[0];
+  Value nper = args[1];
+  Value pmt  = args[2];
 
+  // defaults
+  Value pv (0.0);
+  int type = 0;
+  
+  if (args.count() > 3)
+    pv = Value(calc->conv()->asFloat (args[3]).asFloat());
+
+  if (args.count() == 5)
+    type = calc->conv()->asInteger (args[4]).asInteger();
+
+  //TODO check payType
+
+  Value pvif = Value(pow1p (rate.asFloat(), nper.asFloat()));
+  Value fvifa = calc_fvifa(calc, rate, nper);
+
+  Value res (calc->mul( Value(-1), calc->add(calc->mul(pv,pvif), calc->mul(pmt,calc->mul(calc->add(Value(1),calc->mul(rate,type)), fvifa)))));
+
+  return (res);
   // present * pow (1 + interest, periods)
-  return calc->mul (present, calc->pow (calc->add (interest, 1), periods));
+//   return calc->mul (present, calc->pow (calc->add (interest, 1), periods));
+}
+
+//
+// Function: FVSCHEDULE
+//
+// Returns future value
+//
+Value func_fvschedule (valVector args, ValueCalc *calc, FuncExtra *)
+{
+  Value pv       = args[0];
+  Value schedule = args[1];
+
+  int n = schedule.count();
+  int i;
+ 
+  Value v;
+  Value res (pv);
+
+  for ( i = 0; i < n; ++i )
+  {
+    v = args[1].element( i );
+    res = Value(calc->mul(res, calc->add(Value(1),v)));
+  }
+ 
+  return (res);
 }
 
 
@@ -1399,32 +1487,25 @@ Value func_nominal (valVector args, ValueCalc *calc, FuncExtra *)
 //
 Value func_nper (valVector args, ValueCalc *calc, FuncExtra *)
 {
-  Value rate = args[0];
-  Value pmt  = args[1];
-  Value pv   = args[2];
-  Value fv = Value(0.0);
-  Value type = Value(0);
-  if (args.count() > 3) fv = args[3];
-  if (args.count() == 5) type = args[4];
+  double rate = calc->conv()->asFloat (args[0]).asFloat();
+  double pmt = calc->conv()->asFloat (args[1]).asFloat();
+  double pv = calc->conv()->asFloat (args[2]).asFloat();
+  double fv = 0.0;
+  double type = 0;
+  
+  // opt. params
+  if (args.count() > 3) fv = calc->conv()->asFloat (args[3]).asFloat();
+  if (args.count() == 5) type = calc->conv()->asFloat (args[4]).asFloat();
 
-  if (!calc->greater (rate, Value(0.0)))
-    return Value::errorVALUE();
+  // if rate is 0, ther NPER solves this 
+  //   PV = -FV -( Payment*NPER )
+  if (rate == 0.0)
+    return Value( -(pv + fv) / pmt );
 
-  // taken from Gnumeric
-  // v = 1.0 + rate * type
-  // d1 = pmt * v - fv * rate
-  // d2 = pmt * v - pv * rate
-  // res = d1 / d2;
-  Value v = calc->add (calc->mul (rate, type), 1.0);
-  Value d1 = calc->sub (calc->mul (pmt, v), calc->mul (fv, rate));
-  Value d2 = calc->add (calc->mul (pmt, v), calc->mul (pv, rate));
-  Value res = calc->div (d1, d2);
-
-  if (!calc->greater (res, Value(0.0)))  // res must be >0
-    return Value::errorVALUE();
-
-  // ln (res) / ln (rate + 1.0)
-  return calc->div (calc->ln (res), calc->ln (calc->add (rate, Value(1.0))));
+  if ( type > 0 ) 
+    return Value( log( -(rate*fv-pmt*(1.0+rate)) / (rate*pv+pmt*(1.0+rate)) ) / log(1.0+rate) );
+  else
+    return Value( log( -(rate*fv-pmt)/(rate*pv+pmt)) / log(1.0+rate));
 }
 
 
@@ -1468,8 +1549,8 @@ Value func_oddlprice (valVector args, ValueCalc *calc, FuncExtra *)
   if (args.count() > 7)
     basis = calc->conv()->asInteger (args[7]).asInteger();
 
-  kDebug(36002)<<"ODDLPRICE";
-  kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" last="<<last<<" rate="<<rate<<" yield="<<yield<<" redemp="<<redemp<<" freq="<<freq<<" basis="<<basis;
+//   kDebug(36002)<<"ODDLPRICE";
+//   kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" last="<<last<<" rate="<<rate<<" yield="<<yield<<" redemp="<<redemp<<" freq="<<freq<<" basis="<<basis;
 
   // TODO check frequency
   if( yield <= 0.0 || rate <= 0.0 || maturity <= settlement || settlement <= last)
@@ -1485,7 +1566,7 @@ Value func_oddlprice (valVector args, ValueCalc *calc, FuncExtra *)
   res /= dsci * yield / freq + 1.0;
   res -= ai * 100.0 * rate / freq;
   
-  kDebug(36002)<<"res ="<<res;
+//   kDebug(36002)<<"res ="<<res;
   return Value(res);
 }
 
@@ -1508,8 +1589,8 @@ Value func_oddlyield (valVector args, ValueCalc *calc, FuncExtra *)
   if (args.count() > 7)
     basis = calc->conv()->asInteger (args[7]).asInteger();
 
-  kDebug(36002)<<"ODDLYIELD";
-  kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" last="<<last<<" rate="<<rate<<" price="<<price<<" redemp="<<redemp<<" freq="<<freq<<" basis="<<basis;
+//   kDebug(36002)<<"ODDLYIELD";
+//   kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" last="<<last<<" rate="<<rate<<" price="<<price<<" redemp="<<redemp<<" freq="<<freq<<" basis="<<basis;
 
   // TODO check frequency
   if( rate < 0.0 || price <= 0.0 || maturity <= settlement || settlement <= last)
@@ -1526,7 +1607,7 @@ Value func_oddlyield (valVector args, ValueCalc *calc, FuncExtra *)
   res --;
   res *= freq / dsci;
   
-  kDebug(36002)<<"res ="<<res;
+//   kDebug(36002)<<"res ="<<res;
   return Value(res);
 }
 
@@ -1555,28 +1636,32 @@ Value func_pmt (valVector args, ValueCalc *calc, FuncExtra *)
 //
 Value func_ppmt (valVector args, ValueCalc *calc, FuncExtra *)
 {
-  /*
-Docs partly copied from OO.
-Syntax
-PPMT(Rate;Period;NPER;PV;FV;Type)
-
-Rate is the periodic interest rate.
-Period is the amortizement period. P=1 for the first and P=NPER for the last period.
-NPER is the total number of periods during which annuity is paid.
-PV is the present value in the sequence of payments.
-FV (optional) is the desired (future) value.
-Type (optional) defines the due date. F=1 for payment at the beginning of a period and F=0 for payment at the end of a period.
-  */
+  // Docs partly copied from OO.
+  //
+  // PPMT(Rate;Period;NPER;PV;FV;Type)
+  //
+  // Rate is the periodic interest rate.
+  // Period is the amortizement period. P=1 for the first and P=NPER for the last period.
+  // NPER is the total number of periods during which annuity is paid.
+  // PV is the present value in the sequence of payments.
+  // FV (optional) is the desired (future) value.
+  // Type (optional) defines the due date. F=1 for payment at the beginning of a period and F=0 for payment at the end of a period.
+  //
 
   Value rate = args[0];
   Value per  = args[1];
   Value nper = args[2];
   Value pv   = args[3];
+
+  // defaults
   Value fv = Value(0.0);
   Value type = Value(0);
+  
   if (args.count() > 4) fv = args[4];
   if (args.count() == 6) type = args[5];
 
+  kDebug()<<"Type="<<type;
+
   Value pay  = getPay (calc, rate, nper, pv, fv, type);
   Value ipmt = func_ipmt (args, calc, 0);
   return calc->sub (pay, ipmt);
@@ -1990,14 +2075,14 @@ Value func_xnpv (valVector args, ValueCalc *calc, FuncExtra *)
   if ( rate < -1.0 )
     return Value::errorNUM();
 
-  kDebug(36002)<<"XNPV";
-  kDebug(36002)<<"rate ="<<rate<<" numValues ="<<numValues<<" numDates ="<<numDates;
+//   kDebug(36002)<<"XNPV";
+//   kDebug(36002)<<"rate ="<<rate<<" numValues ="<<numValues<<" numDates ="<<numDates;
 
   QDate date0 = calc->conv()->asDate (args[2].element( 0 )).asDate( calc->doc() );
   double val;
   QDate date;
 
-  kDebug(36002)<<"date0 ="<<date0; 
+//   kDebug(36002)<<"date0 ="<<date0; 
 
   for ( int i = 0; i < numValues; ++i )
   {
@@ -2012,10 +2097,10 @@ Value func_xnpv (valVector args, ValueCalc *calc, FuncExtra *)
       return Value::errorNUM();
 
     // debug
-    kDebug(36002)<<"val ="<<val<<" date ="<<date; 
+//     kDebug(36002)<<"val ="<<val<<" date ="<<date; 
 
     int days = date0.daysTo( date );
-    kDebug(36002)<<"days ="<<days;
+//     kDebug(36002)<<"days ="<<days;
 
     res += val / pow( rate, days / 365.0 );
   }
@@ -2039,8 +2124,8 @@ Value func_yielddisc (valVector args, ValueCalc *calc, FuncExtra *)
   if (args.count() > 4) 
     basis = calc->conv()->asInteger (args[4]).asInteger();
 
-  kDebug(36002)<<"YIELDDISC";
-  kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" price="<<price<<" redemp="<<redemp<<" basis="<<basis;
+//   kDebug(36002)<<"YIELDDISC";
+//   kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" price="<<price<<" redemp="<<redemp<<" basis="<<basis;
 
   if( price <= 0.0 || redemp <= 0.0 || settlement >= maturity )
     return Value::errorVALUE();
@@ -2050,7 +2135,7 @@ Value func_yielddisc (valVector args, ValueCalc *calc, FuncExtra *)
   double res = ( redemp / price ) - 1.0;
   res /= yearFrac(date0, settlement, maturity, basis);
 
-  kDebug(36002)<<"res ="<<res;
+//   kDebug(36002)<<"res ="<<res;
   return Value(res);
 }
 
@@ -2071,8 +2156,8 @@ Value func_yieldmat (valVector args, ValueCalc *calc, FuncExtra *)
   if (args.count() > 5)
     basis = calc->conv()->asInteger (args[5]).asInteger();
 
-  kDebug(36002)<<"YIELDMAT";
-  kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" issue="<<issue<<" rate="<<rate<<" price="<<price<<" basis="<<basis;
+//   kDebug(36002)<<"YIELDMAT";
+//   kDebug(36002)<<"settlement ="<<settlement<<" maturity="<<maturity<<" issue="<<issue<<" rate="<<rate<<" price="<<price<<" basis="<<basis;
 
   if( price <= 0.0 || rate <= 0.0 || settlement >= maturity )
     return Value::errorVALUE();
@@ -2088,7 +2173,7 @@ Value func_yieldmat (valVector args, ValueCalc *calc, FuncExtra *)
   res--;
   res /= setMat;
 
-  kDebug(36002)<<"res ="<<res;
+//   kDebug(36002)<<"res ="<<res;
   return Value(res);
 }
 
