@@ -46,8 +46,8 @@ static Value TestDouble(const QString& formula, const Value& v2, int accuracy)
 
   if (!res)
     kDebug(36002)<<"check failed -->" <<"Epsilon =" << epsilon <<"" << v2.asFloat() <<" to" << result.asFloat() <<"  diff =" << v2.asFloat()-result.asFloat();
-  else
-    kDebug(36002)<<"check -->" <<"  diff =" << v2.asFloat()-result.asFloat();
+//   else
+//     kDebug(36002)<<"check -->" <<"  diff =" << v2.asFloat()-result.asFloat();
   if (res)
     return v2;
   else 
@@ -57,8 +57,20 @@ static Value TestDouble(const QString& formula, const Value& v2, int accuracy)
 // ACCRINT
 void TestFinancialFunctions::testACCRINT()
 {
-  // kspread
-  CHECK_EVAL_SHORT( "ACCRINT( \"02/28/2001\"; \"08/31/2001\"; \"05/01/2001\" ;  0.1; 1000; 2; 0 )", Value( 16.944 ) ); 
+  // odf test
+  CHECK_EVAL( "ACCRINT( \"1992-12-01\"; \"1993-06-01\"; \"1993-07-01\";  0.055; 100 ; 2; 0 ) ", Value( 3.2083333333 ) ); 
+  CHECK_EVAL( "ACCRINT( \"2001-02-28\"; \"2001-08-31\";\"2001-05-01\";  0.1  ; 1000; 2; 0 )",
+              Value( 16.9444444444 ) ); // A security is issued on 2.28.2001.
+                                        // First interest is set for 8.31.2001. The settlement date is 5.1.2001.
+                                        // The Rate is 0.1 or 10% and Par is 1000 currency units. Interest is paid
+                                        // half-yearly (frequency is 2). The basis is the US method (0). How much interest has accrued?
+  CHECK_EVAL( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 4; 0 )", Value( 24.7222222222 ) ); // leap year, quaterly, US (NASD) 30/360
+  CHECK_EVAL_SHORT( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 4; 1 )", Value( 24.590164     ) ); // leap year, quaterly, actual/acual
+  CHECK_EVAL( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 4; 2 )", Value( 25            ) ); // leap year, quaterly, actual/360
+  CHECK_EVAL_SHORT( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 4; 3 )", Value( 24.657534     ) ); // leap year, quaterly, actual/365
+  CHECK_EVAL( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 4; 4 )", Value( 25            ) ); // leap year, quaterly, European 30/360
+  CHECK_EVAL( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 1 )",    Value( 24.7222222222 ) ); // leap year, annual, US (NASD) 30/360
+  CHECK_EVAL( "ACCRINT( \"2004-02-01\"; \"2004-04-01\"; \"2004-05-01\"; 0.1; 1000; 2 )",    Value( 24.7222222222 ) ); // leap year, semiannual, US 30/360
 }
 
 // ACCRINTM
@@ -76,16 +88,27 @@ void TestFinancialFunctions::testACCRINTM()
 // AMORDEGRC
 void TestFinancialFunctions::testAMORDEGRC()
 {
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 1 )"  , Value( 228 ) ); // the first period (10 years life time)
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 8; 0.1; 1 )"  , Value(  52 ) ); // the period before last (10 years)
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 9; 0.1; 1 )"  , Value(  52 ) ); // the last period (10 years life time)
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 10; 0.1; 1 )" , Value(   0 ) ); // beyond life time (10 years life time)
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.25; 1 )" , Value( 342 ) ); // the first period (4 years life time)
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 0 )"  , Value( 229 ) ); // leap year, US (NASD) 30/360
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2004-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 1 )"  , Value( 228 ) ); // leap year, actual/actual
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2004-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 2 )"  , Value( 232 ) ); // leap year, actual/360
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2004-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 3 )"  , Value( 229 ) ); // leap year, actual/365
-  CHECK_EVAL_SHORT( "AMORDEGRC( 1000; \"2004-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 4 )"  , Value( 228 ) ); // leap year, European 30/360
+  // Excel Formen und Funktionen
+  CHECK_EVAL( "AMORDEGRC( 2400; 34199; 34334; 300; 1; 0.15; 1 )" , Value( 775 ) ); 
+
+  // bettersolution.com
+  CHECK_EVAL( "AMORDEGRC( 50000; \"2003-01-01\"; \"2003-12-31\"; 500; 1; 0.15; 1 )" , Value( 11738 ) ); // 
+  CHECK_EVAL( "AMORDEGRC( 50000; \"2003-01-01\"; \"2003-12-31\"; 500; 2; 0.15; 1 )" , Value(  7336 ) ); // 
+  CHECK_EVAL( "AMORDEGRC( 50000; \"2003-01-01\"; \"2003-12-31\"; 500; 3; 0.15; 1 )" , Value(  4585 ) ); // 
+  CHECK_EVAL( "AMORDEGRC( 50000; \"2003-01-01\"; \"2003-12-31\"; 500; 4; 0.15; 1 )" , Value(  2866 ) ); // 
+//   CHECK_EVAL_SHORT( "AMORDEGRC( 50000; \"2003-01-01\"; \"2003-12-31\"; 500; 5; 0.15; 1 )" , Value(  2388 ) ); // TODO check KSpread -> 1791
+
+  // odf tests
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 1 )"  , Value( 228 ) ); // the first period (10 years life time)
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 8; 0.1; 1 )"  , Value(  26 ) ); // (specs. 52) the period before last (10 years)
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 9; 0.1; 1 )"  , Value(  19 ) ); // (specs. 52) the last period (10 years life time)
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 10; 0.1; 1 )" , Value(  15 ) ); // (specs. 15) - beyond life time (10 years life time)
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.25; 1 )" , Value( 342 ) ); // the first period (4 years life time)
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 0 )"  , Value( 229 ) ); // leap year, US (NASD) 30/360
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 1 )"  , Value( 228 ) ); // leap year, actual/actual
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 2 )"  , Value( 231 ) ); // (specs 232) leap year, actual/360
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 3 )"  , Value( 228 ) ); // leap year, actual/365
+  CHECK_EVAL( "AMORDEGRC( 1000; \"2006-02-01\"; \"2006-12-31\"; 10; 0; 0.1; 4 )"  , Value( 228 ) ); // leap year, European 30/360
 }
 
 // AMORLINC
@@ -141,8 +164,8 @@ void TestFinancialFunctions::testCUMPRINC()
   CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 5; 12; 0 )", Value( -11904.054201       ) ); // maturity at the end of a period
   CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 5; 12; 1 )", Value( -11844.830051       ) ); // maturity at the beginning of a period
   CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 0;  0; 0 )", Value( Value::errorVALUE() ) ); // start > 0; end > 0
-  CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 5; 12; 0 )", Value( Value::errorVALUE() ) ); // end > periods
-  CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 5; 12; 0 )", Value( Value::errorVALUE() ) ); // start > end
+  CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000; 5; 61; 0 )", Value( Value::errorVALUE() ) ); // end > periods
+  CHECK_EVAL_SHORT( "CUMPRINC( 0.06/12; 5*12; 100000;15; 12; 0 )", Value( Value::errorVALUE() ) ); // start > end
 }
 
 // Fixed-declining balance depreciation
@@ -572,38 +595,38 @@ void TestFinancialFunctions::testEUROCONVERT()
 void TestFinancialFunctions::testFV()
 {
   // ODF
-  CHECK_EVAL_SHORT( "FV(10%;12;-100;100)" , Value( 1824.59 ) ); // A trivial example of FV.
+  CHECK_EVAL( "FV(10%;12;-100;100)" , Value( 1824.5855390489 ) ); // A trivial example of FV.
 }
 
 // FVSCHEDULE
 void TestFinancialFunctions::testFVSCHEDULE()
 {
   // ODF
-  CHECK_EVAL_SHORT( "FVSCHEDULE(1000000; {0.03; 0.04; 0.05})" , Value( 112476 ) ); // A trivial example of FVSCHEDULE.
+  CHECK_EVAL_SHORT( "FVSCHEDULE(1000000; {0.03; 0.04; 0.05})" , Value( 1124760 ) ); // A trivial example of FVSCHEDULE.
 }
 
 // INTRATE
 void TestFinancialFunctions::testINTRATE()
 {
   // ODF
-  CHECK_EVAL_SHORT( "INTRATE( DATE(2002; 6;8); DATE(1995;10;5); 100000; 200000; 0 )" , Value::errorVALUE() ); // Settlement date must be before the maturity date.
-  CHECK_EVAL_SHORT( "INTRATE( DATE(2002; 6;8); DATE(2002; 6;8); 100000; 200000; 0 )" , Value::errorVALUE() ); // Settlement date must be before the maturity date.
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 50)" , Value::errorVALUE() ); // Unknown Basis returns Error.
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 0 )" , Value( 0.14981 ) );    // An example of INTRATE.
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000    )" , Value( 0.14981 ) );    // Basis defaults to 0.
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 1 )" , Value( 0.14971 ) );    //
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 2 )" , Value( 0.14766 ) );    //
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 3 )" , Value( 0.14971 ) );    //
-  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 4 )" , Value( 0.14981 ) );    //
+  CHECK_EVAL_SHORT( "INTRATE( DATE(2002; 6;8); DATE(1995;10;5); 100000; 200000; 0 )" , Value::errorVALUE()   ); // Settlement date must be before the maturity date.
+  CHECK_EVAL_SHORT( "INTRATE( DATE(2002; 6;8); DATE(2002; 6;8); 100000; 200000; 0 )" , Value::errorVALUE()   ); // Settlement date must be before the maturity date.
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 50)" , Value::errorVALUE()   ); // Unknown Basis returns Error.
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 0 )" , Value( 0.1498127341 ) ); // An example of INTRATE.
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000    )" , Value( 0.1498127341 ) ); // Basis defaults to 0.
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 1 )" , Value( 0.1497128794 ) ); //
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 2 )" , Value( 0.1476620180 ) ); //
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 3 )" , Value( 0.1497128794 ) ); //
+  CHECK_EVAL_SHORT( "INTRATE( DATE(1995;10;5); DATE(2002; 6;8); 100000; 200000; 4 )" , Value( 0.1498127341 ) ); //
 }
 
 // IPMT
 void TestFinancialFunctions::testIPMT()
 {
   // ODF
-  CHECK_EVAL_SHORT( "IPMT(5%/12;10;360;100000)", Value( -412.0850243 ) );     // An example of IPMT.  The interest payment on a 100000 unit loan
-                                                                              // in the 10th month of a 30 year loan at 5% annual interest.
-  CHECK_EVAL_SHORT( "IPMT(5%/12;10;360;100000;0;1)", Value( -412.1699604 ) ); // Payments at the beginning of each period.
+  CHECK_EVAL_SHORT( "IPMT(5%/12;10;360;100000)", Value( -412.0850243 ) );        // An example of IPMT.  The interest payment on a 100000 unit loan
+                                                                                 // in the 10th month of a 30 year loan at 5% annual interest.
+  CHECK_EVAL_SHORT( "IPMT(5%/12;10;360;100000;0;1)", Value( -410.3751278993 ) ); // Payments at the beginning of each period.
 
   // The total payment is the principle plus the interest.
   CHECK_EVAL_SHORT( "IPMT(5%/12;10;360;100000)+IPMT(5%/12;10;360;100000)-PMT(5%/12;360;100000)", Value( 0 ) ); 
@@ -612,10 +635,14 @@ void TestFinancialFunctions::testIPMT()
 // ISPMT
 void TestFinancialFunctions::testISPMT()
 {
+  // betersolutions
+  CHECK_EVAL( "ISPMT(10%/12;1 ;36;8000000)", Value(  -64814.8148148148 ) ); //
+  CHECK_EVAL( "ISPMT(10%   ;1 ;3 ;8000000)", Value( -533333.3333333333 ) ); //
+
   // ODF
-  CHECK_EVAL_SHORT( "ISPMT(5%/12;12;360;100000)", Value( -402.78 ) ); // A trivial example of ISPMT.  A 100000 unit investment with an
-                                                                      // annual interest rate of 5% and a 30 year term has an interest payment 
-                                                                      // of 402.78 units in month 12.
+  CHECK_EVAL( "ISPMT(5%/12;12;360;100000)",  Value(    -402.7777777778 ) ); // A trivial example of ISPMT.  A 100000 unit investment with an
+                                                                            // annual interest rate of 5% and a 30 year term has an interest payment 
+                                                                            // of 402.78 units in month 12.
 }
 
 // Level-coupon bond
@@ -729,29 +756,40 @@ void TestFinancialFunctions::testODDLYIELD()
 // PDURATION
 void TestFinancialFunctions::testPDURATION()
 {
-  CHECK_EVAL_SHORT( "PDURATION( 0.1; 10; 100 )" , Value( 24.158858 ) ); //
+  // is DURATION in kspread
+  CHECK_EVAL_SHORT( "PDURATION( 0.1; 10; 100 )" , Value(  24.158858 ) ); // simple use case
+  CHECK_EVAL_SHORT( "PDURATION( 0.1; 100; 10 )" , Value( -24.158858 ) ); // curentValue > desiredValue
+  CHECK_EVAL_SHORT( "PDURATION(   0; 10;  11 )" , Value::errorVALUE() ); // rate > 0
+  CHECK_EVAL_SHORT( "PDURATION( 0.1;  0;  11 )" , Value::errorVALUE() ); // currentValue > 0
+  CHECK_EVAL_SHORT( "PDURATION( 0.1; 10;   0 )" , Value::errorVALUE() ); // desiredValue > 0
 }
 
 // PMT
 void TestFinancialFunctions::testPMT()
 {
   // ODF
-  CHECK_EVAL_SHORT( "PMT(5%;12;1000)",       Value( -112.82541  ) ); // A trivial example of PMT.
-  CHECK_EVAL_SHORT( "PMT(5%;12;1000;100)",   Value( -119.107951 ) ); // A trivial example of PMT with non-zero FV.
-  CHECK_EVAL_SHORT( "PMT(5%;12;1000;100;1)", Value( -113.43614  ) ); // A trivial example of PMT with non-zero FV and PayType.
+  CHECK_EVAL_SHORT( "PMT(5%;12;1000)",       Value( -112.8254100208 ) ); // A trivial example of PMT.
+  CHECK_EVAL_SHORT( "PMT(5%;12;1000;100)",   Value( -119.1079510229 ) ); // A trivial example of PMT with non-zero FV.
+  CHECK_EVAL_SHORT( "PMT(5%;12;1000;100;1)", Value( -113.4361438313 ) ); // A trivial example of PMT with non-zero FV and PayType.
   CHECK_EVAL_SHORT( "PMT(0;10;1000)",        Value( -100.00000  ) ); // TODO Rate can be zero.
 }
 
 // PPMT
 void TestFinancialFunctions::testPPMT()
 {
+  // bettersolution.com
+  CHECK_EVAL( "PPMT(10%/12;1;24;2000)",      Value(    -75.6231860084 ) ); // A simple test case
+  CHECK_EVAL( "PPMT(8%;10;10;200000)",       Value( -27598.0534624214 ) ); // A simple test case
+
   // ODF
-  CHECK_EVAL_SHORT( "PPMT(3%;1;12;100)",           Value(   -7.046208547 ) ); // A simple test case
-  CHECK_EVAL_SHORT( "PPMT(3%;1;12;100;1;200)",     Value(  -21.138625642 ) ); // With future value
-  CHECK_EVAL_SHORT( "PPMT(3%;1;12;100;1;200;1)",   Value(  -23.435558876 ) ); // With future value and type
-  CHECK_EVAL_SHORT( "PPMT(8%;5;24;10000;0)",       Value( -203.773514049 ) ); // With nPer=5 and Future=0
-  CHECK_EVAL_SHORT( "PPMT(8%;10;24;10000;2000)",   Value( -359.292174601 ) ); // With nPer=10 and Future=2000
-  CHECK_EVAL_SHORT( "PPMT(8%;10;24;10000;2000;1)", Value( -332.677939445 ) ); // With Type=1
+  CHECK_EVAL( "PPMT(3%;1;12;100)",           Value(   -7.0462085473 ) ); // A simple test case
+  CHECK_EVAL( "PPMT(8%;5;24;10000;0)",       Value( -203.7735140493 ) ); // With nPer=5 and Future=0
+  CHECK_EVAL( "PPMT(8%;10;24;10000;2000)",   Value( -359.2921746011 ) ); // With nPer=10 and Future=2000
+  CHECK_EVAL( "PPMT(8%;10;24;10000;2000;1)", Value( -332.6779394454 ) ); // With Type=1
+
+  // these tests seems to be wrong in specs. remove superflous parameter "1".
+  CHECK_EVAL( "PPMT(3%;1;12;100;200)",       Value(  -21.1386256419 ) ); // With future value
+  CHECK_EVAL( "PPMT(3%;1;12;100;200;1)",     Value(  -20.5229375164 ) ); // With future value and type
 }
 
 // PRICEMAT
