@@ -20,6 +20,12 @@
 
 #include "TestKspreadCommon.h"
 
+#include <CellStorage.h>
+#include <Doc.h>
+#include <Formula.h>
+#include <Map.h>
+#include <Sheet.h>
+
 #include "TestMathFunctions.h"
 
 // NOTE: we do not compare the numbers _exactly_ because it is difficult
@@ -31,11 +37,11 @@
 #define CHECK_EVAL_SHORT(x,y) QCOMPARE(TestDouble(x,y,10),y)
 #define ROUND(x) (roundf(1e10 * x) / 1e10)
 
-static Value TestDouble(const QString& formula, const Value& v2, int accuracy)
+Value TestMathFunctions::TestDouble(const QString& formula, const Value& v2, int accuracy)
 {
   double epsilon = DBL_EPSILON*pow(10.0,(double)(accuracy));
 
-  Formula f;
+  Formula f(m_doc->map()->sheet(0));
   QString expr = formula;
   if ( expr[0] != '=' )
     expr.prepend( '=' );
@@ -76,7 +82,7 @@ static Value RoundNumber(const Value& v)
 
 Value TestMathFunctions::evaluate(const QString& formula)
 {
-  Formula f;
+  Formula f(m_doc->map()->sheet(0));
   QString expr = formula;
   if ( expr[0] != '=' )
     expr.prepend( '=' );
@@ -91,6 +97,30 @@ Value TestMathFunctions::evaluate(const QString& formula)
   return RoundNumber(result);
 }
 
+void TestMathFunctions::initTestCase()
+{
+    m_doc = new Doc();
+    m_doc->map()->addNewSheet();
+    Sheet* sheet = m_doc->map()->sheet(0);
+    CellStorage* storage = sheet->cellStorage();
+
+    // B3:B7
+    storage->setValue(2, 3, Value("7"));
+    storage->setValue(2, 4, Value(2));
+    storage->setValue(2, 5, Value(3));
+    storage->setValue(2, 6, Value(true));
+    storage->setValue(2, 7, Value("Hello"));
+    // B9
+    storage->setValue(2, 9, Value::errorDIV0());
+}
+
+void TestMathFunctions::cleanupTestCase()
+{
+    delete m_doc;
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////////
+
 void TestMathFunctions::testABS()
 {
   CHECK_EVAL( "ABS(0)",   Value( 0 ) );
@@ -129,11 +159,11 @@ void TestMathFunctions::testACOT()
   CHECK_EVAL( "ACOT(0)-PI()/2", Value( 0 )     ); //
 }
 
-// void TestMathFunctions::testACOTH()
-// {
-//   // ODF-tests
-//   CHECK_EVAL( "ACOTH(2)", Value( 0.549306144 ) ); //
-// }
+void TestMathFunctions::testACOTH()
+{
+  // ODF-tests
+  CHECK_EVAL( "ACOTH(2)", Value( 0.5493061443 ) ); //
+}
 
 void TestMathFunctions::testASIN()
 {
@@ -266,16 +296,20 @@ void TestMathFunctions::testCEILING()
 void TestMathFunctions::testCOMBIN()
 {
   // ODF-tests
-  CHECK_EVAL( "COMBIN(5;3)",  Value(    10 ) ); //
-  CHECK_EVAL( "COMBIN(6;3)",  Value(    20 ) ); //
-  CHECK_EVAL( "COMBIN(42;3)", Value( 11480 ) ); //
+  CHECK_EVAL( "COMBIN(5;3)",  Value(       10 ) ); //
+  CHECK_EVAL( "COMBIN(6;3)",  Value(       20 ) ); //
+  CHECK_EVAL( "COMBIN(42;3)", Value(    11480 ) ); //
+  CHECK_EVAL( "COMBIN(-1;3)", Value::errorNUM() ); // N must be >= 0
+  CHECK_EVAL( "COMBIN(4;-3)", Value::errorNUM() ); // M must be >= 0
 }
 
-// void TestMathFunctions::testCOMBINA()
-// {
-//   // ODF-tests
-//   CHECK_EVAL( "COMBINA(5;3)", Value( 35 ) ); //
-// }
+void TestMathFunctions::testCOMBINA()
+{
+  // ODF-tests
+  CHECK_EVAL( "COMBINA(5;3)",  Value(       35 ) ); //
+  CHECK_EVAL( "COMBINA(-1;3)", Value::errorNUM() ); // N must be >= 0
+  CHECK_EVAL( "COMBINA(4;-3)", Value::errorNUM() ); // M must be >= 0
+}
 
 void TestMathFunctions::testCONVERT()
 {
@@ -326,20 +360,20 @@ void TestMathFunctions::testCONVERT()
                                                                               // This is 0.946352946 liters,
 }
 
-// void TestMathFunctions::testCOT()
-// {
-//   // ODF-tests
-//   CHECK_EVAL( "COT(PI()/4.0)", Value( 1 ) );  // cotangent of PI()/4.0 radians.
-//   CHECK_EVAL( "COT(PI()/2.0)", Value( 0 ) );  // cotangent of PI()/2 radians.  Not the same as TAN.
-//   CHECK_EVAL( "COT(0)", Value::errorDIV0() ); // cotangent of PI()/4.0 radians.
-// }
-// 
-// void TestMathFunctions::testCOTH()
-// {
-//   // ODF-tests
-//   CHECK_EVAL( "COTH(1)",      Value( 1.313035285 ) ); // 
-//   CHECK_EVAL( "COTH(EXP(1))", Value( 1.00874693  ) ); //
-// }
+void TestMathFunctions::testCOT()
+{
+  // ODF-tests
+  CHECK_EVAL( "COT(PI()/4.0)", Value( 1 ) );         // cotangent of PI()/4.0 radians.
+  CHECK_EVAL( "COT(PI()/2.0)", Value( 0 ) );         // cotangent of PI()/2 radians.  Not the same as TAN.
+  CHECK_EVAL( "COT(0)", Value::errorDIV0() );        // cotangent of PI()/4.0 radians.
+}
+
+void TestMathFunctions::testCOTH()
+{
+  // ODF-tests
+  CHECK_EVAL( "COTH(1)",      Value( 1.3130352855 ) ); // 
+  CHECK_EVAL( "COTH(EXP(1))", Value( 1.0087469296 ) ); //
+}
 
 void TestMathFunctions::testDEGREES()
 {
@@ -409,12 +443,12 @@ void TestMathFunctions::testFIB()
   CHECK_EVAL( "FIB(10)", Value( 55 ) );
 
   // large number
-  CHECK_EVAL( "FIB(100)", Value( 3.54224848179263E+20  ) ); // TODO check CHECK_EVAL for big numbers
-  CHECK_EVAL( "FIB(200)", Value( 2.80571172992512E+41  ) );
-  CHECK_EVAL( "FIB(300)", Value( 2.22232244629423E+62  ) );
-  CHECK_EVAL( "FIB(400)", Value( 1.76023680645016E+83  ) );
-  CHECK_EVAL( "FIB(500)", Value( 1.394232245617E+104   ) );
-  CHECK_EVAL( "FIB(600)", Value( 1.10433070572954E+125 ) );
+  CHECK_EVAL( "FIB(100)/1E+20",  Value( 3.54224848179263 ) );
+  CHECK_EVAL( "FIB(200)/1E+41",  Value( 2.80571172992512 ) );
+  CHECK_EVAL( "FIB(300)/1E+62",  Value( 2.22232244629423 ) );
+  CHECK_EVAL( "FIB(400)/1E+83",  Value( 1.76023680645016 ) );
+  CHECK_EVAL( "FIB(500)/1E+104", Value( 1.394232245617   ) );
+  CHECK_EVAL( "FIB(600)/1E+125", Value( 1.10433070572954 ) );
 
   // invalid
   CHECK_EVAL( "FIB(0)",        Value::errorNUM() );
@@ -422,6 +456,21 @@ void TestMathFunctions::testFIB()
   CHECK_EVAL( "FIB(\"text\")", Value::errorVALUE() );
 }
 
+void TestMathFunctions::testFLOOR()
+{
+    // ODF-Tests
+    CHECK_EVAL("=FLOOR(2; 1)",       Value(2));
+    CHECK_EVAL("=FLOOR(2.5; 1)",     Value(2));
+    CHECK_EVAL("=FLOOR(5; 2)",       Value(4));
+    CHECK_EVAL("=FLOOR(5; 2.2)",     Value(4.4));
+    CHECK_EVAL("=FLOOR(-2.5;1)",     Value::errorVALUE());
+    CHECK_EVAL("=FLOOR(-2.5; -1)",   Value(-3));
+    CHECK_EVAL("=FLOOR(-2.5; -1;1)", Value(-2));
+    CHECK_EVAL("=FLOOR(-2.5;0)",     Value(0));
+    CHECK_EVAL("=FLOOR(0;-1)",       Value(0));
+    CHECK_EVAL("=FLOOR(-1.1)",       Value(-2));
+}
+
 void TestMathFunctions::testGAMMA()
 {
   // ODF-Tests
@@ -468,6 +517,17 @@ void TestMathFunctions::testGESTEP()
   CHECK_EVAL( "GESTEP(\"xxx\";-2)", Value::errorNUM() ); //
 }
 
+void TestMathFunctions::testINT()
+{
+    // ODF-tests
+    CHECK_EVAL("=INT(2)",       Value( 2));
+    CHECK_EVAL("=INT(-3)",      Value(-3));
+    CHECK_EVAL("=INT(1.2)",     Value( 1));
+    CHECK_EVAL("=INT(1.7)",     Value( 1));
+    CHECK_EVAL("=INT(-1.2)",    Value(-2));
+    CHECK_EVAL("=INT((1/3)*3)", Value( 1));
+}
+
 void TestMathFunctions::testLCM()
 {
   CHECK_EVAL( "LCM(5;15;25)",   Value( 75 ) );
@@ -572,6 +632,15 @@ void TestMathFunctions::testMOD()
     CHECK_EVAL( "MOD(10;0)", Value::errorDIV0() ); // Division by zero is not allowed
 }
 
+void TestMathFunctions::testMROUND()
+{
+    // ODF-tests
+    CHECK_EVAL("=MROUND(1564;100)", Value(1600));
+    CHECK_EVAL("=MROUND(1520;100)", Value(1500));
+    CHECK_EVAL("=MROUND(1550;100)", Value(1600));
+    CHECK_EVAL("=MROUND(41.89;8)",  Value(40));
+}
+
 void TestMathFunctions::testMUNIT()
 {
     CHECK_EVAL( "MUNIT(2)", evaluate( "{1;0|0;1}" ) );
@@ -636,6 +705,49 @@ void TestMathFunctions::testRANDBETWEEN()
     CHECK_EVAL( "RANDBETWEEN(15;5)<=15", Value( true ) ); // Must return value in range
 }
 
+void TestMathFunctions::testROUND()
+{
+    // ODF-tests
+    CHECK_EVAL("=ROUND(10.1; 0)",   Value(10));
+    CHECK_EVAL("=ROUND(9.8;0)",     Value( 10));
+    CHECK_EVAL("=ROUND(0.5; 0)",    Value(1));
+    CHECK_EVAL("=ROUND(1/3;0) ",    Value(0));
+    CHECK_EVAL("=ROUND(1/3;1)",     Value(0.3));
+    CHECK_EVAL("=ROUND(1/3;2)",     Value(0.33));
+    CHECK_EVAL("=ROUND(1/3;2.9)",   Value(0.33));
+    CHECK_EVAL("=ROUND(5555;-1)",   Value(5560));
+    CHECK_EVAL("=ROUND(-1.1; 0)",   Value(-1));
+    CHECK_EVAL("=ROUND(-1.5; 0)",   Value(-2));
+    CHECK_EVAL("=ROUND(-1.5)",      Value(-2));
+    CHECK_EVAL("=ROUND(1.1)",       Value(1));
+    CHECK_EVAL("=ROUND(9.8)",       Value(10));
+}
+
+void TestMathFunctions::testROUNDDOWN()
+{
+    // ODF-tests
+    CHECK_EVAL("=ROUNDDOWN(1.45673; 2)",    Value(1.45));
+    CHECK_EVAL("=ROUNDDOWN(1;0)",           Value(1));
+    CHECK_EVAL("=ROUNDDOWN(1)",             Value(1));
+    CHECK_EVAL("=ROUNDDOWN(9;-1)",          Value(0));
+    CHECK_EVAL("=ROUNDDOWN(9;0)",           Value(9));
+    CHECK_EVAL("=ROUNDDOWN(-1.1)",          Value(-2));
+    CHECK_EVAL("=ROUNDDOWN(-1.9)",          Value(-2));
+}
+
+void TestMathFunctions::testROUNDUP()
+{
+    // ODF-tests
+    CHECK_EVAL("=ROUNDUP(1.45673; 2)",  Value(1.46));
+    CHECK_EVAL("=ROUNDUP(1.1;0)",       Value(2));
+    CHECK_EVAL("=ROUNDUP(1.9;0)",       Value(2));
+    CHECK_EVAL("=ROUNDUP(1)",           Value(1));
+    CHECK_EVAL("=ROUNDUP(9;-1)",        Value(10));
+    CHECK_EVAL("=ROUNDUP(9;0)",         Value(9));
+    CHECK_EVAL("=ROUNDUP(-1.1)",        Value(-1));
+    CHECK_EVAL("=ROUNDUP(-1.9)",        Value(-1));
+}
+
 void TestMathFunctions::testSERIESSUM()
 {
     CHECK_EVAL( "SERIESSUM(2;0;2;{1;2})",           Value(        9 ) ); // 
@@ -678,10 +790,38 @@ void TestMathFunctions::testSUMA()
     CHECK_EVAL( "SUMA(TRUE();2;3)", Value( 6 ) ); // TRUE() is 1.
 }
 
+void TestMathFunctions::testSUMIF()
+{
+    // B3 = 7
+    // B4 = 2
+    // B5 = 3
+    CHECK_EVAL( "SUMIF(B4:B5;\">2.5\")",    Value( 3 ) ); // B4 is 2 and B5 is 3, so only B5 has a value greater than 2.5.
+    CHECK_EVAL( "SUMIF(B3:B5;B4)",          Value( 2 ) ); // Test if a cell equals the value in B4.
+    CHECK_EVAL( "SUMIF("";B4)",      Value::errorNUM() ); // Constant values are not allowed for the range.
+    CHECK_EVAL( "SUMIF(B3:B4;\"7\";B4:B5)", Value( 2 ) ); // B3 is the string "7", but its match is mapped to B4 for the summation.
+    CHECK_EVAL( "SUMIF(B3:B10;1+1)",        Value( 2 ) ); // The criteria can be an expression.
+    CHECK_EVAL( "SUMIF(B3:B4;\"7\")",       Value( 0 ) ); // TODO B3 is the string "7", but only numbers are summed.
+}
+
 void TestMathFunctions::testSUMSQ()
 {
     CHECK_EVAL( "SUMSQ(1;2;3)",      Value( 14 ) ); // Simple sum.
     CHECK_EVAL( "SUMSQ(TRUE();2;3)", Value( 14 ) ); // TRUE() is 1.
+    CHECK_EVAL( "SUMSQ(B4:B5)",      Value( 13 ) ); // 2*2+3*3 is 13.
+}
+
+void TestMathFunctions::testTRUNC()
+{
+    // ODF-tests
+    CHECK_EVAL("=TRUNC(10.1)",     Value(10));
+    CHECK_EVAL("=TRUNC(0.5)",      Value(0));
+    CHECK_EVAL("=TRUNC(1/3;0)",    Value(0));
+    CHECK_EVAL("=TRUNC(1/3;1)",    Value(0.3));
+    CHECK_EVAL("=TRUNC(1/3;2)",    Value(0.33));
+    CHECK_EVAL("=TRUNC(1/3;2.9)",  Value(0.33));
+    CHECK_EVAL("=TRUNC(5555;-1)",  Value(5550));
+    CHECK_EVAL("=TRUNC(-1.1)",     Value(-1));
+    CHECK_EVAL("=TRUNC(-1.5)",     Value(-1));
 }
 
 QTEST_KDEMAIN(TestMathFunctions, GUI)
