@@ -85,7 +85,6 @@
 // KOffice
 #include <KoCanvasController.h>
 #include <KoDocumentChild.h>
-#include <KoOasisStore.h>
 #include <KoShapeManager.h>
 #include <KoStore.h>
 #include <KoToolManager.h>
@@ -106,7 +105,6 @@
 #include "Selection.h"
 #include "Sheet.h"
 #include "SheetView.h"
-#include "Undo.h"
 #include "Util.h"
 #include "Validity.h"
 #include "View.h"
@@ -115,6 +113,7 @@
 #include "commands/DeleteCommand.h"
 #include "commands/EmbeddedObjectCommands.h"
 #include "commands/StyleCommand.h"
+#include "commands/Undo.h"
 
 #define MIN_SIZE 10
 
