@@ -20,18 +20,16 @@
 #include "kudesigner_factory.h"
 #include "kudesigner_view.h"
 
-#include <KoTemplateChooseDia.h>
 #include <kparts/componentfactory.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
-#include <kcommand.h>
+#include <k3command.h>
 
 #include <qpainter.h>
 #include <qprinter.h>
-#include <qpaintdevicemetrics.h>
 #include <qfileinfo.h>
-#include <qdockwindow.h>
+#include <q3dockwindow.h>
 #include <qdom.h>
 #include <qtextstream.h>
 #include <qtextcodec.h>
@@ -41,11 +39,12 @@
 
 #include "kudesigner_view.h"
 
-KudesignerDoc::KudesignerDoc( QWidget *parentWidget, const char *widgetName, QObject* parent, const char* name, bool singleViewMode )
-        : KoDocument( parentWidget, widgetName, parent, name, singleViewMode ), m_plugin( 0 ), m_propPos( DockRight ), m_modified( false )
+KudesignerDoc::KudesignerDoc( QWidget *parentWidget, QObject* parent, bool singleViewMode )
+        : KoDocument( parentWidget, parent, singleViewMode ), m_plugin( 0 ), m_propPos( Qt::RightDockWidgetArea ), m_modified( false )
 {
-    setInstance( KudesignerFactory::global(), false );
-    history = new KoCommandHistory( actionCollection() );
+    setComponentData( KudesignerFactory::global(), false );
+    setTemplateType("kudesigner_template");
+    history = new K3CommandHistory( actionCollection() );
 
     //     connect( history, SIGNAL( documentRestored() ), this, SLOT( slotDocumentRestored() ) );
     //     connect( history, SIGNAL( commandExecuted() ), this, SLOT( slotCommandExecuted() ) );
@@ -58,60 +57,16 @@ KudesignerDoc::~KudesignerDoc()
     delete history;
 }
 
-void KudesignerDoc::addCommand( KCommand *cmd )
+void KudesignerDoc::addCommand( K3Command *cmd )
 {
     cmd->execute();
     setModified( true );
     /*    history->addCommand(cmd);*/
 }
 
-bool KudesignerDoc::initDoc( InitDocFlags flags, QWidget* parentWidget )
-{
-    // If nothing is loaded, do initialize here
-    bool ok = FALSE;
-
-    // TODO if (flags==KoDocument::InitDocEmpty)
-
-    QString file;
-    KoTemplateChooseDia::DialogType dlgtype;
-    if ( flags != KoDocument::InitDocFileNew )
-        dlgtype = KoTemplateChooseDia::Everything;
-    else
-        dlgtype = KoTemplateChooseDia::OnlyTemplates;
-
-    KoTemplateChooseDia::ReturnType ret = KoTemplateChooseDia::choose(
-                                              KudesignerFactory::global(), file,
-                                              dlgtype, "kudesigner_template", parentWidget );
-    if ( ret == KoTemplateChooseDia::Template )
-    {
-        resetURL();
-        ok = loadNativeFormat( file );
-        if ( !ok )
-            showLoadingErrorDialog();
-        setEmpty();
-    }
-    else if ( ret == KoTemplateChooseDia::File )
-    {
-        KURL url( file );
-        ok = openURL( url );
-    }
-    else if ( ret == KoTemplateChooseDia::Empty )
-    {
-        QString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
-        resetURL();
-        ok = loadNativeFormat( fileName );
-        if ( !ok )
-            showLoadingErrorDialog();
-        setEmpty();
-    }
-    setModified( FALSE );
-
-    return ok;
-}
-
 void KudesignerDoc::initEmpty()
 {
-    QString fileName( locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
+    QString fileName( KStandardDirs::locate( "kudesigner_template", "General/.source/A4.ktm", KudesignerFactory::global() ) );
     bool ok = loadNativeFormat( fileName );
     if ( !ok )
         showLoadingErrorDialog();
@@ -120,12 +75,12 @@ void KudesignerDoc::initEmpty()
     setModified(false);
 }
 
-KoView* KudesignerDoc::createViewInstance( QWidget* parent, const char* name )
+KoView* KudesignerDoc::createViewInstance( QWidget* parent)
 {
-    return new KudesignerView( this, parent, name );
+    return new KudesignerView( this, parent);
 }
 
-bool KudesignerDoc::loadOasis( const QDomDocument&, KoOasisStyles&, const QDomDocument&, KoStore* )
+bool KudesignerDoc::loadOasis( const KoXmlDocument&, KoOasisStyles&, const KoXmlDocument&, KoStore* )
 {
     return false;
 }
@@ -135,14 +90,11 @@ bool KudesignerDoc::saveOasis( KoStore*, KoXmlWriter* )
     return false;
 }
 
-void KudesignerDoc::paintContent( QPainter& painter, const QRect& rect, bool /*transparent*/,
-                                  double /*zoomX*/, double /*zoomY*/ )
+void KudesignerDoc::paintContent( QPainter& painter, const QRect& rect)
 {
-    // ####### handle transparency
-
     // Need to draw only the document rectangle described in the parameter rect.
 
-    canvas() ->drawArea( rect, &painter, TRUE );
+    canvas() ->drawArea( rect, &painter, true );
 
 }
 
@@ -183,13 +135,13 @@ bool KudesignerDoc::saveToStream( QIODevice * dev )
 
 void KudesignerDoc::loadPlugin( const QString &name )
 {
-    kdDebug() << "Trying to load plugin: " << name << endl;
-    KuDesignerPlugin *plug = KParts::ComponentFactory::createInstanceFromLibrary<KuDesignerPlugin>( name.utf8(), this );
+    kDebug() <<"Trying to load plugin:" << name;
+    KuDesignerPlugin *plug = KLibLoader::createInstance<KuDesignerPlugin>( name.toUtf8(), this );
     m_plugin = plug;
     if ( m_plugin )
-        kdDebug() << "plugin has been loaded" << endl;
+        kDebug() <<"plugin has been loaded";
     else
-        kdDebug() << "plugin couldn't be loaded :(" << endl;
+        kDebug() <<"plugin couldn't be loaded :(";
 }
 
 bool KudesignerDoc::completeSaving( KoStore* store )
@@ -211,12 +163,12 @@ KuDesignerPlugin *KudesignerDoc::plugin()
     return canvas() ->plugin();
 }
 
-Qt::Dock KudesignerDoc::propertyPosition()
+Qt::DockWidgetArea KudesignerDoc::propertyPosition()
 {
     return m_propPos;
 }
 
-void KudesignerDoc::setForcedPropertyEditorPosition( Dock d )
+void KudesignerDoc::setForcedPropertyEditorPosition( Qt::DockWidgetArea d )
 {
     m_propPos = d;
 }
@@ -232,25 +184,22 @@ bool KudesignerDoc::modified( ) const
     return m_modified;
 }
 
-bool KudesignerDoc::loadXML( QIODevice *, const QDomDocument &rt )
+bool KudesignerDoc::loadXML( QIODevice *, const KoXmlDocument &rt )
 {
-    QDomNode report, rep;
-    for ( QDomNode report = rt.firstChild(); !report.isNull(); report = report.nextSibling() )
+    KoXmlElement report;
+    forEachElement(report, rt)
     {
         if ( report.nodeName() == "KugarTemplate" )
         {
-            rep = report;
             break;
         }
     }
-    report = rep;
 
-    QDomNamedNodeMap attributes = report.attributes();
     //getting the page width and height
     int height = 297;
     int width = 210;
 
-    if ( attributes.namedItem( "PageOrientation" ).nodeValue().toInt() )
+    if ( report.attribute( "PageOrientation" ).toInt() )
     {
         int temp = height;
         height = width;
@@ -263,13 +212,12 @@ bool KudesignerDoc::loadXML( QIODevice *, const QDomDocument &rt )
     // Set the page size
     printer = new QPrinter();
     printer->setFullPage( true );
-    printer->setPageSize( ( QPrinter::PageSize ) attributes.namedItem( "PageSize" ).nodeValue().toInt() );
-    printer->setOrientation( ( QPrinter::Orientation ) attributes.namedItem( "PageOrientation" ).nodeValue().toInt() );
+    printer->setPageSize( ( QPrinter::PageSize ) report.attribute( "PageSize" ).toInt() );
+    printer->setOrientation( ( QPrinter::Orientation ) report.attribute( "PageOrientation" ).toInt() );
 
     // Get the page metrics and set appropriate wigth and height
-    QPaintDeviceMetrics pdm( printer );
-    width = pdm.width();
-    height = pdm.height();
+    width = printer->width();
+    height = printer->height();
 
     //this is not needed anymore
     delete printer;
