@@ -8,8 +8,11 @@
   email     : cloudtemple@mksat.net
 ***************************************************************************/
 
-#include <qfile.h>
+#include <QFile>
 #include <qprinter.h>
+//Added by qt3to4:
+#include <Q3PtrList>
+#include <Q3MemArray>
 
 #include "mreportengine.h"
 #include "mutil.h"
@@ -85,7 +88,7 @@ MReportEngine::~MReportEngine()
 {
     // Clear the grand total data
     grandTotal.clear();
-    kdDebug( 31000 ) << k_funcinfo << endl;
+    kDebug( 31000 ) ;
 }
 
 void MReportEngine::addRef()
@@ -131,7 +134,7 @@ bool MReportEngine::setReportData( const QString &data )
 
     if ( !rd.setContent( data ) )
     {
-        kdDebug() << "Unable to parse report data" << endl;
+        kDebug() <<"Unable to parse report data";
         return false;
     }
     initData();
@@ -146,7 +149,7 @@ bool MReportEngine::setReportData( QIODevice *dev )
 {
     if ( !rd.setContent( dev ) )
     {
-        kdDebug() << "Unable to parse report data" << endl;
+        kDebug() <<"Unable to parse report data";
         return false;
     }
     initData();
@@ -169,7 +172,7 @@ void MReportEngine::initData()
 
             records = n.childNodes();
 
-            // See if there is a prefered template given.
+            // See if there is a preferred template given.
 
             QDomNamedNodeMap attr = n.attributes();
             QDomNode tempattr = attr.namedItem( "Template" );
@@ -192,7 +195,7 @@ bool MReportEngine::setReportTemplate( const QString &tpl )
 
     if ( !rt.setContent( tpl ) )
     {
-        kdDebug() << "Unable to parse report template" << endl;
+        kDebug() <<"Unable to parse report template";
         return false;
     }
 
@@ -211,7 +214,7 @@ bool MReportEngine::setReportTemplate( QIODevice *dev )
 
     if ( !rt.setContent( dev ) )
     {
-        kdDebug() << "Unable to parse report template" << endl;
+        kDebug() <<"Unable to parse report template";
         return false;
     }
 
@@ -227,7 +230,7 @@ void MReportEngine::slotCancelRendering()
     cancelRender = true;
 }
 
-/** Finds the detail header object, which is apropriate for the given level */
+/** Finds the detail header object, which is appropriate for the given level */
 MReportSection *MReportEngine::findDetailHeader( int level )
 {
     MReportSection * sec;
@@ -239,7 +242,7 @@ MReportSection *MReportEngine::findDetailHeader( int level )
     return NULL;
 }
 
-/** Finds the detail object, which is apropriate for the given level */
+/** Finds the detail object, which is appropriate for the given level */
 MReportDetail *MReportEngine::findDetail( int level )
 {
     MReportDetail * sec;
@@ -251,7 +254,7 @@ MReportDetail *MReportEngine::findDetail( int level )
     return NULL;
 }
 
-/** Finds the detail footer object, which is apropriate for the given level */
+/** Finds the detail footer object, which is appropriate for the given level */
 MReportSection *MReportEngine::findDetailFooter( int level )
 {
     MReportSection * sec;
@@ -314,7 +317,7 @@ MPageCollection* MReportEngine::renderReport()
     // Initialize the grand total array
     grandTotal.clear();
     for ( int i = 0; i < rFooter.getCalcFieldCount(); i++ )
-        grandTotal.append( new QMemArray<double> );
+        grandTotal.append( new Q3MemArray<double> );
 
     // Create the first page
     startPage( pages );
@@ -618,12 +621,10 @@ QSize MReportEngine::getPageMetrics( int size, int orientation )
     printer->setPageSize( ( QPrinter::PageSize ) size );
     printer->setOrientation( ( QPrinter::Orientation ) orientation );
 
-    // Get the page metrics
-    QPaintDeviceMetrics pdm( printer );
 
     // Display the first page of the report
-    ps.setWidth( pdm.width() );
-    ps.setHeight( pdm.height() );
+    ps.setWidth( printer->width() );
+    ps.setHeight( printer->height() );
 
     delete printer;
 
@@ -766,7 +767,7 @@ void MReportEngine::setReportAttributes( QDomNode* report )
     widthDelta = ( float ) pageWidth / templateWidth;
     heightDelta = ( float ) pageHeight / templateheight;
 
-    kdDebug( 30001 ) << "pagewidth: " << pageWidth
+    kDebug( 30001 ) <<"pagewidth:" << pageWidth
     << " pageheight: " << pageHeight << "\n"
     << "templateWidth: " << templateWidth
     << " templateheight: " << templateheight << "\n"
@@ -1048,7 +1049,7 @@ void MReportEngine::copy( const MReportEngine* mReportEngine )
     pHeader = mReportEngine->pHeader;
     // Copy the detail sections
     MReportDetail *detail;
-    QPtrList<MReportDetail> temp = mReportEngine->details;
+    Q3PtrList<MReportDetail> temp = mReportEngine->details;
     temp.setAutoDelete( false );
     for ( detail = temp.first(); detail; detail = temp.next() )
     {
