@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
  * Copyright (C) 2002-2006 David Faure <faure@kde.org>
  * Copyright (C) 2005-2007 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -41,6 +42,7 @@
 // koffice libs includes
 #include <KoShapeManager.h>
 #include <KoShapeContainer.h>
+#include <KoOdfWriteStore.h>
 #include <KoOasisStyles.h>
 #include <KoToolManager.h>
 #include <KoShapeRegistry.h>
@@ -48,7 +50,6 @@
 #include <KoStyleManager.h>
 #include <KoInteractionTool.h>
 #include <KoStoreDevice.h>
-#include <KoSavingContext.h>
 #include <KoXmlWriter.h>
 #include <KoInlineTextObjectManager.h>
 #include <KoImageCollection.h>
@@ -61,6 +62,7 @@
 #include <kstandardaction.h>
 #include <kmessagebox.h>
 #include <kaction.h>
+#include <kdebug.h>
 #include <KTemporaryFile>
 #include <QIODevice>
 #include <QTimer>
@@ -96,7 +98,6 @@ KWDocument::KWDocument( QWidget *parentWidget, QObject* parent, bool singleViewM
 
 KWDocument::~KWDocument() {
     saveConfig();
-    delete m_styleManager;
     qDeleteAll(m_frameSets);
     delete m_imageCollection;
     m_imageCollection = 0;
@@ -148,46 +149,26 @@ bool KWDocument::saveOasis(KoStore* store, KoXmlWriter* manifestWriter) {
         return false;
 
     KoStoreDevice contentDev( store );
-    KoXmlWriter* contentWriter = createOasisXmlWriter( &contentDev, "office:document-content" );
-
-    KoGenStyles mainStyles;
-    
-    KoSavingContext savingContext( mainStyles, KoSavingContext::Store );
+    KoXmlWriter* contentWriter = KoOdfWriteStore::createOasisXmlWriter( &contentDev, "office:document-content" );
 
     // for office:master-styles
     KTemporaryFile masterStyles;
     masterStyles.open();
     KoXmlWriter masterStylesTmpWriter( &masterStyles, 1 );
 
-/*
-    KoPASavingContext paContext( masterStylesTmpWriter, savingContext, 1 );
-
-    paContext.setOptions( KoPASavingContext::DrawId | KoPASavingContext::AutoStyleInStyleXml );
-
-    masterStylesTmpWriter.startElement( "office:master-styles" );
-
-    // save master pages
-    foreach( KoPAPageBase *page, m_masterPages )
-    {
-        page->saveOdf( paContext );
-    }
-    masterStylesTmpWriter.endElement();
-
-    masterStyles.close();
-*/
     // for office:body
     KTemporaryFile contentTmpFile;
     contentTmpFile.open();
     KoXmlWriter contentTmpWriter( &contentTmpFile, 1 );
 
     contentTmpWriter.startElement( "office:body" );
-    
     contentTmpWriter.startElement( "office:text" );
 
-    KoShapeSavingContext context (contentTmpWriter, savingContext);
+    KoGenStyles mainStyles;
+    KoShapeSavingContext context (contentTmpWriter, mainStyles);
 
     KWTextFrameSet *mainTextFrame = 0;
-    
+
     foreach(KWFrameSet *fs, frameSets()) {
         // TODO loop over all non-autocreated frames and save them.
         KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*> (fs);
@@ -228,14 +209,7 @@ bool KWDocument::saveOasis(KoStore* store, KoXmlWriter* manifestWriter) {
 
     contentTmpFile.close();
 
-    contentWriter->startElement( "office:automatic-styles" );
-    //saveOdfAutomaticStyles( *contentWriter, mainStyles, false );
-    Q3ValueList<KoGenStyles::NamedStyle> styles = mainStyles.styles(KoGenStyle::StyleAuto, false);
-    Q3ValueList<KoGenStyles::NamedStyle>::iterator it;
-    for ( it = styles.begin(); it != styles.end(); ++it ) {
-        (*it).style->writeStyle(contentWriter, mainStyles, "style:style", (*it).name, "");
-    }
-    contentWriter->endElement();
+    mainStyles.saveOdfAutomaticStyles( contentWriter, false );
 
     // And now we can copy over the contents from the tempfile to the real one
     contentWriter->addCompleteElement( &contentTmpFile );
@@ -250,24 +224,9 @@ bool KWDocument::saveOasis(KoStore* store, KoXmlWriter* manifestWriter) {
     //add manifest line for content.xml
     manifestWriter->addManifestEntry( "content.xml", "text/xml" );
 
-    if ( !store->open( "styles.xml" ) )
+    if ( !mainStyles.saveOdfStylesDotXml( store, manifestWriter ) )
         return false;
-    //saveOdfDocumentStyles( store, mainStyles, &masterStyles );
-    KoStoreDevice stylesDev( store );
-    KoXmlWriter* stylesWriter = createOasisXmlWriter( &stylesDev, "office:document-styles" );
-    stylesWriter->startElement("office:styles");
-    styles = mainStyles.styles(KoGenStyle::StyleUser, true);
-    for ( it = styles.begin(); it != styles.end(); ++it ) {
-        (*it).style->writeStyle(stylesWriter, mainStyles, "style:style", (*it).name, "");
-    }
-    stylesWriter->endElement(); // "office:styles"
-    stylesWriter->endElement(); // "office:document-styles"
-    stylesWriter->endDocument();
-    
-    if ( !store->close() ) // done with styles.xml
-        return false;
-    manifestWriter->addManifestEntry( "styles.xml", "text/xml" );
-    
+
     if (!context.saveImages(store, manifestWriter))
         return false;
     return true;
@@ -337,7 +296,7 @@ void KWDocument::removeFrameSet( KWFrameSet *fs ) {
     m_frameSets.removeAt( m_frameSets.indexOf(fs) );
     setModified( true );
     foreach(KWFrame *frame, fs->frames()) {
-        frame->shape()->repaint();
+        frame->shape()->update();
         foreach(KoView *view, views()) {
             KWCanvas *canvas = static_cast<KWView*>(view)->kwcanvas();
             canvas->shapeManager()->remove(frame->shape());
@@ -358,7 +317,7 @@ void KWDocument::addFrameSet(KWFrameSet *fs) {
     if(tfs) {
         tfs->setPageManager(pageManager());
         m_styleManager->add( tfs->document() );
-        KWTextDocumentLayout *lay = dynamic_cast<KWTextDocumentLayout*> (tfs->document()->documentLayout());
+        KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*> (tfs->document()->documentLayout());
         if(lay)
             lay->setStyleManager(m_styleManager);
         if(tfs->textFrameSetType() == KWord::MainTextFrameSet ||
@@ -394,7 +353,7 @@ void KWDocument::addFrame(KWFrame *frame) {
             canvas->shapeManager()->add(frame->shape());
         canvas->resourceProvider()->setResource(KWord::CurrentFrameSetCount, m_frameSets.count());
     }
-    frame->shape()->repaint();
+    frame->shape()->update();
 }
 
 void KWDocument::removeFrame(KWFrame *frame) {
@@ -417,15 +376,22 @@ void KWDocument::removeFrame(KWFrame *frame) {
 
 void KWDocument::setPageSettings(const KWPageSettings &newPageSettings) {
     m_pageSettings = newPageSettings;
-    // TODO be much more intelligent about removing
-    // only frames that are not needed anymore in the new settings should be removed.
     foreach(KWFrameSet *fs, m_frameSets) {
         KWTextFrameSet *tfs = dynamic_cast<KWTextFrameSet*> (fs);
         if(tfs == 0) continue;
-        if(tfs->textFrameSetType() == KWord::OtherTextFrameSet) continue;
+        if(tfs->textFrameSetType() != KWord::MainTextFrameSet) continue;
         // we switch to the interaction tool to avoid crashes if the tool was editing a frame.
         KoToolManager::instance()->switchToolRequested(KoInteractionTool_ID);
+        QSet<KWPage*> coveredPages;
         foreach(KWFrame *frame, tfs->frames()) {
+            KWPage *page = pageManager()->page(frame->shape());
+            if(page) {
+                if(! coveredPages.contains(page)) {
+                    coveredPages += page;
+                    continue; // keep one frame per page.
+                }
+            }
+
             foreach(KoView *view, views()) {
                 KWCanvas *canvas = static_cast<KWView*>(view)->kwcanvas();
                 canvas->shapeManager()->remove(frame->shape());
@@ -525,18 +491,28 @@ void KWDocument::clear() {
     m_inlineTextObjectManager->setProperty(KoInlineObject::PageCount, pageCount());
 }
 
-bool KWDocument::loadOasis(const KoXmlDocument& doc, KoOasisStyles& styles, const KoXmlDocument& settings, KoStore* store) {
+bool KWDocument::loadOdf( KoOdfReadStore & odfStore )
+{
     clear();
+    foreach(KoView *view, views()) {
+        KWCanvas *canvas = static_cast<KWView*>(view)->kwcanvas();
+        canvas->resourceProvider()->setResource(KoCanvasResource::DocumentIsLoading, true);
+    }
+
     KWOpenDocumentLoader loader(this);
-    bool rc = loader.load(doc, styles, settings, store);
+    bool rc = loader.load(odfStore);
     if (rc)
         endOfLoading();
     return rc;
 }
 
 bool KWDocument::loadXML( QIODevice *, const KoXmlDocument & doc ) {
-    KoXmlElement root = doc.documentElement();
+    foreach(KoView *view, views()) {
+        KWCanvas *canvas = static_cast<KWView*>(view)->kwcanvas();
+        canvas->resourceProvider()->setResource(KoCanvasResource::DocumentIsLoading, true);
+    }
     clear();
+    KoXmlElement root = doc.documentElement();
     KWDLoader loader(this);
     bool rc = loader.load(root);
     if (rc)
@@ -662,9 +638,12 @@ void KWDocument::endOfLoading() // called by both oasis and oldxml
 }
 
 bool KWDocument::completeLoading (KoStore *store) {
-    if(! m_imageCollection->loadFromStore(store))
-        return false;
-    return true;
+    const bool ok = m_imageCollection->loadFromStore(store);
+    foreach(KoView *view, views()) {
+        KWCanvas *canvas = static_cast<KWView*>(view)->kwcanvas();
+        canvas->resourceProvider()->setResource(KoCanvasResource::DocumentIsLoading, false);
+    }
+    return ok;
 }
 
 
@@ -764,6 +743,23 @@ QWidget* KWDocument::createCustomDocumentWidget(QWidget *parent) {
     return new KWStartupWidget(parent, this, columns);
 }
 
+void KWDocument::saveConfig()
+{
+    if ( !isReadWrite() )
+        return;
+//   KConfigGroup group( KoGlobal::kofficeConfig(), "Spelling" );
+//   group.writeEntry( "PersonalDict", m_spellCheckPersonalDict );
+
+    if (isEmbedded() )
+        return;
+    m_config.save();
+    KSharedConfigPtr config = KGlobal::config();
+    KConfigGroup interface = config->group( "Interface" );
+    interface.writeEntry( "ResolutionX", gridData().gridX() );
+    interface.writeEntry( "ResolutionY", gridData().gridY() );
+}
+
+
 // ************* PageProcessingQueue ************
 PageProcessingQueue::PageProcessingQueue(KWDocument *parent) {
     m_document = parent;
@@ -785,21 +781,4 @@ void PageProcessingQueue::process() {
     m_pages.clear();
     deleteLater();
 }
-
-void KWDocument::saveConfig()
-{
-    if ( !isReadWrite() )
-        return;
-//   KConfigGroup group( KoGlobal::kofficeConfig(), "Spelling" );
-//   group.writeEntry( "PersonalDict", m_spellCheckPersonalDict );
-
-    if (isEmbedded() )
-        return;
-    m_config.save();
-    KSharedConfigPtr config = KGlobal::config();
-    KConfigGroup interface = config->group( "Interface" );
-    interface.writeEntry( "ResolutionX", gridData().gridX() );
-    interface.writeEntry( "ResolutionY", gridData().gridY() );
-}
-
 #include "KWDocument.moc"
