@@ -36,7 +36,10 @@
 #include <KoToolDockerFactory.h>
 #include <KoRulerController.h>
 
+#include <KActionCollection>
 #include <QGridLayout>
+#include <QTimer>
+#include <QAction>
 
 KWGui::KWGui( const QString& viewMode, KWView *parent )
   : QWidget( parent),
@@ -90,6 +93,8 @@ KWGui::KWGui( const QString& viewMode, KWView *parent )
     connect(m_canvas->shapeManager()->selection(), SIGNAL(selectionChanged()), this, SLOT(shapeSelectionChanged()));
 
     pageSetupChanged();
+
+    QTimer::singleShot(0, this, SLOT(setupUnitActions()));
 }
 
 KWGui::~KWGui() {
@@ -155,4 +160,13 @@ void KWGui::shapeSelectionChanged() {
     m_verticalRuler->setActiveRange(start.y(), end.y());
 }
 
+void KWGui::setupUnitActions() {
+    QList<QAction*> unitActions = m_view->createChangeUnitActions();
+    QAction *separator = new QAction(this);
+    separator->setSeparator(true);
+    unitActions.append(separator);
+    unitActions.append(m_view->actionCollection()->action("format_page"));
+    m_horizontalRuler->setPopupActionList(unitActions);
+}
+
 #include "KWGui.moc"
