@@ -2,8 +2,8 @@
  * Copyright (C) 2005 David Faure <faure@kde.org>
  * Copyright (C) 2007 Thomas Zander <zander@kde.org>
  * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
- * Copyright (C) 2007 Sebastian Sauer <mail@dipe.org>
  * Copyright (C) 2007 Pierre Ducroquet <pinaraf@gmail.com>
+ * Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -31,11 +31,14 @@
 #include <KoTextLoadingContext.h>
 #include <KoOasisStyles.h>
 #include <KoOasisSettings.h>
+#include <KoOdfReadStore.h>
+#include <KoXmlReader.h>
 #include <KoXmlNS.h>
 #include <KoDom.h>
 #include <KoShapeRegistry.h>
 #include <KoShapeFactory.h>
 #include <KoImageData.h>
+#include <KoTextShapeData.h>
 #include <KoTextAnchor.h>
 #include <KoShapeContainer.h>
 #include <KoTextDocumentLayout.h>
@@ -50,6 +53,7 @@
 #include <QTextCursor>
 #include <QTextBlock>
 #include <klocale.h>
+#include <kdebug.h>
 
 /**
 * The KWOpenDocumentFrameLoader class implements a KoTextFrameLoader to
@@ -245,12 +249,12 @@ QString KWOpenDocumentLoader::currentMasterPage() const { return d->currentMaste
 QString KWOpenDocumentLoader::currentFramesetName() const { return d->currentFramesetName; }
 
 //1.6: KWDocument::loadOasis
-bool KWOpenDocumentLoader::load(const KoXmlDocument& doc, KoOasisStyles& styles, const KoXmlDocument& settings, KoStore* store)
+bool KWOpenDocumentLoader::load( KoOdfReadStore & odfStore )
 {
     emit sigProgress( 0 );
     kDebug(32001) <<"========================> KWOpenDocumentLoader::load START";
 
-    KoXmlElement content = doc.documentElement();
+    KoXmlElement content = odfStore.contentDoc().documentElement();
     KoXmlElement realBody ( KoDom::namedItemNS( content, KoXmlNS::office, "body" ) );
     if ( realBody.isNull() ) {
         kError(32001) << "No office:body found!" << endl;
@@ -274,7 +278,7 @@ bool KWOpenDocumentLoader::load(const KoXmlDocument& doc, KoOasisStyles& styles,
 
     // TODO check versions and mimetypes etc.
 
-    KoTextLoadingContext context( d->document, styles, store );
+    KoTextLoadingContext context( this, d->document, odfStore.styles(), odfStore.store() );
 
     KoColumns columns;
     columns.columns = 1;
@@ -390,26 +394,50 @@ bool KWOpenDocumentLoader::load(const KoXmlDocument& doc, KoOasisStyles& styles,
     fs->setName( i18n( "Main Text Frameset" ) );
     //fs->loadOasisContent( body, context );
 
+    // Get the factory for the TextShape
     KoShapeFactory *factory = KoShapeRegistry::instance()->value(TextShape_SHAPEID);
     Q_ASSERT(factory);
+    // Create a TextShape
     KoShape *shape = factory->createDefaultShape();
+    Q_ASSERT(shape);
+    // The TextShape will be displayed within a KWTextFrame
     KWTextFrame *frame = new KWTextFrame(shape, fs);
     Q_UNUSED(frame);
     d->currentFramesetName = fs->name();
     d->document->addFrameSet(fs);
 
+
+
+
+    // Set the KWOpenDocumentFrameLoader which implements the KoTextFrameLoader to
+    // handle loading of frames (e.g. images) within KWord.
+    Q_ASSERT(! d->frameLoader);
+    d->frameLoader = new KWOpenDocumentFrameLoader(this);
+
+    // The KoTextShapeData does contain the data for our TextShape
+    KoTextShapeData *textShapeData = dynamic_cast<KoTextShapeData*>(shape->userData());
+    Q_ASSERT(textShapeData);
+    textShapeData->setDocument( fs->document(), false /*transferOwnership*/ );
+    // Let the TextShape handle loading the body element.
+    KoShapeLoadingContext sc(context);
+    shape->loadOdf(body, sc);
+/*
     QTextCursor cursor( fs->document() );
 
     Q_ASSERT(! d->frameLoader);
     d->frameLoader = new KWOpenDocumentFrameLoader(this);
     loadBody(context, body, cursor);
+*/
+
+
+
 
 #endif
 
     if ( !loadMasterPageStyle(context, d->currentMasterPage) )
         return false;
 
-    loadSettings(context, settings);
+    loadSettings(context, odfStore.settingsDoc() );
 
 #if 0 //1.6:
     // This sets the columns and header/footer flags, and calls recalcFrames, so it must be done last.
