@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2006 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006-2007 Thomas Zander <zander@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,13 +24,14 @@
 
 KWFrameGeometry::KWFrameGeometry(FrameConfigSharedState *state)
     : m_state(state),
-    m_frame(0)
+    m_frame(0),
+    m_blockSignals(false)
 {
     m_state->addUser();
     widget.setupUi(this);
     setUnit(m_state->document()->unit());
-    widget.left->setMinimum(0.0);
-    widget.top->setMinimum(0.0);
+    widget.xPos->setMinimum(0.0);
+    widget.yPos->setMinimum(0.0);
     widget.width->setMinimum(0.0);
     widget.height->setMinimum(0.0);
     widget.leftMargin->setMinimum(0.0);
@@ -38,10 +39,22 @@ KWFrameGeometry::KWFrameGeometry(FrameConfigSharedState *state)
     widget.bottomMargin->setMinimum(0.0);
     widget.topMargin->setMinimum(0.0);
 
+    widget.keepAspect->setKeepAspectRatio(m_state->keepAspectRatio());
+
     connect(widget.leftMargin, SIGNAL(valueChangedPt(double)), this, SLOT(syncMargins(double)));
     connect(widget.rightMargin, SIGNAL(valueChangedPt(double)), this, SLOT(syncMargins(double)));
     connect(widget.bottomMargin, SIGNAL(valueChangedPt(double)), this, SLOT(syncMargins(double)));
     connect(widget.topMargin, SIGNAL(valueChangedPt(double)), this, SLOT(syncMargins(double)));
+
+    connect(widget.width, SIGNAL(valueChangedPt(double)), this, SLOT(widthChanged(double)));
+    connect(widget.height, SIGNAL(valueChangedPt(double)), this, SLOT(heightChanged(double)));
+
+    connect(m_state, SIGNAL(keepAspectRatioChanged(bool)), widget.keepAspect, SLOT(setKeepAspectRatio(bool)));
+    connect(widget.keepAspect, SIGNAL(keepAspectRatioChanged(bool)), this, SLOT(updateAspectRatio(bool)));
+
+    connect(widget.positionSelector, SIGNAL(positionSelected(KoFlake::Position)),
+        this, SLOT(setGeometryAlignment(KoFlake::Position)));
+
 }
 
 KWFrameGeometry::~KWFrameGeometry() {
@@ -55,12 +68,13 @@ void KWFrameGeometry::open(KWFrame* frame) {
 }
 
 void KWFrameGeometry::open(KoShape *shape) {
-    mOriginalPosition = shape->absolutePosition();
-    mOriginalSize = shape->size();
-    widget.left->changeValue(mOriginalPosition.x());
-    widget.top->changeValue(mOriginalPosition.y());
-    widget.width->changeValue(mOriginalSize.width());
-    widget.height->changeValue(mOriginalSize.height());
+    m_originalPosition = shape->absolutePosition();
+    m_originalSize = shape->size();
+    QPointF position = shape->absolutePosition(widget.positionSelector->position());
+    widget.xPos->changeValue(position.x());
+    widget.yPos->changeValue(position.y());
+    widget.width->changeValue(m_originalSize.width());
+    widget.height->changeValue(m_originalSize.height());
 
     connect(widget.protectSize, SIGNAL(stateChanged(int)),
             this, SLOT(protectSizeChanged(int)));
@@ -69,25 +83,26 @@ void KWFrameGeometry::open(KoShape *shape) {
         widget.protectSize->setCheckState(Qt::Checked);
     }
 
-    connect(widget.left, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
-    connect(widget.top, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
+    connect(widget.xPos, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
+    connect(widget.yPos, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
     connect(widget.width, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
     connect(widget.height, SIGNAL(valueChanged(double)), this, SLOT(updateShape()));
 }
 
 void KWFrameGeometry::updateShape() {
+    if(m_blockSignals) return;
     KWFrame *frame = m_frame;
     if(frame == 0) {
         frame = m_state->frame();
         m_state->markFrameUsed();
     }
     Q_ASSERT(frame);
-    frame->shape()->repaint();
-    QPointF pos(widget.left->value(), widget.top->value());
-    frame->shape()->setAbsolutePosition(pos);
+    frame->shape()->update();
+    QPointF pos(widget.xPos->value(), widget.yPos->value());
+    frame->shape()->setAbsolutePosition(pos, widget.positionSelector->position());
     QSizeF size(widget.width->value(), widget.height->value());
     frame->shape()->setSize(size);
-    frame->shape()->repaint();
+    frame->shape()->update();
 }
 
 void KWFrameGeometry::protectSizeChanged(int protectSizeState)
@@ -100,8 +115,8 @@ void KWFrameGeometry::protectSizeChanged(int protectSizeState)
     Q_ASSERT(frame);
     bool lock = (protectSizeState == Qt::Checked);
     frame->shape()->setLocked(lock);
-    widget.left->setDisabled(lock);
-    widget.top->setDisabled(lock);
+    widget.xPos->setDisabled(lock);
+    widget.yPos->setDisabled(lock);
     widget.width->setDisabled(lock);
     widget.height->setDisabled(lock);
 }
@@ -127,13 +142,29 @@ void KWFrameGeometry::cancel() {
         m_state->markFrameUsed();
     }
     Q_ASSERT(frame);
-    frame->shape()->setAbsolutePosition(mOriginalPosition);
-    frame->shape()->setSize(mOriginalSize);
+    frame->shape()->setAbsolutePosition(m_originalPosition);
+    frame->shape()->setSize(m_originalSize);
+}
+
+void KWFrameGeometry::widthChanged(double value) {
+    if(! m_state->keepAspectRatio())  return;
+    if(m_blockSignals) return;
+    m_blockSignals = true;
+    widget.height->changeValue(m_originalSize.width() / m_originalSize.height() * value);
+    m_blockSignals = false;
+}
+
+void KWFrameGeometry::heightChanged(double value) {
+    if(! m_state->keepAspectRatio())  return;
+    if(m_blockSignals) return;
+    m_blockSignals = true;
+    widget.width->changeValue(m_originalSize.width() / m_originalSize.height() * value);
+    m_blockSignals = false;
 }
 
 void KWFrameGeometry::setUnit(KoUnit unit) {
-    widget.left->setUnit(unit);
-    widget.top->setUnit(unit);
+    widget.xPos->setUnit(unit);
+    widget.yPos->setUnit(unit);
     widget.width->setUnit(unit);
     widget.height->setUnit(unit);
     widget.leftMargin->setUnit(unit);
@@ -142,4 +173,18 @@ void KWFrameGeometry::setUnit(KoUnit unit) {
     widget.bottomMargin->setUnit(unit);
 }
 
+void KWFrameGeometry::setGeometryAlignment(KoFlake::Position position) {
+    QPointF pos = m_frame->shape()->absolutePosition(position);
+    m_blockSignals = true;
+    widget.xPos->changeValue(pos.x());
+    widget.yPos->changeValue(pos.y());
+    m_blockSignals = false;
+}
+
+void KWFrameGeometry::updateAspectRatio(bool keep) {
+    m_state->setKeepAspectRatio(keep);
+    if(keep)
+        widget.height->changeValue(m_originalSize.width() / m_originalSize.height() * widget.width->value());
+}
+
 #include "KWFrameGeometry.moc"
