@@ -147,7 +147,7 @@ void KWTextFrameSet::requestMoreFrames(double textHeight) {
         QPointF orig = shape->absolutePosition(KoFlake::TopLeftCorner);
         shape->setSize(QSizeF(size.width(), size.height() + textHeight));
         shape->setAbsolutePosition(orig, KoFlake::TopLeftCorner);
-        shape->repaint(QRectF(0.0, size.height(), size.width(), textHeight));
+        shape->update(QRectF(0.0, size.height(), size.width(), textHeight));
         lastFrame->allowToGrow();
     }
 }
@@ -257,14 +257,14 @@ void KWTextFrameSet::printDebug(KWFrame *frame) {
     KWFrameSet::printDebug(frame);
     KoTextShapeData *textShapeData = dynamic_cast<KoTextShapeData*> (frame->shape()->userData());
     if(textShapeData == 0) return;
-    kDebug() <<"     Text position:" << textShapeData->position() <<", end:" << textShapeData->endPosition();
-    kDebug() <<"     Offset in text-document;" << textShapeData->documentOffset();
+    kDebug(32001) <<"     Text position:" << textShapeData->position() <<", end:" << textShapeData->endPosition();
+    kDebug(32001) <<"     Offset in text-document;" << textShapeData->documentOffset();
 }
 
 void KWTextFrameSet::printDebug() {
     static const char * type[] = { "FirstPageHeader", "OddPagesHeader", "EvenPagesHeader", "FirstPageFooter", "OddPagesFooter", "EvenPagesFooter", "Main", "FootNote", "Other", "ERROR" };
-    kDebug() <<" | Is a KWTextFrameSet";
-    kDebug() <<" | FS Type:" << type[m_textFrameSetType];
+    kDebug(32001) <<" | Is a KWTextFrameSet";
+    kDebug(32001) <<" | FS Type:" << type[m_textFrameSetType];
     KWFrameSet::printDebug();
 }
 #endif
