@@ -32,12 +32,13 @@
 #include <KoMainWindow.h>
 
 #include <ksharedconfig.h>
-
+#include <kconfiggroup.h>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QPainter>
 #include <QtGui/QScrollBar>
 #include <QtCore/QEvent>
 #include <QtGui/QDockWidget>
+#include <QtCore/QTimer>
 
 #include <config-opengl.h>
 
@@ -94,6 +95,12 @@ void KoCanvasController::scrollContentsBy ( int dx, int dy )
     setDocumentOffset();
 }
 
+void KoCanvasController::setDrawShadow( bool drawShadow )
+{
+    m_d->viewportWidget->setDrawShadow( drawShadow );
+}
+
+
 void KoCanvasController::resizeEvent(QResizeEvent * resizeEvent)
 {
     emit sizeChanged(resizeEvent->size());
@@ -118,7 +125,7 @@ void KoCanvasController::setCanvas(KoCanvasBase *canvas) {
     canvas->setCanvasController(this);
 
     emit canvasSet(this);
-    activate();
+    QTimer::singleShot(0, this, SLOT(activate()));
 }
 
 KoCanvasBase* KoCanvasController::canvas() const {
@@ -166,6 +173,21 @@ int KoCanvasController::visibleWidth() const {
 void KoCanvasController::setCanvasMode( CanvasMode mode )
 {
     m_d->canvasMode = mode;
+    switch(mode) {
+        case AlignTop:
+            m_d->preferredCenterFractionX = 0;
+            m_d->preferredCenterFractionY = 0.5;
+            break;
+        case Centered:
+            m_d->preferredCenterFractionX = 0.5;
+            m_d->preferredCenterFractionY = 0.5;
+            break;
+        case Infinite:
+        case Presentation:
+            m_d->preferredCenterFractionX = 0;
+            m_d->preferredCenterFractionY = 0;
+            break;
+    };
 }
 
 KoCanvasController::CanvasMode KoCanvasController::canvasMode() const
@@ -207,6 +229,7 @@ void KoCanvasController::updateCanvasOffsetX() {
     emit canvasOffsetXChanged(canvasOffsetX());
     if(m_d->viewportWidget && m_d->viewportWidget->canvas())
         m_d->viewportWidget->canvas()->setFocus(); // workaround ugly bug in Qt that the focus is transferred to the sliders
+    m_d->preferredCenterFractionX = (horizontalScrollBar()->value() + horizontalScrollBar()->pageStep() /2.0) / m_d->documentSize.width();
 }
 
 void KoCanvasController::updateCanvasOffsetY() {
@@ -215,6 +238,7 @@ void KoCanvasController::updateCanvasOffsetY() {
     emit canvasOffsetYChanged(canvasOffsetY());
     if(m_d->viewportWidget && m_d->viewportWidget->canvas())
         m_d->viewportWidget->canvas()->setFocus(); // workaround ugly bug in Qt that the focus is transferred to the sliders
+    m_d->preferredCenterFractionY = (verticalScrollBar()->value() + verticalScrollBar()->pageStep() /2.0) / m_d->documentSize.height();
 }
 
 bool KoCanvasController::eventFilter(QObject* watched, QEvent* event) {
@@ -312,17 +336,14 @@ void KoCanvasController::recenterPreferred()
 
     QScrollBar *hBar = horizontalScrollBar();
     // try to centralize the centerpoint which we want to make visible
-    {//if( hBar && hBar->isVisible() ) {
-        topLeft.rx() = qMax( topLeft.x(), hBar->minimum() );
-        topLeft.rx() = qMin( topLeft.x(), hBar->maximum() );
-        hBar->setValue( topLeft.x() );
-    }
+    topLeft.rx() = qMax( topLeft.x(), hBar->minimum() );
+    topLeft.rx() = qMin( topLeft.x(), hBar->maximum() );
+    hBar->setValue( topLeft.x() );
+
     QScrollBar *vBar = verticalScrollBar();
-    {//if( vBar && vBar->isVisible() ) {
-        topLeft.ry() = qMax( topLeft.y(), vBar->minimum() );
-        topLeft.ry() = qMin( topLeft.y(), vBar->maximum() );
-        vBar->setValue( topLeft.y() );
-    }
+    topLeft.ry() = qMax( topLeft.y(), vBar->minimum() );
+    topLeft.ry() = qMin( topLeft.y(), vBar->maximum() );
+    vBar->setValue( topLeft.y() );
 }
 
 void KoCanvasController::zoomIn(const QPoint &center)
@@ -332,6 +353,7 @@ void KoCanvasController::zoomIn(const QPoint &center)
 
     emit zoomBy(sqrt(2.0));
     recenterPreferred();
+    m_d->canvas->canvasWidget()->update();
 }
 
 void KoCanvasController::zoomOut(const QPoint &center)
@@ -341,6 +363,7 @@ void KoCanvasController::zoomOut(const QPoint &center)
 
     emit zoomBy(sqrt(0.5));
     recenterPreferred();
+    m_d->canvas->canvasWidget()->update();
 }
 
 void KoCanvasController::zoomTo(const QRect &viewRect)
@@ -352,18 +375,29 @@ void KoCanvasController::zoomTo(const QRect &viewRect)
     else
         scale = 1.0 * viewport()->width() / viewRect.width();
 
-    m_d->preferredCenterFractionX = 1.0 * viewRect.center().x() / m_d->documentSize.width();
-    m_d->preferredCenterFractionY = 1.0 * viewRect.center().y() / m_d->documentSize.height();
+    const double preferredCenterFractionX = 1.0 * viewRect.center().x() / m_d->documentSize.width();
+    const double preferredCenterFractionY = 1.0 * viewRect.center().y() / m_d->documentSize.height();
 
     emit zoomBy(scale);
+
+    m_d->preferredCenterFractionX = preferredCenterFractionX;
+    m_d->preferredCenterFractionY = preferredCenterFractionY;
+    recenterPreferred();
+    m_d->canvas->canvasWidget()->update();
 }
 
 void KoCanvasController::setToolOptionWidget(QWidget *widget) {
     emit toolOptionWidgetChanged(widget);
 }
 
-void KoCanvasController::setDocumentSize( const QSize & sz )
+void KoCanvasController::setDocumentSize( const QSize & sz, bool recalculateCenter )
 {
+    if (!recalculateCenter) {
+        // assume the distance from the top stays equal and recalculate the center.
+        m_d->preferredCenterFractionX = m_d->documentSize.width() * m_d->preferredCenterFractionX / sz.width();
+        m_d->preferredCenterFractionY = m_d->documentSize.height() * m_d->preferredCenterFractionY / sz.height();
+    }
+
     m_d->ignoreScrollSignals = true;
     m_d->documentSize = sz;
     m_d->viewportWidget->setDocumentSize( sz );
@@ -514,7 +548,7 @@ void KoCanvasController::wheelEvent( QWheelEvent *event ) {
 void KoCanvasController::activate()
 {
     QWidget *parent = this;
-    while( parent->parentWidget() ) 
+    while( parent->parentWidget() )
         parent = parent->parentWidget();
 
     KoMainWindow *mw = dynamic_cast<KoMainWindow*> (parent);
