@@ -33,8 +33,8 @@ class KoCanvasBase;
 class FLAKE_EXPORT KoCanvasObserver
 {
 public:
-    KoCanvasObserver() { }
-    virtual ~KoCanvasObserver() { }
+    KoCanvasObserver();
+    virtual ~KoCanvasObserver();
     virtual void setCanvas(KoCanvasBase *canvas) = 0;
 
 };
