@@ -22,18 +22,19 @@
 #ifndef CONNECTIONSHAPEFACTORY_H
 #define CONNECTIONSHAPEFACTORY_H
 
-#include <KoShapeFactoryBase.h>
+#include <KoShapeFactory.h>
 
 class KoShape;
 
-class KoConnectionShapeFactory : public KoShapeFactoryBase
+class KoConnectionShapeFactory : public KoShapeFactory
 {
 public:
-    KoConnectionShapeFactory(QObject *parent);
+    KoConnectionShapeFactory( QObject* parent);
     ~KoConnectionShapeFactory() {}
 
-    virtual KoShape *createDefaultShape(KoResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement &e) const;
+    virtual KoShape* createDefaultShape() const;
+    virtual KoShape* createShape( const KoProperties* params ) const;
+    virtual bool supports(const KoXmlElement & e) const;
     virtual QList<KoShapeConfigWidgetBase*> createShapeOptionPanels();
 };
 
