@@ -33,12 +33,15 @@
 #include "KoSelection.h"
 #include "KoShapeManager.h"
 #include "KoInteractionStrategy.h"
+#include "KoInteractionToolWidget.h"
 #include "KoCanvasBase.h"
 #include "KoPanTool.h"
 #include "KoCanvasResourceProvider.h"
 #include "commands/KoShapeMoveCommand.h"
 
 #include <QUndoCommand>
+#include <kaction.h>
+#include <kicon.h>
 #include <kcursor.h>
 #include <kstandarddirs.h>
 #include <k3staticdeleter.h>
@@ -73,6 +76,8 @@ KoInteractionTool::KoInteractionTool( KoCanvasBase *canvas )
     m_currentStrategy(0),
     d( new Private())
 {
+    setupActions();
+
     QPixmap rotatePixmap, shearPixmap;
     rotatePixmap.load(KStandardDirs::locate("data", "koffice/icons/rotate.png"));
     shearPixmap.load(KStandardDirs::locate("data", "koffice/icons/shear.png"));
@@ -125,6 +130,60 @@ bool KoInteractionTool::wantsAutoScroll()
     return true;
 }
 
+void KoInteractionTool::setupActions()
+{
+    KAction* actionBringToFront = new KAction( KIcon( "bring_forward" ),
+                                               i18n( "Bring to &Front" ), this );
+    addAction( "object_move_totop", actionBringToFront );
+    actionBringToFront->setShortcut( QKeySequence( "Ctrl+Shift+]" ) );
+//     connect(actionBringToFront, SIGNAL(triggered()), this, SLOT(selectionBringToFront()));
+
+    KAction* actionRaise = new KAction( KIcon( "raise" ), i18n( "&Raise" ), this );
+    addAction( "object_move_up", actionRaise );
+    actionRaise->setShortcut( QKeySequence( "Ctrl+]" ) );
+//    connect(actionRaise, SIGNAL(triggered()), this, SLOT(selectionMoveUp()));
+
+    KAction* actionLower = new KAction( KIcon( "lower" ), i18n( "&Lower" ), this );
+    addAction( "object_move_down", actionLower );
+    actionLower->setShortcut( QKeySequence( "Ctrl+[" ) );
+//    connect(actionLower, SIGNAL(triggered()), this, SLOT(selectionMoveDown()));
+
+    KAction* actionSendToBack = new KAction( KIcon( "send_backward" ),
+                                             i18n( "Send to &Back" ), this );
+    addAction( "object_move_tobottom", actionSendToBack );
+    actionSendToBack->setShortcut( QKeySequence( "Ctrl+Shift+[" ) );
+//    connect(actionSendToBack, SIGNAL(triggered()), this, SLOT(selectionSendToBack()));
+
+    KAction* actionAlignLeft = new KAction( KIcon( "aoleft" ),
+                                            i18n( "Align Left" ), this );
+    addAction( "object_align_horizontal_left", actionAlignLeft );
+    connect(actionAlignLeft, SIGNAL(triggered()), this, SLOT(selectionAlignHorizontalLeft()));
+
+    KAction* actionAlignCenter = new KAction( KIcon( "aocenterh" ),
+                                              i18n( "Horizontally Center" ), this );
+    addAction( "object_align_horizontal_center", actionAlignCenter );
+    connect(actionAlignCenter, SIGNAL(triggered()), this, SLOT(selectionAlignHorizontalCenter()));
+
+    KAction* actionAlignRight = new KAction( KIcon( "aoright" ),
+                                             i18n( "Align Right" ), this );
+    addAction( "object_align_horizontal_right", actionAlignRight );
+    connect(actionAlignRight, SIGNAL(triggered()), this, SLOT(selectionAlignHorizontalRight()));
+
+    KAction* actionAlignTop = new KAction( KIcon( "aotop" ), i18n( "Align Top" ), this );
+    addAction( "object_align_vertical_top", actionAlignTop );
+    connect(actionAlignTop, SIGNAL(triggered()), this, SLOT(selectionAlignVerticalTop()));
+
+    KAction* actionAlignMiddle = new KAction( KIcon( "aocenterv" ),
+                                              i18n( "Vertically Center" ), this );
+    addAction( "object_align_vertical_center", actionAlignMiddle );
+    connect(actionAlignMiddle, SIGNAL(triggered()), this, SLOT(selectionAlignVerticalCenter()));
+
+    KAction* actionAlignBottom = new KAction( KIcon( "aobottom" ),
+                                              i18n( "Align Bottom" ), this );
+    addAction( "object_align_vertical_bottom", actionAlignBottom );
+    connect(actionAlignBottom, SIGNAL(triggered()), this, SLOT(selectionAlignVerticalBottom()));
+}
+
 double KoInteractionTool::rotationOfHandle( KoFlake::SelectionHandle handle, bool useEdgeRotation )
 {
     QPointF selectionCenter = koSelection()->absolutePosition();
@@ -588,10 +647,10 @@ void KoInteractionTool::recalcSelectionBox() {
     d->selectionBox[KoFlake::BottomLeftHandle] = outline.value(3);
     d->selectionBox[KoFlake::LeftMiddleHandle] = (outline.value(3)+outline.value(0))/2;
     d->selectionBox[KoFlake::TopLeftHandle] = outline.value(0);
-    if(koSelection()->count() == 1) {
+    if (koSelection()->count() == 1) {
+#if 0        // TODO detect mirroring
         KoShape *s = koSelection()->firstSelectedShape();
-        // TODO detect mirroring
-        /*
+
         if(s->scaleX() < 0) { // vertically mirrored: swap left / right
             qSwap(d->selectionBox[KoFlake::TopLeftHandle], d->selectionBox[KoFlake::TopRightHandle]);
             qSwap(d->selectionBox[KoFlake::LeftMiddleHandle], d->selectionBox[KoFlake::RightMiddleHandle]);
@@ -602,7 +661,7 @@ void KoInteractionTool::recalcSelectionBox() {
             qSwap(d->selectionBox[KoFlake::TopMiddleHandle], d->selectionBox[KoFlake::BottomMiddleHandle]);
             qSwap(d->selectionBox[KoFlake::TopRightHandle], d->selectionBox[KoFlake::BottomRightHandle]);
         }
-        */
+#endif
     }
 }
 
@@ -614,6 +673,59 @@ void KoInteractionTool::activate(bool temporary) {
     repaintDecorations();
 }
 
+void KoInteractionTool::selectionAlignHorizontalLeft() {
+
+    selectionAlign(KoShapeAlignCommand::HorizontalLeftAlignment);
+}
+
+void KoInteractionTool::selectionAlignHorizontalCenter() {
+
+    selectionAlign(KoShapeAlignCommand::HorizontalCenterAlignment);
+}
+
+
+void KoInteractionTool::selectionAlignHorizontalRight() {
+
+    selectionAlign(KoShapeAlignCommand::HorizontalRightAlignment);
+}
+
+void KoInteractionTool::selectionAlignVerticalTop() {
+
+    selectionAlign(KoShapeAlignCommand::VerticalTopAlignment);
+}
+
+void KoInteractionTool::selectionAlignVerticalCenter() {
+
+    selectionAlign(KoShapeAlignCommand::VerticalCenterAlignment);
+}
+
+void KoInteractionTool::selectionAlignVerticalBottom() {
+
+    selectionAlign(KoShapeAlignCommand::VerticalBottomAlignment);
+}
+
+
+void KoInteractionTool::selectionAlign(KoShapeAlignCommand::Align align)
+{
+    KoSelection* selection = m_canvas->shapeManager()->selection();
+    if( ! selection )
+        return;
+
+    QList<KoShape*> selectedShapes = selection->selectedShapes( KoFlake::TopLevelSelection );
+    if( selectedShapes.count() < 1)
+        return;
+
+    QRectF bRect = selection->boundingRect();
+    KoShapeAlignCommand *cmd = new KoShapeAlignCommand( selectedShapes, align, bRect);
+
+    m_canvas->addCommand( cmd );
+}
+
+QWidget* KoInteractionTool::createOptionWidget() {
+    return new KoInteractionToolWidget( this );
+}
+
+
 // ##########  SelectionDecorator ############
 QImage * SelectionDecorator::s_rotateCursor=0;
 static K3StaticDeleter<QImage> staticRotateCursorDeleter;
@@ -791,3 +903,6 @@ void SelectionDecorator::paint(QPainter &painter, const KoViewConverter &convert
     } */
 #endif
 }
+
+
+#include "KoInteractionTool.moc"
