@@ -152,6 +152,7 @@ public:
      */
     KoPathPoint * arcTo( double rx, double ry, double startAngle, double sweepAngle );
 
+
     /**
      * @brief close the current subpath
      */
@@ -168,14 +169,6 @@ public:
      */
     void closeMerge();
 
-    /**
-     * @brief The path is updated
-     *
-     * This is called when a point of the path is updated. It will be used 
-     * to make it possible to cache things.
-     */
-    void update();
-
     /**
      * @brief Normalizes the path data.
      *
@@ -442,6 +435,11 @@ public:
     /// Returns a odf/svg string represenatation of the path data with the given matrix applied.
     QString toString( const QMatrix &matrix ) const;
 
+    /// Returns the fill rule for the path object
+    Qt::FillRule fillRule() const;
+
+    /// Sets the fill rule to be used for painting the background
+    void setFillRule( Qt::FillRule fillRule );
 private:
     // TODO move all the private methods to live on the d pointer object
     void map( const QMatrix &matrix );
@@ -462,6 +460,10 @@ private:
 #ifndef NDEBUG
     void paintDebug( QPainter &painter );
 #endif
+    /// reimplemented
+    virtual QString saveStyle( KoGenStyle &style, KoShapeSavingContext &context ) const;
+    /// reimplemented
+    virtual void loadStyle( const KoXmlElement & element, KoShapeLoadingContext &context );
 
 protected:
     QRectF handleRect( const QPointF &p, double radius ) const;
