@@ -57,7 +57,6 @@ class KoShape::Private {
 public:
     Private(KoShape *shape)
         : size( 50, 50 ),
-        pos( 0, 0 ),
         zIndex( 0 ),
         parent( 0 ),
         visible( true ),
@@ -94,7 +93,6 @@ public:
     }
 
     QSizeF size; // size in pt
-    QPointF pos; // position (top left) in pt
     QString shapeId;
     QString name; ///< the shapes names
 
@@ -343,35 +341,29 @@ int KoShape::zIndex() const {
     return d->zIndex;
 }
 
-void KoShape::repaint() const {
+void KoShape::update() const {
     if ( !d->shapeManagers.empty() )
     {
-        QRectF rect(QPointF(0, 0), size() );
-        if(d->border) {
-            KoInsets insets;
-            d->border->borderInsets(this, insets);
-            rect.adjust(-insets.left, -insets.top, insets.right, insets.bottom);
-        }
-        rect = absoluteTransformation(0).mapRect(rect);
+        QRectF rect( boundingRect() );
         foreach( KoShapeManager * manager, d->shapeManagers )
-            manager->repaint( rect, this, true );
+            manager->update( rect, this, true );
     }
 }
 
-void KoShape::repaint(const QRectF &shape) const {
+void KoShape::update(const QRectF &shape) const {
     if ( !d->shapeManagers.empty() && isVisible() )
     {
         QRectF rect(absoluteTransformation(0).mapRect(shape));
         foreach( KoShapeManager * manager, d->shapeManagers )
         {
-            manager->repaint(rect);
+            manager->update(rect);
         }
     }
 }
 
 const QPainterPath KoShape::outline() const {
     QPainterPath path;
-    path.addRect(QRectF( QPointF(0, 0), size() ));
+    path.addRect(QRectF( QPointF(0, 0), QSizeF( qMax(d->size.width(), 0.0001), qMax(d->size.height(), 0.0001) ) ));
     return path;
 }
 
@@ -398,7 +390,6 @@ void KoShape::setAbsolutePosition(QPointF newPosition, KoFlake::Position anchor)
 }
 
 void KoShape::copySettings(const KoShape *shape) {
-    d->pos = shape->position();
     d->size = shape->size();
     d->connectors.clear();
     foreach(QPointF point, shape->connectors())
@@ -502,6 +493,10 @@ QList<QPointF> KoShape::connectors() const {
     return d->connectors.toList();
 }
 
+QList<QPointF> KoShape::connectionPoints() const {
+    return d->connectors.toList();
+}
+
 void KoShape::setBackground ( const QBrush & brush ) {
     d->backgroundBrush = brush;
 }
@@ -605,6 +600,12 @@ QList<KoShapeConnection*> KoShape::connections() const {
     return d->connections;
 }
 
+void KoShape::removeConnectionPoint( int index )
+{
+    if( index < d->connectors.count() )
+        d->connectors.remove( index );
+}
+
 QString KoShape::name() const {
     return d->name;
 }
@@ -627,16 +628,8 @@ void KoShape::saveOdfConnections(KoShapeSavingContext &context) const {
     Q_UNUSED( context );
 }
 
-QString KoShape::style( KoShapeSavingContext &context ) const
+QString KoShape::saveStyle( KoGenStyle &style, KoShapeSavingContext &context ) const
 {
-    KoGenStyle style;
-    if ( context.isSet( KoShapeSavingContext::PresentationShape ) ) {
-        style = KoGenStyle( KoGenStyle::StylePresentationAuto, "presentation" );
-    }
-    else {
-        style = KoGenStyle( KoGenStyle::StyleGraphicAuto, "graphic" );
-    }
-
     // and fill the style
     KoShapeBorderModel * b = border();
     if ( b )
@@ -649,6 +642,12 @@ QString KoShape::style( KoShapeSavingContext &context ) const
     return styleWriter.addFillStyle( style, background() );
 }
 
+void KoShape::loadStyle( const KoXmlElement & element, KoShapeLoadingContext &context )
+{
+    setBackground( loadOdfFill( element, context ) );
+    setBorder( loadOdfStroke( element, context ) );
+}
+
 bool KoShape::loadOdfAttributes( const KoXmlElement & element, KoShapeLoadingContext &context, int attributes )
 {
     if ( attributes & OdfSize ) {
@@ -688,8 +687,7 @@ bool KoShape::loadOdfAttributes( const KoXmlElement & element, KoShapeLoadingCon
         if( element.hasAttributeNS( KoXmlNS::draw, "name" ) )
             setName( element.attributeNS( KoXmlNS::draw, "name" ) );
 
-        setBackground( loadOdfFill( element, context ) );
-        setBorder( loadOdfStroke( element, context ) );
+        loadStyle( element, context );
     }
 
     if( attributes & OdfTransformation )
@@ -702,27 +700,34 @@ bool KoShape::loadOdfAttributes( const KoXmlElement & element, KoShapeLoadingCon
     return true;
 }
 
-QBrush KoShape::loadOdfFill( const KoXmlElement & element, KoShapeLoadingContext & context )
+QString KoShape::getStyleProperty( const char *property, const KoXmlElement & element, KoShapeLoadingContext & context )
 {
     KoStyleStack &styleStack = context.koLoadingContext().styleStack();
-    QString fill;
+    QString value;
     if( element.hasAttributeNS( KoXmlNS::draw, "style-name" ) )
     {
         // fill the style stack with the shapes style
         context.koLoadingContext().fillStyleStack( element, KoXmlNS::draw, "style-name", "graphic" );
         styleStack.setTypeProperties( "graphic" );
-        if( styleStack.hasProperty( KoXmlNS::draw, "fill" ) )
-            fill = styleStack.property( KoXmlNS::draw, "fill" );
+        if( styleStack.hasProperty( KoXmlNS::draw, property ) )
+            value = styleStack.property( KoXmlNS::draw, property );
     }
     else if( element.hasAttributeNS( KoXmlNS::presentation, "style-name" ) )
     {
         // fill the style stack with the shapes style
         context.koLoadingContext().fillStyleStack( element, KoXmlNS::presentation, "style-name", "presentation" );
         styleStack.setTypeProperties( "presentation" );
-        if ( styleStack.hasProperty( KoXmlNS::presentation, "fill" ) )
-            fill = styleStack.property( KoXmlNS::presentation, "fill" );
+        if ( styleStack.hasProperty( KoXmlNS::presentation, property ) )
+            value = styleStack.property( KoXmlNS::presentation, property );
     }
 
+    return value;
+}
+
+QBrush KoShape::loadOdfFill( const KoXmlElement & element, KoShapeLoadingContext & context )
+{
+    KoStyleStack &styleStack = context.koLoadingContext().styleStack();
+    QString fill = getStyleProperty( "fill", element, context );
     if ( fill == "solid" || fill == "hatch" )
         return KoOasisStyles::loadOasisFillStyle( styleStack, fill, context.koLoadingContext().oasisStyles() );
     else if( fill == "gradient" )
@@ -736,24 +741,7 @@ QBrush KoShape::loadOdfFill( const KoXmlElement & element, KoShapeLoadingContext
 KoShapeBorderModel * KoShape::loadOdfStroke( const KoXmlElement & element, KoShapeLoadingContext & context )
 {
     KoStyleStack &styleStack = context.koLoadingContext().styleStack();
-    QString stroke;
-    if( element.hasAttributeNS( KoXmlNS::draw, "style-name" ) )
-    {
-        // fill the style stack with the shapes style
-        context.koLoadingContext().fillStyleStack( element, KoXmlNS::draw, "style-name", "graphic" );
-        styleStack.setTypeProperties( "graphic" );
-        if( styleStack.hasProperty( KoXmlNS::draw, "stroke" ) )
-            stroke = styleStack.property( KoXmlNS::draw, "stroke" );
-    }
-    else if( element.hasAttributeNS( KoXmlNS::presentation, "style-name" ) )
-    {
-        // fill the style stack with the shapes style
-        context.koLoadingContext().fillStyleStack( element, KoXmlNS::presentation, "style-name", "presentation" );
-        styleStack.setTypeProperties( "presentation" );
-        if ( styleStack.hasProperty( KoXmlNS::presentation, "stroke" ) )
-            stroke = styleStack.property( KoXmlNS::presentation, "stroke" );
-    }
-
+    QString stroke = getStyleProperty( "stroke", element, context );
     if( stroke == "solid" || stroke == "dash" )
     {
         QPen pen = KoOasisStyles::loadOasisStrokeStyle( styleStack, stroke, context.koLoadingContext().oasisStyles() );
@@ -850,10 +838,16 @@ void KoShape::saveOdfFrameAttributes(KoShapeSavingContext &context) const {
 
 void KoShape::saveOdfAttributes(KoShapeSavingContext &context, int attributes) const {
     if(attributes & OdfMandatories) {
+        KoGenStyle style;
         // all items that should be written to 'draw:frame' and any other 'draw:' object that inherits this shape
-        context.xmlWriter().addAttribute( context.isSet( KoShapeSavingContext::PresentationShape ) ?
-                                          "presentation:style-name": "draw:style-name",
-                                          style( context ) );
+        if ( context.isSet( KoShapeSavingContext::PresentationShape ) ) {
+            style = KoGenStyle( KoGenStyle::StylePresentationAuto, "presentation" );
+            context.xmlWriter().addAttribute( "presentation:style-name", saveStyle( style, context ) );
+        }
+        else {
+            style = KoGenStyle( KoGenStyle::StyleGraphicAuto, "graphic" );
+            context.xmlWriter().addAttribute( "draw:style-name", saveStyle( style, context ) );
+        }
 
         if ( context.isSet( KoShapeSavingContext::DrawId ) )
         {
@@ -878,12 +872,13 @@ void KoShape::saveOdfAttributes(KoShapeSavingContext &context, int attributes) c
         QSizeF s( size() );
         context.xmlWriter().addAttributePt( "svg:width", s.width() );
         context.xmlWriter().addAttributePt( "svg:height", s.height() );
-        context.xmlWriter().addAttributePt( "svg:x", d->pos.x() );
-        context.xmlWriter().addAttributePt( "svg:y", d->pos.y() );
+        // the position is hidden in the transformation
+        context.xmlWriter().addAttributePt( "svg:x", 0.0 );
+        context.xmlWriter().addAttributePt( "svg:y", 0.0 );
     }
 
     if(attributes & OdfMandatories) {
-        context.xmlWriter().addAttribute("draw:z-index", zIndex());
+        context.xmlWriter().addAttribute("draw:z-index", d->zIndex);
     }
 
     if(attributes & OdfTransformation) {
