@@ -31,10 +31,10 @@
 #include <QSet>
 #include <QBrush>
 
-#include <flake_export.h>
-
 #include <KoXmlReaderForward.h>
 
+#include "flake_export.h"
+
 class QPainter;
 class QRectF;
 class QPainterPath;
@@ -49,6 +49,7 @@ class KoShapeApplicationData;
 class KoShapeSavingContext;
 class KoCanvasBase;
 class KoShapeLoadingContext;
+class KoGenStyle;
 
 /**
  *
@@ -276,12 +277,11 @@ public:
     void addConnectionPoint( const QPointF &point );
 
     /**
-     * Return a list of the connectors that have been added to this shape.
-     * Note that altering the list or the points in there will not have any
-     * effect on the shape.
+     * Return a list of the connection points that have been added to this shape.
      * @return a list of the connectors that have been added to this shape.
      */
-    QList<QPointF> connectors() const;
+    KDE_DEPRECATED QList<QPointF> connectors() const;
+    QList<QPointF> connectionPoints() const;
 
     /**
      * Set the background of the shape.
@@ -390,7 +390,7 @@ public:
      * <p>This method will return immediately and only request a repaint. Successive calls
      * will be merged into an appropriate repaint action.
      */
-    virtual void repaint() const;
+    virtual void update() const;
 
     /**
      * Request a repaint to be queued.
@@ -401,7 +401,7 @@ public:
      * will be merged into an appropriate repaint action.
      * @param shape the rectangle (in pt) to queue for repaint.
      */
-    void repaint(const QRectF &shape) const;
+    void update(const QRectF &shape) const;
 
     /**
      * This is a method used to sort a list using the STL sorting methods.
@@ -660,15 +660,25 @@ protected:
     void saveOdfConnections( KoShapeSavingContext &context ) const;
 
     /**
-     * @brief Get the style used for the shape
+     * @brief Saves the style used for the shape
      *
-     * This method calls fillStyle and add then the style to the context
+     * This method fills the given style object with the border and
+     * background properties and then adds the style to the context.
      *
+     * @param style the style object to fill
      * @param context used for saving
      * @return the name of the style
      * @see saveOdf
      */
-    QString style( KoShapeSavingContext &context ) const;
+    virtual QString saveStyle( KoGenStyle &style, KoShapeSavingContext &context ) const;
+
+    /**
+     * Loads the stroke and fill style from the given element.
+     *
+     * @param element the xml element to  load the style from
+     * @param context the loading context used for loading
+     */
+    virtual void loadStyle( const KoXmlElement & element, KoShapeLoadingContext &context );
 
     /// Loads the fill style
     QBrush loadOdfFill( const KoXmlElement & element, KoShapeLoadingContext & context );
@@ -676,6 +686,11 @@ protected:
     /// Loads the stroke style
     KoShapeBorderModel * loadOdfStroke( const KoXmlElement & element, KoShapeLoadingContext & context );
 
+    /**
+     * Fills the style stack and returns the value of the given style property (e.g fill, stroke).
+     */
+    QString getStyleProperty( const char *property, const KoXmlElement & element, KoShapeLoadingContext & context );
+
 /* ** end loading saving */
 
 
@@ -714,6 +729,9 @@ protected:
      */
     void removeConnection(KoShapeConnection *connection);
 
+    /// Removes connection point with given index
+    void removeConnectionPoint( int index );
+
 private:
     friend class KoShapeManager;
     void addShapeManager( KoShapeManager * manager );
