@@ -6,7 +6,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or ( at your option ) any later version.
+   version 2 of the License, or (at your option) any later version.
  
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,18 +23,20 @@
 #include "KoShapeLayer.h"
 
 #include <KoGenStyles.h>
-#include <KoSavingContext.h>
 #include <KoXmlWriter.h>
 #include <KoStore.h>
 #include <KoStoreDevice.h>
 
 #include <kmimetype.h>
 
-KoShapeSavingContext::KoShapeSavingContext( KoXmlWriter &xmlWriter, KoSavingContext &context )
+#include <QtCore/QTime>
+
+KoShapeSavingContext::KoShapeSavingContext( KoXmlWriter &xmlWriter, KoGenStyles& mainStyles, SavingMode savingMode )
 : m_xmlWriter( &xmlWriter )
 , m_savingOptions( 0 )
 , m_drawId( 0 )
-, m_context( context )
+, m_mainStyles( mainStyles )
+, m_savingMode( savingMode )
 {
 }
 
@@ -54,7 +56,7 @@ void KoShapeSavingContext::setXmlWriter( KoXmlWriter &_xmlWriter )
 
 KoGenStyles & KoShapeSavingContext::mainStyles() 
 {
-    return m_context.mainStyles(); 
+    return m_mainStyles; 
 }
 
 bool KoShapeSavingContext::isSet( ShapeSavingOption option ) const
@@ -84,12 +86,15 @@ void KoShapeSavingContext::removeOption( ShapeSavingOption option) {
 const QString KoShapeSavingContext::drawId( const KoShape * shape, bool insert )
 {
     QMap<const KoShape *, QString>::const_iterator it( m_drawIds.find( shape ) );
-    if ( it == m_drawIds.constEnd() && insert == true )
-    {
-        it = m_drawIds.insert( shape, QString( "shape" ).arg( ++m_drawId ) );
-        return it.value();
+    if ( it == m_drawIds.constEnd() ) {
+        if ( insert == true ) {
+            it = m_drawIds.insert( shape, QString( "shape" ).arg( ++m_drawId ) );
+        }
+        else {
+            return QString();
+        }
     }
-    return QString();
+    return it.value();
 }
 
 void KoShapeSavingContext::addLayerForSaving( const KoShapeLayer * layer )
