@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
  *  Copyright (c) 2005-2006 Boudewijn Rempt <boud@valdyas.org>
- * Copyright (C) 2006, 2008 Thomas Zander <zander@kde.org>
+ * Copyright (C) 2006 Thomas Zander <zander@kde.org>
  * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
@@ -21,22 +21,22 @@
 #ifndef KO_TOOL_MANAGER
 #define KO_TOOL_MANAGER
 
-#include "KoInputDevice.h"
-#include "flake_export.h"
+#include <KoInputDevice.h>
+#include <flake_export.h>
 
 #include <QObject>
 #include <QCursor>
 #include <QList>
 
+class ToolHelper;
 class KoCanvasController;
 class KoCanvasBase;
-class KoToolBase;
+class KoTool;
 class KoCreateShapesTool;
 class KActionCollection;
 class KoShape;
-class QToolButton;
-class KoInputDeviceHandlerEvent;
-class KoShapeLayer;
+class KoToolProxy;
+class QAbstractButton;
 
 /**
  * This class manages the activation and deactivation of tools for
@@ -92,8 +92,7 @@ class KoShapeLayer;
    the tool stuff.)
 
  */
-class FLAKE_EXPORT KoToolManager : public QObject
-{
+class FLAKE_EXPORT KoToolManager : public QObject {
     Q_OBJECT
 
 public:
@@ -101,6 +100,9 @@ public:
     static KoToolManager* instance();
     ~KoToolManager();
 
+    /// You can just create a toolProxy with new, no need to use this method.
+    KDE_DEPRECATED KoToolProxy *createToolProxy(KoCanvasBase *parentCanvas);
+
     /**
      * Register actions for switching to tools at the actionCollection parameter.
      * The actions will have the text / shortcut as stated by the toolFactory.
@@ -137,14 +139,6 @@ public:
      */
     KoCreateShapesTool *shapeCreatorTool(KoCanvasBase *canvas) const;
 
-    /**
-     * Returns the tool that is able to add/edit guides for this param canvas.
-     * @param canvas the canvas that is a child of a previously registered controller
-     *    who's tool you want.
-     * @see addController()
-     */
-    KoToolBase *toolById(KoCanvasBase *canvas, const QString id) const;
-
     /// @return the currently active pointing device
     KoInputDevice currentInputDevice() const;
 
@@ -157,9 +151,9 @@ public:
 
     /// Struct for the createToolList return type.
     struct Button {
-        QToolButton *button;///< a newly created button.
+        QAbstractButton *button;///< a newly created button.
         QString section;        ///< The section the button wants to be in.
-        int priority;           ///< Lower number (higher priority) means coming first in the section.
+        int priority;           ///< Higher priority means coming first in the section.
         int buttonGroupId;      ///< An unique ID for this button as passed by changedTool()
         QString visibilityCode; ///< This button should become visible when we emit this string in toolCodesSelected()
     };
@@ -169,25 +163,7 @@ public:
      * @returns a list of Buttons.
      * This is a factory method for buttons and meta information on the button to better display the button.
      */
-    QList<Button> createToolList(KoCanvasBase *canvas) const;
-
-    /// Request tool activation for the given canvas controller
-    void requestToolActivation(KoCanvasController *controller);
-
-    /// Injects an input event from a plugin based input device
-    void injectDeviceEvent(KoInputDeviceHandlerEvent *event);
-
-    /// Returns the toolId of the currently active tool
-    QString activeToolId() const;
-
-    class Private;
-    /**
-     * \internal return the private object for the toolmanager.
-     */
-    KoToolManager::Private *priv();
-
-    /// reimplemented from QObject
-    virtual bool eventFilter(QObject *object, QEvent *event);
+    QList<Button> createToolList() const;
 
 public slots:
     /**
@@ -202,7 +178,7 @@ signals:
      * @param canvas the currently active canvas.
      * @param uniqueToolId a random but unique code for the new tool.
      */
-    void changedTool(KoCanvasController *canvas, int uniqueToolId);
+    void changedTool(const KoCanvasController *canvas, int uniqueToolId);
 
     /**
      * Emitted after the selection changed to state which unique shape-types are now
@@ -210,14 +186,7 @@ signals:
      * @param canvas the currently active canvas.
      * @param types a list of string that are the shape types of the selected objects.
      */
-    void toolCodesSelected(const KoCanvasController *canvas, const QList<QString> &types);
-
-    /**
-     * Emitted after the current layer changed either its properties or to a new layer.
-     * @param canvas the currently active canvas.
-     * @param layer the layer that is selected.
-     */
-    void currentLayerChanged(const KoCanvasController *canvas, const KoShapeLayer *layer);
+    void toolCodesSelected(const KoCanvasController *canvas, QList<QString> types);
 
     /**
      * Every time a new input device gets used by a tool, this event is emitted.
@@ -225,34 +194,50 @@ signals:
      */
     void inputDeviceChanged(const KoInputDevice &device);
 
+protected:
+    friend class KoToolProxy;
     /**
-     * Emitted whenever the active canvas changed.
-     * @param canvas the new activated canvas (might be 0)
+     * Request a switch from to the param input device.
+     * This will cause the tool for that device to be selected.
      */
-    void changedCanvas(const KoCanvasBase *canvas);
+    void switchInputDevice(const KoInputDevice &device);
 
     /**
-     * Emitted whenever the active tool changes the status text.
-     * @param statusText the new status text
+     * Whenever a new tool proxy class is instantiated, it will use this method to register itself
+     * so the toolManager can update it to the latest active tool.
+     * @param proxy the proxy to register.
+     * @param canvas which canvas the proxy is associated with; whenever a new tool is selected for that canvas,
+     *        the proxy gets an update.
      */
-    void changedStatusText(const QString &statusText);
+    void registerToolProxy(KoToolProxy *proxy, KoCanvasBase *canvas);
 
 private:
+
     KoToolManager();
     KoToolManager(const KoToolManager&);
     KoToolManager operator=(const KoToolManager&);
+    void setup();
+    void switchTool(KoTool *tool, bool temporary);
+    void switchTool(const QString &id, bool temporary);
+    void postSwitchTool();
+    bool eventFilter(QObject *object, QEvent *event);
 
-    Q_PRIVATE_SLOT(d, void toolActivated(ToolHelper *tool))
-    Q_PRIVATE_SLOT(d, void detachCanvas(KoCanvasController *controller))
-    Q_PRIVATE_SLOT(d, void attachCanvas(KoCanvasController *controller))
-    Q_PRIVATE_SLOT(d, void movedFocus(QWidget *from, QWidget *to))
-    Q_PRIVATE_SLOT(d, void updateCursor(const QCursor &cursor))
-    Q_PRIVATE_SLOT(d, void switchBackRequested())
-    Q_PRIVATE_SLOT(d, void selectionChanged(QList<KoShape*> shapes))
-    Q_PRIVATE_SLOT(d, void currentLayerChanged(const KoShapeLayer *layer))
-    Q_PRIVATE_SLOT(d, void switchToolTemporaryRequested(const QString &id))
+private slots:
 
+    void toolActivated(ToolHelper *tool);
+    void detachCanvas(KoCanvasController *controller);
+    void attachCanvas(KoCanvasController *controller);
+    void movedFocus(QWidget *from, QWidget *to);
+    void updateCursor(QCursor cursor);
+    void switchToolTemporaryRequested(const QString &id);
+    void switchBackRequested();
+    void selectionChanged(QList<KoShape*> shapes);
+
+private:
+    class Private;
     Private *const d;
+
+    static KoToolManager* s_instance;
 };
 
 #endif
