@@ -111,6 +111,20 @@ KoScriptingPart::KoScriptingPart(KoScriptingModule* const module, const QStringL
         QDockWidget* docker = mainwindow->createDockWidget(&factory);
         Q_UNUSED(docker);
     }
+
+    if( view ) {
+        if( Kross::ActionCollection* c = Kross::Manager::self().actionCollection()->collection("docker") ) {
+            foreach(Kross::Action* a, c->actions()) {
+                if( ! a->isEnabled() )
+                    continue;
+                a->addObject(d->module);
+                KoScriptingDockerFactory *f = new KoScriptingDockerFactory(view, d->module, a);
+                QDockWidget *dock = view->createDockWidget(f);
+                //dock->setEnabled(false);
+                kDebug(41011) <<"Adding scripting docker with id=" << f->id();
+            }
+        }
+    }
 }
 
 KoScriptingPart::~KoScriptingPart()
@@ -196,6 +210,15 @@ void KoScriptingPart::slotFinished(Kross::Action* action)
     if( d->module && d->module == action->object( d->module->objectName() ) ) {
         //d->view->document()->setModified(true);
         //QApplication::restoreOverrideCursor();
+        KoView* view = d->module ? d->module->view() : 0;
+        if( view && view->shell() /* && view == view->shell()->rootView() */ ) {
+            if( action->hadError() ) {
+                if( action->errorTrace().isNull() )
+                    KMessageBox::error(view, action->errorMessage());
+                else
+                    KMessageBox::detailedError(view, action->errorMessage(), action->errorTrace());
+            }
+        }
         myFinished(action);
     }
 }
@@ -206,15 +229,6 @@ void KoScriptingPart::slotFinalized(Kross::Action* action)
     disconnect(action, SIGNAL(finalized(Kross::Action*)), this, SLOT(slotFinalized(Kross::Action*)));
     d->actions.removeAll(action);
     if( d->module && d->module == action->object( d->module->objectName() ) ) {
-        KoView* view = d->module ? d->module->view() : 0;
-        if( view && view->shell() /* && view == view->shell()->rootView() */ ) {
-            if( action->hadError() ) {
-                if( action->errorTrace().isNull() )
-                    KMessageBox::error(view, action->errorMessage());
-                else
-                    KMessageBox::detailedError(view, action->errorMessage(), action->errorTrace());
-            }
-        }
         myFinalized(action);
     }
 }
