@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2006-2007 Thorsten Zachmann <zachmann@kde.org>
+   Copyright (C) 2007 Thomas Zander <zander@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,17 +20,21 @@
 
 #include "KoPADocument.h"
 
-#include <KTemporaryFile>
-
 #include <KoStore.h>
 #include <KoStoreDevice.h>
 #include <KoXmlWriter.h>
 #include <KoXmlReader.h>
 #include <KoOasisStyles.h>
-#include <KoSavingContext.h>
+#include <KoOdfReadStore.h>
+#include <KoOdfWriteStore.h>
 #include <KoOasisLoadingContext.h>
 #include <KoShapeManager.h>
 #include <KoShapeLayer.h>
+#include <KoTextShapeData.h>
+#include <KoTextDocumentLayout.h>
+#include <KoInlineTextObjectManager.h>
+#include <KoShapeStyleWriter.h>
+#include <KoStyleManager.h>
 #include <KoPathShape.h>
 #include <KoLineBorder.h>
 #include <KoDom.h>
@@ -40,36 +45,34 @@
 #include "KoPAPage.h"
 #include "KoPAMasterPage.h"
 #include "KoPASavingContext.h"
-#include "KoPAStyles.h"
 #include "KoPALoadingContext.h"
 
+#include <kdebug.h>
+
 #include <typeinfo>
 
+class KoPADocument::Private {
+public:
+
+    QList<KoPAPageBase*> pages;
+    QList<KoPAPageBase*> masterPages;
+    KoInlineTextObjectManager *inlineTextObjectManager;
+    KoStyleManager *styleManager;
+};
+
 KoPADocument::KoPADocument( QWidget* parentWidget, QObject* parent, bool singleViewMode )
-: KoDocument( parentWidget, parent, singleViewMode )
+: KoDocument( parentWidget, parent, singleViewMode ),
+    d(new Private())
 {
-//    KoPAMasterPage * masterPage = new KoPAMasterPage();
-//    m_masterPages.append( masterPage );
-#ifndef NDEBUG
-    //TODO This produces some pages to be used for testing remove when we have loading support
-/*    KoPathShape *pathShape = new KoPathShape();
-    pathShape->lineTo( QPointF( 100, 100 ) );
-    pathShape->setPosition( QPointF( 100, 100 ) );
-    pathShape->setBorder( new KoLineBorder( 1.0 ) );
-    KoShapeLayer * parentShape = dynamic_cast<KoShapeLayer *>( masterPage->iterator()[0] );
-    if ( parentShape )
-    {
-        parentShape->addChild( pathShape );
-    }
-    insertPage( new KoPAPage(  masterPage ), 1 );
-    insertPage(  new KoPAPage(  masterPage ), 2 );*/
-#endif
+    d->inlineTextObjectManager = new KoInlineTextObjectManager(this);
+    d->styleManager = new KoStyleManager(this);
 }
 
 KoPADocument::~KoPADocument()
 {
-    qDeleteAll( m_pages );
-    qDeleteAll( m_masterPages );
+    qDeleteAll( d->pages );
+    qDeleteAll( d->masterPages );
+    delete d;
 }
 
 void KoPADocument::paintContent( QPainter &painter, const QRect &rect)
@@ -87,17 +90,13 @@ bool KoPADocument::loadXML( QIODevice *, const KoXmlDocument & doc )
     return true;
 }
 
-bool KoPADocument::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisStyles,
-                              const KoXmlDocument & settings, KoStore* store )
+bool KoPADocument::loadOdf( KoOdfReadStore & odfStore )
 {
-    Q_UNUSED( doc );
-    Q_UNUSED( settings );
-
     emit sigProgress( 0 );
-    KoOasisLoadingContext loadingContext( this, oasisStyles, store );
+    KoOasisLoadingContext loadingContext( this, odfStore.styles(), odfStore.store() );
     KoPALoadingContext paContext( loadingContext );
 
-    KoXmlElement content = doc.documentElement();
+    KoXmlElement content = odfStore.contentDoc().documentElement();
     KoXmlElement realBody ( KoDom::namedItemNS( content, KoXmlNS::office, "body" ) );
 
     if ( realBody.isNull() ) {
@@ -112,27 +111,10 @@ bool KoPADocument::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisSty
         return false;
     }
 
-    //load master pages
-    const QHash<QString, KoXmlElement*> masterStyles( oasisStyles.masterPages() );
-    QHash<QString, KoXmlElement*>::const_iterator it( masterStyles.constBegin() );
-    for ( ; it != masterStyles.constEnd(); ++it )
-    {
-        qDebug() << "Master:" << it.key();
-        KoPAMasterPage * masterPage = newMasterPage();
-        masterPage->loadOdf( *( it.value() ), paContext );
-        m_masterPages.append( masterPage );
-        paContext.addMasterPage (it.key(), masterPage);
-    }
-
-    KoXmlElement element;
-    forEachElement( element, body )
-    {
-        if ( element.tagName() == "page" && element.namespaceURI() == KoXmlNS::draw ) {
-            KoPAPage* page = newPage();
-            page->loadOdf( element, paContext );
-
-            insertPage( page, -1 );
-        }
+    d->masterPages = loadOdfMasterPages( odfStore.styles().masterPages(), paContext );
+    d->pages = loadOdfPages( body, paContext );
+    if ( d->pages.size() > 1 ) {
+        setActionEnabled( KoPAView::ActionDeletePage, false );
     }
 
     emit sigProgress( 100 );
@@ -141,146 +123,103 @@ bool KoPADocument::loadOasis( const KoXmlDocument & doc, KoOasisStyles& oasisSty
 
 bool KoPADocument::saveOasis( KoStore* store, KoXmlWriter* manifestWriter )
 {
-    if ( !store->open( "content.xml" ) )
+    KoOdfWriteStore oasisStore( store );
+    KoXmlWriter* contentWriter = oasisStore.contentWriter();
+    if ( !contentWriter )
         return false;
 
-    KoStoreDevice contentDev( store );
-    KoXmlWriter* contentWriter = createOasisXmlWriter( &contentDev, "office:document-content" );
-
     KoGenStyles mainStyles;
-    KoSavingContext savingContext( mainStyles, KoSavingContext::Store );
+    KoXmlWriter * bodyWriter = oasisStore.bodyWriter();
 
-    // for office:master-styles
-    KTemporaryFile masterStyles;
-    masterStyles.open();
-    KoXmlWriter masterStylesTmpWriter( &masterStyles, 1 );
+    KoPASavingContext paContext( *bodyWriter, mainStyles, 1, KoShapeSavingContext::Store );
 
-    KoPASavingContext paContext( masterStylesTmpWriter, savingContext, 1 );
-
-    paContext.setOptions( KoPASavingContext::DrawId | KoPASavingContext::AutoStyleInStyleXml );
-
-    masterStylesTmpWriter.startElement( "office:master-styles" );
-
-    // save master pages
-    foreach( KoPAPageBase *page, m_masterPages )
-    {
-        page->saveOdf( paContext );
-    }
-    masterStylesTmpWriter.endElement();
-
-    masterStyles.close();
-
-    // for office:body
-    KTemporaryFile contentTmpFile;
-    contentTmpFile.open();
-    KoXmlWriter contentTmpWriter( &contentTmpFile, 1 );
-
-    contentTmpWriter.startElement( "office:body" );
-    contentTmpWriter.startElement( odfTagName( true ) );
-
-    paContext.setXmlWriter( contentTmpWriter );
-    paContext.setOptions( KoPASavingContext::DrawId );
-
-    // save pages
-    foreach ( KoPAPageBase *page, m_pages )
-    {
-        page->saveOdf( paContext );
-        paContext.incrementPage();
-    }
-
-    contentTmpWriter.endElement(); // office:odfTagName()
-    contentTmpWriter.endElement(); // office:body
-
-    contentTmpFile.close();
-
-    contentWriter->startElement( "office:automatic-styles" );
-    saveOdfAutomaticStyles( *contentWriter, mainStyles, false );
-    contentWriter->endElement();
-
-    // And now we can copy over the contents from the tempfile to the real one
-    contentWriter->addCompleteElement( &contentTmpFile );
-
-    contentWriter->endElement(); // root element
-    contentWriter->endDocument();
-    delete contentWriter;
-
-    if ( !store->close() ) // done with content.xml
+    if ( !saveOasisPages( paContext, d->pages, d->masterPages ) ) {
         return false;
+    }
+
+    mainStyles.saveOdfAutomaticStyles( contentWriter, false );
+
+    oasisStore.closeContentWriter();
 
     //add manifest line for content.xml
     manifestWriter->addManifestEntry( "content.xml", "text/xml" );
 
-    if ( !store->open( "styles.xml" ) )
-        return false;
+    return mainStyles.saveOdfStylesDotXml( store, manifestWriter );
+}
 
-    manifestWriter->addManifestEntry( "styles.xml", "text/xml" );
-    saveOdfDocumentStyles( store, mainStyles, &masterStyles );
+QList<KoPAPageBase *> KoPADocument::loadOdfMasterPages( const QHash<QString, KoXmlElement*> masterStyles, KoPALoadingContext & context )
+{
+    QList<KoPAPageBase *> masterPages;
 
-    if ( !store->close() ) // done with styles.xml
-        return false;
+    QHash<QString, KoXmlElement*>::const_iterator it( masterStyles.constBegin() );
+    for ( ; it != masterStyles.constEnd(); ++it )
+    {
+        qDebug() << "Master:" << it.key();
+        KoPAMasterPage * masterPage = newMasterPage();
+        masterPage->loadOdf( *( it.value() ), context );
+        masterPages.append( masterPage );
+        context.addMasterPage( it.key(), masterPage );
+    }
+    return masterPages;
+}
+
+QList<KoPAPageBase *> KoPADocument::loadOdfPages( const KoXmlElement & body, KoPALoadingContext & context )
+{
+    QList<KoPAPageBase *> pages;
+    KoXmlElement element;
+    forEachElement( element, body )
+    {
+        if ( element.tagName() == "page" && element.namespaceURI() == KoXmlNS::draw ) {
+            KoPAPage* page = newPage();
+            page->loadOdf( element, context );
+            pages.append( page );
+        }
+    }
+    return pages;
+}
+
+bool KoPADocument::saveOasisPages( KoPASavingContext &paContext, QList<KoPAPageBase *> &pages, QList<KoPAPageBase *> &masterPages )
+{
+    paContext.setOptions( KoPASavingContext::DrawId | KoPASavingContext::AutoStyleInStyleXml );
+
+    // save master pages
+    foreach( KoPAPageBase *page, masterPages ) {
+        page->saveOdf( paContext );
+    }
+
+    KoXmlWriter & bodyWriter = paContext.xmlWriter();
+    bodyWriter.startElement( "office:body" );
+    bodyWriter.startElement( odfTagName( true ) );
+
+    paContext.setOptions( KoPASavingContext::DrawId );
+
+    // save pages
+    foreach ( KoPAPageBase *page, pages ) {
+        page->saveOdf( paContext );
+        paContext.incrementPage();
+    }
+
+    bodyWriter.endElement(); // office:odfTagName()
+    bodyWriter.endElement(); // office:body
 
     return true;
 }
 
-void KoPADocument::saveOdfAutomaticStyles( KoXmlWriter& contentWriter, KoGenStyles& mainStyles, bool stylesDotXml )
-{
-    // test style writing
-    QList<KoGenStyles::NamedStyle> styles = mainStyles.styles( KoGenStyle::StyleGraphicAuto, stylesDotXml );
-    QList<KoGenStyles::NamedStyle>::const_iterator it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        //qDebug() << "style:style" << ( *it ).name;
-        ( *it ).style->writeStyle( &contentWriter, mainStyles, "style:style", ( *it ).name , "style:graphic-properties" );
-    }
-
-    styles = mainStyles.styles( KoPAStyles::STYLE_PAGE, stylesDotXml );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        //qDebug() << "style:style" << ( *it ).name;
-        ( *it ).style->writeStyle( &contentWriter, mainStyles, "style:style", ( *it ).name , "style:drawing-page-properties" );
-    }
-
-    styles = mainStyles.styles( KoGenStyle::StylePageLayout, stylesDotXml );
-    it = styles.begin();
-    for ( ; it != styles.end() ; ++it ) {
-        //qDebug() << "style:style" << ( *it ).name;
-        (*it).style->writeStyle( &contentWriter, mainStyles, "style:page-layout", (*it).name, "style:page-layout-properties" );
-    }
-}
-
-void KoPADocument::saveOdfDocumentStyles( KoStore * store, KoGenStyles& mainStyles, QFile *masterStyles )
-{
-    KoStoreDevice stylesDev( store );
-    KoXmlWriter* stylesWriter = createOasisXmlWriter( &stylesDev, "office:document-styles" );
-
-    stylesWriter->startElement( "office:styles" );
-    stylesWriter->endElement(); // office:styles
-
-    stylesWriter->startElement( "office:automatic-styles" );
-    saveOdfAutomaticStyles( *stylesWriter, mainStyles, true );
-    stylesWriter->endElement(); // office:automatic-styles
-
-    stylesWriter->addCompleteElement( masterStyles );
-
-    stylesWriter->endElement(); // root element (office:document-styles)
-    stylesWriter->endDocument();
-    delete stylesWriter;
-}
-
 KoPAPageBase* KoPADocument::pageByIndex( int index, bool masterPage ) const
 {
     if ( masterPage )
     {
-        return m_masterPages.at( index );
+        return d->masterPages.at( index );
     }
     else
     {
-        return m_pages.at( index );
+        return d->pages.at( index );
     }
 }
 
 KoPAPageBase* KoPADocument::pageByNavigation( KoPAPageBase * currentPage, KoPageApp::PageNavigation pageNavigation ) const
 {
-    const QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( currentPage ) ? m_masterPages : m_pages;
+    const QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( currentPage ) ? d->masterPages : d->pages;
 
     Q_ASSERT( ! pages.isEmpty() );
 
@@ -323,10 +262,17 @@ void KoPADocument::addShape( KoShape * shape )
     if(!shape)
         return;
 
+    KoTextShapeData *data = qobject_cast<KoTextShapeData*> (shape->userData());
+    if (data) { // its a text shape.
+        KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*> (data->document()->documentLayout());
+        if(lay)
+            lay->setStyleManager(d->styleManager);
+    }
+
     // the KoShapeController sets the active layer as parent
     KoPAPageBase * page( pageByShape( shape ) );
 
-    bool isMaster = dynamic_cast<KoPAMasterPage*>( page ) != 0; 
+    bool isMaster = dynamic_cast<KoPAMasterPage*>( page ) != 0;
 
     foreach( KoView *view, views() )
     {
@@ -358,9 +304,9 @@ void KoPADocument::removeShape( KoShape *shape )
 
     KoPAPageBase * page( pageByShape( shape ) );
 
-    bool isMaster = dynamic_cast<KoPAMasterPage*>( page ) != 0; 
+    bool isMaster = dynamic_cast<KoPAMasterPage*>( page ) != 0;
 
-    foreach( KoView *view, views() ) 
+    foreach( KoView *view, views() )
     {
         KoPAView * kopaView = static_cast<KoPAView*>( view );
         KoPAPage * p;
@@ -396,7 +342,7 @@ KoPAPageBase * KoPADocument::pageByShape( KoShape * shape ) const
 
 void KoPADocument::setActionEnabled( int actions, bool enable )
 {
-    foreach( KoView *view, views() ) 
+    foreach( KoView *view, views() )
     {
         KoPAView * kopaView = static_cast<KoPAView*>( view );
         kopaView->setActionEnabled( actions, enable );
@@ -408,7 +354,7 @@ void KoPADocument::insertPage( KoPAPageBase* page, int index )
     if ( !page )
         return;
 
-    QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? m_masterPages : m_pages;
+    QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? d->masterPages : d->pages;
 
     if ( index > pages.size() || index < 0 )
     {
@@ -416,7 +362,7 @@ void KoPADocument::insertPage( KoPAPageBase* page, int index )
     }
 
     pages.insert( index, page );
-    
+
     if ( pages.size() == 2 ) {
         setActionEnabled( KoPAView::ActionDeletePage, true );
     }
@@ -427,7 +373,7 @@ void KoPADocument::insertPage( KoPAPageBase* page, KoPAPageBase* after )
     if ( !page )
         return;
 
-    QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? m_masterPages : m_pages;
+    QList<KoPAPageBase*>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? d->masterPages : d->pages;
 
     int index = 0;
 
@@ -445,7 +391,7 @@ void KoPADocument::insertPage( KoPAPageBase* page, KoPAPageBase* after )
     if ( pages.size() == 2 ) {
         setActionEnabled( KoPAView::ActionDeletePage, true );
     }
-    
+
     // move active view to new page
 }
 
@@ -453,7 +399,7 @@ int KoPADocument::takePage( KoPAPageBase *page )
 {
     Q_ASSERT( page );
 
-    QList<KoPAPageBase *>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? m_masterPages : m_pages;
+    QList<KoPAPageBase *>& pages = dynamic_cast<KoPAMasterPage *>( page ) ? d->masterPages : d->pages;
 
     int index = pages.indexOf( page );
 
@@ -481,9 +427,9 @@ int KoPADocument::takePage( KoPAPageBase *page )
     return index;
 }
 
-QList<KoPAPageBase*> KoPADocument::pages() const
+QList<KoPAPageBase*> KoPADocument::pages( bool masterPages ) const
 {
-    return m_pages;
+    return masterPages ? d->masterPages : d->pages;
 }
 
 KoPAPage * KoPADocument::newPage( KoPAMasterPage * masterPage )
@@ -496,5 +442,10 @@ KoPAMasterPage * KoPADocument::newMasterPage()
     return new KoPAMasterPage();
 }
 
+/// return the inlineTextObjectManager for this document.
+KoInlineTextObjectManager *KoPADocument::inlineTextObjectManager() const {
+    return d->inlineTextObjectManager;
+}
+
 
 #include "KoPADocument.moc"
