@@ -1,6 +1,5 @@
 /* This file is part of the KDE project
  * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
- * Copyright (C) 2008 Fredy Yanardi <fyanardi@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,9 +19,8 @@
 
 #include "KoPADocumentModel.h"
 
-#include "KoPADocument.h"
-#include "KoPAPageBase.h"
-#include "KoPAPageProvider.h"
+#include <KoPADocument.h>
+#include <KoPAPageBase.h>
 #include <KoShapePainter.h>
 #include <KoShapeManager.h>
 #include <KoShapeBorderModel.h>
@@ -32,12 +30,11 @@
 #include <KoCanvasController.h>
 #include <KoShapeControllerBase.h>
 #include <KoSelection.h>
+#include <KoZoomHandler.h>
 #include <KoShapeLayer.h>
 #include <KoShapeGroup.h>
 #include <KoShapeGroupCommand.h>
 #include <KoShapeUngroupCommand.h>
-#include <KoShapeRenameCommand.h>
-#include <KoZoomHandler.h>
 
 #include <klocale.h>
 #include <kicon.h>
@@ -47,20 +44,17 @@
 #include <QtCore/QAbstractItemModel>
 #include <QtCore/QMimeData>
 
-#include "commands/KoPAPageMoveCommand.h"
 
-KoPADocumentModel::KoPADocumentModel( QObject* parent, KoPADocument *document )
-: KoDocumentSectionModel( parent )
-, m_master(false)
+
+KoPADocumentModel::KoPADocumentModel( KoPADocument *document )
+: m_document( document )
 , m_lastContainer( 0 )
 {
-    setDocument( document );
     setSupportedDragActions( Qt::MoveAction );
 }
 
 void KoPADocumentModel::update()
 {
-    emit layoutAboutToBeChanged();
     emit layoutChanged();
 }
 
@@ -71,7 +65,7 @@ int KoPADocumentModel::rowCount( const QModelIndex &parent ) const
 
     // check if parent is root node
     if( ! parent.isValid() )
-        return m_document->pages(m_master).count();
+        return m_document->pages().count();
 
     Q_ASSERT(parent.model() == this);
     Q_ASSERT(parent.internalPointer());
@@ -96,8 +90,8 @@ QModelIndex KoPADocumentModel::index( int row, int column, const QModelIndex &pa
     // check if parent is root node
     if( ! parent.isValid() )
     {
-        if( row >= 0 && row < m_document->pages(m_master).count() )
-            return createIndex( row, column, m_document->pages(m_master).at(row) );
+        if( row >= 0 && row < m_document->pages().count() )
+            return createIndex( row, column, m_document->pages().at(row) );
         else
             return QModelIndex();
     }
@@ -138,7 +132,7 @@ QModelIndex KoPADocumentModel::parent( const QModelIndex &child ) const
     if( ! grandParentShape )
     {
         KoPAPageBase* page = dynamic_cast<KoPAPageBase*>( parentShape);
-        return createIndex( m_document->pages(m_master).indexOf( page ), 0, parentShape );
+        return createIndex( m_document->pages().indexOf( page ), 0, parentShape );
     }
 
     return createIndex( indexFromChild( grandParentShape, parentShape ), 0, parentShape );
@@ -162,36 +156,23 @@ QVariant KoPADocumentModel::data( const QModelIndex &index, int role ) const
             if( name.isEmpty() )
             {
                 if ( dynamic_cast<KoPAPageBase *>( shape ) ) {
-                    if(m_document->pageType() == KoPageApp::Slide ) {
-                        name = i18n("Slide %1",  m_document->pageIndex(dynamic_cast<KoPAPageBase *>(shape)) + 1);
-                    } else {
-                        name = i18n("Page  %1", m_document->pageIndex(dynamic_cast<KoPAPageBase *>(shape)) + 1);
-                    }
+                    name = i18n("Page");
                 }
                 else if( dynamic_cast<KoShapeLayer*>( shape ) ) {
-                    name = i18n("Layer") + QString(" (%1)").arg(shape->zIndex());
+                    name = i18n("Layer");
                 }
                 else if( dynamic_cast<KoShapeGroup*>( shape ) ) {
-                    name = i18n("Group") + QString(" (%1)").arg(shape->zIndex());
+                    name = i18n("Group");
                 }
                 else {
-                    name = i18n("Shape") + QString(" (%1)").arg(shape->zIndex());
+                    name = i18n("Shape");
                 }
             }
-            return name;
+            return name + QString(" (%1)").arg( shape->zIndex() );
         }
         case Qt::DecorationRole: return QVariant();//return shape->icon();
         case Qt::EditRole: return shape->name();
-        case Qt::SizeHintRole:
-        {
-            KoPAPageBase *page = dynamic_cast<KoPAPageBase*>(shape);
-            if (page) { // return actual page size for page
-                KoPageLayout layout = page->pageLayout();
-                return QSize(layout.width, layout.height);
-            }
-            else
-                return shape->size();
-        }
+        case Qt::SizeHintRole: return shape->size();
         case ActiveRole:
         {
             KoCanvasController * canvasController = KoToolManager::instance()->activeCanvasController();
@@ -199,11 +180,11 @@ QVariant KoPADocumentModel::data( const QModelIndex &index, int role ) const
             if( ! selection )
                 return false;
 
-            /* KoShapeLayer *layer = dynamic_cast<KoShapeLayer*>( shape );
+            KoShapeLayer *layer = dynamic_cast<KoShapeLayer*>( shape );
             if( layer )
                 return (layer == selection->activeLayer() );
-            else */
-            return selection->isSelected( shape );
+            else
+                return selection->isSelected( shape );
         }
         case PropertiesRole: return QVariant::fromValue( properties( shape ) );
         case AspectRatioRole:
@@ -214,10 +195,10 @@ QVariant KoPADocumentModel::data( const QModelIndex &index, int role ) const
             if( container )
             {
                 bbox = QRectF();
-                foreach( KoShape* shape, container->childShapes() )
+                foreach( KoShape* shape, container->iterator() )
                     bbox = bbox.united( shape->outline().boundingRect() );
             }
-            return qreal(bbox.width()) / bbox.height();
+            return double(bbox.width()) / bbox.height();
         }
         default:
             if (role >= int(BeginThumbnailRole))
@@ -257,25 +238,21 @@ bool KoPADocumentModel::setData(const QModelIndex &index, const QVariant &value,
     {
         case Qt::DisplayRole:
         case Qt::EditRole:
-        {
-            QUndoCommand * cmd = new KoShapeRenameCommand( shape, value.toString() );
-            // TODO 2.1 use different text for the command if e.g. it is a page/slide or layer
-            m_document->addCommand( cmd );
-        }   break;
+            shape->setName( value.toString() );
+            break;
         case PropertiesRole:
             setProperties( shape, value.value<PropertyList>());
             break;
         case ActiveRole:
-            /* if (value.toBool())
+            if (value.toBool())
             {
                 KoCanvasController * canvasController = KoToolManager::instance()->activeCanvasController();
                 KoSelection * selection = canvasController->canvas()->shapeManager()->selection();
 
                 KoShapeLayer *layer = dynamic_cast<KoShapeLayer*>( shape );
-                if( layer && selection ) {
+                if( layer && selection )
                     selection->setActiveLayer( layer );
-                }
-            } */
+            }
             break;
         default:
             return false;
@@ -289,68 +266,53 @@ KoDocumentSectionModel::PropertyList KoPADocumentModel::properties( KoShape* sha
 {
     PropertyList l;
     l << Property(i18n("Visible"), SmallIcon("14_layer_visible"), SmallIcon("14_layer_novisible"), shape->isVisible());
-    l << Property(i18n("Locked"), SmallIcon("object-locked"), SmallIcon("object-unlocked"), shape->isGeometryProtected());
+    l << Property(i18n("Locked"), SmallIcon("security-high"), SmallIcon("security-low"), shape->isLocked());
     return l;
 }
 
 void KoPADocumentModel::setProperties( KoShape* shape, const PropertyList &properties )
 {
     bool oldVisibleState = shape->isVisible();
-    bool oldLockedState = shape->isGeometryProtected();
+    bool oldLockedState = shape->isLocked();
 
     shape->setVisible( properties.at( 0 ).state.toBool() );
-    shape->setGeometryProtected( properties.at( 1 ).state.toBool() );
+    shape->setLocked( properties.at( 1 ).state.toBool() );
 
-    if( ( oldVisibleState != shape->isVisible() ) || ( oldLockedState != shape->isGeometryProtected() ) )
+    if( ( oldVisibleState != shape->isVisible() ) || ( oldLockedState != shape->isLocked() ) )
         shape->update();
 }
 
 QImage KoPADocumentModel::createThumbnail( KoShape* shape, const QSize &thumbSize ) const
 {
-    QSize size(thumbSize.width(), thumbSize.height());
-    KoShapePainter shapePainter;
+    KoShapePainter painter;
 
     QList<KoShape*> shapes;
 
-    KoPAPageBase *page = dynamic_cast<KoPAPageBase*>(shape);
-    if (page) { // We create a thumbnail with actual width / height ratio for page
-        KoZoomHandler zoomHandler;
-        KoPageLayout layout = page->pageLayout();
-        qreal ratio = (zoomHandler.resolutionX() * layout.width) / (zoomHandler.resolutionY() * layout.height);
-        if ( ratio > 1 ) {
-            size.setHeight( size.width() / ratio );
-        }
-        else {
-            size.setWidth( size.height() * ratio );
-        }
-        QPixmap pixmap = m_document->pageThumbnail( page, size );
-        return pixmap.toImage();
-    }
-
     KoShapeContainer * container = dynamic_cast<KoShapeContainer*>( shape );
     if( container )
-        shapes = container->childShapes();
+        shapes = container->iterator();
     else
         shapes.append( shape );
 
-    shapePainter.setShapes( shapes );
+    painter.setShapes( shapes );
 
-    QImage thumb( size, QImage::Format_RGB32 );
+    QImage thumb( thumbSize, QImage::Format_RGB32 );
     // draw the background of the thumbnail
     thumb.fill( QColor( Qt::white ).rgb() );
-    shapePainter.paintShapes( thumb );
+
+    painter.paintShapes( thumb );
 
     return thumb;
 }
 
 KoShape * KoPADocumentModel::childFromIndex( KoShapeContainer *parent, int row ) const
 {
-    return parent->childShapes().at(row);
+    return parent->iterator().at(row);
 
     if( parent != m_lastContainer )
     {
         m_lastContainer = parent;
-        m_childs = parent->childShapes();
+        m_childs = parent->iterator();
         qSort( m_childs.begin(), m_childs.end(), KoShape::compareShapeZIndex );
     }
     return m_childs.at( row );
@@ -361,12 +323,12 @@ int KoPADocumentModel::indexFromChild( KoShapeContainer *parent, KoShape *child
     if ( !m_document )
         return 0;
 
-    return parent->childShapes().indexOf( child );
+    return parent->iterator().indexOf( child );
 
     if( parent != m_lastContainer )
     {
         m_lastContainer = parent;
-        m_childs = parent->childShapes();
+        m_childs = parent->iterator();
         qSort( m_childs.begin(), m_childs.end(), KoShape::compareShapeZIndex );
     }
     return m_childs.indexOf( child );
@@ -439,27 +401,20 @@ bool KoPADocumentModel::dropMimeData( const QMimeData * data, Qt::DropAction act
 
     QList<KoShape*> toplevelShapes;
     QList<KoShapeLayer*> layers;
-    QList<KoPAPageBase *> pages;
     // remove shapes having its parent in the list
     // and separate the layers
     foreach( KoShape * shape, shapes )
     {
-        // check whether the selection contains page
-        // by the UI rules, the selection should contains page only
-        KoPAPageBase *page = dynamic_cast<KoPAPageBase *>( shape );
-        if ( page ) {
-            pages.append( page );
-            continue;
-        }
-
-        KoShapeContainer *parentShape = shape->parent();
+        KoShapeContainer * parent = shape->parent();
         bool hasParentInList = false;
-        while ( parentShape ) {
-            if ( shapes.contains( parentShape ) ) {
+        while( parent )
+        {
+            if( shapes.contains( parent ) )
+            {
                 hasParentInList = true;
                 break;
             }
-            parentShape = parentShape->parent();
+            parent = parent->parent();
         }
         if( hasParentInList )
             continue;
@@ -471,56 +426,41 @@ bool KoPADocumentModel::dropMimeData( const QMimeData * data, Qt::DropAction act
             toplevelShapes.append( shape );
     }
 
-    // dropping to root, only page(s) is allowed
-    if ( !parent.isValid() ) {
-        if ( !pages.isEmpty() ) {
-            if ( row < 0 ) {
-                return false;
-            }
-            KoPAPageBase *after = ( row != 0 ) ? m_document->pageByIndex( row - 1, false ) : 0;
-            KoPAPageMoveCommand *command = new KoPAPageMoveCommand( m_document, pages, after );
-            m_document->addCommand( command );
-            kDebug(30010) << "KoPADocumentModel::dropMimeData parent = root, dropping page(s) as root, moving page(s)";
-            return true;
-        }
-        else {
-            kDebug(30010) << "KoPADocumentModel::dropMimeData parent = root, dropping non-page as root, returning false";
-            return false;
-        }
+    if( ! parent.isValid() )
+    {
+        kDebug(38000) <<"KoPADocumentModel::dropMimeData parent = root";
+        return false;
     }
-
     KoShape *shape = static_cast<KoShape*>( parent.internalPointer() );
     KoShapeContainer * container = dynamic_cast<KoShapeContainer*>( shape );
-    if( container ) {
+    if( container )
+    {
         KoShapeGroup * group = dynamic_cast<KoShapeGroup*>( container );
         if( group )
         {
-            kDebug(30010) <<"KoPADocumentModel::dropMimeData parent = group";
+            kDebug(38000) <<"KoPADocumentModel::dropMimeData parent = group";
             if( ! toplevelShapes.count() )
                 return false;
 
-            emit layoutAboutToBeChanged();
             beginInsertRows( parent, group->childCount(), group->childCount()+toplevelShapes.count() );
 
             QUndoCommand * cmd = new QUndoCommand();
             cmd->setText( i18n("Reparent shapes") );
 
             foreach( KoShape * shape, toplevelShapes )
-                new KoShapeUngroupCommand( shape->parent(), QList<KoShape*>() << shape, QList<KoShape*>(), cmd );
+                new KoShapeUngroupCommand( shape->parent(), QList<KoShape*>() << shape, cmd );
 
             new KoShapeGroupCommand( group, toplevelShapes, cmd );
             KoCanvasController * canvasController = KoToolManager::instance()->activeCanvasController();
             canvasController->canvas()->addCommand( cmd );
 
             endInsertRows();
-            emit layoutChanged();
         }
         else
         {
-            kDebug(30010) <<"KoPADocumentModel::dropMimeData parent = container";
+            kDebug(38000) <<"KoPADocumentModel::dropMimeData parent = container";
             if( toplevelShapes.count() )
             {
-                emit layoutAboutToBeChanged();
                 beginInsertRows( parent, container->childCount(), container->childCount()+toplevelShapes.count() );
 
                 QUndoCommand * cmd = new QUndoCommand();
@@ -536,7 +476,7 @@ bool KoPADocumentModel::dropMimeData( const QMimeData * data, Qt::DropAction act
                     }
 
                     clipped.append( shape->parent()->childClipped( shape ) );
-                    new KoShapeUngroupCommand( shape->parent(), QList<KoShape*>() << shape, QList<KoShape*>(), cmd );
+                    new KoShapeUngroupCommand( shape->parent(), QList<KoShape*>() << shape, cmd );
                 }
                 // shapes are dropped on a container, so add them to the container
                 new KoShapeGroupCommand( container, toplevelShapes, clipped, cmd );
@@ -544,7 +484,6 @@ bool KoPADocumentModel::dropMimeData( const QMimeData * data, Qt::DropAction act
                 canvasController->canvas()->addCommand( cmd );
 
                 endInsertRows();
-                emit layoutChanged();
             }
             else if( layers.count() )
             {
@@ -559,7 +498,7 @@ bool KoPADocumentModel::dropMimeData( const QMimeData * data, Qt::DropAction act
     }
     else
     {
-        kDebug(30010) <<"KoPADocumentModel::dropMimeData parent = shape";
+        kDebug(38000) <<"KoPADocumentModel::dropMimeData parent = shape";
         if( ! toplevelShapes.count() )
             return false;
 
@@ -592,7 +531,7 @@ QModelIndex KoPADocumentModel::parentIndexFromShape( const KoShape * child )
     if( parentLayer ) {
         KoPAPageBase * page = dynamic_cast<KoPAPageBase*>( parentLayer->parent() );
         if ( page )
-            return createIndex( m_document->pages(m_master).count() - 1 - m_document->pages(m_master).indexOf( page ), 0, parentLayer );
+            return createIndex( m_document->pages().count() - 1 - m_document->pages().indexOf( page ), 0, parentLayer );
     }
     // get the grandparent to determine the row of the parent shape
     KoShapeContainer *grandParentShape = parentShape->parent();
@@ -605,22 +544,7 @@ QModelIndex KoPADocumentModel::parentIndexFromShape( const KoShape * child )
 void KoPADocumentModel::setDocument( KoPADocument* document )
 {
     m_document = document;
-
-    if ( m_document )
-    {
-        connect( m_document, SIGNAL(pageAdded( KoPAPageBase* ) ), this, SLOT( update() ) );
-        connect( m_document, SIGNAL(pageRemoved( KoPAPageBase* ) ), this, SLOT( update() ) );
-        connect( m_document, SIGNAL(shapeAdded( KoShape* ) ), this, SLOT( update() ) );
-        connect( m_document, SIGNAL(shapeRemoved( KoShape* ) ), this, SLOT( update() ) );
-    }
-
-    reset();
+    update();
 }
 
-void KoPADocumentModel::setMasterMode(bool master)
-{
-    m_master = master;
-    update(); // Rebuild the model
-}
-
-#include <KoPADocumentModel.moc>
+#include "KoPADocumentModel.moc"
