@@ -21,10 +21,13 @@
 
 #include "kotext_export.h"
 
-#include <QStringList>
-#include <QChar>
-#include <QTextCharFormat>
-#include <QMetaType>
+#include <kdeversion.h>
+
+#include <QtCore/QStringList>
+#include <QtCore/QChar>
+#include <QtGui/QTextCharFormat>
+#include <QtCore/QMetaType>
+#include <QtGui/QTextOption>
 
 /**
  * Generic namespace of the KOffice Text library for helper methods and data.
@@ -49,6 +52,7 @@ namespace KoText {
         SelectedTextAnchor = 3344189
     };
 
+#if QT_VERSION < KDE_MAKE_VERSION(4,4,0) // remove when 4.4 is mandatory
     /// enum for a type of tabulator used
     enum TabType {
         LeftTab,        ///< A left-tab
@@ -56,11 +60,15 @@ namespace KoText {
         CenterTab,      ///< A centered-tab
         DelimiterTab    ///< A tab stopping at a certain delimiter-character
     };
+#endif
 
     /// For paragraphs each tab definition is represented by this struct.
     struct KOTEXT_EXPORT Tab {
         Tab();
         double position;    ///< distance in point from the start of the text-shape
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+        QTextOption::
+#endif
         TabType type;       ///< Determine which type is used.
         QChar delimiter;    ///< If type is DelimitorTab; tab until this char was found in the text.
         QTextCharFormat::UnderlineStyle leaderStyle;
