@@ -80,6 +80,7 @@ public:
     KoInlineTextObjectManager *inlineTextObjectManager;
     bool scheduled;
     KoTextDocumentLayout *parent;
+    KoPostscriptPaintDevice *paintDevice;
 };
 
 // ------------------- KoTextDocumentLayout --------------------
@@ -88,12 +89,15 @@ KoTextDocumentLayout::KoTextDocumentLayout(QTextDocument *doc, KoTextDocumentLay
     m_state(layout),
     d(new Private(this))
 {
-    setPaintDevice( new KoPostscriptPaintDevice() );
+    d->paintDevice = new KoPostscriptPaintDevice();
+    setPaintDevice( d->paintDevice );
     if(m_state == 0)
         m_state = new LayoutStateDummy();
 }
 
 KoTextDocumentLayout::~KoTextDocumentLayout() {
+    delete d->paintDevice;
+    delete d;
     delete m_state;
     m_state = 0;
 }
@@ -147,7 +151,7 @@ KoInlineTextObjectManager *KoTextDocumentLayout::inlineObjectTextManager() {
 QRectF KoTextDocumentLayout::blockBoundingRect(const QTextBlock &block) const {
     // nobody calls this code and I have no way of implementing it anyway...
     Q_UNUSED(block);
-    kWarning() << "KoTextDocumentLayout::blockBoundingRect is not implemented";
+    //kWarning() << "KoTextDocumentLayout::blockBoundingRect is not implemented";
     return QRectF(0, 0, 10, 10);
 }
 
@@ -187,7 +191,6 @@ int KoTextDocumentLayout::hitTest(const QPointF &point, Qt::HitTestAccuracy accu
         }
         for(int i=0; i < layout->lineCount(); i++) {
             QTextLine line = layout->lineAt(i);
-            updateTabsForLine(block, i);
             // kDebug() <<" + line[" << line.textStart() <<"]:" << line.y() <<"-" << line.height();
             if(point.y() > line.y() + line.height()) {
                 position = line.textStart() + line.textLength();
@@ -310,7 +313,7 @@ void KoTextDocumentLayout::layout() {
             double posY = m_state->y();
             bool moreText = m_state->nextParag();
             if(m_state->shape && m_state->y() > posY)
-                m_state->shape->repaint(QRectF(0, posY,
+                m_state->shape->update(QRectF(0, posY,
                             m_state->shape->size().width(), m_state->y() - posY));
 
             if(! moreText)
@@ -334,7 +337,7 @@ void KoTextDocumentLayout::layout() {
         repaintRect.moveTop(repaintRect.y() - m_state->docOffsetInShape());
         repaintRect.setX(0.0); // just take full width since we can't force a repaint of
         repaintRect.setWidth(m_state->shape->size().width()); // where lines were before layout.
-        m_state->shape->repaint(repaintRect);
+        m_state->shape->update(repaintRect);
     }
 }
 
@@ -357,18 +360,4 @@ KoShape* KoTextDocumentLayout::shapeForPosition(int position) const {
     return 0;
 }
 
-// static
-void KoTextDocumentLayout::updateTabsForLine(const QTextBlock &block, int lineNumber) {
-    if(! block.isValid()) return;
-    KoTextBlockData *blockData = dynamic_cast<KoTextBlockData*> (block.userData());
-    if(blockData == 0) return;
-    QList<KoTextBlockData::TabLineData> tabsData = blockData->tabLineData();
-    if(tabsData.count() <= lineNumber) return;
-
-    KoTextBlockData::TabLineData tabs = tabsData[lineNumber];
-    QTextOption textOption = block.layout()->textOption();
-    textOption.setTabArray(tabs.tabs);
-    block.layout()->setTextOption(textOption);
-}
-
 #include "KoTextDocumentLayout.moc"
