@@ -31,6 +31,7 @@
 #include <KoUnit.h>
 #include <KoGenStyle.h>
 
+#include <kdeversion.h>
 #include <KDebug>
 
 class KoCharacterStyle::Private {
@@ -96,13 +97,13 @@ KoCharacterStyle::KoCharacterStyle(const KoCharacterStyle &style)
 }
 
 
-KoCharacterStyle::KoCharacterStyle(const QTextFormat &textFormat)
+KoCharacterStyle::KoCharacterStyle(const QTextCharFormat &format)
     : QObject(0), d( new Private() )
 {
-    QMapIterator<int, QVariant> i(textFormat.properties());
-    while (i.hasNext()) {
-        i.next();
-        d->setProperty(i.key(), i.value());
+    QMapIterator<int, QVariant> iter(format.properties());
+    while (iter.hasNext()) {
+        iter.next();
+        d->setProperty(iter.key(), iter.value());
     }
 }
 
@@ -167,6 +168,10 @@ void KoCharacterStyle::applyStyle(QTextCharFormat &format) const {
         QTextFormat::TextOutline,
         QTextFormat::BackgroundBrush,
         QTextFormat::ForegroundBrush,
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+        QTextFormat::FontLetterSpacing,
+        QTextFormat::FontWordSpacing,
+#endif
         KoCharacterStyle::StrikeOutStyle,
         KoCharacterStyle::StrikeOutType,
         KoCharacterStyle::StrikeOutColor,
@@ -174,6 +179,7 @@ void KoCharacterStyle::applyStyle(QTextCharFormat &format) const {
         KoCharacterStyle::UnderlineType,
         KoCharacterStyle::UnderlineColor,
         KoCharacterStyle::TransformText,
+        KoCharacterStyle::HasHyphenation,
         -1
     };
 
@@ -184,6 +190,23 @@ void KoCharacterStyle::applyStyle(QTextCharFormat &format) const {
             format.setProperty(properties[i], variant);
         i++;
     }
+
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+    QVariant variant = d->stylesPrivate->value(TransformText);
+    if(!variant.isNull()) {
+        switch(static_cast<Transform>(variant.toInt())) {
+        case Capitalize:
+            format.setProperty(TransformText, Capitalize);
+            // fall through
+        case MixedCase:
+            format.setFontCapitalization(QFont::MixedCase);
+            break;
+        case SmallCaps: format.setFontCapitalization(QFont::SmallCaps); break;
+        case AllUppercase: format.setFontCapitalization(QFont::AllUppercase); break;
+        case AllLowercase: format.setFontCapitalization(QFont::AllLowercase); break;
+        }
+    }
+#endif
 }
 
 void KoCharacterStyle::applyStyle(QTextBlock &block) const {
@@ -409,6 +432,34 @@ QColor KoCharacterStyle::underlineColor () const {
     return d->propertyColor(UnderlineColor);
 }
 
+void KoCharacterStyle::setFontLetterSpacing(qreal spacing) {
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+    d->setProperty(QTextCharFormat::FontLetterSpacing, spacing);
+#endif
+}
+
+qreal KoCharacterStyle::fontLetterSpacing() const {
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+    return d->propertyDouble(QTextCharFormat::FontLetterSpacing);
+#else
+    return 0.0;
+#endif
+}
+
+void KoCharacterStyle::setFontWordSpacing(qreal spacing) {
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+    d->setProperty(QTextCharFormat::FontWordSpacing, spacing);
+#endif
+}
+
+qreal KoCharacterStyle::fontWordSpacing() const {
+#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
+    return d->propertyDouble(QTextCharFormat::FontWordSpacing);
+#else
+    return 0.0;
+#endif
+}
+
 
 void KoCharacterStyle::setTransform(KoCharacterStyle::Transform transformtext) {
     d->setProperty(KoCharacterStyle::TransformText, transformtext);
@@ -589,7 +640,13 @@ void KoCharacterStyle::loadOasis(KoTextLoadingContext& context) {
                             va, d->m_relativeTextSize, d->m_offsetFromBaseLine, context );
     }
 #endif
-
+    if( styleStack.hasProperty( KoXmlNS::style, "text-position")) { // OO 3.10.7
+        QString textPosition = styleStack.property( KoXmlNS::style, "text-position");
+        if (textPosition.startsWith("super"))
+            setVerticalAlignment(QTextCharFormat::AlignSuperScript);
+        else if (textPosition.startsWith("sub"))
+            setVerticalAlignment(QTextCharFormat::AlignSubScript);
+    }
     // The fo:font-variant attribute provides the option to display text as small capitalized letters.
     if ( styleStack.hasProperty( KoXmlNS::fo, "font-variant" ) ) {
         if ( styleStack.property( KoXmlNS::fo, "font-variant" ) == "small-caps" )
@@ -599,9 +656,9 @@ void KoCharacterStyle::loadOasis(KoTextLoadingContext& context) {
     else if ( styleStack.hasProperty( KoXmlNS::fo, "text-transform" ) ) {
         QString textTransform = styleStack.property( KoXmlNS::fo, "text-transform" );
         if ( textTransform == "uppercase" )
-            setTransform( Uppercase );
+            setTransform( AllUppercase );
         else if ( textTransform == "lowercase" )
-            setTransform( Lowercase );
+            setTransform( AllLowercase );
         else if ( textTransform == "capitalize" )
             setTransform( Capitalize );
     }
