@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 2000-2005 David Faure <faure@kde.org>
+   Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +31,8 @@
 #include "KoFilterManager.h"
 #include "KoDocumentInfo.h"
 #include "KoOasisStyles.h"
-#include "KoOasisStore.h"
+#include "KoOdfReadStore.h"
+#include "KoOdfWriteStore.h"
 #include "KoXmlNS.h"
 #include "KoOpenPane.h"
 
@@ -38,6 +40,7 @@
 
 #include <kdialog.h>
 #include <kfileitem.h>
+#include <kdebug.h>
 #include <kio/job.h>
 #include <kio/jobuidelegate.h>
 #include <kio/netaccess.h>
@@ -48,6 +51,8 @@
 #include <kxmlguifactory.h>
 #include <KIconLoader>
 #include <kundostack.h>
+#include <kdebug.h>
+#include <kdeprintdialog.h>
 
 #include <QBuffer>
 #include <QDir>
@@ -57,6 +62,8 @@
 #include <QDBusConnection>
 #include <QLayout>
 #include <QApplication>
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
 
 // Define the protocol used here for embedded documents' URL
 // This used to "store" but KUrl didn't like it,
@@ -221,11 +228,12 @@ void KoBrowserExtension::print()
     KoViewWrapperWidget * wrapper = static_cast<KoViewWrapperWidget *>( doc->widget() );
     KoView * view = wrapper->koView();
     // TODO remove code duplication (KoMainWindow), by moving this to KoView
-    KPrinter printer;
+    QPrinter printer;
+    QPrintDialog *printDialog = KdePrint::createPrintDialog(&printer, view->printDialogPages(), view);
     // ### TODO: apply global koffice settings here
-    view->setupPrinter( printer );
-    if ( printer.setup( view ) )
-        view->print( printer );
+    view->setupPrinter( printer, *printDialog );
+    if ( printDialog->exec() )
+        view->print( printer, *printDialog );
 }
 
 KoDocument::KoDocument( QWidget * parentWidget, QObject* parent, bool singleViewMode )
@@ -413,7 +421,8 @@ bool KoDocument::saveFile()
                 backup.setPath( backup.path() + QString::fromLatin1("~") );
                 KFileItem item( entry, url() );
                 Q_ASSERT( item.name() == url().fileName() );
-                KIO::NetAccess::file_copy( url(), backup, item.permissions(), true /*overwrite*/, false /*resume*/, shells().current() );
+		KIO::FileCopyJob *job = KIO::file_copy( url(), backup, item.permissions(),KIO::Overwrite | KIO::HideProgressInfo);
+		job->exec();
             }
         }
     }
@@ -1021,7 +1030,7 @@ bool KoDocument::saveNativeFormat( const QString & file )
         kDebug(30003) <<"Saving to OASIS format";
         // Tell KoStore not to touch the file names
         store->disallowNameExpansion();
-        KoOasisStore oasisStore( store );
+        KoOdfWriteStore oasisStore( store );
         KoXmlWriter* manifestWriter = oasisStore.manifestWriter( mimeType );
 
         if ( !saveOasis( store, manifestWriter ) )
@@ -1075,7 +1084,7 @@ bool KoDocument::saveNativeFormat( const QString & file )
           if ( store->open( "VersionList.xml" ) )
           {
             KoStoreDevice dev( store );
-            KoXmlWriter* xmlWriter = KoDocument::createOasisXmlWriter( &dev,
+            KoXmlWriter* xmlWriter = KoOdfWriteStore::createOasisXmlWriter( &dev,
                 "VL:version-list" );
             for (int i = 0; i < d->m_versionInfo.size(); ++i)
             {
@@ -1408,8 +1417,7 @@ bool KoDocument::openUrl( const KUrl & _url )
         d->lastErrorMessage = i18n( "Malformed URL\n%1",_url.url() ); // ## used anywhere ?
         return false;
     }
-    if ( !closeUrl() )
-        return false;
+    abortLoad();
 
     KUrl url( _url );
     bool autosaveOpened = false;
@@ -1854,7 +1862,6 @@ bool KoDocument::loadNativeFormatFromStoreInternal( KoStore * store )
     {
         store->disallowNameExpansion();
 
-        KoOasisStore oasisStore( store );
         // We could check the 'mimetype' file, but let's skip that and be tolerant.
 
         if ( !loadOasisFromStore( store ) ) {
@@ -1893,7 +1900,7 @@ bool KoDocument::loadNativeFormatFromStoreInternal( KoStore * store )
 
     if ( oasis && store->hasFile( "meta.xml" ) ) {
         KoXmlDocument metaDoc;
-        KoOasisStore oasisStore( store );
+        KoOdfReadStore oasisStore( store );
         if ( oasisStore.loadAndParse( "meta.xml", metaDoc, d->lastErrorMessage ) ) {
             d->m_docInfo->loadOasis( metaDoc );
         }
@@ -1916,7 +1923,7 @@ bool KoDocument::loadNativeFormatFromStoreInternal( KoStore * store )
     if ( oasis && store->hasFile( "VersionList.xml" ) ) {
         KMessageBox::information( 0, i18n("This document contains several versions. Go to File->Versions to open an old version."), QString(), "informVersionsAtLoading" );
         KoXmlDocument versionInfo;
-        KoOasisStore oasisStore( store );
+        KoOdfReadStore oasisStore( store );
         if ( oasisStore.loadAndParse( "VersionList.xml", versionInfo, d->lastErrorMessage ) )
         {
             KoXmlNode list = KoDom::namedItemNS( versionInfo, KoXmlNS::VL, "version-list" );
@@ -1987,35 +1994,11 @@ bool KoDocument::loadFromStore( KoStore* _store, const QString& url )
 
 bool KoDocument::loadOasisFromStore( KoStore* store )
 {
-    KoOasisStyles oasisStyles;
-    KoXmlDocument contentDoc;
-    KoXmlDocument settingsDoc;
-    KoOasisStore oasisStore( store );
-    bool ok = oasisStore.loadAndParse( "content.xml", contentDoc, d->lastErrorMessage );
-    if ( !ok )
+    KoOdfReadStore odfStore( store );
+    if ( ! odfStore.loadAndParse( d->lastErrorMessage ) ) {
         return false;
-
-    KoXmlDocument stylesDoc;
-    (void)oasisStore.loadAndParse( "styles.xml", stylesDoc, d->lastErrorMessage );
-    // Load styles from style.xml
-    oasisStyles.createStyleMap( stylesDoc, true );
-    // Also load styles from content.xml
-    oasisStyles.createStyleMap( contentDoc, false );
-
-    // TODO post 1.4, pass manifestDoc to the apps so that they don't have to do it themselves
-    // (when calling KoDocumentChild::loadOasisDocument)
-    //QDomDocument manifestDoc;
-    //KoOasisStore oasisStore( store );
-    //if ( !oasisStore.loadAndParse( "tar:/META-INF/manifest.xml", manifestDoc, d->lastErrorMessage ) )
-    //    return false;
-
-    if ( store->hasFile( "settings.xml" ) ) {
-        (void)oasisStore.loadAndParse( "settings.xml", settingsDoc, d->lastErrorMessage );
     }
-    if ( !loadOasis( contentDoc, oasisStyles, settingsDoc, store ) )
-        return false;
-
-    return true;
+    return loadOdf( odfStore );
 }
 
 bool KoDocument::addVersion( const QString& comment )
@@ -2047,7 +2030,7 @@ bool KoDocument::addVersion( const QString& comment )
     kDebug(30003) <<"Saving to OASIS format";
     // Tell KoStore not to touch the file names
     store->disallowNameExpansion();
-    KoOasisStore oasisStore( store );
+    KoOdfWriteStore oasisStore( store );
     KoXmlWriter* manifestWriter = oasisStore.manifestWriter( mimeType );
 
     if ( !saveOasis( store, manifestWriter ) )
@@ -2325,45 +2308,6 @@ QDomDocument KoDocument::createDomDocument( const QString& appName, const QStrin
     return doc;
 }
 
-KoXmlWriter* KoDocument::createOasisXmlWriter( QIODevice* dev, const char* rootElementName )
-{
-    KoXmlWriter* writer = new KoXmlWriter( dev );
-    writer->startDocument( rootElementName );
-    writer->startElement( rootElementName );
-
-    if ( qstrcmp( rootElementName, "VL:version-list" ) == 0 ) {
-        writer->addAttribute( "xmlns:VL", KoXmlNS::VL );
-        writer->addAttribute( "xmlns:dc", KoXmlNS::dc );
-        return writer;
-    }
-
-    writer->addAttribute( "xmlns:office", KoXmlNS::office );
-    writer->addAttribute( "xmlns:meta", KoXmlNS::meta );
-
-    if ( qstrcmp( rootElementName, "office:document-meta" ) != 0 ) {
-        writer->addAttribute( "xmlns:config", KoXmlNS::config );
-        writer->addAttribute( "xmlns:text", KoXmlNS::text );
-        writer->addAttribute( "xmlns:table", KoXmlNS::table );
-        writer->addAttribute( "xmlns:draw", KoXmlNS::draw );
-        writer->addAttribute( "xmlns:presentation", KoXmlNS::presentation );
-        writer->addAttribute( "xmlns:dr3d", KoXmlNS::dr3d );
-        writer->addAttribute( "xmlns:chart", KoXmlNS::chart );
-        writer->addAttribute( "xmlns:form", KoXmlNS::form );
-        writer->addAttribute( "xmlns:script", KoXmlNS::script );
-        writer->addAttribute( "xmlns:style", KoXmlNS::style );
-        writer->addAttribute( "xmlns:number", KoXmlNS::number );
-        writer->addAttribute( "xmlns:math", KoXmlNS::math );
-        writer->addAttribute( "xmlns:svg", KoXmlNS::svg );
-        writer->addAttribute( "xmlns:fo", KoXmlNS::fo );
-        writer->addAttribute( "xmlns:koffice", KoXmlNS::koffice );
-    }
-    // missing: office:version="1.0"
-
-    writer->addAttribute( "xmlns:dc", KoXmlNS::dc );
-    writer->addAttribute( "xmlns:xlink", KoXmlNS::xlink );
-    return writer;
-}
-
 QDomDocument KoDocument::saveXML()
 {
     kError(30003) << "KoDocument::saveXML not implemented" << endl;
@@ -2448,7 +2392,7 @@ QByteArray KoDocument::readNativeFormatMimeType( const KComponentData &component
         else {
             QString instname = componentData.isValid() ? componentData.componentName() : KGlobal::mainComponent().componentName();
             if ( instname != "koshell" ) // hack for koshell
-                kWarning(30003) << service->desktopEntryPath() << ": no X-KDE-NativeMimeType entry!";
+                kWarning(30003) << service->entryPath() << ": no X-KDE-NativeMimeType entry!";
         }
     }
 
@@ -2463,22 +2407,6 @@ QStringList KoDocument::readExtraNativeMimeTypes( const KComponentData &componen
     return service->property( "X-KDE-ExtraNativeMimeTypes" ).toStringList();
 }
 
-void KoDocument::setupXmlReader( QXmlSimpleReader& reader, bool namespaceProcessing )
-{
-    if ( namespaceProcessing )
-    {
-        reader.setFeature( "http://xml.org/sax/features/namespaces", true );
-        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", false );
-    }
-    else
-    {
-        reader.setFeature( "http://xml.org/sax/features/namespaces", false );
-        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true );
-    }
-    reader.setFeature( "http://trolltech.com/xml/features/report-whitespace-only-CharData", true );
-}
-
-
 bool KoDocument::isNativeFormat( const QByteArray& mimetype ) const
 {
     if ( mimetype == nativeFormatMimeType() )
@@ -2745,7 +2673,7 @@ void KoDocument::showStartUpWidget( KoMainWindow* parent, bool alwaysShow )
 
     if(!alwaysShow) {
         KConfigGroup cfgGrp( componentData().config(), "TemplateChooserDialog" );
-        QString fullTemplateName = cfgGrp.readPathEntry( "AlwaysUseTemplate" );
+        QString fullTemplateName = cfgGrp.readPathEntry( "AlwaysUseTemplate", QString() );
 
         if( !fullTemplateName.isEmpty() ) {
             openTemplate( fullTemplateName );
