@@ -30,6 +30,7 @@
 #include "KoVersionDialog.h"
 #include "kkbdaccessextensions.h"
 #include "KoDockFactory.h"
+#include "KoDockWidgetTitleBar.h"
 
 #include <krecentfilesaction.h>
 #include <kaboutdata.h>
@@ -50,14 +51,18 @@
 #include <kxmlguifactory.h>
 #include <kfileitem.h>
 #include <ktoolbar.h>
+#include <kdebug.h>
 #include <kactionmenu.h>
 #include <kactioncollection.h>
+#include <kdeprintdialog.h>
 
 //   // qt includes
 #include <QDockWidget>
 #include <QApplication>
 #include <QProgressBar>
 #include <QSplitter>
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
 
 class KoPartManager : public KParts::PartManager
 {
@@ -220,17 +225,17 @@ KoMainWindow::KoMainWindow( const KComponentData &componentData )
     actionCollection()->addAction("file_versions_file", d->m_versionsfile );
     connect( d->m_versionsfile, SIGNAL( triggered(bool) ), this, SLOT( slotVersionsFile() ) );
 
-    d->m_importFile  = new KAction(KIcon("file-import"), i18n("I&mport..."), this);
+    d->m_importFile  = new KAction(KIcon("document-import"), i18n("I&mport..."), this);
     actionCollection()->addAction("file_import_file", d->m_importFile );
     connect( d->m_importFile, SIGNAL( triggered(bool) ), this, SLOT( slotImportFile() ) );
 
-    d->m_exportFile  = new KAction(KIcon("file-export"), i18n("E&xport..."), this);
+    d->m_exportFile  = new KAction(KIcon("document-export"), i18n("E&xport..."), this);
     actionCollection()->addAction("file_export_file", d->m_exportFile );
     connect( d->m_exportFile, SIGNAL( triggered(bool) ), this, SLOT( slotExportFile() ) );
 
     /* The following entry opens the document information dialog.  Since the action is named so it
         intends to show data this entry should not have a trailing ellipses (...).  */
-    d->m_paDocInfo  = new KAction(KIcon("documentinfo-koffice"), i18n("Document Information"), this);
+    d->m_paDocInfo  = new KAction(KIcon("document-properties"), i18n("Document Information"), this);
     actionCollection()->addAction("file_documentinfo", d->m_paDocInfo );
     connect( d->m_paDocInfo, SIGNAL( triggered(bool) ), this, SLOT( slotDocumentInfo() ) );
 
@@ -1242,7 +1247,7 @@ void KoMainWindow::print(bool quick) {
         return;
     }
 
-    KPrinter printer( true /*, QPrinter::HighResolution*/ );
+    QPrinter printer( QPrinter::HighResolution );
     QString title = rootView()->koDocument()->documentInfo()->aboutInfo( "title" );
     QString fileName = rootView()->koDocument()->url().fileName();
 
@@ -1263,15 +1268,18 @@ void KoMainWindow::print(bool quick) {
         title = i18n("%1 unsaved document (%2)",programName,KGlobal::locale()->formatDate(QDate::currentDate(), KLocale::ShortDate));
     }
     printer.setDocName( title );
+#if 0 // XXX
     printer.setDocFileName( fileName );
     printer.setDocDirectory( rootView()->koDocument()->url().directory() );
-
+#endif
     // ### TODO: apply global koffice settings here
 
-    rootView()->setupPrinter( printer );
+    QPrintDialog *printDialog = KdePrint::createPrintDialog(&printer, rootView()->printDialogPages(), this);
 
-    if ( quick ||  printer.setup( this ) )
-        rootView()->print( printer );
+    rootView()->setupPrinter( printer, *printDialog );
+
+    if ( quick ||  printDialog->exec() )
+        rootView()->print( printer, *printDialog );
 }
 
 
@@ -1287,7 +1295,7 @@ void KoMainWindow::slotFilePrintPreview()
         kWarning() << "KoMainWindow::slotFilePrint : No root view!";
         return;
     }
-    KPrinter printer( false );
+    QPrinter printer( QPrinter::HighResolution );
     KTemporaryFile tmpFile;
     tmpFile.setAutoRemove(false);
     // The temp file is deleted by KoPrintPreview
@@ -1295,9 +1303,14 @@ void KoMainWindow::slotFilePrintPreview()
 
     // This line has to be before setupPrinter to let the apps decide what to
     // print and what not (if they want to :)
+#if 0 //XXX_PORT
     printer.setFromTo( printer.minPage(), printer.maxPage() );
     printer.setPreviewOnly( true );
-    rootView()->setupPrinter( printer );
+#endif
+
+    QPrintDialog *printDialog = KdePrint::createPrintDialog(&printer, rootView()->printDialogPages(), this);
+
+    rootView()->setupPrinter( printer, *printDialog );
 
     QString oldFileName = printer.outputFileName();
     printer.setOutputFileName( tmpFile.fileName() );
@@ -1305,16 +1318,19 @@ void KoMainWindow::slotFilePrintPreview()
     printer.setNumCopies( 1 );
     // Disable kdeprint's own preview, we'd get two. This shows that KPrinter needs
     // a "don't use the previous settings" mode. The current way is really too much of a hack.
+#if 0
     QString oldKDEPreview = printer.option( "kde-preview" );
     printer.setOption( "kde-preview", "0" );
-
-    rootView()->print(printer);
+#endif
+    rootView()->print(printer, *printDialog);
     //KoPrintPreview::preview(this, "KoPrintPreviewDialog", tmpFile.fileName());
 
     // Restore previous values
     printer.setOutputFileName( oldFileName );
     printer.setNumCopies( oldNumCopies );
+#if 0
     printer.setOption( "kde-preview", oldKDEPreview );
+#endif
 }
 
 void KoMainWindow::slotConfigureKeys()
@@ -1756,7 +1772,19 @@ QDockWidget* KoMainWindow::createDockWidget( KoDockFactory* factory )
 
     if( !d->m_dockWidgetMap.contains( factory->id() ) ) {
         dockWidget = factory->createDockWidget();
-        Q_ASSERT(dockWidget);
+        
+        // It is quite possible that a dock factory cannot create the dock; don't
+        // do anything in that case.
+        if (!dockWidget) return 0;
+
+        // Check if the dock widget is supposed to be collapsable
+        QVariant isCollapsable = dockWidget->property("KoDockWidgetCollapsable");
+        if (!isCollapsable.isValid() || isCollapsable.toBool()) {
+            if (!dockWidget->titleBarWidget()) {
+                dockWidget->setTitleBarWidget(new KoDockWidgetTitleBar(dockWidget));
+            }
+        }
+
         dockWidget->setObjectName(factory->id());
         dockWidget->setParent( this );
         Qt::DockWidgetArea side = Qt::RightDockWidgetArea;
@@ -1773,11 +1801,12 @@ QDockWidget* KoMainWindow::createDockWidget( KoDockFactory* factory )
             default:;
         }
 
-        if( dockWidget->features() & QDockWidget::DockWidgetClosable ) {
-            d->m_dockWidgetMenu->setVisible( visible ); // This doesn't actually work; not sure why
-            d->m_dockWidgetMenu->addAction( dockWidget->toggleViewAction() );
-        }
         addDockWidget( side, dockWidget );
+        if( dockWidget->features() & QDockWidget::DockWidgetClosable ) {
+            d->m_dockWidgetMenu->addAction( dockWidget->toggleViewAction() );
+            if (!visible)
+                dockWidget->hide();
+        }
         d->m_dockWidgetMap.insert( factory->id(), dockWidget );
     } else {
         dockWidget = d->m_dockWidgetMap[ factory->id() ];
@@ -1796,7 +1825,7 @@ QDockWidget* KoMainWindow::createDockWidget( KoDockFactory* factory )
     return dockWidget;
 }
 
-QList<QDockWidget*> KoMainWindow::dockWidgets() 
+QList<QDockWidget*> KoMainWindow::dockWidgets()
 {
     return d->m_dockWidgetMap.values();
 }
