@@ -1388,6 +1388,8 @@ void KoOasisStyles::saveOasisFillStyle( KoGenStyle &styleFill, KoGenStyles& main
     case Qt::SolidPattern:
         styleFill.addProperty( "draw:fill","solid" );
         styleFill.addProperty( "draw:fill-color", brush.color().name() );
+        if( ! brush.isOpaque() )
+            styleFill.addProperty( "draw:opacity", QString("%1%").arg( brush.color().alphaF() * 100.0 ) );
         break;
     case Qt::Dense1Pattern:
         styleFill.addProperty( "draw:transparency", "94%" );
@@ -1475,6 +1477,96 @@ QString KoOasisStyles::saveOasisHatchStyle( KoGenStyles& mainStyles, const QBrus
     return mainStyles.lookup( hatchStyle, "hatch" );
 }
 
+QMatrix KoOasisStyles::loadTransformation( const QString &transformation )
+{
+    QMatrix matrix;
+
+    // Split string for handling 1 transform statement at a time
+    QStringList subtransforms = transformation.split(')', QString::SkipEmptyParts);
+    QStringList::ConstIterator it = subtransforms.begin();
+    QStringList::ConstIterator end = subtransforms.end();
+    for(; it != end; ++it)
+    {
+        QStringList subtransform = (*it).split('(', QString::SkipEmptyParts);
+
+        subtransform[0] = subtransform[0].trimmed().toLower();
+        subtransform[1] = subtransform[1].simplified();
+        QRegExp reg("[,( ]");
+        QStringList params = subtransform[1].split(reg, QString::SkipEmptyParts);
+
+        if(subtransform[0].startsWith(';') || subtransform[0].startsWith(','))
+            subtransform[0] = subtransform[0].right(subtransform[0].length() - 1);
+
+        if(subtransform[0] == "rotate")
+        {
+            // TODO find out what oo2 really does when rotating, it seems severly broken
+            if(params.count() == 3)
+            {
+                double x = KoUnit::parseValue( params[1] );
+                double y = KoUnit::parseValue( params[2] );
+
+                matrix.translate(x, y);
+                // oo2 rotates by radians
+                matrix.rotate( params[0].toDouble()*180.0/M_PI );
+                matrix.translate(-x, -y);
+            }
+            else
+            {
+                // oo2 rotates by radians
+                matrix.rotate( params[0].toDouble()*180.0/M_PI );
+            }
+        }
+        else if(subtransform[0] == "translate")
+        {
+            if(params.count() == 2)
+            {
+                double x = KoUnit::parseValue( params[0] );
+                double y = KoUnit::parseValue( params[1] );
+                matrix.translate(x, y);
+            }
+            else    // Spec : if only one param given, assume 2nd param to be 0
+                matrix.translate( KoUnit::parseValue( params[0] ) , 0);
+        }
+        else if(subtransform[0] == "scale")
+        {
+            if(params.count() == 2)
+                matrix.scale(params[0].toDouble(), params[1].toDouble());
+            else    // Spec : if only one param given, assume uniform scaling
+                matrix.scale(params[0].toDouble(), params[0].toDouble());
+        }
+        else if(subtransform[0] == "skewx")
+            matrix.shear(tan(params[0].toDouble()), 0.0F);
+        else if(subtransform[0] == "skewy")
+            matrix.shear(tan(params[0].toDouble()), 0.0F);
+        else if(subtransform[0] == "skewy")
+            matrix.shear(0.0F, tan(params[0].toDouble()));
+        else if(subtransform[0] == "matrix")
+        {
+            if(params.count() >= 6)
+                matrix.setMatrix(params[0].toDouble(), params[1].toDouble(), params[2].toDouble(), params[3].toDouble(), KoUnit::parseValue( params[4] ), KoUnit::parseValue( params[5] ) );
+        }
+    }
+
+    return matrix;
+}
+
+QString KoOasisStyles::saveTransformation( const QMatrix &transformation, bool appendTranslateUnit )
+{
+    QString transform;
+    if( appendTranslateUnit )
+        transform = QString( "matrix(%1 %2 %3 %4 %5pt %6pt)" )
+            .arg( transformation.m11() ).arg( transformation.m12() )
+            .arg( transformation.m21() ).arg( transformation.m22() )
+            .arg( transformation.dx() ) .arg( transformation.dy() );
+    else
+        transform = QString( "matrix(%1 %2 %3 %4 %5 %6)" )
+            .arg( transformation.m11() ).arg( transformation.m12() )
+            .arg( transformation.m21() ).arg( transformation.m22() )
+            .arg( transformation.dx() ) .arg( transformation.dy() );
+
+    return transform;
+}
+
 QString KoOasisStyles::saveOasisGradientStyle( KoGenStyles &mainStyles, const QBrush &brush )
 {
     KoGenStyle gradientStyle;
@@ -1507,6 +1599,11 @@ QString KoOasisStyles::saveOasisGradientStyle( KoGenStyles &mainStyles, const QB
     else
         gradientStyle.addAttribute( "svg:spreadMethod", "pad" );
 
+    if( ! brush.matrix().isIdentity() )
+    {
+        gradientStyle.addAttribute( "svg:gradientTransform", saveTransformation( brush.matrix() ) );
+    }
+
     QBuffer buffer;
     buffer.open( QIODevice::WriteOnly );
     KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
@@ -1517,7 +1614,7 @@ QString KoOasisStyles::saveOasisGradientStyle( KoGenStyles &mainStyles, const QB
     {
         elementWriter.startElement( "svg:stop" );
         elementWriter.addAttribute( "svg:offset", QString( "%1" ).arg( stop.first ) );
-        elementWriter.addAttribute( "svg:color", stop.second.name() );
+        elementWriter.addAttribute( "svg:stop-color", stop.second.name() );
         if( stop.second.alphaF() < 1.0 )
             elementWriter.addAttribute( "svg:stop-opacity", QString( "%1" ).arg( stop.second.alphaF() ) );
         elementWriter.endElement();
@@ -1538,6 +1635,7 @@ QBrush KoOasisStyles::loadOasisGradientStyle( const KoStyleStack &styleStack, co
         return QBrush();
 
     QGradient * gradient = 0;
+    QMatrix matrix;
 
     if( e->namespaceURI() == KoXmlNS::draw && e->localName() == "gradient" )
     {
@@ -1624,6 +1722,9 @@ QBrush KoOasisStyles::loadOasisGradientStyle( const KoStyleStack &styleStack, co
         else
             gradient->setSpread( QGradient::PadSpread );
 
+        if( e->hasAttributeNS( KoXmlNS::svg, "gradientTransform" ) )
+            matrix = loadTransformation( e->attributeNS( KoXmlNS::svg, "gradientTransform", QString() ) );
+
         QGradientStops stops;
 
         // load stops
@@ -1633,7 +1734,7 @@ QBrush KoOasisStyles::loadOasisGradientStyle( const KoStyleStack &styleStack, co
             if( colorstop.namespaceURI() == KoXmlNS::svg && colorstop.localName() == "stop" )
             {
                 QGradientStop stop;
-                stop.second = QColor( colorstop.attributeNS( KoXmlNS::svg, "color", QString() ) );
+                stop.second = QColor( colorstop.attributeNS( KoXmlNS::svg, "stop-color", QString() ) );
                 stop.second.setAlphaF( colorstop.attributeNS( KoXmlNS::svg, "stop-opacity", "1.0" ).toDouble() );
                 stop.first = colorstop.attributeNS( KoXmlNS::svg, "offset", "0.0" ).toDouble();
                 stops.append( stop );
@@ -1647,6 +1748,8 @@ QBrush KoOasisStyles::loadOasisGradientStyle( const KoStyleStack &styleStack, co
         return QBrush();
 
     QBrush resultBrush( *gradient );
+    resultBrush.setMatrix( matrix );
+
     delete gradient;
     return resultBrush;
 }
@@ -1659,6 +1762,17 @@ QBrush KoOasisStyles::loadOasisFillStyle( const KoStyleStack &styleStack, const
         tmpBrush.setStyle(static_cast<Qt::BrushStyle>( 1 ) );
         if ( styleStack.hasProperty( KoXmlNS::draw, "fill-color" ) )
             tmpBrush.setColor(styleStack.property( KoXmlNS::draw, "fill-color" ) );
+        if( styleStack.hasProperty( KoXmlNS::draw, "opacity" ) )
+        {
+            QString opacity = styleStack.property( KoXmlNS::draw, "opacity" );
+            if( ! opacity.isEmpty() && opacity.right( 1 ) == "%" )
+            {
+                float percent = opacity.left( opacity.length()-1 ).toFloat();
+                QColor color = tmpBrush.color();
+                color.setAlphaF( percent / 100.0 );
+                tmpBrush.setColor( color );
+            }
+        }
         if ( styleStack.hasProperty( KoXmlNS::draw, "transparency" ) )
         {
             QString transparency = styleStack.property( KoXmlNS::draw, "transparency" );
