@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
+   Copyright (C) 2007 Thomas Zander <zander@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,6 +20,7 @@
 
 // local directory
 #include "KoView.h"
+#include "KoView_p.h"
 #include "KoDockRegistry.h"
 #include "KoDocument.h"
 #include "KoMainWindow.h"
@@ -33,10 +35,14 @@
 #include <kparts/partmanager.h>
 #include <kparts/event.h>
 #include <kstatusbar.h>
+#include <kdebug.h>
+#include <kconfiggroup.h>
 #include <QTimer>
 #include <QtGui/QDockWidget>
 #include <QToolBar>
 #include <QApplication>
+#include <Q3ValueList>
+#include <QPrintDialog>
 
 //static
 QString KoView::newObjectName()
@@ -76,6 +82,9 @@ public:
                           // since this only happens in ~QObject, and views
                           // get deleted by ~KoDocument].
   QTimer *m_scrollTimer;
+  //Temporary until Qt4.4. provides API for add/set/get of pages
+  QList<QWidget*> m_printDialogPages;
+
 
   // Hmm sorry for polluting the private class with such a big inner class.
   // At the beginning it was a little struct :)
@@ -153,7 +162,6 @@ KoView::KoView( KoDocument *document, QWidget *parent )
            this, SLOT( endOperation() ) );
 
 
-  actionCollection()->setAssociatedWidget(this);
   setupGlobalActions();
 
   KStatusBar * sb = statusBar();
@@ -185,6 +193,8 @@ KoView::KoView( KoDocument *document, QWidget *parent )
         KoDockFactory *factory = KoDockRegistry::instance()->value(docker);
         createDockWidget(factory);
     }
+
+  actionCollection()->associateWidget(this);
 }
 
 KoView::~KoView()
@@ -677,16 +687,23 @@ void KoView::setupGlobalActions()
   connect( actionNewView, SIGNAL(triggered(bool)), this, SLOT(newView()) );
 }
 
-void KoView::setupPrinter( KPrinter & )
+void KoView::setupPrinter( QPrinter &, QPrintDialog &printDialog )
 {
+    Q_UNUSED( printDialog );
+
     kDebug(30003) <<"KoView::setupPrinter not implemented by the application!";
 }
 
-void KoView::print( KPrinter & )
+void KoView::print( QPrinter &, QPrintDialog &printDialog )
 {
     kDebug(30003) <<"KoView::print not implemented by the application!";
 }
 
+QList<QWidget*> KoView::printDialogPages()
+{
+    return QList<QWidget*>();
+}
+
 void KoView::newView() {
     Q_ASSERT( ( d!=0L && d->m_doc ) );
 
@@ -792,5 +809,18 @@ QToolBar* KoView::viewBar()
     return d->m_viewBar;
 }
 
-#include "KoView.moc"
+QList<QAction*> KoView::createChangeUnitActions() {
+    QList<QAction*> answer;
+    answer.append(new UnitChangeAction(KoUnit::Millimeter, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Centimeter, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Decimeter, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Inch, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Pica, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Cicero, this, d->m_doc));
+    answer.append(new UnitChangeAction(KoUnit::Point, this, d->m_doc));
 
+    return answer;
+}
+
+#include "KoView_p.moc"
+#include "KoView.moc"
