@@ -35,13 +35,11 @@
 #include <KoID.h>
 #include <pigment_export.h>
 
-
-
-
 class KoCompositeOp;
 class KoColorProfile;
 class KoColorSpaceRegistry;
 class KoColorTransformation;
+class KoColorConversionTransformationFactory;
 class KisFilter;
 class QBitArray;
 
@@ -127,7 +125,7 @@ public:
  * Some subclasses implement only some parts and are named Traits
  *
  */
-class PIGMENT_EXPORT KoColorSpace {
+class PIGMENTCMS_EXPORT KoColorSpace {
 
 protected:
     /// Only for use by classes that serve as baseclass for real color spaces
@@ -208,7 +206,10 @@ public:
 	 * to floating point range 0 to 1.
 	 */
 	virtual void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels) const = 0;
-	virtual void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) = 0;
+  /**
+   * Write in the pixel the value from the normalized vector.
+   */
+	virtual void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) const = 0;
 
     /**
      * Convert the value of the channel at the specified position into
@@ -243,7 +244,21 @@ public:
      */
     virtual QString name() const;
 
-    virtual bool profileIsCompatible(KoColorProfile* profile) const =0;
+    /**
+     * @return a string that identify the color model (for instance "RGB" or "CMYK" ...)
+     * @see KoColorModelStandardIds.h
+     */
+    virtual KoID colorModelId() const = 0;
+    /**
+     * @return a string that identify the bit depth (for instance "U8" or "F16" ...)
+     * @see KoColorModelStandardIds.h
+     */
+    virtual KoID colorDepthId() const = 0;
+
+    /**
+     * @return true if the profile given in argument can be used by this color space
+     */
+    virtual bool profileIsCompatible(const KoColorProfile* profile) const =0;
 
     /**
      * If false, images in this colorspace will degrade considerably by
@@ -287,7 +302,7 @@ public:
     /**
      * Return the profile of this color space. This may be 0
      */
-    virtual KoColorProfile * profile() const = 0;
+    virtual const KoColorProfile * profile() const = 0;
 
 //================= Conversion functions ==================================//
 
@@ -301,7 +316,7 @@ public:
      * @param dst a pointer to a pixel
      * @param profile the optional profile that describes the color values of QColor
      */
-    virtual void fromQColor(const QColor& color, quint8 *dst, KoColorProfile * profile = 0) const = 0;
+    virtual void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * profile = 0) const = 0;
 
     /**
      * The fromQColor methods take a given color defined as an RGB QColor
@@ -313,7 +328,7 @@ public:
      * @param dst a pointer to a pixel
      * @param profile the optional profile that describes the color values of QColor
      */
-    virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, KoColorProfile * profile = 0) const = 0;
+    virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, const KoColorProfile * profile = 0) const = 0;
 
     /**
      * The toQColor methods take a byte array that is at least pixelSize() long
@@ -324,7 +339,7 @@ public:
      * @param c the QColor that will be filled with the color at src
      * @param profile the optional profile that describes the color in c, for instance the monitor profile
      */
-    virtual void toQColor(const quint8 *src, QColor *c, KoColorProfile * profile = 0) const = 0;
+    virtual void toQColor(const quint8 *src, QColor *c, const KoColorProfile * profile = 0) const = 0;
 
     /**
      * The toQColor methods take a byte array that is at least pixelSize() long
@@ -336,7 +351,7 @@ public:
      * @param opacity a pointer to a byte that will be filled with the opacity a src
      * @param profile the optional profile that describes the color in c, for instance the monitor profile
      */
-    virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, KoColorProfile * profile = 0) const = 0;
+    virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, const KoColorProfile * profile = 0) const = 0;
 
     /**
      * Convert the pixels in data to (8-bit BGRA) QImage using the specified profiles.
@@ -353,7 +368,7 @@ public:
      * @param exposure The exposure setting for rendering a preview of a high dynamic range image.
      */
     virtual QImage convertToQImage(const quint8 *data, qint32 width, qint32 height,
-                                   KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual,
+                                   const KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual,
                                    float exposure = 0.0f) const = 0;
 
     /**
@@ -369,7 +384,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of source pixels
      */
-    virtual void toLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const = 0;
+    virtual void toLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
 
     /**
      * Convert the specified data from Lab (D50). to this colorspace. All colorspaces are
@@ -379,7 +394,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of pixels in the array
      */
-    virtual void fromLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const = 0;
+    virtual void fromLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
 
     /**
      * Convert the specified data to sRGB 16 bits. All colorspaces are guaranteed to support this
@@ -388,7 +403,7 @@ public:
      * @param dst the destination data
      * @param nPixels the number of source pixels
      */
-    virtual void toRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const =0;
+    virtual void toRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
 
     /**
      * Convert the specified data from sRGB 16 bits. to this colorspace. All colorspaces are
@@ -398,13 +413,22 @@ public:
      * @param dst the destination data
      * @param nPixels the number of pixels in the array
      */
-    virtual void fromRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const =0;
+    virtual void fromRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const;
 
+    /**
+     * Create a color conversion transformation.
+     */
+    virtual KoColorConversionTransformation* createColorConverter(const KoColorSpace * dstColorSpace, KoColorConversionTransformation::Intent renderingIntent = KoColorConversionTransformation::IntentPerceptual) const;
+    
     /**
      * Convert a byte array of srcLen pixels *src to the specified color space
      * and put the converted bytes into the prepared byte array *dst.
      *
      * Returns false if the conversion failed, true if it succeeded
+     * 
+     * This function is not thread-safe. If you want to apply multiple conversion
+     * in different threads at the same time, you need to create one color converter
+     * per-thread using createColorConverter.
      */
     virtual bool convertPixelsTo(const quint8 * src,
                                  quint8 * dst, const KoColorSpace * dstColorSpace,
@@ -540,7 +564,7 @@ public:
      */
     virtual void bitBlt(quint8 *dst,
 			qint32 dststride,
-			KoColorSpace * srcSpace,
+			const KoColorSpace * srcSpace,
 			const quint8 *src,
 			qint32 srcRowStride,
 			const quint8 *srcAlphaMask,
@@ -555,7 +579,7 @@ public:
      */
     virtual void bitBlt(quint8 *dst,
 			qint32 dststride,
-			KoColorSpace * srcSpace,
+			const KoColorSpace * srcSpace,
 			const quint8 *src,
 			qint32 srcRowStride,
 			const quint8 *srcAlphaMask,
@@ -570,7 +594,7 @@ public:
      */
     virtual void bitBlt(quint8 *dst,
 			qint32 dststride,
-			KoColorSpace * srcSpace,
+			const KoColorSpace * srcSpace,
 			const quint8 *src,
 			qint32 srcRowStride,
 			const quint8 *srcAlphaMask,
@@ -586,7 +610,7 @@ public:
      */
     virtual void bitBlt(quint8 *dst,
 			qint32 dststride,
-			KoColorSpace * srcSpace,
+			const KoColorSpace * srcSpace,
 			const quint8 *src,
 			qint32 srcRowStride,
 			const quint8 *srcAlphaMask,
@@ -605,12 +629,18 @@ public:
      */
     virtual QList<KisFilter*> createBackgroundFilters() const
         { return QList<KisFilter*>(); }
+    
+    KoColorTransformation* createColorTransformation( QString id, QHash<QString, QVariant> parameters) const;
 protected:
     /**
      * Use this function in the constructor of your colorspace to add the information about a channel.
      * @param ci a pointer to the information about a channel
      */
     virtual void addChannel(KoChannelInfo * ci);
+    const KoColorConversionTransformation* toLabA16Converter() const;
+    const KoColorConversionTransformation* fromLabA16Converter() const;
+    const KoColorConversionTransformation* toRgbA16Converter() const;
+    const KoColorConversionTransformation* fromRgbA16Converter() const;
 private:
 
     /**
@@ -623,6 +653,9 @@ private:
     Private * const d;
 };
 
+/**
+ * This class is used to create color spaces.
+ */
 class KoColorSpaceFactory {
 public:
     virtual ~KoColorSpaceFactory() {}
@@ -636,19 +669,71 @@ public:
      */
     virtual QString name() const = 0;
 
-
+    /**
+     * @return true if the color space should be shown in an User Interface, or false
+     *         other wise.
+     */
+    virtual bool userVisible() const =0;
+    /**
+     * @return a string that identify the color model (for instance "RGB" or "CMYK" ...)
+     * @see KoColorModelStandardIds.h
+     */
     virtual KoID colorModelId() const = 0;
+    /**
+     * @return a string that identify the bit depth (for instance "U8" or "F16" ...)
+     * @see KoColorModelStandardIds.h
+     */
     virtual KoID colorDepthId() const = 0;
 
-    virtual bool profileIsCompatible(KoColorProfile* profile) const =0;
-    virtual KoColorSpace *createColorSpace(KoColorSpaceRegistry * parent, KoColorProfile *) = 0;
+    /**
+     * @param profile a pointer to a color profile
+     * @return true if the color profile can be used by a color space created by
+     * this factory
+     */
+    virtual bool profileIsCompatible(const KoColorProfile* profile) const =0;
+    /**
+     * creates a color space using the given profile.
+     */
+    virtual KoColorSpace *createColorSpace(KoColorSpaceRegistry * parent, KoColorProfile *) const = 0;
 
+    /**
+     * @return true if the color space follows ICC specification
+     */
+    virtual bool isIcc() const = 0;
+    /**
+     * @return true if the color space supports High-Dynamic Range.
+     */
+    virtual bool isHdr() const = 0;
+    /**
+     * @return the reference depth, that is for a color space where all channels have the same
+     * depth, this is the depth of one channel, for a color space with different bit depth for
+     * each channel, it's usually the higest bit depth. This value is used by the Color
+     * Conversion System to check if a lost of bit depth during a color conversion is
+     * acceptable, for instance when converting from RGB32bit to XYZ16bit, it's acceptable to go
+     * throught a conversion to RGB16bit, while it's not the case for RGB32bit to XYZ32bit.
+     */
+    virtual int referenceDepth() const = 0;
+    /**
+     * @return the list of color conversion provided by this colorspace, the factories
+     * constructed by this functions are owned by the caller of the function
+     */
+    virtual QList<KoColorConversionTransformationFactory*> colorConversionLinks() const = 0;
+    
+    /**
+     * This function will create a 
+     * @return a factory to create color conversion objects between two icc color spaces, or null,
+     * if one of the color space is not ICC, or if the ICC engine can't handle the conversion.
+     */
+    virtual KoColorConversionTransformationFactory* createICCColorConversionTransformationFactory(QString _colorModelId, QString _colorDepthId) const = 0;
+    /**
+     *  @return 
+     */
     /**
      * Returns the default icc profile for use with this colorspace. This may be ""
      *
-     & @return the default icc profile name
-    */
-    virtual QString defaultProfile() = 0;
+     * @return the default icc profile name
+     */
+    virtual QString defaultProfile() const = 0;
 
 };
 
