@@ -35,9 +35,10 @@
 
 #include "KoPluginLoader.h"
 #include "KoColorSpace.h"
+#include "KoColorConversionSystem.h"
 #include "KoBasicHistogramProducers.h"
 
-#include "colorprofiles/KoLcmsColorProfile.h"
+#include "colorprofiles/KoLcmsColorProfileContainer.h"
 #include "colorspaces/KoAlphaColorSpace.h"
 #include "colorspaces/KoLabColorSpace.h"
 #include "colorspaces/KoRgbU16ColorSpace.h"
@@ -45,10 +46,11 @@
 
 struct KoColorSpaceRegistry::Private {
     QMap<QString, KoColorProfile * > profileMap;
-    QMap<QString, KoColorSpace * > csMap;
+    QMap<QString, const KoColorSpace * > csMap;
     typedef QList<KisPaintDeviceAction *> PaintActionList;
     QMap<QString, PaintActionList> paintDevActionMap;
-    KoColorSpace *alphaCs;
+    const KoColorSpace *alphaCs;
+    KoColorConversionSystem *colorConversionSystem;
     static KoColorSpaceRegistry *singleton;
 };
 
@@ -67,31 +69,15 @@ KoColorSpaceRegistry* KoColorSpaceRegistry::instance()
 
 void KoColorSpaceRegistry::init()
 {
+    d->colorConversionSystem = new KoColorConversionSystem;
     // prepare a list of the profiles
-    KGlobal::mainComponent().dirs()->addResourceType("kis_profiles",
-                                                     "data", "krita/profiles/");
+    KGlobal::mainComponent().dirs()->addResourceType("icc_profiles", 0, "share/color/icc/");
 
     QStringList profileFilenames;
-    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("kis_profiles", "*.icm");
-    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("kis_profiles", "*.ICM");
-    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("kis_profiles", "*.ICC");
-    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("kis_profiles", "*.icc");
-
-    QDir dir("/usr/share/color/icc/", "*.icc;*.ICC;*.icm;*.ICM");
-
-    QStringList filenames = dir.entryList();
-
-    for (QStringList::iterator it = filenames.begin(); it != filenames.end(); ++it) {
-        profileFilenames += dir.absoluteFilePath(*it);
-    }
-
-    dir.setPath(QDir::homePath() + "/.color/icc/");
-    filenames = dir.entryList();
-
-    for (QStringList::iterator it = filenames.begin(); it != filenames.end(); ++it) {
-        profileFilenames += dir.absoluteFilePath(*it);
-    }
-
+    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("icc_profiles", "*.icm",  KStandardDirs::Recursive);
+    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("icc_profiles", "*.ICM",  KStandardDirs::Recursive);
+    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("icc_profiles", "*.ICC",  KStandardDirs::Recursive);
+    profileFilenames += KGlobal::mainComponent().dirs()->findAllResources("icc_profiles", "*.icc",  KStandardDirs::Recursive);
     // Set lcms to return NUll/false etc from failing calls, rather than aborting the app.
     cmsErrorAction(LCMS_ERROR_SHOW);
 
@@ -99,23 +85,26 @@ void KoColorSpaceRegistry::init()
     if (!profileFilenames.empty()) {
         KoColorProfile * profile = 0;
         for ( QStringList::Iterator it = profileFilenames.begin(); it != profileFilenames.end(); ++it ) {
-            profile = new KoLcmsColorProfile(*it);
+            profile = new KoIccColorProfile(*it);
             Q_CHECK_PTR(profile);
 
             profile->load();
             if (profile->valid()) {
+                kDebug(31000) << "Valid profile : " << profile->name();
                 d->profileMap[profile->name()] = profile;
+            } else {
+                kDebug(31000) << "Invalid profile : " << profile->name();
             }
         }
     }
 
-    KoColorProfile *labProfile = new KoLcmsColorProfile(cmsCreateLabProfile(NULL));
+    KoColorProfile *labProfile = KoLcmsColorProfileContainer::createFromLcmsProfile(cmsCreateLabProfile(NULL));
     addProfile(labProfile);
     add(new KoLabColorSpaceFactory());
     KoHistogramProducerFactoryRegistry::instance()->add(
                 new KoBasicHistogramProducerFactory<KoBasicU16HistogramProducer>
                 (KoID("LABAHISTO", i18n("L*a*b* Histogram")), lab16()));
-    KoColorProfile *rgbProfile = new KoLcmsColorProfile(cmsCreate_sRGBProfile());
+    KoColorProfile *rgbProfile = KoLcmsColorProfileContainer::createFromLcmsProfile(cmsCreate_sRGBProfile());
     addProfile(rgbProfile);
     add(new KoRgbU16ColorSpaceFactory());
 
@@ -131,7 +120,8 @@ void KoColorSpaceRegistry::init()
     LPGAMMATABLE Gamma = cmsBuildGamma(256, 2.2);
     cmsHPROFILE hProfile = cmsCreateGrayProfile(cmsD50_xyY(), Gamma);
     cmsFreeGamma(Gamma);
-    KoColorProfile *defProfile = new KoLcmsColorProfile(hProfile);
+    KoColorProfile *defProfile = KoLcmsColorProfileContainer::createFromLcmsProfile(hProfile);
+    kDebug(31000) << "Gray " << defProfile->name();
     addProfile(defProfile);
 
     // Create the built-in colorspaces
@@ -141,18 +131,39 @@ void KoColorSpaceRegistry::init()
     config.whiteList = "ColorSpacePlugins";
     config.blacklist = "ColorSpacePluginsDisabled";
     config.group = "koffice";
-    KoPluginLoader::instance()->load("KOffice/ColorSpace","[X-Pigment-Version] == 1", config);
+    KoPluginLoader::instance()->load("KOffice/ColorSpace","[X-Pigment-MinVersion] <= 0", config);
+
+    KoPluginLoader::PluginsConfig configExtensions;
+    configExtensions.whiteList = "ColorSpaceExtensionsPlugins";
+    configExtensions.blacklist = "ColorSpaceExtensionsPluginsDisabled";
+    configExtensions.group = "koffice";
+    KoPluginLoader::instance()->load("KOffice/ColorSpaceExtension","[X-Pigment-MinVersion] <= 0", configExtensions);
+
 }
 
 KoColorSpaceRegistry::KoColorSpaceRegistry() : d(new Private())
 {
+    d->colorConversionSystem = 0;
 }
 
 KoColorSpaceRegistry::~KoColorSpaceRegistry()
 {
+    delete d->colorConversionSystem;
     delete d;
 }
 
+void KoColorSpaceRegistry::add(KoColorSpaceFactory* item)
+{
+    KoGenericRegistry<KoColorSpaceFactory *>::add(item);
+    d->colorConversionSystem->insertColorSpace(item);
+}
+
+void KoColorSpaceRegistry::add(const QString &id, KoColorSpaceFactory* item)
+{
+    KoGenericRegistry<KoColorSpaceFactory *>::add(id, item);
+    d->colorConversionSystem->insertColorSpace(item);
+}
+
 KoColorProfile *  KoColorSpaceRegistry::profileByName(const QString & name) const
 {
     if (d->profileMap.find(name) == d->profileMap.end()) {
@@ -190,17 +201,17 @@ void KoColorSpaceRegistry::addProfile(KoColorProfile *p)
       }
 }
 
-void KoColorSpaceRegistry::addPaintDeviceAction(KoColorSpace* cs,
+void KoColorSpaceRegistry::addPaintDeviceAction(const KoColorSpace* cs,
         KisPaintDeviceAction* action) {
     d->paintDevActionMap[cs->id()].append(action);
 }
 
 QList<KisPaintDeviceAction *>
-KoColorSpaceRegistry::paintDeviceActionsFor(KoColorSpace* cs) {
+KoColorSpaceRegistry::paintDeviceActionsFor(const KoColorSpace* cs) {
     return d->paintDevActionMap[cs->id()];
 }
 
-KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const QString &pName)
+const KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const QString &pName)
 {
     QString profileName = pName;
 
@@ -220,17 +231,17 @@ KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const QStri
         KoColorSpaceFactory *csf = value(csID);
         if(!csf)
         {
-            kDebug() <<"Unknown color space type :" << csf;
+            kDebug(31000) <<"Unknown color space type :" << csf;
             return 0;
         }
 
         KoColorProfile *p = profileByName(profileName);
         if(!p && !profileName.isEmpty())
         {
-            kDebug() <<"Profile not found :" << profileName;
+            kDebug(31000) <<"Profile not found :" << profileName;
             return 0;
         }
-        KoColorSpace *cs = csf->createColorSpace(this, p);
+        const KoColorSpace *cs = csf->createColorSpace(this, p);
         if(!cs)
             return 0;
 
@@ -244,11 +255,11 @@ KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const QStri
 }
 
 
-KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const KoColorProfile *profile)
+const KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const KoColorProfile *profile)
 {
     if( profile )
     {
-        KoColorSpace *cs = colorSpace( csID, profile->name());
+        const KoColorSpace *cs = colorSpace( csID, profile->name());
 
         if(!cs)
         {
@@ -256,7 +267,7 @@ KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const KoCol
             KoColorSpaceFactory *csf = value(csID);
             if(!csf)
             {
-                kDebug() <<"Unknown color space type :" << csf;
+                kDebug(31000) <<"Unknown color space type :" << csf;
                 return 0;
             }
 
@@ -274,48 +285,49 @@ KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const KoCol
     }
 }
 
-KoColorSpace * KoColorSpaceRegistry::alpha8()
+const KoColorSpace * KoColorSpaceRegistry::alpha8()
 {
    return d->alphaCs;
 }
 
-KoColorSpace * KoColorSpaceRegistry::rgb8(const QString &profileName)
+const KoColorSpace * KoColorSpaceRegistry::rgb8(const QString &profileName)
 {
     return colorSpace(KoRgbU8ColorSpace::colorSpaceId(), profileName);
 }
 
-KoColorSpace * KoColorSpaceRegistry::rgb8(KoColorProfile * profile)
+const KoColorSpace * KoColorSpaceRegistry::rgb8(const KoColorProfile * profile)
 {
     return colorSpace(KoRgbU8ColorSpace::colorSpaceId(), profile);
 }
 
-KoColorSpace * KoColorSpaceRegistry::rgb16(const QString &profileName)
+const KoColorSpace * KoColorSpaceRegistry::rgb16(const QString &profileName)
 {
     return colorSpace(KoRgbU16ColorSpace::colorSpaceId(), profileName);
 }
 
-KoColorSpace * KoColorSpaceRegistry::rgb16(KoColorProfile * profile)
+const KoColorSpace * KoColorSpaceRegistry::rgb16(const KoColorProfile * profile)
 {
     return colorSpace(KoRgbU16ColorSpace::colorSpaceId(), profile);
 }
 
-KoColorSpace * KoColorSpaceRegistry::lab16(const QString &profileName)
+const KoColorSpace * KoColorSpaceRegistry::lab16(const QString &profileName)
 {
     return colorSpace(KoLabColorSpace::colorSpaceId(), profileName);
 }
 
-KoColorSpace * KoColorSpaceRegistry::lab16(KoColorProfile * profile)
+const KoColorSpace * KoColorSpaceRegistry::lab16(const KoColorProfile * profile)
 {
     return colorSpace(KoLabColorSpace::colorSpaceId(), profile);
 }
 
-QList<KoID> KoColorSpaceRegistry::colorModelsList() const
+QList<KoID> KoColorSpaceRegistry::colorModelsList(ColorSpaceListVisibility option ) const
 {
     QList<KoID> ids;
     QList<KoColorSpaceFactory*> factories = values();
     foreach(KoColorSpaceFactory* factory, factories)
     {
-        if(!ids.contains(factory->colorModelId()))
+        if(not ids.contains(factory->colorModelId())
+           and ( option == AllColorSpaces or factory->userVisible() ) )
         {
             ids << factory->colorModelId();
         }
@@ -323,13 +335,15 @@ QList<KoID> KoColorSpaceRegistry::colorModelsList() const
     return ids;
 }
 
-QList<KoID> KoColorSpaceRegistry::colorDepthList(const KoID& colorModelId) const
+QList<KoID> KoColorSpaceRegistry::colorDepthList(const KoID& colorModelId, ColorSpaceListVisibility option ) const
 {
     QList<KoID> ids;
     QList<KoColorSpaceFactory*> factories = values();
     foreach(KoColorSpaceFactory* factory, factories)
     {
-        if(!ids.contains(factory->colorDepthId()) && factory->colorModelId() == colorModelId )
+        if(not ids.contains(factory->colorDepthId())
+           and factory->colorModelId() == colorModelId
+           and ( option == AllColorSpaces or factory->userVisible() ))
         {
             ids << factory->colorDepthId();
         }
@@ -337,12 +351,12 @@ QList<KoID> KoColorSpaceRegistry::colorDepthList(const KoID& colorModelId) const
     return ids;
 }
 
-QString KoColorSpaceRegistry::colorSpaceId(const KoID& colorModelId, const KoID& colorDepthId)
+QString KoColorSpaceRegistry::colorSpaceId(QString colorModelId, QString colorDepthId)
 {
     QList<KoColorSpaceFactory*> factories = values();
     foreach(KoColorSpaceFactory* factory, factories)
     {
-        if(factory->colorModelId() == colorModelId && factory->colorDepthId() == colorDepthId )
+        if(factory->colorModelId().id() == colorModelId and factory->colorDepthId().id() == colorDepthId )
         {
             return factory->id();
         }
@@ -350,4 +364,15 @@ QString KoColorSpaceRegistry::colorSpaceId(const KoID& colorModelId, const KoID&
     return "";
 }
 
+
+QString KoColorSpaceRegistry::colorSpaceId(const KoID& colorModelId, const KoID& colorDepthId)
+{
+    return colorSpaceId( colorModelId.id(), colorDepthId.id());
+}
+
+const KoColorConversionSystem* KoColorSpaceRegistry::colorConversionSystem() const
+{
+    return d->colorConversionSystem;
+}
+
 #include "KoColorSpaceRegistry.moc"
