@@ -33,10 +33,11 @@ class KisPaintDeviceAction;
 class KoColorSpace;
 class KoColorSpaceFactory;
 class KoColorProfile;
+class KoColorConversionSystem;
+
+// XXX: USE STATIC DELETER! USE STATIC DELETER!
 
 /**
- *
- * XXX: USE STATIC DELETER! USE STATIC DELETER!
  *
  * The registry for colorspaces and profiles.
  * This class contains:
@@ -44,11 +45,15 @@ class KoColorProfile;
  *      - a registry of singleton colorspace factories.
  *      - a registry of icc profiles
  */
-class PIGMENT_EXPORT KoColorSpaceRegistry : public QObject,  public KoGenericRegistry<KoColorSpaceFactory *> {
+class PIGMENTCMS_EXPORT KoColorSpaceRegistry : public QObject,  public KoGenericRegistry<KoColorSpaceFactory *> {
 
 
     Q_OBJECT
-
+public:
+    enum ColorSpaceListVisibility {
+        OnlyUserVisible = 1, ///< Only user visible color space
+        AllColorSpaces = 4 ///< All color space even those not visible to the user
+    };
 public:
 
     /**
@@ -60,6 +65,18 @@ public:
     virtual ~KoColorSpaceRegistry();
 
 public:
+   /**
+     * add a color space to the registry
+     * @param item the color space factory to add
+     */
+    void add(KoColorSpaceFactory* item);
+
+    /**
+     * add a color space to the registry
+     * @param id the id of the color space
+     * @param item the color space factory to add
+     */
+    void add(const QString &id, KoColorSpaceFactory* item);
 
     /**
      * register the profile with the color space registry
@@ -115,7 +132,7 @@ public:
      * @param profileName the name of the KoColorProfile to be combined with the colorspace
      * @return the wanted colorspace, or 0 when the cs and profile can not be combined.
      */
-    KoColorSpace *  colorSpace(const KoID &csID, const QString & profileName) {
+    const KoColorSpace *  colorSpace(const KoID &csID, const QString & profileName) {
         return colorSpace(csID.id(), profileName);
     }
 
@@ -125,14 +142,14 @@ public:
      * @param profile the profile be combined with the colorspace
      * @return the wanted colorspace, or 0 when the cs and profile can not be combined.
      */
-    KoColorSpace * colorSpace(const QString &colorSpaceId, const KoColorProfile *profile);
+    const KoColorSpace * colorSpace(const QString &colorSpaceId, const KoColorProfile *profile);
 
     /**
      * Return a colorspace that works with the parameter profile.
      * @param profileName the name of the KoColorProfile to be combined with the colorspace
      * @return the wanted colorspace, or 0 when the cs and profile can not be combined.
      */
-    KoColorSpace * colorSpace(const QString &colorSpaceId, const QString &profileName);
+    const KoColorSpace * colorSpace(const QString &colorSpaceId, const QString &profileName);
 
     /**
      * Return the id of the colorspace that have the defined colorModelId with colorDepthId.
@@ -140,12 +157,20 @@ public:
      * @param colorDepthId id of the color depth
      * @return the id of the wanted colorspace, or "" if no colorspace correspond to those ids
      */
+    QString colorSpaceId(QString colorModelId, QString colorDepthId);
+    /**
+     * It's a convenient function that behave like the above.
+     * Return the id of the colorspace that have the defined colorModelId with colorDepthId.
+     * @param colorModelId id of the color model
+     * @param colorDepthId id of the color depth
+     * @return the id of the wanted colorspace, or "" if no colorspace correspond to those ids
+     */
     QString colorSpaceId(const KoID& colorModelId, const KoID& colorDepthId);
     
     /**
      * Convenience method to get the often used alpha colorspace
      */
-    KoColorSpace * alpha8();
+    const KoColorSpace * alpha8();
 
     /**
      * Convenience method to get an RGB 8bit colorspace. If a profile is not specified,
@@ -153,14 +178,14 @@ public:
      * @param profileName the name of an RGB color profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * rgb8(const QString &profileName = QString());
+    const KoColorSpace * rgb8(const QString &profileName = QString());
     
     /**
      * Convenience method to get an RGB 8bit colorspace with the given profile.
      * @param profile an RGB profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * rgb8(KoColorProfile * profile);
+    const KoColorSpace * rgb8(const KoColorProfile * profile);
     
     /**
      * Convenience method to get an RGB 16bit colorspace. If a profile is not specified,
@@ -168,14 +193,14 @@ public:
      * @param profileName the name of an RGB color profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * rgb16(const QString &profileName = QString());
+    const KoColorSpace * rgb16(const QString &profileName = QString());
 
     /**
      * Convenience method to get an RGB 16bit colorspace with the given profile.
      * @param profile an RGB profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * rgb16(KoColorProfile * profile);
+    const KoColorSpace * rgb16(const KoColorProfile * profile);
 
     /**
      * Convenience method to get an Lab 16bit colorspace. If a profile is not specified,
@@ -183,33 +208,39 @@ public:
      * @param profileName the name of an Lab color profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * lab16(const QString &profileName = QString());
+    const KoColorSpace * lab16(const QString &profileName = QString());
 
     /**
      * Convenience method to get an Lab 16bit colorspace with the given profile.
      * @param profile an Lab profile
      * @return the wanted colorspace, or 0 if the color space and profile can not be combined.
      */
-    KoColorSpace * lab16(KoColorProfile * profile);
+    const KoColorSpace * lab16(const KoColorProfile * profile);
 
     /**
      * add a KisConstructPaintDeviceAction to the registry for a colorspace
      */
-    void addPaintDeviceAction(KoColorSpace* colorSpace, KisPaintDeviceAction* action);
+    void addPaintDeviceAction(const KoColorSpace* colorSpace, KisPaintDeviceAction* action);
 
     /**
      * Get a list of KisConstructPaintDeviceAction for a colorspace
      */
-    QList<KisPaintDeviceAction *> paintDeviceActionsFor(KoColorSpace* colorSpace);
+    QList<KisPaintDeviceAction *> paintDeviceActionsFor(const KoColorSpace* colorSpace);
 
     /**
      * @return the list of available color models
      */
-    QList<KoID> colorModelsList() const;
+    QList<KoID> colorModelsList(ColorSpaceListVisibility option ) const;
     /**
      * @return the list of available color models for the given colorModelId
      */
-    QList<KoID> colorDepthList(const KoID& colorModelId) const;
+    QList<KoID> colorDepthList(const KoID& colorModelId, ColorSpaceListVisibility option ) const;
+    
+    /**
+     * @return the color conversion system use by the registry and the color
+     * spaces to create color conversion transformation
+     */
+    const KoColorConversionSystem* colorConversionSystem() const;
     
 private:
     KoColorSpaceRegistry();
@@ -223,4 +254,3 @@ private:
 };
 
 #endif // KOCOLORSPACEFACTORYREGISTRY_H
-
