@@ -66,16 +66,41 @@ const QString COMPOSITE_COPY_OPACITY = "copy_opacity";
 /**
  * Base for colorspace-specific blending modes.
  */
-class PIGMENT_EXPORT KoCompositeOp {
+class PIGMENTCMS_EXPORT KoCompositeOp {
 public:
 
-    KoCompositeOp(KoColorSpace * cs, const QString& id, const QString& description, const bool userVisible = true);
-    virtual ~KoCompositeOp() {}
+    /**
+     * @param cs a pointer to the color space that can be used with this composite op
+     * @param id the identifiant for this composite op (not user visible)
+     * @param description an user visible string describing this composite operation
+     * @param category the name of the category where to put that composite op when displayed
+     * @param userVisible define wether or not that composite op should be visible in an user
+     *                    interface
+     */
+    KoCompositeOp(const KoColorSpace * cs, const QString& id, const QString& description, QString category = "", const bool userVisible = true);
+    virtual ~KoCompositeOp();
 
-    QString id() const { return m_id; }
-    QString description() const { return m_description; }
-    KoColorSpace * colorSpace() const { return m_colorSpace; }
-    bool userVisible() const { return m_userVisible; }
+    /**
+     * @return the identifiant of this composite op
+     */
+    QString id() const;
+    /**
+     * @return the user visible string for this composite op
+     */
+    QString description() const;
+    /**
+     * @return the color space that can use and own this composite op
+     */
+    const KoColorSpace * colorSpace() const;
+    /**
+     * @return wether this composite op should be visible in the user interface
+     */
+    bool userVisible() const;
+    /**
+     * @return the category associated with the composite op
+     */
+    QString category() const;
+    
     /**
       @param dstRowStart pointer to the start of the byte array we will composite the source on
       @param dstRowStride length of the rows of the block of destination pixels in bytes
@@ -111,15 +136,10 @@ public:
 			   qint32 rows, qint32 numColumns,
 			   quint8 opacity,
 			   const QBitArray & channelFlags) const = 0;
-
-protected:
-    KoCompositeOp();
-
-    KoColorSpace * m_colorSpace;
-    QString m_id;
-    QString m_description;
-    bool m_userVisible;
-    QBitArray m_defaultChannelFlags;
+    private:
+        KoCompositeOp();
+        struct Private;
+        Private* const d;
 };
 
 #endif // KOCOMPOSITEOP_H
