@@ -25,10 +25,12 @@
 #include <kconfig.h>
 #include <kglobal.h>
 
-#include <colorprofiles/KoLcmsColorProfile.h>
+#include <colorprofiles/KoLcmsColorProfileContainer.h>
 #include <KoColorSpaceAbstract.h>
 #include <KoColorSpaceRegistry.h>
 
+#include <pigment_export.h>
+
 struct KoLcmsColorTransformation : public KoColorTransformation
 {
     KoLcmsColorTransformation() : KoColorTransformation()
@@ -62,38 +64,47 @@ struct KoLcmsColorTransformation : public KoColorTransformation
     cmsHTRANSFORM cmstransform;
 };
 
-struct KoLcmsDarkenTransformation : public KoColorTransformation
-{
-    KoLcmsDarkenTransformation(const KoColorSpace* cs, cmsHTRANSFORM defaultToLab, cmsHTRANSFORM defaultFromLab, qint32 shade, bool compensate, double compensation) : m_colorSpace(cs), m_defaultToLab(defaultToLab), m_defaultFromLab(defaultFromLab), m_shade(shade), m_compensate(compensate), m_compensation(compensation)
-    {
-        
-    }
-    virtual void transform(const quint8 *src, quint8 *dst, qint32 nPixels) const
-    {
-        quint16 * labcache = new quint16[nPixels * 4];
-        cmsDoTransform( m_defaultToLab, const_cast<quint8*>( src ), reinterpret_cast<quint8*>( labcache ), nPixels );
-        for ( int i = 0; i < nPixels * 4; ++i ) {
-            if ( m_compensate ) {
-                labcache[i] = static_cast<quint16>( ( labcache[i] * m_shade ) / ( m_compensation * 255 ) );
-            }
-            else {
-                labcache[i] = static_cast<quint16>( labcache[i] * m_shade  / 255 );
-            }
+class PIGMENTCMS_EXPORT KoLcmsColorConversionTransformation : public KoColorConversionTransformation {
+    public:
+        KoLcmsColorConversionTransformation(const KoColorSpace* srcCs, quint32 srcColorSpaceType, KoLcmsColorProfileContainer* srcProfile, const KoColorSpace* dstCs, quint32 dstColorSpaceType, KoLcmsColorProfileContainer* dstProfile, Intent renderingIntent = IntentPerceptual) : KoColorConversionTransformation(srcCs, dstCs, renderingIntent), m_transform(0)
+        {
+            m_transform = this->createTransform(
+                            srcColorSpaceType,
+                            srcProfile,
+                            dstColorSpaceType,
+                            dstProfile,
+                            renderingIntent);
         }
-        cmsDoTransform( m_defaultFromLab, reinterpret_cast<quint8*>( labcache ), dst, nPixels );
-        // Copy alpha
-        for ( int i = 0; i < nPixels; ++i ) {
-            quint8 alpha = m_colorSpace->alpha( src );
-            m_colorSpace->setAlpha( dst, alpha, 1 );
+    public:
+        virtual void transform(const quint8 *src, quint8 *dst, qint32 numPixels) const
+        {
+            Q_ASSERT(m_transform);
+
+            qint32 srcPixelSize = srcColorSpace()->pixelSize();
+            qint32 dstPixelSize = dstColorSpace()->pixelSize();
+
+            cmsDoTransform(m_transform, const_cast<quint8 *>(src), dst, numPixels);
+
+        // Lcms does nothing to the destination alpha channel so we must convert that manually.
+            while (numPixels > 0) {
+                quint8 alpha = srcColorSpace()->alpha(src);
+                dstColorSpace()->setAlpha(dst, alpha, 1);
+
+                src += srcPixelSize;
+                dst += dstPixelSize;
+                numPixels--;
+            }
+
         }
-        delete [] labcache;
-    }
-    const KoColorSpace* m_colorSpace;
-    cmsHTRANSFORM m_defaultToLab;
-    cmsHTRANSFORM m_defaultFromLab;
-    qint32 m_shade;
-    bool m_compensate;
-    double m_compensation;
+    private:
+        cmsHTRANSFORM createTransform(
+                quint32 srcColorSpaceType,
+                KoLcmsColorProfileContainer *  srcProfile,
+                quint32 dstColorSpaceType,
+                KoLcmsColorProfileContainer *  dstProfile,
+                qint32 renderingIntent) const;
+    private:
+        mutable cmsHTRANSFORM m_transform;
 };
 
 class KoLcmsInfo {
@@ -133,23 +144,12 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
             mutable quint8 * qcolordata; // A small buffer for conversion from and to qcolor.
             cmsHTRANSFORM defaultToRGB;    // Default transform to 8 bit sRGB
             cmsHTRANSFORM defaultFromRGB;  // Default transform from 8 bit sRGB
-            cmsHTRANSFORM defaultToRGB16;    // Default transform to 16 bit sRGB
-            cmsHTRANSFORM defaultFromRGB16;  // Default transform from 16 bit sRGB
-    
+
             mutable cmsHPROFILE   lastRGBProfile;  // Last used profile to transform to/from RGB
             mutable cmsHTRANSFORM lastToRGB;       // Last used transform to transform to RGB
             mutable cmsHTRANSFORM lastFromRGB;     // Last used transform to transform from RGB
-    
-            cmsHTRANSFORM defaultToLab;
-            cmsHTRANSFORM defaultFromLab;
-    
-            KoLcmsColorProfile *  profile;
-            mutable const KoColorSpace *lastUsedDstColorSpace;
-            mutable cmsHTRANSFORM lastUsedTransform;
-            
-        // cmsHTRANSFORM is a void *, so this should work.
-            typedef QMap<const KoColorSpace *, cmsHTRANSFORM>  TransformMap;
-            mutable TransformMap transforms; // Cache for existing transforms
+            KoLcmsColorProfileContainer *  profile;
+            KoColorProfile* colorProfile;
         };
     protected:
         KoLcmsColorSpace(const QString &id, const QString &name, KoColorSpaceRegistry * parent, DWORD cmType,
@@ -157,19 +157,15 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
                          KoColorProfile *p) : KoColorSpaceAbstract<_CSTraits>(id, name, parent), KoLcmsInfo( cmType, colorSpaceSignature), d( new Private())
 
         {
-            d->profile = toLcmsProfile(p);
+            Q_ASSERT(p); // No profile means the lcms color space can't work
+            d->profile = asLcmsProfile(p);
+            d->colorProfile = p;
             d->qcolordata = 0;
-            d->lastUsedDstColorSpace = 0;
-            d->lastUsedTransform = 0;
             d->lastRGBProfile = 0;
             d->lastToRGB = 0;
             d->lastFromRGB = 0;
             d->defaultFromRGB = 0;
             d->defaultToRGB = 0;
-            d->defaultFromLab = 0;
-            d->defaultToLab = 0;
-            d->defaultToRGB16 = 0;
-            d->defaultFromRGB16 = 0;
         }
         virtual ~KoLcmsColorSpace()
         {
@@ -195,40 +191,25 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
                     d->lastFromRGB, TYPE_BGR_8,
                     INTENT_PERCEPTUAL, 0);
 
-            d->defaultFromRGB16 = cmsCreateTransform(d->lastFromRGB, TYPE_BGRA_16,
-                    d->profile->lcmsProfile(), this->colorSpaceType(),
-                    INTENT_PERCEPTUAL, 0);
-
-            d->defaultToRGB16 =  cmsCreateTransform(d->profile->lcmsProfile(), this->colorSpaceType(),
-                    d->lastFromRGB, TYPE_BGRA_16,
-                    INTENT_PERCEPTUAL, 0);
-
-            cmsHPROFILE hLab  = cmsCreateLabProfile(NULL);
-
-            d->defaultFromLab = cmsCreateTransform(hLab,  (COLORSPACE_SH(PT_Lab)|CHANNELS_SH(3)|BYTES_SH(2)|EXTRA_SH(1)), d->profile->lcmsProfile(), this->colorSpaceType(),
-                    INTENT_PERCEPTUAL, 0);
-
-            d->defaultToLab = cmsCreateTransform(d->profile->lcmsProfile(), this->colorSpaceType(), hLab,  (COLORSPACE_SH(PT_Lab)|CHANNELS_SH(3)|BYTES_SH(2)|EXTRA_SH(1)),
-                    INTENT_PERCEPTUAL, 0);
         }
     public:
-        
+
         virtual bool hasHighDynamicRange() const { return false; }
-        virtual KoColorProfile * profile() const { return lcmsProfile(); }
-        
-        virtual bool profileIsCompatible(KoColorProfile* profile) const
+        virtual const KoColorProfile * profile() const { return d->colorProfile; }
+
+        virtual bool profileIsCompatible(const KoColorProfile* profile) const
         {
-            KoLcmsColorProfile* p = dynamic_cast<KoLcmsColorProfile*>(profile);
-            return (p && p->colorSpaceSignature() == colorSpaceSignature());
+            const KoIccColorProfile* p = dynamic_cast<const KoIccColorProfile*>(profile);
+            return (p && p->asLcms()->colorSpaceSignature() == colorSpaceSignature());
         }
-        
-        virtual void fromQColor(const QColor& color, quint8 *dst, KoColorProfile * koprofile=0) const
+
+        virtual void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * koprofile=0) const
         {
             d->qcolordata[2] = color.red();
             d->qcolordata[1] = color.green();
             d->qcolordata[0] = color.blue();
 
-            KoLcmsColorProfile* profile = toLcmsProfile(koprofile);
+            KoLcmsColorProfileContainer* profile = asLcmsProfile(koprofile);
             if (profile == 0) {
 	    // Default sRGB
                 if (!d->defaultFromRGB) return;
@@ -249,15 +230,15 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
             this->setAlpha(dst, OPACITY_OPAQUE, 1);
         }
 
-        virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, KoColorProfile * profile=0) const
+        virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, const KoColorProfile * profile=0) const
         {
             this->fromQColor(color, dst, profile);
             this->setAlpha(dst, opacity, 1);
         }
 
-        virtual void toQColor(const quint8 *src, QColor *c, KoColorProfile * koprofile =0) const
+        virtual void toQColor(const quint8 *src, QColor *c, const KoColorProfile * koprofile =0) const
         {
-            KoLcmsColorProfile* profile = toLcmsProfile(koprofile);
+            KoLcmsColorProfileContainer* profile = asLcmsProfile(koprofile);
             if (profile == 0) {
 	// Default sRGB transform
                 if (!d->defaultToRGB) return;
@@ -275,148 +256,26 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
             c->setRgb(d->qcolordata[2], d->qcolordata[1], d->qcolordata[0]);
         }
 
-        virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, KoColorProfile * profile =0) const
+        virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, const KoColorProfile * profile =0) const
         {
             this->toQColor(src, c, profile);
             *opacity = this->alpha(src);
         }
         virtual QImage convertToQImage(const quint8 *data, qint32 width, qint32 height,
-                KoColorProfile *dstProfile,
+                const KoColorProfile *dstProfile,
                 KoColorConversionTransformation::Intent renderingIntent, float exposure) const
 
         {
             Q_UNUSED(exposure);
             QImage img = QImage(width, height, QImage::Format_ARGB32);
 
-            KoColorSpace * dstCS;
-
-            dstCS = KoColorSpaceRegistry::instance()->colorSpace("RGBA", dstProfile);
+            const KoColorSpace * dstCS = KoColorSpaceRegistry::instance()->rgb8(dstProfile);
 
             if (data)
-                convertPixelsTo(const_cast<quint8 *>(data), img.bits(), dstCS, width * height, renderingIntent);
+                this->convertPixelsTo(const_cast<quint8 *>(data), img.bits(), dstCS, width * height, renderingIntent);
 
             return img;
         }
-        virtual void toLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const
-        {
-            if ( d->defaultToLab == 0 ) return;
-
-            cmsDoTransform( d->defaultToLab, const_cast<quint8 *>( src ), dst, nPixels );
-            quint16* dstU16 = reinterpret_cast<quint16*>(dst);
-            for(quint32 i = 0; i < nPixels; i++)
-            {
-                dstU16[4*i+3] = KoColorSpaceMaths<quint8,quint16>::scaleToA(this->alpha(src));
-                src += this->pixelSize();
-            }
-        }
-
-        virtual void fromLabA16(const quint8 * src, quint8 * dst, quint32 nPixels) const
-        {
-            if ( d->defaultFromLab == 0 ) return;
-
-            cmsDoTransform( d->defaultFromLab,  const_cast<quint8 *>( src ), dst,  nPixels );
-            const quint16* srcU16 = reinterpret_cast<const quint16*>(src);
-            for(quint32 i = 0; i < nPixels; i++)
-            {
-                this->setAlpha(dst, KoColorSpaceMaths<quint16,quint8>::scaleToA(srcU16[4*i+3]), 1 );
-                dst += this->pixelSize();
-            }
-        }
-        virtual void fromRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const
-        {
-            if ( d->defaultFromRGB16 == 0 ) return;
-
-            cmsDoTransform( d->defaultFromRGB16,  const_cast<quint8 *>( src ), dst,  nPixels );
-            const quint16* srcU16 = reinterpret_cast<const quint16*>(src);
-            for(quint32 i = 0; i < nPixels; i++)
-            {
-                this->setAlpha(dst, KoColorSpaceMaths<quint16,quint8>::scaleToA(srcU16[4*i+3]), 1 );
-                dst += this->pixelSize();
-            }
-        }
-        virtual void toRgbA16(const quint8 * src, quint8 * dst, quint32 nPixels) const
-        {
-            if ( d->defaultToRGB16 == 0 ) return;
-
-            cmsDoTransform( d->defaultToRGB16, const_cast<quint8 *>( src ), dst, nPixels );
-            quint16* dstU16 = reinterpret_cast<quint16*>(dst);
-            for(quint32 i = 0; i < nPixels; i++)
-            {
-                dstU16[4*i+3] = KoColorSpaceMaths<quint8,quint16>::scaleToA(this->alpha(src));
-                src += this->pixelSize();
-            }
-        }
-
-        virtual bool convertPixelsTo(const quint8 * src,
-                quint8 * dst,
-                const KoColorSpace * dstColorSpace,
-                quint32 numPixels,
-                KoColorConversionTransformation::Intent renderingIntent) const
-        {
-            if (dstColorSpace->id() == this->id()
-                && dstColorSpace->profile() == profile())
-            {
-                if (src!= dst)
-                    memcpy (dst, src, numPixels * this->pixelSize());
-
-                return true;
-            }
-
-            cmsHTRANSFORM tf = 0;
-
-            qint32 srcPixelSize = this->pixelSize();
-            qint32 dstPixelSize = dstColorSpace->pixelSize();
-
-            if (d->lastUsedTransform != 0 && d->lastUsedDstColorSpace != 0) {
-                if (dstColorSpace->id() == d->lastUsedDstColorSpace->id() &&
-                    dstColorSpace->profile() == d->lastUsedDstColorSpace->profile()) {
-                    tf = d->lastUsedTransform;
-                    }
-            }
-            KoLcmsColorProfile* dstprofile = toLcmsProfile(dstColorSpace->profile());
-
-            if (!tf && d->profile && dstprofile) {
-
-                if (!d->transforms.contains(dstColorSpace)) {
-                    tf = this->createTransform(dstColorSpace,
-                            d->profile,
-                            dstprofile,
-                            renderingIntent);
-                    if (tf) {
-            // XXX: Should we clear the transform cache if it gets too big?
-                        d->transforms[dstColorSpace] = tf;
-                    }
-                }
-                else {
-                    tf = d->transforms[dstColorSpace];
-                }
-
-                if ( tf ) {
-                    d->lastUsedTransform = tf;
-                    d->lastUsedDstColorSpace = dstColorSpace;
-                }
-            }
-
-            if (tf) {
-
-                cmsDoTransform(tf, const_cast<quint8 *>(src), dst, numPixels);
-
-        // Lcms does nothing to the destination alpha channel so we must convert that manually.
-                while (numPixels > 0) {
-                    quint8 alpha = this->alpha(src);
-                    dstColorSpace->setAlpha(dst, alpha, 1);
-
-                    src += srcPixelSize;
-                    dst += dstPixelSize;
-                    numPixels--;
-                }
-
-                return true;
-            }
-
-        // Last resort fallback. This happens when either src or dst isn't a lcms colorspace.
-            return KoColorSpace::convertPixelsTo(src, dst, dstColorSpace, numPixels, renderingIntent);
-        }
 
         virtual KoColorTransformation *createBrightnessContrastAdjustment(const quint16 *transferValues) const
         {
@@ -525,58 +384,39 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
             return adj;
         }
 
-        virtual KoColorTransformation *createDarkenAdjustement(qint32 shade, bool compensate, double compensation) const
-        {
-            return new KoLcmsDarkenTransformation(this, d->defaultToLab, d->defaultFromLab, shade, compensate, compensation);
-        }
-
         virtual quint8 difference(const quint8* src1, const quint8* src2) const
         {
-            if (d->defaultToLab) {
+            quint8 lab1[8], lab2[8];
+            cmsCIELab labF1, labF2;
 
-                quint8 lab1[8], lab2[8];
-                cmsCIELab labF1, labF2;
-
-                if (this->alpha(src1) == OPACITY_TRANSPARENT || this->alpha(src2) == OPACITY_TRANSPARENT)
-                    return (this->alpha(src1) == this->alpha(src2) ? 0 : 255);
-
-                cmsDoTransform( d->defaultToLab, const_cast<quint8*>( src1 ), lab1, 1);
-                cmsDoTransform( d->defaultToLab, const_cast<quint8*>( src2 ), lab2, 1);
-                cmsLabEncoded2Float(&labF1, (WORD *)lab1);
-                cmsLabEncoded2Float(&labF2, (WORD *)lab2);
-                double diff = cmsDeltaE(&labF1, &labF2);
-                if(diff>255)
-                    return 255;
-                else
-                    return qint8(diff);
-            }
-            else {
-                QColor c1;
-                quint8 opacity1;
-                toQColor(src1, &c1, &opacity1);
-
-                QColor c2;
-                quint8 opacity2;
-                toQColor(src2, &c2, &opacity2);
-
-                quint8 red = abs(c1.red() - c2.red());
-                quint8 green = abs(c1.green() - c2.green());
-                quint8 blue = abs(c1.blue() - c2.blue());
-                return qMax(red, qMax(green, blue));
-            }
+            if (this->alpha(src1) == OPACITY_TRANSPARENT || this->alpha(src2) == OPACITY_TRANSPARENT)
+                return (this->alpha(src1) == this->alpha(src2) ? 0 : 255);
+            Q_ASSERT(this->toLabA16Converter());
+            this->toLabA16Converter()->transform( src1, lab1, 1),
+            this->toLabA16Converter()->transform( src2, lab2, 1),
+            cmsLabEncoded2Float(&labF1, (WORD *)lab1);
+            cmsLabEncoded2Float(&labF2, (WORD *)lab2);
+            double diff = cmsDeltaE(&labF1, &labF2);
+            if(diff>255)
+                return 255;
+            else
+                return qint8(diff);
         }
 
     private:
-        inline KoLcmsColorProfile* lcmsProfile() const {
+        inline KoLcmsColorProfileContainer* lcmsProfile() const {
             return d->profile;
         }
-        inline static KoLcmsColorProfile* toLcmsProfile(KoColorProfile* p)
+        inline static KoLcmsColorProfileContainer* asLcmsProfile(const KoColorProfile* p)
         {
-            KoLcmsColorProfile* lp = dynamic_cast<KoLcmsColorProfile*>(p);
-            if(lp) return lp;
-            KoIccColorProfile* iccp = dynamic_cast<KoIccColorProfile*>(p);
-            if(iccp) return new KoLcmsColorProfile(iccp->rawData());
-            return 0;
+            if(!p) return 0;
+            const KoIccColorProfile* iccp = dynamic_cast<const KoIccColorProfile*>(p);
+            if( !iccp )
+            {
+                return 0;
+            }
+            Q_ASSERT(iccp->asLcms());
+            return iccp->asLcms();
         }
         typedef struct {
             double Saturation;
@@ -584,7 +424,7 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
         } BCHSWADJUSTS, *LPBCHSWADJUSTS;
 
 
-        static int desaturateSampler(register WORD In[], register WORD Out[], register LPVOID /*Cargo*/) 
+        static int desaturateSampler(register WORD In[], register WORD Out[], register LPVOID /*Cargo*/)
         {
             cmsCIELab LabIn, LabOut;
             cmsCIELCh LChIn, LChOut;
@@ -606,49 +446,23 @@ class KoLcmsColorSpace : public KoColorSpaceAbstract<_CSTraits>, public KoLcmsIn
 
             return true;
         }
-        cmsHTRANSFORM createTransform(const KoColorSpace * dstColorSpace,
-                KoColorProfile *  srcKoProfile,
-                KoColorProfile *  dstKoProfile,
-                qint32 renderingIntent) const
-        {
-            KConfigGroup cfg = KGlobal::config()->group("");
-            bool bpCompensation = cfg.readEntry("useBlackPointCompensation", false);
-
-            int flags = 0;
-
-            if (bpCompensation) {
-                flags = cmsFLAGS_BLACKPOINTCOMPENSATION;
-            }
-            const KoLcmsInfo* dstColorSpaceInfo = dynamic_cast<const KoLcmsInfo*>(dstColorSpace);
-            
-            KoLcmsColorProfile *  srcProfile = dynamic_cast<KoLcmsColorProfile *>(srcKoProfile);
-            KoLcmsColorProfile *  dstProfile = dynamic_cast<KoLcmsColorProfile *>(dstKoProfile);
-            
-            if (dstColorSpaceInfo && dstProfile && srcProfile ) {
-                cmsHTRANSFORM tf = cmsCreateTransform(srcProfile->lcmsProfile(),
-                        this->colorSpaceType(),
-                        dstProfile->lcmsProfile(),
-                        dstColorSpaceInfo->colorSpaceType(),
-                        renderingIntent,
-                        flags);
-
-                return tf;
-            }
-            return 0;
-        }
         Private * const d;
 };
 
-class KoLcmsColorSpaceFactory : public KoColorSpaceFactory, private KoLcmsInfo {
+class PIGMENTCMS_EXPORT KoLcmsColorSpaceFactory : public KoColorSpaceFactory, private KoLcmsInfo {
     public:
         KoLcmsColorSpaceFactory(DWORD cmType, icColorSpaceSignature colorSpaceSignature) : KoLcmsInfo(cmType, colorSpaceSignature)
         {
         }
-        virtual bool profileIsCompatible(KoColorProfile* profile) const
+        virtual bool profileIsCompatible(const KoColorProfile* profile) const
         {
-            KoLcmsColorProfile* p = dynamic_cast<KoLcmsColorProfile*>(profile);
-            return p && p->colorSpaceSignature() == colorSpaceSignature();
+            const KoIccColorProfile* p = dynamic_cast<const KoIccColorProfile*>(profile);
+            return (p && p->asLcms()->colorSpaceSignature() == colorSpaceSignature());
         }
+        virtual KoColorConversionTransformationFactory* createICCColorConversionTransformationFactory(QString _colorModelId, QString _colorDepthId) const;
+        virtual bool isIcc() const { return true; }
+        virtual bool isHdr() const { return false; }
+        virtual QList<KoColorConversionTransformationFactory*> colorConversionLinks() const;
 };
 
 #endif
