@@ -27,16 +27,20 @@
 #include "KoLcmsColorSpace.h"
 #include "KoColorSpaceTraits.h"
 
+#include "KoColorModelStandardIds.h"
+
 typedef KoColorSpaceTrait<quint8, 1, 0> AlphaU8Traits;
 
 /**
  * The alpha mask is a special color strategy that treats all pixels as
  * alpha value with a color common to the mask. The default color is white.
  */
-class PIGMENT_EXPORT KoAlphaColorSpace : public KoColorSpaceAbstract<AlphaU8Traits> {
+class PIGMENTCMS_EXPORT KoAlphaColorSpace : public KoColorSpaceAbstract<AlphaU8Traits> {
 public:
     explicit KoAlphaColorSpace(KoColorSpaceRegistry * parent);
     virtual ~KoAlphaColorSpace();
+    virtual KoID colorModelId() const { return AlphaColorModelID; }
+    virtual KoID colorDepthId() const { return Integer8BitsColorDepthID; }
 
 public:
     virtual bool willDegrade(ColorSpaceIndependence independence) const
@@ -45,17 +49,17 @@ public:
             return false;
         }
 
-    virtual bool profileIsCompatible(KoColorProfile* /*profile*/) const {
+    virtual bool profileIsCompatible(const KoColorProfile* /*profile*/) const {
         return false;
     }
 
-    virtual void fromQColor(const QColor& color, quint8 *dst, KoColorProfile * profile = 0) const;
-    virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, KoColorProfile * profile = 0) const;
+    virtual void fromQColor(const QColor& color, quint8 *dst, const KoColorProfile * profile = 0) const;
+    virtual void fromQColor(const QColor& color, quint8 opacity, quint8 *dst, const KoColorProfile * profile = 0) const;
 
     virtual void alpha(const quint8 *pixel, quint8 *alpha) const;
 
-    virtual void toQColor(const quint8 *src, QColor *c, KoColorProfile * profile = 0) const;
-    virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, KoColorProfile * profile = 0) const;
+    virtual void toQColor(const quint8 *src, QColor *c, const KoColorProfile * profile = 0) const;
+    virtual void toQColor(const quint8 *src, QColor *c, quint8 *opacity, const KoColorProfile * profile = 0) const;
 
     virtual quint8 difference(const quint8 *src1, const quint8 *src2) const;
     virtual void mixColors(const quint8 **colors, const quint8 *weights, quint32 nColors, quint8 *dst) const;
@@ -72,9 +76,9 @@ public:
     virtual icColorSpaceSignature colorSpaceSignature() const { return icSigGrayData; }
 
     virtual bool hasHighDynamicRange() const { return false; }
-    virtual KoColorProfile* profile() const { return 0; }
+    virtual const KoColorProfile* profile() const { return 0; }
     virtual QImage convertToQImage(const quint8 *data, qint32 width, qint32 height,
-                                   KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent,
+                                   const KoColorProfile *  dstProfile, KoColorConversionTransformation::Intent renderingIntent,
                                    float exposure = 0.0f) const;
 
     virtual void toLabA16(const quint8* src, quint8* dst, quint32 nPixels) const
