@@ -42,7 +42,7 @@ class KoCompositeOpAlphaBase : public KoCompositeOp {
     typedef typename _CSTraits::channels_type channels_type;
 public:
 
-    KoCompositeOpAlphaBase(KoColorSpace * cs, const QString& id, const QString& description)
+    KoCompositeOpAlphaBase(const KoColorSpace * cs, const QString& id, const QString& description)
         : KoCompositeOp(cs, id, description )
         {
         }
@@ -117,7 +117,7 @@ public:
 
                     while (columns > 0) {
 
-                        channels_type srcAlpha = srcN[_CSTraits::alpha_pos];
+                        channels_type srcAlpha = _compositeOp::selectAlpha(srcN[_CSTraits::alpha_pos], dstN[_CSTraits::alpha_pos]);
 
                         // apply the alphamask
                         if (mask != 0) {
