@@ -31,12 +31,16 @@ class KoCompositeOpDivide : public KoCompositeOpAlphaBase<_CSTraits, KoComposite
     typedef typename KoColorSpaceMathsTraits<typename _CSTraits::channels_type>::compositetype compositetype;
     public:
 
-        KoCompositeOpDivide(KoColorSpace * cs)
+        KoCompositeOpDivide(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpDivide<_CSTraits> >(cs, COMPOSITE_DIVIDE, i18n("Divide" ) )
         {
         }
 
     public:
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            return QMIN(srcAlpha, dstAlpha);
+        }
 
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* src,
