@@ -32,13 +32,16 @@ class KoCompositeOpDodge : public KoCompositeOpAlphaBase<_CSTraits, KoCompositeO
     typedef typename KoColorSpaceMathsTraits<typename _CSTraits::channels_type>::compositetype compositetype;
     public:
 
-        KoCompositeOpDodge(KoColorSpace * cs)
+        KoCompositeOpDodge(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpDodge<_CSTraits> >(cs, COMPOSITE_DODGE, i18n("Dodge" ) )
         {
         }
 
     public:
-
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            return QMIN(srcAlpha, dstAlpha);
+        }
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* src,
                                                  channels_type* dst,
