@@ -30,12 +30,16 @@ class KoCompositeOpMultiply : public KoCompositeOpAlphaBase<_CSTraits, KoComposi
     typedef typename _CSTraits::channels_type channels_type;
     public:
 
-        KoCompositeOpMultiply(KoColorSpace * cs)
+        KoCompositeOpMultiply(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpMultiply<_CSTraits> >(cs, COMPOSITE_MULT, i18n("Multiply" ) )
         {
         }
 
     public:
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            return QMIN(srcAlpha, dstAlpha);
+        }
 
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* src,
