@@ -31,12 +31,17 @@ class KoCompositeOpOver : public KoCompositeOpAlphaBase<_CSTraits, KoCompositeOp
     typedef typename _CSTraits::channels_type channels_type;
     public:
 
-        KoCompositeOpOver(KoColorSpace * cs)
+        KoCompositeOpOver(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpOver<_CSTraits> >(cs, COMPOSITE_OVER, i18n("Normal" ) )
         {
         }
 
     public:
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            Q_UNUSED(dstAlpha);
+            return srcAlpha;
+        }
 
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* srcN,
