@@ -31,12 +31,16 @@ class KoCompositeOpOverlay : public KoCompositeOpAlphaBase<_CSTraits, KoComposit
     typedef typename KoColorSpaceMathsTraits<typename _CSTraits::channels_type>::compositetype compositetype;
     public:
 
-        KoCompositeOpOverlay(KoColorSpace * cs)
+        KoCompositeOpOverlay(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpOverlay<_CSTraits> >(cs, COMPOSITE_OVERLAY, i18n("Overlay" ) )
         {
         }
 
     public:
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            return QMIN(srcAlpha, dstAlpha);
+        }
 
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* src,
