@@ -31,12 +31,16 @@ class KoCompositeOpScreen : public KoCompositeOpAlphaBase<_CSTraits, KoComposite
     typedef typename KoColorSpaceMathsTraits<typename _CSTraits::channels_type>::compositetype compositetype;
     public:
 
-        KoCompositeOpScreen(KoColorSpace * cs)
+        KoCompositeOpScreen(const KoColorSpace * cs)
         : KoCompositeOpAlphaBase<_CSTraits, KoCompositeOpScreen<_CSTraits> >(cs, COMPOSITE_SCREEN, i18n("Screen" ) )
         {
         }
 
     public:
+        inline static channels_type selectAlpha( channels_type srcAlpha, channels_type dstAlpha)
+        {
+            return QMIN(srcAlpha, dstAlpha);
+        }
 
         inline static void composeColorChannels( channels_type srcBlend,
                                                  const channels_type* src,
