@@ -24,9 +24,9 @@
 #include <kdebug.h>
 
 ConnectionToolFactory::ConnectionToolFactory(QObject *parent)
-: KoToolFactory(parent, "ConnectionToolFactory_ID", i18n("Connection tool"))
+: KoToolFactory(parent, "ConnectionToolFactory_ID", i18n("Connection Tool"))
 {
-    setToolTip (i18n("Connection Creation tool"));
+    setToolTip (i18n("Connection creation tool"));
     setToolType (mainToolType());
     setIcon ("connect-no");
     setPriority (9);
