@@ -23,7 +23,9 @@
 
 namespace MusicCore {
     class Bar;
+    class VoiceBar;
     class Sheet;
+    class Part;
 }
 
 /**
@@ -33,8 +35,9 @@ namespace MusicCore {
 class Engraver {
     public:
         Engraver();
-        void engraveSheet(MusicCore::Sheet* sheet, QSizeF size, bool engraveBars = true);
+        void engraveSheet(MusicCore::Sheet* sheet, int firstSystem, QSizeF size, bool engraveBars = true, int* lastSystem=0);
         void engraveBar(MusicCore::Bar* bar);
+        void rebeamBar(MusicCore::Part* part, MusicCore::VoiceBar* bar);
 };
 
 #endif // MUSIC_ENGRAVER_H
