@@ -32,18 +32,28 @@
 #include "core/TimeSignature.h"
 #include "core/StaffSystem.h"
 
+#include <QMultiMap>
+
+#include <climits>
+
 using namespace MusicCore;
 
 MusicRenderer::MusicRenderer(MusicStyle* style) : m_style(style), m_debug(false)
 {
 }
 
-void MusicRenderer::renderSheet(QPainter& painter, Sheet* sheet)
+void MusicRenderer::renderSheet(QPainter& painter, Sheet* sheet, int firstSystem, int lastSystem)
 {
-    for (int i = 0; i < sheet->partCount(); i++) {
-        renderPart(painter, sheet->part(i));
+    int firstBar = sheet->staffSystem(firstSystem)->firstBar();
+    int lastBar = INT_MAX;
+    if (lastSystem < sheet->staffSystemCount()-1) {
+        lastBar = sheet->staffSystem(lastSystem+1)->firstBar()-1;
     }
-    for (int i = 0; i < sheet->staffSystemCount(); i++) {
+    
+    for (int i = 0; i < sheet->partCount(); i++) {
+        renderPart(painter, sheet->part(i), firstBar, lastBar);
+    }
+    for (int i = firstSystem; i <= lastSystem && i < sheet->staffSystemCount(); i++) {
         StaffSystem* ss = sheet->staffSystem(i);
         if (ss->indent() == 0) continue;
         int b = ss->firstBar();
@@ -79,15 +89,17 @@ void MusicRenderer::renderSheet(QPainter& painter, Sheet* sheet)
     }
 }
 
-void MusicRenderer::renderPart(QPainter& painter, Part* part)
+void MusicRenderer::renderPart(QPainter& painter, Part* part, int firstBar, int lastBar, const QColor& color)
 {
+    if (lastBar < firstBar) return;
+
     for (int i = 0; i < part->staffCount(); i++) {
-        renderStaff(painter, part->staff(i));
+        renderStaff(painter, part->staff(i), firstBar, lastBar, color);
     }
     double firstStaff = part->staff(0)->top();
     int c = part->staffCount()-1;
     double lastStaff = part->staff(c)->bottom();
-    for (int b = 0; b < part->sheet()->barCount(); b++) {
+    for (int b = firstBar; b <= lastBar && b < part->sheet()->barCount(); b++) {
         Bar* bar = part->sheet()->bar(b);
         QPointF p = bar->position();
         painter.drawLine(QPointF(p.x() + bar->size(), p.y() + firstStaff), QPointF(p.x() + bar->size(), p.y() + lastStaff));
@@ -111,24 +123,24 @@ void MusicRenderer::renderPart(QPainter& painter, Part* part)
             double w = bar->size();
             for (int sid = 0; sid < part->staffCount(); sid++) {
                 Staff* s = part->staff(sid);
-                renderRest(painter, Chord::Whole, pos + QPointF(w/2, s->top() + s->lineSpacing()), Qt::black);
+                renderRest(painter, WholeNote, pos + QPointF(w/2, s->top() + s->lineSpacing()), color);
             }
         }
     }
     for (int i = 0; i < part->voiceCount(); i++) {
-        renderVoice(painter, part->voice(i));
+        renderVoice(painter, part->voice(i), firstBar, lastBar, color);
     }
 }
 
-void MusicRenderer::renderStaff(QPainter& painter, Staff *staff )
+void MusicRenderer::renderStaff(QPainter& painter, Staff *staff, int firstBar, int lastBar, const QColor& color)
 {
     double dy = staff->lineSpacing();
     double y = staff->top();
-    for (int b = 0; b < staff->part()->sheet()->barCount(); b++) {
+    for (int b = firstBar; b <= lastBar && b < staff->part()->sheet()->barCount(); b++) {
         Bar* bar = staff->part()->sheet()->bar(b);
         QPointF p = bar->position();
         QPointF prep = bar->prefixPosition() + QPointF(bar->prefix(), 0);
-        painter.setPen(m_style->staffLinePen());
+        painter.setPen(m_style->staffLinePen(color));
         for (int i = 0; i < staff->lineCount(); i++) {
             painter.drawLine(QPointF(p.x(), p.y() + y + i * dy), QPointF(p.x() + bar->size(), p.y() + y + i * dy));
         }
@@ -142,19 +154,19 @@ void MusicRenderer::renderStaff(QPainter& painter, Staff *staff )
         for (int e = 0; e < bar->staffElementCount(staff); e++) {
             StaffElement* se = bar->staffElement(staff, e);
             if (se->startTime() == 0) {
-                renderStaffElement(painter, bar->staffElement(staff, e), prep, state, 1);
+                renderStaffElement(painter, bar->staffElement(staff, e), prep, state, 1, color);
             } else {
-                renderStaffElement(painter, bar->staffElement(staff, e), p, state, bar->scale());
+                renderStaffElement(painter, bar->staffElement(staff, e), p, state, bar->scale(), color);
             }
         }
     }
 }
 
-void MusicRenderer::renderVoice(QPainter& painter, Voice *voice, const QColor& color)
+void MusicRenderer::renderVoice(QPainter& painter, Voice *voice, int firstBar, int lastBar, const QColor& color)
 {
     RenderState state;
     state.clef = 0;
-    for (int b = 0; b < voice->part()->sheet()->barCount(); b++) {
+    for (int b = firstBar; b <= lastBar && b < voice->part()->sheet()->barCount(); b++) {
         Bar* bar = voice->part()->sheet()->bar(b);
         QPointF p = bar->position();
         VoiceBar* vb = voice->bar(bar);
@@ -162,12 +174,12 @@ void MusicRenderer::renderVoice(QPainter& painter, Voice *voice, const QColor& c
             if (vb->element(e)->staff()) {
                 state.clef = vb->element(e)->staff()->lastClefChange(b, 0);
             }
-            renderElement(painter, vb->element(e), p, state, bar->scale(), color);
+            renderElement(painter, vb->element(e), voice, p, state, bar->scale(), color);
         }
     }
 }
 
-void MusicRenderer::renderElement(QPainter& painter, VoiceElement* me, const QPointF& pos, RenderState& state, double xScale, const QColor& color)
+void MusicRenderer::renderElement(QPainter& painter, VoiceElement* me, Voice* voice, const QPointF& pos, RenderState& state, double xScale, const QColor& color)
 {
     Q_UNUSED( state ); // unused for now, but will probably be used again in the future
     
@@ -184,10 +196,10 @@ void MusicRenderer::renderElement(QPainter& painter, VoiceElement* me, const QPo
 
     // TODO: make this less hacky
     Chord *c = dynamic_cast<Chord*>(me);
-    if (c) renderChord(painter, c, pos, xScale, color);
+    if (c) renderChord(painter, c, voice, pos, xScale, color);
 }
 
-void MusicRenderer::renderStaffElement(QPainter& painter, MusicCore::StaffElement* se, const QPointF& pos, RenderState& state, double xScale)
+void MusicRenderer::renderStaffElement(QPainter& painter, MusicCore::StaffElement* se, const QPointF& pos, RenderState& state, double xScale, const QColor& color)
 {
     double top = 0;
     top += se->staff()->top();
@@ -201,22 +213,22 @@ void MusicRenderer::renderStaffElement(QPainter& painter, MusicCore::StaffElemen
     }
 
     Clef *cl = dynamic_cast<Clef*>(se);
-    if (cl) renderClef(painter, cl, pos, state, xScale);
+    if (cl) renderClef(painter, cl, pos, state, xScale, color);
     KeySignature *ks = dynamic_cast<KeySignature*>(se);
-    if (ks) renderKeySignature(painter, ks, pos, state, xScale);
+    if (ks) renderKeySignature(painter, ks, pos, state, xScale, color);
     TimeSignature* ts = dynamic_cast<TimeSignature*>(se);
-    if (ts) renderTimeSignature(painter, ts, pos, xScale);
+    if (ts) renderTimeSignature(painter, ts, pos, xScale, color);
 }
 
 
-void MusicRenderer::renderClef(QPainter& painter, Clef *c, const QPointF& pos, RenderState& state, double xScale)
+void MusicRenderer::renderClef(QPainter& painter, Clef *c, const QPointF& pos, RenderState& state, double xScale, const QColor& color)
 {
     state.clef = c;
     Staff* s = c->staff();
     m_style->renderClef(painter, pos.x() + c->x() * xScale, pos.y() + s->top() + (s->lineCount() - c->line()) * s->lineSpacing(), c->shape());
 }
 
-void MusicRenderer::renderKeySignature(QPainter& painter, KeySignature* ks, const QPointF& pos, RenderState& state, double xScale)
+void MusicRenderer::renderKeySignature(QPainter& painter, KeySignature* ks, const QPointF& pos, RenderState& state, double xScale, const QColor& color)
 {
     Staff * s = ks->staff();
     double curx = pos.x() + ks->x() * xScale;
@@ -287,7 +299,7 @@ void MusicRenderer::renderKeySignature(QPainter& painter, KeySignature* ks, cons
     }
 }
 
-void MusicRenderer::renderTimeSignature(QPainter& painter, TimeSignature* ts, const QPointF& pos, double xScale)
+void MusicRenderer::renderTimeSignature(QPainter& painter, TimeSignature* ts, const QPointF& pos, double xScale, const QColor& color)
 {
     Staff* s = ts->staff();
     double hh = 0.5 * (s->lineCount() - 1) * s->lineSpacing();
@@ -295,26 +307,36 @@ void MusicRenderer::renderTimeSignature(QPainter& painter, TimeSignature* ts, co
     m_style->renderTimeSignatureNumber( painter, pos.x() + ts->x() * xScale, pos.y() + s->top() + 2*hh, ts->width(), ts->beat());
 }
 
-void MusicRenderer::renderRest(QPainter& painter, Chord::Duration duration, const QPointF& pos, const QColor& color)
+void MusicRenderer::renderRest(QPainter& painter, Duration duration, const QPointF& pos, const QColor& color)
 {
     m_style->renderRest(painter, pos.x(), pos.y(), duration, color);
 }
 
-void MusicRenderer::renderChord(QPainter& painter, Chord* chord, const QPointF& ref, double xScale, const QColor& color)
+void MusicRenderer::renderChord(QPainter& painter, Chord* chord, Voice* voice, const QPointF& ref, double xScale, const QColor& color)
 {
     double x = chord->x() * xScale;
     if (chord->noteCount() == 0) { // a rest
         Staff *s = chord->staff();
-        renderRest(painter, chord->duration(), ref + QPointF(x, s->top() + (2 - (chord->duration() == Chord::Whole)) * s->lineSpacing()), color);
+        renderRest(painter, chord->duration(), ref + QPointF(x, s->top() + (2 - (chord->duration() == WholeNote)) * s->lineSpacing()), color);
         return;
     }
     int topLine = 0, bottomLine = 0;
     VoiceBar* vb = chord->voiceBar();
     Bar* bar = vb->bar();
+    Sheet* sheet = voice->part()->sheet();
     int barIdx = bar->sheet()->indexOfBar(bar);
     double topy = 1e9, bottomy = -1e9;
     Staff* topStaff = 0, *bottomStaff = 0;
     
+    double mainNoteX = (chord->stemDirection() == StemUp ? x : chord->stemX(xScale));
+    double alternateNoteX = mainNoteX + (chord->stemDirection() == StemUp ? 6 : -6);
+    bool prevAlternate = false;
+    double maxNoteX = 0;
+    
+    QMultiMap<Staff*, int> dots;
+    
+    Chord* nextChord = 0;
+    
     for (int i = 0; i < chord->noteCount(); i++) {
         Note *n = chord->note(i);
         Staff * s = n->staff();
@@ -322,17 +344,34 @@ void MusicRenderer::renderChord(QPainter& painter, Chord* chord, const QPointF&
         int line = 10;
         if (clef) line = clef->pitchToLine(n->pitch());
 
+        double noteX = mainNoteX;
+        if (i > 0) {
+            int prevPitch = chord->note(i-1)->pitch();
+            if (abs(prevPitch - n->pitch()) <= 1 && !prevAlternate) {
+                noteX = alternateNoteX;
+            }
+        }
+        if (i < chord->noteCount()-1 && chord->stemDirection() == StemDown) {
+            int pitch = n->pitch();
+            int nPitch = chord->note(i+1)->pitch();
+            if (abs(pitch - nPitch) <= 1 && !prevAlternate) {
+                noteX = alternateNoteX;
+            }
+        }
+        prevAlternate = noteX != mainNoteX;
+        if (noteX > maxNoteX) maxNoteX = noteX;
+        
         if (line > 9) { // lines under the bar
             painter.setPen(m_style->staffLinePen(color));
             for (int i = 10; i <= line; i+= 2) {
                 double y = s->top() + i * s->lineSpacing() / 2;
-                painter.drawLine(ref + QPointF(x - 4, y), ref + QPointF(x + 10, y));
+                painter.drawLine(ref + QPointF(noteX - 4, y), ref + QPointF(noteX + 10, y));
             }
         } else if (line < -1) { // lines above the bar
             painter.setPen(m_style->staffLinePen(color));
             for (int i = -2; i >= line; i-= 2) {
                 double y = s->top() + i * s->lineSpacing() / 2;
-                painter.drawLine(ref + QPointF(x - 4, y), ref + QPointF(x + 10, y));
+                painter.drawLine(ref + QPointF(noteX - 4, y), ref + QPointF(noteX + 10, y));
             }
         }
 
@@ -348,7 +387,7 @@ void MusicRenderer::renderChord(QPainter& painter, Chord* chord, const QPointF&
             bottomStaff = s;
         }        
         
-        m_style->renderNoteHead( painter, ref.x() + x, ref.y() + /*chord->y() +*/ s->top() + line * s->lineSpacing() / 2, chord->duration(), color );
+        m_style->renderNoteHead( painter, ref.x() + noteX, ref.y() + s->top() + line * s->lineSpacing() / 2, chord->duration(), color );
 
         // render accidentals
         // TODO I think this could really use some improvements
@@ -375,44 +414,178 @@ void MusicRenderer::renderChord(QPainter& painter, Chord* chord, const QPointF&
         if (n->accidentals() != curAccidentals) {
             m_style->renderAccidental( painter, ref.x() + x - 10, ref.y() + /*chord->y() +*/ s->top() + line * s->lineSpacing() / 2, n->accidentals(), color );
         }
+        
+        dots.insert(s, line);
+        
+        if (n->isStartTie()) {
+            // render tie for this note...
+            if (!nextChord) {
+                // figure out what the next chord in this voice is
+                bool afterCurrent = false;
+                for (int e = 0; e < vb->elementCount(); e++) {
+                    if (afterCurrent) {
+                        nextChord = dynamic_cast<Chord*>(vb->element(e));
+                        if (nextChord) break;
+                    } else {
+                        if (vb->element(e) == chord) {
+                            afterCurrent = true;
+                        }
+                    }
+                }
+                if (!nextChord) {
+                    // check the next bar
+                    int nextBar = sheet->indexOfBar(bar)+1;
+                    if (nextBar < sheet->barCount()) {
+                        VoiceBar* nextVB = voice->bar(nextBar);
+                        for (int e = 0; e < nextVB->elementCount(); e++) {
+                            nextChord = dynamic_cast<Chord*>(nextVB->element(e));
+                            if (nextChord) break;
+                        }
+                    }
+                }
+            }
+            
+            // okay, now nextChord is the chord to which the tie should go
+            if (nextChord) {
+                QPointF startPos = bar->position() + QPointF(1 + chord->xScaled() + chord->width(), ypos);
+                QPointF endPos = nextChord->voiceBar()->bar()->position() + QPointF(nextChord->xScaled() - 1, ypos);
+                endPos.setY(startPos.y());
+                QPointF c1a = startPos + QPointF(2, 4);
+                QPointF c2a = endPos + QPointF(-2, 4);
+                QPointF c1b = startPos + QPointF(2, 5);
+                QPointF c2b = endPos + QPointF(-2, 5);
+                
+                QPainterPath p;
+                p.moveTo(startPos);
+                p.cubicTo(c1a, c2a, endPos);
+                p.cubicTo(c2b, c1b, startPos);
+                painter.setPen(Qt::NoPen);//m_style->slurPen(color));
+                painter.setBrush(QBrush(color));
+                painter.drawPath(p);
+            }
+        }
+    }
+    
+    // calculate correct positioning of dots
+    // render dots of notes
+    painter.setPen(m_style->noteDotPen(color));
+    foreach (Staff* s, dots.keys()) {
+        QList<int> lines = dots.values(s);
+        qSort(lines);
 
-        // render dots of notes
-        double dotX = x + 11;
-        painter.setPen(m_style->noteDotPen(color));
-        for (int i = 0; i < chord->dots(); i++) {
-            painter.drawPoint(ref + QPointF(dotX, /*chord->y() +*/ s->top() + line * s->lineSpacing() / 2));
-            dotX += 3;
+        int lastLine = INT_MIN;
+        bool moveGroupDown = true;
+        for (int i = 0; i < lines.size(); i++) {
+            int line = lines[i];
+            if (line % 2 == 0) {
+                line--;
+            }
+            if (line == lastLine) {
+                if (moveGroupDown) {
+                    lines[i-1] += 2;
+                    for (int j = i-2; j >= 0; j--) {
+                        if (lines[j] == lines[j+1]) {
+                            lines[j] += 2;
+                        } else {
+                            break;
+                        }
+                    }
+                } else {
+                    line -= 2;
+                }
+                moveGroupDown = !moveGroupDown;
+            }
+            lines[i] = line;
+            lastLine = line;
+        }
+        
+        foreach (int line, lines) {
+            double dotX = maxNoteX + 11;
+            for (int i = 0; i < chord->dots(); i++) {
+                painter.drawPoint(ref + QPointF(dotX, s->top() + line * s->lineSpacing() / 2));
+                dotX += 3;
+            }
         }
     }
 
     double stemLen = chord->stemLength() * 2;
     if (stemLen != 0.0 && stemLen != -0.0) {
-        double stemX = x + 6;
-        bool stemsUp = chord->stemDirection() == Chord::StemUp;
-        if (!stemsUp) { stemX = x; }
+        double stemX = chord->stemX(xScale);
+        bool stemsUp = chord->stemDirection() == StemUp;
         
         painter.setPen(m_style->stemPen(color));
         if (stemsUp) {
-            painter.drawLine(ref + QPointF(stemX, /*chord->y() +*/ topStaff->top() + (topLine - stemLen) * topStaff->lineSpacing() / 2),
-                             ref + QPointF(stemX, /*chord->y() +*/ bottomStaff->top() + bottomLine * bottomStaff->lineSpacing() / 2));
-            m_style->renderNoteFlags( painter, ref.x() + stemX, ref.y() + /*chord->y() +*/ topStaff->top() + (topLine - stemLen) * topStaff->lineSpacing() / 2, chord->duration(), stemsUp, color );
+            painter.drawLine(ref + QPointF(stemX, chord->stemEndY(xScale)),
+                             ref + QPointF(stemX, bottomStaff->top() + bottomLine * bottomStaff->lineSpacing() / 2));
+            if (chord->beamType(0) == BeamFlag) {
+                m_style->renderNoteFlags( painter, ref.x() + stemX, ref.y() + topStaff->top() + (topLine - stemLen) * topStaff->lineSpacing() / 2, chord->duration(), stemsUp, color );
+            }
         } else {
-            painter.drawLine(ref + QPointF(stemX, /*chord->y() +*/ topStaff->top() + topLine * topStaff->lineSpacing() / 2),
-                             ref + QPointF(stemX, /*chord->y() +*/ bottomStaff->top() + (bottomLine + stemLen) * bottomStaff->lineSpacing() / 2));
-            m_style->renderNoteFlags( painter, ref.x() + stemX, ref.y() + /*chord->y() +*/ bottomStaff->top() + (bottomLine + stemLen) * bottomStaff->lineSpacing() / 2, chord->duration(), stemsUp, color );
+            painter.drawLine(ref + QPointF(stemX, topStaff->top() + topLine * topStaff->lineSpacing() / 2),
+                             ref + QPointF(stemX, chord->stemEndY(xScale)));
+            if (chord->beamType(0) == BeamFlag) {
+                m_style->renderNoteFlags( painter, ref.x() + stemX, ref.y() + bottomStaff->top() + (bottomLine + stemLen) * bottomStaff->lineSpacing() / 2, chord->duration(), stemsUp, color );
+            }
         }
+
+        painter.setPen(QPen(Qt::NoPen));
+        painter.setBrush(QBrush(color));
+        for (int i = 0; i < chord->beamCount(); i++) {
+            if (chord->beamType(i) == BeamStart) {
+                const Chord* endChord = chord->beamEnd(i);
+                
+                QPointF beamStart(chord->stemX(xScale), chord->stemEndY(xScale));
+                QPointF beamEnd(endChord->stemX(xScale), endChord->stemEndY(xScale));
+                if (stemsUp) {
+                    beamStart += QPointF(0, topStaff->lineSpacing() * i);
+                    beamEnd += QPointF(0, topStaff->lineSpacing() * i);
+                } else {
+                    beamStart -= QPointF(0, bottomStaff->lineSpacing() * i);
+                    beamEnd -= QPointF(0, bottomStaff->lineSpacing() * i);
+                }
+
+                
+                QPointF dir(0, (stemsUp ? 1 : -1) * m_style->beamLineWidth());
+                QPointF p[4];
+                p[0] = ref + beamStart;
+                p[1] = ref + beamEnd;
+                p[2] = p[1] + dir;
+                p[3] = p[0] + dir;
+                painter.drawConvexPolygon(p, 4);
+            } else if (chord->beamType(i) == BeamForwardHook || chord->beamType(i) == BeamBackwardHook) {
+                QPointF beamStart(chord->stemX(xScale), chord->stemEndY(xScale));
+                double dir = 6;
+                if (chord->beamType(i) == BeamBackwardHook) dir = -dir;
+                if (stemsUp) {
+                    beamStart += QPointF(0, topStaff->lineSpacing() * i);
+                } else {
+                    beamStart -= QPointF(0, bottomStaff->lineSpacing() * i);
+                }
+                
+                QPointF beamEnd = beamStart + QPointF(dir, dir * chord->beamDirection(xScale));
+                
+                QPointF bdir(0, (stemsUp ? 1 : -1) * m_style->beamLineWidth());
+                QPointF p[4];
+                p[0] = ref + beamStart;
+                p[1] = ref + beamEnd;
+                p[2] = p[1] + bdir;
+                p[3] = p[0] + bdir;
+                painter.drawConvexPolygon(p, 4);                
+            }
+        }
+
     }
 }
 
-void MusicRenderer::renderNote(QPainter& painter, MusicCore::Chord::Duration duration, const QPointF& pos, double stemLength, const QColor& color)
+void MusicRenderer::renderNote(QPainter& painter, Duration duration, const QPointF& pos, double stemLength, const QColor& color)
 {
     m_style->renderNoteHead(painter, pos.x(), pos.y(), duration, color);
 
-    if (duration <= MusicCore::Chord::Half) {
+    if (duration <= HalfNote) {
         painter.setPen(m_style->stemPen(color));
         painter.drawLine(pos + QPointF(6, -stemLength), pos + QPointF(6, 0));
     }
-    if (duration <= MusicCore::Chord::Eighth) {
+    if (duration <= EighthNote) {
         m_style->renderNoteFlags(painter, pos.x()+6, pos.y() - stemLength, duration, true, color);
     }
 }
