@@ -55,6 +55,8 @@
 #include "actions/TimeSignatureAction.h"
 #include "actions/KeySignatureAction.h"
 #include "actions/RemoveBarAction.h"
+#include "actions/TiedNoteAction.h"
+#include "actions/SelectionAction.h"
 
 #include "commands/AddBarsCommand.h"
 
@@ -69,21 +71,24 @@
 #include "core/MusicXmlReader.h"
 #include "core/MusicXmlWriter.h"
 
+#include <algorithm>
+
 using namespace MusicCore;
 
 SimpleEntryTool::SimpleEntryTool( KoCanvasBase* canvas )
     : KoTool( canvas ),
     m_musicshape(0),
-    m_voice(0)
+    m_voice(0),
+    m_selectionStart(-1)
 {
     QActionGroup* actionGroup = new QActionGroup(this);
     connect(actionGroup, SIGNAL(triggered(QAction*)), this, SLOT(activeActionChanged(QAction*)));
 
-    QAction* importAction = new QAction(KIcon("file-import"), i18n("Import"), this);
+    QAction* importAction = new QAction(KIcon("document-import"), i18n("Import"), this);
     addAction("import", importAction);
     connect(importAction, SIGNAL(triggered()), this, SLOT(importSheet()));
 
-    QAction* exportAction = new QAction(KIcon("file-export"), i18n("Export"), this);
+    QAction* exportAction = new QAction(KIcon("document-export"), i18n("Export"), this);
     addAction("export", exportAction);
     connect(exportAction, SIGNAL(triggered()), this, SLOT(exportSheet()));
 
@@ -91,75 +96,75 @@ SimpleEntryTool::SimpleEntryTool( KoCanvasBase* canvas )
     addAction("add_bars", addBars);
     connect(addBars, SIGNAL(triggered()), this, SLOT(addBars()));
 
-    AbstractMusicAction* actionBreveNote = new NoteEntryAction(Chord::Breve, false, this);
+    AbstractMusicAction* actionBreveNote = new NoteEntryAction(BreveNote, false, this);
     addAction("note_breve", actionBreveNote);
     actionGroup->addAction(actionBreveNote);
 
-    AbstractMusicAction* actionWholeNote = new NoteEntryAction(Chord::Whole, false, this);
+    AbstractMusicAction* actionWholeNote = new NoteEntryAction(WholeNote, false, this);
     addAction("note_whole", actionWholeNote);
     actionGroup->addAction(actionWholeNote);
 
-    AbstractMusicAction* actionHalfNote = new NoteEntryAction(Chord::Half, false, this);
+    AbstractMusicAction* actionHalfNote = new NoteEntryAction(HalfNote, false, this);
     addAction("note_half", actionHalfNote);
     actionGroup->addAction(actionHalfNote);
 
-    AbstractMusicAction* actionQuarterNote = new NoteEntryAction(Chord::Quarter, false, this);
+    AbstractMusicAction* actionQuarterNote = new NoteEntryAction(QuarterNote, false, this);
     addAction("note_quarter", actionQuarterNote);
     actionGroup->addAction(actionQuarterNote);
 
-    AbstractMusicAction* actionNote8 = new NoteEntryAction(Chord::Eighth, false, this);
+    AbstractMusicAction* actionNote8 = new NoteEntryAction(EighthNote, false, this);
     addAction("note_eighth", actionNote8);
     actionGroup->addAction(actionNote8);
 
-    AbstractMusicAction* actionNote16 = new NoteEntryAction(Chord::Sixteenth, false, this);
+    AbstractMusicAction* actionNote16 = new NoteEntryAction(SixteenthNote, false, this);
     addAction("note_16th", actionNote16);
     actionGroup->addAction(actionNote16);
 
-    AbstractMusicAction* actionNote32 = new NoteEntryAction(Chord::ThirtySecond, false, this);
+    AbstractMusicAction* actionNote32 = new NoteEntryAction(ThirtySecondNote, false, this);
     addAction("note_32nd", actionNote32);
     actionGroup->addAction(actionNote32);
 
-    AbstractMusicAction* actionNote64 = new NoteEntryAction(Chord::SixtyFourth, false, this);
+    AbstractMusicAction* actionNote64 = new NoteEntryAction(SixtyFourthNote, false, this);
     addAction("note_64th", actionNote64);
     actionGroup->addAction(actionNote64);
 
-    AbstractMusicAction* actionNote128 = new NoteEntryAction(Chord::HundredTwentyEighth, false, this);
+    AbstractMusicAction* actionNote128 = new NoteEntryAction(HundredTwentyEighthNote, false, this);
     addAction("note_128th", actionNote128);
     actionGroup->addAction(actionNote128);
 
-    AbstractMusicAction* actionBreveRest = new NoteEntryAction(Chord::Breve, true, this);
+    AbstractMusicAction* actionBreveRest = new NoteEntryAction(BreveNote, true, this);
     addAction("rest_breve", actionBreveRest);
     actionGroup->addAction(actionBreveRest);
 
-    AbstractMusicAction* actionWholeRest = new NoteEntryAction(Chord::Whole, true, this);
+    AbstractMusicAction* actionWholeRest = new NoteEntryAction(WholeNote, true, this);
     addAction("rest_whole", actionWholeRest);
     actionGroup->addAction(actionWholeRest);
 
-    AbstractMusicAction* actionHalfRest = new NoteEntryAction(Chord::Half, true, this);
+    AbstractMusicAction* actionHalfRest = new NoteEntryAction(HalfNote, true, this);
     addAction("rest_half", actionHalfRest);
     actionGroup->addAction(actionHalfRest);
 
-    AbstractMusicAction* actionQuarterRest = new NoteEntryAction(Chord::Quarter, true, this);
+    AbstractMusicAction* actionQuarterRest = new NoteEntryAction(QuarterNote, true, this);
     addAction("rest_quarter", actionQuarterRest);
     actionGroup->addAction(actionQuarterRest);
 
-    AbstractMusicAction* actionRest8 = new NoteEntryAction(Chord::Eighth, true, this);
+    AbstractMusicAction* actionRest8 = new NoteEntryAction(EighthNote, true, this);
     addAction("rest_eighth", actionRest8);
     actionGroup->addAction(actionRest8);
 
-    AbstractMusicAction* actionRest16 = new NoteEntryAction(Chord::Sixteenth, true, this);
+    AbstractMusicAction* actionRest16 = new NoteEntryAction(SixteenthNote, true, this);
     addAction("rest_16th", actionRest16);
     actionGroup->addAction(actionRest16);
 
-    AbstractMusicAction* actionRest32 = new NoteEntryAction(Chord::ThirtySecond, true, this);
+    AbstractMusicAction* actionRest32 = new NoteEntryAction(ThirtySecondNote, true, this);
     addAction("rest_32nd", actionRest32);
     actionGroup->addAction(actionRest32);
 
-    AbstractMusicAction* actionRest64 = new NoteEntryAction(Chord::SixtyFourth, true, this);
+    AbstractMusicAction* actionRest64 = new NoteEntryAction(SixtyFourthNote, true, this);
     addAction("rest_64th", actionRest64);
     actionGroup->addAction(actionRest64);
 
-    AbstractMusicAction* actionRest128 = new NoteEntryAction(Chord::HundredTwentyEighth, true, this);
+    AbstractMusicAction* actionRest128 = new NoteEntryAction(HundredTwentyEighthNote, true, this);
     addAction("rest_128th", actionRest128);
     actionGroup->addAction(actionRest128);
 
@@ -191,7 +196,15 @@ SimpleEntryTool::SimpleEntryTool( KoCanvasBase* canvas )
     action = new DotsAction(this);
     addAction("dots", action);
     actionGroup->addAction(action);
+    
+    action = new TiedNoteAction(this);
+    addAction("tiednote", action);
+    actionGroup->addAction(action);
 
+    action = new SelectionAction(this);
+    addAction("select", action);
+    actionGroup->addAction(action);
+    
     actionQuarterNote->setChecked(true);
     m_activeAction = actionQuarterNote;
 
@@ -308,35 +321,108 @@ void SimpleEntryTool::deactivate()
 
 void SimpleEntryTool::paint( QPainter& painter, const KoViewConverter& viewConverter )
 {
-    painter.setMatrix( m_musicshape->absoluteTransformation(&viewConverter) * painter.matrix() );
-    KoShape::applyConversion( painter, viewConverter );
-    painter.setClipRect(QRectF(QPointF(0, 0), m_musicshape->size()));
-
     Sheet* sheet = m_musicshape->sheet();
-    for (int i = 0; i < sheet->partCount(); i++) {
-        Part* p = sheet->part(i);
-        if (p->voiceCount() > m_voice) {
-            m_musicshape->renderer()->renderVoice(painter, p->voice(m_voice), Qt::red);
+    int firstSystem = m_musicshape->firstSystem();
+    int lastSystem = m_musicshape->lastSystem();
+    int firstBar = sheet->staffSystem(firstSystem)->firstBar();
+    int lastBar = INT_MAX;
+    if (lastSystem < sheet->staffSystemCount()-1) {
+        lastBar = sheet->staffSystem(lastSystem+1)->firstBar()-1;
+    }
+
+    // somehow check for selections
+    if (m_selectionStart >= 0) {
+        // find first shape
+        MusicShape* shape = m_musicshape;
+        while (shape->predecessor()) shape = shape->predecessor();
+        
+        // now loop over all shapes
+        while (shape) {
+            painter.save();
+            painter.setMatrix( shape->absoluteTransformation(&viewConverter) * painter.matrix() );
+            KoShape::applyConversion( painter, viewConverter );
+            painter.setClipRect(QRectF(QPointF(0, 0), shape->size()));            
+            
+            for (int b = qMax(shape->firstBar(), m_selectionStart); b <= m_selectionEnd && b < sheet->barCount() && b <= shape->lastBar(); b++) {
+                Bar* bar = sheet->bar(b);
+                bool selectedStaff = false;
+                for (int p = 0; p < sheet->partCount(); p++) {
+                    Part* part = sheet->part(p);
+                    for (int s = 0; s < part->staffCount(); s++) {
+                        Staff* staff = part->staff(s);
+                        if (staff == m_selectionStaffStart) {
+                            selectedStaff = true;
+                        }
+                        if (selectedStaff) {
+                            QPointF p1 = bar->position() + QPointF(0, staff->top());
+                            QPointF p2 = QPointF(p1.x() + bar->size(), p1.y() + (staff->lineCount()-1) * staff->lineSpacing());
+                            painter.setBrush(QBrush(Qt::yellow));
+                            painter.setPen(Qt::NoPen);
+                            painter.drawRect(QRectF(p1, p2));
+                        }
+                        if (staff == m_selectionStaffEnd) {
+                            selectedStaff = false;
+                        }
+                    }
+                }
+            }
+            for (int p = 0; p < sheet->partCount(); p++) {
+                Part* part = sheet->part(p);
+                shape->renderer()->renderPart(painter, part, qMax(shape->firstBar(), m_selectionStart), qMin(shape->lastBar(), m_selectionEnd), Qt::black);
+            }
+            shape = shape->successor();
+            painter.restore();
         }
     }
 
+    painter.setMatrix( m_musicshape->absoluteTransformation(&viewConverter) * painter.matrix() );
+    KoShape::applyConversion( painter, viewConverter );
+    painter.setClipRect(QRectF(QPointF(0, 0), m_musicshape->size()));
+        
+    if (m_activeAction->isVoiceAware()) {
+        for (int i = 0; i < sheet->partCount(); i++) {
+            Part* p = sheet->part(i);
+            if (p->voiceCount() > m_voice) {
+                m_musicshape->renderer()->renderVoice(painter, p->voice(m_voice), firstBar, lastBar, Qt::red);
+            }
+        }
+    }
+    
     m_activeAction->renderPreview(painter, m_point);
 }
 
 void SimpleEntryTool::mousePressEvent( KoPointerEvent* event )
 {
+    if(!m_musicshape->boundingRect().contains(event->point)) {
+        QRectF area(event->point, QSizeF(1,1));
+        foreach(KoShape *shape, m_canvas->shapeManager()->shapesAt(area, true)) {
+            MusicShape *musicshape = dynamic_cast<MusicShape*>(shape);
+            if(musicshape) {
+                m_musicshape->update();
+                m_musicshape = musicshape;
+                m_musicshape->update();
+                break; // stop looking.
+            }
+        }
+    }
+    
     QPointF p = m_musicshape->absoluteTransformation(0).inverted().map(event->point);
     Sheet *sheet = m_musicshape->sheet();
 
+    p.setY(p.y() + sheet->staffSystem(m_musicshape->firstSystem())->top());
+
+    kDebug() << "pos:" << p;
     // find closest staff system
     StaffSystem* system = 0;
-    for (int i = 0; i < sheet->staffSystemCount(); i++) {
+    for (int i = m_musicshape->firstSystem(); i <= m_musicshape->lastSystem() && i < sheet->staffSystemCount(); i++) {
         StaffSystem* ss = sheet->staffSystem(i);
+        kDebug() << "system" << i << "has top" << ss->top();
         if (ss->top() > p.y()) break;
         system = ss;
     }
 
     if(system == 0) {
+        kDebug() << "no staff system found";
         return;
     }
 
@@ -405,15 +491,108 @@ void SimpleEntryTool::mousePressEvent( KoPointerEvent* event )
         m_contextMenuStaff = closestStaff;
         m_contextMenuBar = barIdx;
         m_contextMenuPoint = point;
+        event->ignore();
     } else {
         m_activeAction->mousePress(closestStaff, barIdx, point);
+        event->accept();
     }
 }
 
 void SimpleEntryTool::mouseMoveEvent( KoPointerEvent* event )
 {
+    if(!m_musicshape->boundingRect().contains(event->point)) {
+        QRectF area(event->point, QSizeF(1,1));
+        foreach(KoShape *shape, m_canvas->shapeManager()->shapesAt(area, true)) {
+            MusicShape *musicshape = dynamic_cast<MusicShape*>(shape);
+            if(musicshape) {
+                if (musicshape->sheet() == m_musicshape->sheet() || !event->buttons()) {
+                    m_musicshape->update();
+                    m_musicshape = musicshape;
+                    m_musicshape->update();
+                    break; // stop looking.
+                }
+            }
+        }
+    }
+    
     m_point = m_musicshape->absoluteTransformation(0).inverted().map(event->point);
     m_canvas->updateCanvas(QRectF(QPointF(event->point.x() - 100, event->point.y() - 100), QSizeF(200, 200)));
+    if (event->buttons()) {
+        QPointF p = m_musicshape->absoluteTransformation(0).inverted().map(event->point);
+        Sheet *sheet = m_musicshape->sheet();
+        
+        p.setY(p.y() + sheet->staffSystem(m_musicshape->firstSystem())->top());
+        // find closest staff system
+        StaffSystem* system = 0;
+        for (int i = m_musicshape->firstSystem(); i <= m_musicshape->lastSystem() && i < sheet->staffSystemCount(); i++) {
+            StaffSystem* ss = sheet->staffSystem(i);
+            if (ss->top() > p.y()) break;
+            system = ss;
+        }
+        
+        if(system == 0) {
+            return;
+        }
+        
+        // find closest staff
+        Staff* closestStaff = 0;
+        double dist = 1e99;
+        double yrel = p.y() - system->top();
+        for (int prt = 0; prt < sheet->partCount(); prt++) {
+            Part* part = sheet->part(prt);
+            for (int st = 0; st < part->staffCount(); st++) {
+                Staff* staff = part->staff(st);
+                double top = staff->top();
+                double bot = staff->top() + (staff->lineCount() - 1) * staff->lineSpacing();
+                if (fabs(top - yrel) < dist) {
+                    closestStaff = staff;
+                    dist = fabs(top - yrel);
+                }
+                if (fabs(bot - yrel) < dist) {
+                    closestStaff = staff;
+                    dist = fabs(bot - yrel);
+                }
+            }
+        }
+        
+        //    int line = closestStaff->line(yrel - closestStaff->top());
+        //    kDebug() << "line: " << line << endl;
+        
+        Part* part = closestStaff->part();
+        for (int i = part->voiceCount(); i <= m_voice; i++) {
+            part->addVoice();
+        }
+        
+        // find correct bar
+        Bar* bar = 0;
+        int barIdx = -1;
+        bool inPrefix = false;
+        for (int b = system->firstBar(); b < sheet->barCount(); b++) {
+            Bar* bb = sheet->bar(b);
+            if (bb->position().x() <= p.x() && bb->position().x() + bb->size() >= p.x()) {
+                bar = bb;
+                barIdx = b;
+                break;
+            }
+            if (bb->prefixPosition().x() <= p.x() && bb->prefixPosition().x() + bb->prefix() >= p.x()) {
+                bar = bb;
+                barIdx = b;
+                inPrefix = true;
+                break;
+            }
+        }
+        
+        if (!bar) return;
+        
+        QPointF point;
+        if (inPrefix) {
+            point = QPointF(p.x() - bar->prefixPosition().x() - bar->prefix(), yrel - closestStaff->top());
+        } else {
+            point = QPointF((p.x() - bar->position().x()) / bar->scale(), yrel - closestStaff->top());
+        }
+        
+        m_activeAction->mouseMove(closestStaff, barIdx, point);
+    }
 }
 
 void SimpleEntryTool::mouseReleaseEvent( KoPointerEvent* )
@@ -437,13 +616,18 @@ QWidget * SimpleEntryTool::createOptionWidget()
 
 void SimpleEntryTool::activeActionChanged(QAction* action)
 {
+    bool oldVoiceAware = m_activeAction->isVoiceAware();
     m_activeAction = qobject_cast<AbstractMusicAction*>(action);
+    if (m_activeAction->isVoiceAware() != oldVoiceAware) {
+        m_musicshape->update();
+        reinterpret_cast<SimpleEntryWidget*>(optionWidget())->setVoiceListEnabled(m_activeAction->isVoiceAware());
+    }
 }
 
 void SimpleEntryTool::voiceChanged(int voice)
 {
     m_voice = voice;
-    m_musicshape->repaint();
+    m_musicshape->update();
 }
 
 void SimpleEntryTool::addBars()
@@ -471,6 +655,42 @@ int SimpleEntryTool::voice()
     return m_voice;
 }
 
+void SimpleEntryTool::setSelection(int firstBar, int lastBar, Staff* startStaff, Staff* endStaff)
+{
+    kDebug() << "firstBar:" << firstBar << "lastBar:" << lastBar;
+    m_selectionStart = firstBar;
+    m_selectionEnd = lastBar;
+    m_selectionStaffStart = startStaff;
+    m_selectionStaffEnd = endStaff;
+    bool foundEnd = false;
+    Sheet* sheet = m_musicshape->sheet();
+    for (int p = 0; p < sheet->partCount(); p++) {
+        Part* part = sheet->part(p);
+        for (int s = 0; s < part->staffCount(); s++) {
+            Staff* staff = part->staff(s);
+            if (staff == m_selectionStaffStart) {
+                if (foundEnd) {
+                    std::swap(m_selectionStaffStart, m_selectionStaffEnd);
+                }
+                break;
+            }
+            if (staff == m_selectionStaffEnd) {
+                foundEnd = true;
+            }
+        }
+    }
+    MusicShape* shape = m_musicshape;
+    while (shape) {
+        shape->update();
+        shape = shape->predecessor();
+    }
+    shape = m_musicshape->successor();
+    while (shape) {
+        shape->update();
+        shape = shape->successor();
+    }
+}
+
 void SimpleEntryTool::importSheet()
 {
     QString file = KFileDialog::getOpenFileName(KUrl(), "*xml|MusicXML files (*.xml)", 0, "Import");
@@ -483,8 +703,8 @@ void SimpleEntryTool::importSheet()
     kDebug() << e.localName() << e.nodeName();
     Sheet* sheet = MusicXmlReader(0).loadSheet(doc.documentElement());
     if (sheet) {
-        m_musicshape->setSheet(sheet);
-        m_musicshape->repaint();
+        m_musicshape->setSheet(sheet, 0);
+        m_musicshape->update();
     }
 }
 
