@@ -19,8 +19,11 @@
 #include "AbstractMusicAction.h"
 #include "../SimpleEntryTool.h"
 
+#include <QPainter>
+
 AbstractMusicAction::AbstractMusicAction(const QIcon& icon, const QString& text, SimpleEntryTool* tool)
     : QAction(icon, text, tool)
+    , m_isVoiceAware(false)
     , m_tool(tool)
 {
     setCheckable(true);
@@ -28,6 +31,7 @@ AbstractMusicAction::AbstractMusicAction(const QIcon& icon, const QString& text,
 
 AbstractMusicAction::AbstractMusicAction(const QString& text, SimpleEntryTool* tool)
     : QAction(text, tool)
+    , m_isVoiceAware(false)
     , m_tool(tool)
 {
     setCheckable(true);
@@ -40,4 +44,13 @@ void AbstractMusicAction::renderPreview(QPainter& painter, const QPointF& point)
     Q_UNUSED( point );
 }
 
+bool AbstractMusicAction::isVoiceAware()
+{
+    return m_isVoiceAware;
+}
+
+void AbstractMusicAction::mouseMove(MusicCore::Staff*, int, const QPointF&)
+{
+}
+
 #include "AbstractMusicAction.moc"
