@@ -27,6 +27,7 @@
 #include "dialogs/CreateNewBookmarkDialog.h"
 #include "dialogs/SelectBookmarkDialog.h"
 #include "dialogs/InsertCharacter.h"
+#include "dialogs/FontDia.h"
 #include "commands/TextCommandBase.h"
 #include "commands/ChangeListCommand.h"
 
@@ -51,6 +52,7 @@
 #include <KoBookmark.h>
 #include <KoBookmarkManager.h>
 #include <KoListStyle.h>
+#include <KoStyleManager.h>
 #include <KoXmlWriter.h>
 
 #include <kdebug.h>
@@ -75,7 +77,6 @@
 #include <QTextLayout>
 #include <QUndoCommand>
 #include <KoGenStyles.h>
-#include <KoSavingContext.h>
 #include <KoShapeSavingContext.h>
 
 static bool hit(const QKeySequence &input, KStandardShortcut::StandardShortcut shortcut) {
@@ -120,7 +121,10 @@ TextTool::TextTool(KoCanvasBase *canvas)
     m_allowAddUndoCommand(true),
     m_trackChanges(false),
     m_allowResourceProviderUpdates(true),
+    m_needSpellChecking(true),
+    m_processingKeyPress(false),
     m_prevCursorPosition(-1),
+    m_spellcheckPlugin(0),
     m_currentCommand(0),
     m_currentCommandHasChildren(false),
     m_specialCharacterDocker(0)
@@ -149,21 +153,21 @@ TextTool::TextTool(KoCanvasBase *canvas)
     connect( m_actionFormatStrikeOut, SIGNAL(triggered(bool)), &m_selectionHandler, SLOT(strikeOut(bool)) );
 
     QActionGroup *alignmentGroup = new QActionGroup(this);
-    m_actionAlignLeft  = new QAction(KIcon("text-left"), i18n("Align Left"), this);
+    m_actionAlignLeft  = new QAction(KIcon("format-justify-left"), i18n("Align Left"), this);
     addAction("format_alignleft", m_actionAlignLeft );
     m_actionAlignLeft->setShortcut(Qt::CTRL + Qt::Key_L);
     m_actionAlignLeft->setCheckable(true);
     alignmentGroup->addAction(m_actionAlignLeft);
     connect(m_actionAlignLeft, SIGNAL(triggered(bool)), this, SLOT(alignLeft()));
 
-    m_actionAlignRight  = new QAction(KIcon("text-right"), i18n("Align Right"), this);
+    m_actionAlignRight  = new QAction(KIcon("format-justify-right"), i18n("Align Right"), this);
     addAction("format_alignright", m_actionAlignRight );
     m_actionAlignRight->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_R);
     m_actionAlignRight->setCheckable(true);
     alignmentGroup->addAction(m_actionAlignRight);
     connect(m_actionAlignRight, SIGNAL(triggered(bool)), this, SLOT(alignRight()));
 
-    m_actionAlignCenter  = new QAction(KIcon("text-center"), i18n("Align Center"), this);
+    m_actionAlignCenter  = new QAction(KIcon("format-justify-center"), i18n("Align Center"), this);
     addAction("format_aligncenter", m_actionAlignCenter );
     m_actionAlignCenter->setShortcut(Qt::CTRL + Qt::ALT + Qt::Key_C);
     m_actionAlignCenter->setCheckable(true);
@@ -177,12 +181,12 @@ TextTool::TextTool(KoCanvasBase *canvas)
     alignmentGroup->addAction(m_actionAlignBlock);
     connect(m_actionAlignBlock, SIGNAL(triggered(bool)), this, SLOT(alignBlock()));
 
-    m_actionFormatSuper = new QAction(KIcon("text-super"), i18n("Superscript"), this);
+    m_actionFormatSuper = new QAction(KIcon("format-text-superscript"), i18n("Superscript"), this);
     addAction("format_super", m_actionFormatSuper );
     m_actionFormatSuper->setCheckable(true);
     connect(m_actionFormatSuper, SIGNAL(triggered(bool)), this, SLOT(superScript(bool)));
 
-    m_actionFormatSub = new QAction(KIcon("text-sub"), i18n("Subscript"), this);
+    m_actionFormatSub = new QAction(KIcon("format-text-subscript"), i18n("Subscript"), this);
     addAction("format_sub", m_actionFormatSub );
     m_actionFormatSub->setCheckable(true);
     connect(m_actionFormatSub, SIGNAL(triggered(bool)), this, SLOT(subScript(bool)));
@@ -226,15 +230,15 @@ TextTool::TextTool(KoCanvasBase *canvas)
     // ----------------------- More format actions, for the toolbar only
     QActionGroup* spacingActionGroup = new QActionGroup( this );
     spacingActionGroup->setExclusive( true );
-    m_actionFormatSpacingSingle = new KToggleAction( i18n( "Line Spacing 1" ), "spacesimple", Qt::CTRL + Qt::Key_1,
+    m_actionFormatSpacingSingle = new KToggleAction( i18n( "Line Spacing 1" ), "format-line-spacing-simple", Qt::CTRL + Qt::Key_1,
             this, SLOT( textSpacingSingle() ),
             actionCollection(), "format_spacingsingle" );
     m_actionFormatSpacingSingle->setActionGroup( spacingActionGroup );
-    m_actionFormatSpacingOneAndHalf = new KToggleAction( i18n( "Line Spacing 1.5" ), "spacedouble", Qt::CTRL + Qt::Key_5,
+    m_actionFormatSpacingOneAndHalf = new KToggleAction( i18n( "Line Spacing 1.5" ), "format-line-spacing-double", Qt::CTRL + Qt::Key_5,
             this, SLOT( textSpacingOneAndHalf() ),
             actionCollection(), "format_spacing15" );
     m_actionFormatSpacingOneAndHalf->setActionGroup( spacingActionGroup );
-    m_actionFormatSpacingDouble = new KToggleAction( i18n( "Line Spacing 2" ), "spacetriple", Qt::CTRL + Qt::Key_2,
+    m_actionFormatSpacingDouble = new KToggleAction( i18n( "Line Spacing 2" ), "format-line-spacing-triple", Qt::CTRL + Qt::Key_2,
             this, SLOT( textSpacingDouble() ),
             actionCollection(), "format_spacingdouble" );
     m_actionFormatSpacingDouble->setActionGroup( spacingActionGroup );
@@ -304,6 +308,7 @@ action->setShortcut( Qt::CTRL+ Qt::Key_T);
 
     action = new QAction(i18n("Bookmark..."), this);
     //action->setIcon(KIcon("bookmark-new"));
+    action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_G );
     addAction("add_bookmark", action);
     connect(action, SIGNAL(triggered()), this, SLOT( addBookmark() ));
 
@@ -318,7 +323,7 @@ action->setShortcut( Qt::CTRL+ Qt::Key_T);
     action->setShortcut( Qt::ALT + Qt::CTRL + Qt::Key_F);
     action->setToolTip( i18n( "Change character size, font, boldface, italics etc." ) );
     action->setWhatsThis( i18n( "Change the attributes of the currently selected characters." ) );
-    connect(action, SIGNAL(triggered()), &m_selectionHandler, SLOT( selectFont() ));
+    connect(action, SIGNAL(triggered()), this, SLOT( selectFont() ));
 
     m_actionFormatFontSize = new KFontSizeAction( i18n( "Font Size" ), this);
     addAction("format_fontsize", m_actionFormatFontSize );
@@ -340,7 +345,15 @@ action->setShortcut( Qt::CTRL+ Qt::Key_T);
             kWarning(32500) << "Duplicate id for textEditingPlugin, ignoring one! (" << factory->id() << ")\n";
             continue;
         }
-        m_textEditingPlugins.insert(factory->id(), factory->create());
+        QString factoryId = factory->id();
+        KoTextEditingPlugin *plugin = factory->create();
+        if (factoryId == "spellcheck") {
+            kDebug(32500) << "KOffice SpellCheck plugin found";
+            m_spellcheckPlugin = plugin;
+            connect(m_canvas->resourceProvider(), SIGNAL(resourceChanged(int, const QVariant &)),
+                m_spellcheckPlugin, SLOT(resourceChanged(int, const QVariant &)));
+        }
+        m_textEditingPlugins.insert(factory->id(), plugin);
     }
 
     foreach (KoTextEditingPlugin* plugin, m_textEditingPlugins.values()) {
@@ -405,6 +418,7 @@ action->setShortcut( Qt::CTRL+ Qt::Key_T);
 
     connect(&m_selectionHandler, SIGNAL(startMacro(const QString&)), this, SLOT(startMacro(const QString&)));
     connect(&m_selectionHandler, SIGNAL(stopMacro()), this, SLOT(stopMacro()));
+    connect(m_canvas->shapeManager()->selection(), SIGNAL(selectionChanged()), this, SLOT(shapeAddedToCanvas()));
 }
 
 TextTool::~TextTool() {
@@ -453,7 +467,6 @@ void TextTool::paint( QPainter &painter, const KoViewConverter &converter) {
     }
     painter.setPen(pen);
     const int posInParag = m_caret.position() - block.position();
-    KoTextDocumentLayout::updateTabsForLine(block, block.layout()->lineForTextPosition(posInParag).lineNumber());
     block.layout()->drawCursor(&painter, QPointF(0,0), posInParag);
 }
 
@@ -530,16 +543,20 @@ void TextTool::mousePressEvent( KoPointerEvent *event ) {
             }
             new KRun(m_caret.charFormat().anchorHref(), 0);
         }
+        else
+            event->ignore(); // allow the event to be used by another
     }
 }
 
 void TextTool::setShapeData(KoTextShapeData *data) {
     bool docChanged = data == 0 || m_textShapeData == 0 || m_textShapeData->document() != data->document();
     if(m_textShapeData && docChanged)
-        disconnect(m_textShapeData->document(), SIGNAL(undoAvailable(bool)), this, SLOT(addUndoCommand()));
+        disconnect(m_textShapeData->document(), SIGNAL(undoCommandAdded()), this, SLOT(addUndoCommand()));
     m_textShapeData = data;
-    if(m_textShapeData && docChanged) {
-        connect(m_textShapeData->document(), SIGNAL(undoAvailable(bool)), this, SLOT(addUndoCommand()));
+    if (m_textShapeData == 0)
+        return;
+    if(docChanged) {
+        connect(m_textShapeData->document(), SIGNAL(undoCommandAdded()), this, SLOT(addUndoCommand()));
         m_caret = QTextCursor(m_textShapeData->document());
 
         if(m_textShape->demoText()) {
@@ -548,11 +565,17 @@ void TextTool::setShapeData(KoTextShapeData *data) {
         }
         m_textShapeData->document()->setUndoRedoEnabled(true); // allow undo history
     }
-    if(m_textShapeData && m_trackChanges) {
+    if(m_trackChanges) {
         if(m_changeTracker == 0)
             m_changeTracker = new ChangeTracker(this);
         m_changeTracker->setDocument(m_textShapeData->document());
     }
+    if(m_spellcheckPlugin)
+        m_spellcheckPlugin->checkSection(m_textShapeData->document(), 0, 0);
+
+    KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*> (m_textShapeData->document()->documentLayout());
+    if(lay && lay->styleManager() == 0) // this means there is no (ko)document-wide stylemanager.
+        lay->setStyleManager( new KoStyleManager(m_textShapeData));
 }
 
 void TextTool::updateSelectionHandler() {
@@ -595,8 +618,7 @@ void TextTool::copy() const {
     buffer.open( QIODevice::WriteOnly );
     KoXmlWriter writer( &buffer );
     KoGenStyles mainStyles;
-    KoSavingContext savingContext( mainStyles, KoSavingContext::Store );
-    KoShapeSavingContext context (writer, savingContext);
+    KoShapeSavingContext context (writer, mainStyles);
     //writer.startDocument( "foobar" );
     m_textShapeData->saveOdf(context, from, to);
     //writer.endDocument();
@@ -610,8 +632,8 @@ kDebug() <<"output:" << QString::fromUtf8(bytes);
 bool TextTool::paste() {
     const QMimeData *data = QApplication::clipboard()->mimeData();
 
-    if(data->hasFormat("application/vnd.oasi.opendocument.text")) {
-        kDebug() <<"TODO load ODF style text!";
+    if(data->hasFormat("application/vnd.oasis.opendocument.text")) {
+        kDebug(32500) <<"TODO load ODF style text!";
         // TODO create a KoTextShapeData::loadOdf() method and call it here.
     }
     else if(data->hasHtml()) {
@@ -658,6 +680,7 @@ void TextTool::mouseDoubleClickEvent( KoPointerEvent *event ) {
         m_caret.movePosition(QTextCursor::WordRight, QTextCursor::KeepAnchor);
 
     repaintSelection();
+    updateSelectionHandler();
 }
 
 void TextTool::mouseMoveEvent( KoPointerEvent *event ) {
@@ -730,7 +753,7 @@ void TextTool::keyPressEvent(QKeyEvent *event) {
     else {
         // check for shortcuts.
         QKeySequence item(event->key() | ((Qt::ControlModifier | Qt::AltModifier) & event->modifiers()));
-        if(hit(item, KStandardShortcut::Home))
+        if(hit(item, KStandardShortcut::Begin))
             // Goto beginning of the document. Default: Ctrl-Home
             destinationPosition = 0;
         else if(hit(item, KStandardShortcut::End)) {
@@ -760,7 +783,8 @@ void TextTool::keyPressEvent(QKeyEvent *event) {
             fn->setText("Lorem ipsum dolor sit amet, XgXgectetuer adiXiscing elit, sed diam nonummy");
             fn->setLabel("1");
             KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*> (m_textShapeData->document()->documentLayout());
-           lay->inlineObjectTextManager()->insertInlineObject(m_caret, fn);
+            Q_ASSERT(lay);
+            lay->inlineObjectTextManager()->insertInlineObject(m_caret, fn);
         }
 #endif
         else if((event->modifiers() & (Qt::ControlModifier | Qt::AltModifier)) || event->text().length() == 0) {
@@ -768,6 +792,7 @@ void TextTool::keyPressEvent(QKeyEvent *event) {
             return;
         }
         else if(event->text().at(0) == '\r') {
+            startKeyPressMacro();
             if (m_caret.hasSelection())
                 m_selectionHandler.deleteInlineObjects();
             QTextBlockFormat format = m_caret.blockFormat();
@@ -794,7 +819,8 @@ void TextTool::keyPressEvent(QKeyEvent *event) {
             editingPluginEvents();
             ensureCursorVisible();
         }
-        else if(! (event->text().length() == 1 && !event->text().at(0).isPrint())) { // insert the text
+        else if(event->key() == Qt::Key_Tab || ! (event->text().length() == 1 && !event->text().at(0).isPrint())) { // insert the text
+            startKeyPressMacro();
             if (m_caret.hasSelection())
                 m_selectionHandler.deleteInlineObjects();
             m_prevCursorPosition = m_caret.position();
@@ -996,6 +1022,18 @@ void TextTool::activate (bool temporary) {
             break;
         }
     }
+
+    if (m_needSpellChecking && m_spellcheckPlugin) {
+        foreach (KoShape *shape, m_canvas->shapeManager()->shapes()) {
+            TextShape *textShape = dynamic_cast<TextShape*>(shape);
+            if (textShape) {
+                KoTextShapeData *textShapeData = static_cast<KoTextShapeData*>(textShape->userData());
+                m_spellcheckPlugin->checkSection(textShapeData->document(), 0, -1);
+            }
+        }
+        m_needSpellChecking = false;
+    }
+
     m_textShape->repaint();
 
     updateSelectionHandler();
@@ -1038,7 +1076,6 @@ void TextTool::repaintCaret() {
         QRectF repaintRect;
         if(tl.isValid()) {
             repaintRect = tl.rect();
-            KoTextDocumentLayout::updateTabsForLine(block, tl.lineNumber());
             repaintRect.setX(tl.cursorToX(m_caret.position() - block.position()) - 2);
             repaintRect.setWidth(6);
         }
@@ -1085,7 +1122,6 @@ QRectF TextTool::textRect(int startPosition, int endPosition) const {
     QTextLine line1 = block.layout()->lineForTextPosition(startPosition - block.position());
     if(! line1.isValid())
         return QRectF();
-    KoTextDocumentLayout::updateTabsForLine(block, line1.lineNumber());
     double startX = line1.cursorToX(startPosition - block.position());
     if(startPosition == endPosition)
         return QRectF(startX, line1.y(), 1, line1.height());
@@ -1094,7 +1130,6 @@ QRectF TextTool::textRect(int startPosition, int endPosition) const {
     QTextLine line2 = block2.layout()->lineForTextPosition(endPosition - block2.position());
     if(! line2.isValid())
         return QRectF();
-    KoTextDocumentLayout::updateTabsForLine(block2, line2.lineNumber());
     double endX = line2.cursorToX(endPosition - block2.position());
 
     if(line1.textStart() + block.position() == line2.textStart()+ block2.position() )
@@ -1152,9 +1187,10 @@ void TextTool::addUndoCommand() {
             if(m_document.isNull())
                 return;
             if(! m_tool.isNull()) {
+                m_tool->stopMacro();
                 m_tool->m_allowAddUndoCommand = false;
-                if(m_tool->m_changeTracker)
-                    m_tool->m_changeTracker->notifyForUndo();
+               if(m_tool->m_changeTracker && !m_tool->m_canvas->resourceProvider()->boolResource(KoCanvasResource::DocumentIsLoading))
+                   m_tool->m_changeTracker->notifyForUndo();
                 m_document->undo(&m_tool->m_caret);
             }
             else
@@ -1166,9 +1202,10 @@ void TextTool::addUndoCommand() {
         void redo () {
             if(m_document.isNull())
                 return;
+
             if(! m_tool.isNull()) {
                 m_tool->m_allowAddUndoCommand = false;
-                 m_document->redo(&m_tool->m_caret);
+                m_document->redo(&m_tool->m_caret);
             }
             else
                 m_document->redo();
@@ -1181,6 +1218,8 @@ void TextTool::addUndoCommand() {
     };
     if(m_currentCommand) {
         new UndoTextCommand(m_textShapeData->document(), this, m_currentCommand);
+        if (! m_currentCommandHasChildren)
+            m_canvas->addCommand(m_currentCommand);
         m_currentCommandHasChildren = true;
     }
     else
@@ -1270,7 +1309,7 @@ void TextTool::decreaseIndent() {
 
 void TextTool::textDefaultFormat() {
     // TODO
-    kDebug() <<"TextTool::textDefaultFormat";
+    kDebug(32500) <<"TextTool::textDefaultFormat";
 }
 
 void TextTool::insertIndexMarker() {
@@ -1445,15 +1484,15 @@ void TextTool::startMacro(const QString &title) {
     };
     m_currentCommand = new MacroCommand(title);
     m_currentCommandHasChildren = false;
+    m_processingKeyPress = false;
 }
 
 void TextTool::stopMacro() {
     if(m_currentCommand == 0) return;
-    if(m_currentCommandHasChildren)
-        m_canvas->addCommand(m_currentCommand);
-    else
+    if (! m_currentCommandHasChildren)
         delete m_currentCommand;
     m_currentCommand = 0;
+    m_processingKeyPress = false;
 }
 
 void TextTool::showStyleManager() {
@@ -1567,6 +1606,27 @@ void TextTool::insertSpecialCharacter() {
     m_specialCharacterDocker->show();
 }
 
+void TextTool::selectFont() {
+    FontDia *fontDlg = new FontDia( m_caret.charFormat());
+    fontDlg->exec();
+    fontDlg->style().applyStyle(&m_caret);
+    delete fontDlg;
+}
+
+void TextTool::shapeAddedToCanvas() {
+    if (m_textShape) {
+        KoSelection *selection = m_canvas->shapeManager()->selection();
+        KoShape *shape = selection->firstSelectedShape();
+        if (shape != m_textShape) {
+            // this situation applies when someone, not us, changed the selection by selecting another
+            // text shape. Possibly by adding one.
+            // Deselect the new shape again, so we can keep editing what we were already editing
+            selection->select(m_textShape);
+            selection->deselect(shape);
+        }
+    }
+}
+
 // ---------- editing plugins methods.
 void TextTool::editingPluginEvents() {
     if(m_prevCursorPosition == -1 || m_prevCursorPosition == m_caret.position())
@@ -1606,4 +1666,27 @@ void TextTool::setTextColor(const KoColor &color)
     m_selectionHandler.setTextColor(color.toQColor());
 }
 
+
+void TextTool::startKeyPressMacro() {
+/* we have a little state machine here;
+    As soon as the user presses a key (i.e. we enter the keyPressEvent) this method should be
+    called and we make sure that all commands from that point on are combined into one so things like
+    spell checking will not create extra undo states :)  [state a]
+    As soon as the user does a different action, like executing a menu option, we create new undo states
+    again, separating them into different user-undoable actions.  [state b]
+
+    Then there is the 'macro' function that plugins etc can start;  which is [state c].
+*/
+
+    if (m_currentCommand) {
+        if (m_processingKeyPress) // already have a key-press macro
+            return;
+        stopMacro();
+    }
+
+    startMacro(i18n("Key press"));
+    m_processingKeyPress = true;
+}
+
+
 #include "TextTool.moc"
