@@ -837,235 +837,6 @@ void TestDocumentLayout::testNonBreakableLines() {
     QCOMPARE(l->lineAt(0).y(), 110.);
 }
 
-void TestDocumentLayout::testDefaultTabs() {
-    initForNewTest("Foo\tBar\ta slightly longer text\tend.");
-    // test the indents to be based on the default tab positions
-    shape1->setSize(QSizeF(400, 1000));
-    m_textLayout->setTabSpacing(80.0);
-    layout->layout();
-
-    QTextBlock block = doc->begin();
-    KoTextBlockData *data = dynamic_cast<KoTextBlockData*> (block.userData());
-    QVERIFY(data);
-    QTextLayout *lay = block.layout();
-    QVERIFY(lay);
-    QCOMPARE(lay->lineCount(), 1);
-
-    QTextOption textOption = lay->textOption();
-    textOption.setTabArray(data->tabLineData()[0].tabs);
-    lay->setTextOption(textOption);
-
-    QTextLine line = lay->lineAt(0);
-    QCOMPARE(line.cursorToX(4), 80.); // default tab is 80
-    QCOMPARE(line.cursorToX(8), 160.);
-    QCOMPARE(line.cursorToX(31), 320.);
-}
-
-void TestDocumentLayout::testTabs() {
-    initForNewTest("Foo\tBar.");
-    KoParagraphStyle style;
-    QList<KoText::Tab> tabs;
-    KoText::Tab tab;
-    tab.position = 150;
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    QTextBlock block = doc->begin();
-    style.applyStyle(block);
-
-    m_textLayout->start();
-    QTextLayout *lay = block.layout();
-    QVERIFY(lay);
-    lay->beginLayout();
-    QTextLine line = lay->createLine();
-    line.setLineWidth(200.);
-    KoTextBlockData::TabLineData tabData = m_textLayout->applyTabs(line);
-    QVERIFY(line.naturalTextWidth() > 150);
-    QCOMPARE(tabData.tabs[0], 150.);
-}
-
-void TestDocumentLayout::testMultilineTab() {
-    initForNewTest(loremIpsum.left(20) +"\tBar.");
-    // test if this works on the second line.
-
-    QTextLayout *lay = doc->begin().layout();
-    QVERIFY(lay);
-    m_textLayout->setTabSpacing(80.0);
-    m_textLayout->start();
-    lay->beginLayout();
-    QTextLine line = lay->createLine();
-    line.setLineWidth(200.);
-    KoTextBlockData::TabLineData tabData = m_textLayout->applyTabs(line);
-    QCOMPARE(tabData.tabs.count(), 2);
-    QCOMPARE(tabData.tabs[0], 80.);
-    lay->endLayout();
-
-    KoParagraphStyle style;
-    QList<KoText::Tab> tabs;
-    KoText::Tab tab;
-    tab.position = 150;
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    QTextBlock block = doc->begin();
-    style.applyStyle(block);
-
-    m_textLayout->start();
-    lay->beginLayout();
-    line = lay->createLine();
-    QVERIFY(line.isValid());
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QCOMPARE(tabData.tabs.count(), 1);
-    QCOMPARE(tabData.tabs[0], 150.);
-    lay->endLayout();
-}
-
-void TestDocumentLayout::testRightTab() {
-    initForNewTest("Foo\t" + loremIpsum.left(32) + "\tBar baz\tText\tEnd\n");
-    KoParagraphStyle style;
-    QList<KoText::Tab> tabs;
-    KoText::Tab tab;
-    tab.position = 190;
-    tab.type = KoText::RightTab;
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    QTextBlock block = doc->begin();
-    style.applyStyle(block);
-    QVERIFY(block.blockFormat().hasProperty(KoParagraphStyle::TabPositions)); // verify that applying works
-
-    /*
-     I expect the output to be:
-        Foo Lorem ipsum dolor sit amet, XgXgectetuer
-        adiXiscing elit                  Bar Baz
-        Text                                 End
-
-     a) tab replaced with a single space due to the text not fitting before the tab.
-     b) tab takes space so the text until the 3th tab fits to the tab pos.
-     c) tab is after last tab (both auto and defined) and thus moves text to start of next line.
-     d) tab takes space so text until enter fits to tab pos.
-     */
-
-    m_textLayout->start();
-    QTextLayout *lay = doc->begin().layout();
-    QVERIFY(lay);
-    lay->beginLayout();
-    QTextLine line = lay->createLine();
-    line.setLineWidth(200.);
-    KoTextBlockData::TabLineData tabData = m_textLayout->applyTabs(line);
-    double x = line.cursorToX(4);
-    QVERIFY(x + 2 < line.cursorToX(5)); // tab takes at least 2 pt (i.e. is converted to a space)
-    QVERIFY(x + 8 > line.cursorToX(5)); // tab takes at max 8 pt (i.e. is not taking more than a space)
-
-    line = lay->createLine();
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QVERIFY(tabData.tabs.count() >= 2);
-    QCOMPARE(tabData.tabLength.count(), tabData.tabs.count());
-    double wordLengh = line.cursorToX(44) - line.cursorToX(37);
-    QCOMPARE(tabData.tabs[0] + wordLengh, 190.);
-
-    line = lay->createLine();
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QCOMPARE(line.cursorToX(45), 0.);
-    wordLengh = line.cursorToX(53) - line.cursorToX(50);
-    QCOMPARE(tabData.tabs[0] + wordLengh, 190.);
-
-
-    // mix tabs
-    tabs.clear();
-    tab = KoText::Tab();
-    tab.position = 100;
-    tabs.append(tab);
-    tab = KoText::Tab();
-    tab.position = 190;
-    tab.type = KoText::RightTab;
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    block = doc->begin();
-    style.applyStyle(block);
-
-    m_textLayout->start();
-    lay = block.layout();
-    lay->beginLayout();
-    line = lay->createLine();
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QCOMPARE(tabData.tabs.count(), 1);
-    QCOMPARE(tabData.tabLength.count(), 1);
-    QCOMPARE(tabData.tabs[0], 100.);
-
-    line = lay->createLine();
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QVERIFY(tabData.tabs.count() >= 2);
-    QCOMPARE(tabData.tabLength.count(), tabData.tabs.count());
-    wordLengh = line.cursorToX(44) - line.cursorToX(37);
-    QCOMPARE(tabData.tabs[0] + wordLengh, 190.);
-
-    line = lay->createLine();
-    line.setLineWidth(200.);
-    tabData = m_textLayout->applyTabs(line);
-    QCOMPARE(line.cursorToX(45), 0.);
-    QCOMPARE(tabData.tabs[0], 100.);
-}
-
-void TestDocumentLayout::testCenteredTab() {
-    initForNewTest("Foo\tBar.");
-    // test if centering the tab works.  We expect the center of 'Bar.' to be at the tab point.
-    KoParagraphStyle style;
-    QList<KoText::Tab> tabs;
-    KoText::Tab tab;
-    tab.position = 150;
-    tab.type = KoText::CenterTab;
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    QTextBlock block = doc->begin();
-    style.applyStyle(block);
-
-    m_textLayout->start();
-    QTextLayout *lay = doc->begin().layout();
-    lay->beginLayout();
-    QTextLine line = lay->createLine();
-    line.setLineWidth(200.);
-    KoTextBlockData::TabLineData tabData = m_textLayout->applyTabs(line);
-
-    double wordLength = line.cursorToX(9)- line.cursorToX(4);
-    QCOMPARE(tabData.tabs.count(), 1);
-    QCOMPARE(tabData.tabs[0], 150 - wordLength / 2.0);
-    QCOMPARE(tabData.tabLength.count(), 1);
-    QCOMPARE(tabData.tabLength[0], (150 - wordLength / 2.0) - line.cursorToX(3));
-}
-
-void TestDocumentLayout::testAlignedTab() {
-    initForNewTest("Foo\tBar. Barrabas");
-    // try the different delimiter characters to see if the alignment works there.
-
-    KoParagraphStyle style;
-    QList<KoText::Tab> tabs;
-    KoText::Tab tab;
-    tab.position = 100;
-    tab.type = KoText::DelimiterTab;
-    tab.delimiter = QChar('.');
-    tabs.append(tab);
-    style.setTabPositions(tabs);
-    QTextBlock block = doc->begin();
-    style.applyStyle(block);
-
-    m_textLayout->start();
-    QTextLayout *lay = doc->begin().layout();
-    lay->beginLayout();
-    QTextLine line = lay->createLine();
-    line.setLineWidth(200.);
-    KoTextBlockData::TabLineData tabData = m_textLayout->applyTabs(line);
-
-    double length = line.cursorToX(7)- line.cursorToX(4); // the 'Bar' section.
-    length += (line.cursorToX(8) - line.cursorToX(7)) / 2.0; // half of the '.' character
-    QCOMPARE(tabData.tabs.count(), 1);
-    QCOMPARE(tabData.tabs[0], 100 - length);
-    QCOMPARE(tabData.tabLength.count(), 1);
-    QCOMPARE(tabData.tabLength[0], (100 - length) - line.cursorToX(3));
-}
-
 QTEST_KDEMAIN(TestDocumentLayout, GUI)
 
 #include "TestDocumentLayout.moc"
